@@ -32,7 +32,7 @@
 namespace Base
 {
 
-    class HelpManager:public QObject, public Counter
+    class HelpManager:public QObject, private Counter<HelpManager>
     {
 
         Q_OBJECT
@@ -40,11 +40,7 @@ namespace Base
         public:
 
         //* constructor
-        HelpManager( QObject* parent );
-
-        //* destructor
-        virtual ~HelpManager( void )
-        { Debug::Throw( "HelpManager::~HelpManager.\n" ); }
+        explicit HelpManager( QObject* parent );
 
         //*@name accessors
         //@{
@@ -57,11 +53,11 @@ namespace Base
         void install( const QString text[], bool clear = true );
 
         //* list of items
-        const HelpItem::List& items( void )
+        const HelpItem::List& items()
         { return items_; }
 
         //* clear help
-        void clear( void )
+        void clear()
         { items_.clear(); }
 
         //* set dialog caption
@@ -70,13 +66,13 @@ namespace Base
         //@}
 
         //* display action
-        QAction& displayAction( void )
+        QAction& displayAction()
         { return *displayAction_; }
 
         protected Q_SLOTS:
 
         //* opens help dialog
-        void _display( void );
+        void _display();
 
         private:
 
