@@ -31,17 +31,14 @@ namespace Notifications
         public:
 
         //* constructor
-        ImageData( void )
+        explicit ImageData()
         {}
 
         //* constructor
-        ImageData( QImage image );
-
-        //* destructor
-        ~ImageData( void ) = default;
+        explicit ImageData( QImage image );
 
         //* validity
-        bool isValid( void ) const
+        bool isValid() const
         { return width > 0 && height > 0; }
 
         int width = 0;
