@@ -28,7 +28,9 @@ SystemNotifications::SystemNotifications( QObject* parent, const QString& applic
     Counter( "SystemNotifications" )
 {
 
-    d = new SystemNotificationsP( this );
+    d = new Private::SystemNotificationsP( this );
+    connect( d, SIGNAL(notificationSent(quint32)), this, SIGNAL(notificationSent(quint32)) );
+    connect( d, SIGNAL(notificationClosed(quint32)), this, SIGNAL(notificationClosed(quint32)) );
     connect( d, SIGNAL(actionInvoked(quint32,QString)), this, SIGNAL(actionInvoked(quint32,QString)) );
 
     if( !applicationName.isNull() ) setApplicationName( applicationName );
@@ -37,7 +39,7 @@ SystemNotifications::SystemNotifications( QObject* parent, const QString& applic
 }
 
 //____________________________________________
-SystemNotifications::~SystemNotifications( void )
+SystemNotifications::~SystemNotifications()
 { _sendPendingNotification(); }
 
 //____________________________________________
@@ -45,7 +47,7 @@ void SystemNotifications::setApplicationName( const QString& value )
 { d->setApplicationName( value ); }
 
 //____________________________________________
-void SystemNotifications::initialize( void )
+void SystemNotifications::initialize()
 { d->initialize(); }
 
 //____________________________________________
@@ -53,7 +55,7 @@ void SystemNotifications::setApplicationIcon( const QIcon& value )
 { d->setApplicationIcon( value ); }
 
 //____________________________________________
-bool SystemNotifications::isSupported( void ) const
+bool SystemNotifications::isSupported() const
 { return d->isSupported(); }
 
 //____________________________________________
@@ -96,7 +98,7 @@ void SystemNotifications::timerEvent( QTimerEvent* event )
 }
 
 //____________________________________________
-void SystemNotifications::_sendPendingNotification( void )
+void SystemNotifications::_sendPendingNotification()
 {
     Debug::Throw( "SystemNotifications::_sendPendingNotification.\n" );
     if( notification_.isValid() )
