@@ -29,9 +29,12 @@
 #include <QStringList>
 #include <QTimerEvent>
 
-class SystemNotificationsP;
+namespace Private
+{
+    class SystemNotificationsP;
+};
 
-class SystemNotifications: public QObject, public Counter
+class SystemNotifications: public QObject, private Base::Counter<SystemNotifications>
 {
 
     Q_OBJECT
@@ -39,16 +42,16 @@ class SystemNotifications: public QObject, public Counter
     public:
 
     //* constructor
-    SystemNotifications( QObject* = nullptr, const QString& = QString(), const QIcon& = QIcon() );
+    explicit SystemNotifications( QObject* = nullptr, const QString& = QString(), const QIcon& = QIcon() );
 
     //* destructor
-    virtual ~SystemNotifications( void );
+    ~SystemNotifications() override;
 
     //* @name modifiers
     //@{
 
     //* initialize
-    void initialize( void );
+    void initialize();
 
     //* applicatino name
     void setApplicationName( const QString& );
@@ -57,11 +60,11 @@ class SystemNotifications: public QObject, public Counter
     void setApplicationIcon( const QIcon& );
 
     //* process message
-    virtual void send( const QString& summary, const QString& body )
+    void send( const QString& summary, const QString& body )
     { sendNotification( Notification( summary, body ) ); }
 
     //* process notification
-    virtual void sendNotification( const Notification& );
+    void sendNotification( const Notification& );
 
     //@}
 
@@ -69,22 +72,28 @@ class SystemNotifications: public QObject, public Counter
     //@{
 
     //* true if available
-    bool isSupported( void ) const;
+    bool isSupported() const;
 
     //@}
 
     Q_SIGNALS:
 
+    //* notification sent
+    void notificationSent( quint32 );
+
+    //* notification closed
+    void notificationClosed( quint32 );
+
     //* action invoked
     void actionInvoked( quint32, QString );
 
     protected:
 
     //* event handler
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     //* process message queue
-    void _sendPendingNotification( void );
+    void _sendPendingNotification();
 
     private:
 
@@ -95,7 +104,7 @@ class SystemNotifications: public QObject, public Counter
     Notification notification_;
 
     //* private
-    SystemNotificationsP* d;
+    Private::SystemNotificationsP* d;
 
 };
 
