@@ -21,6 +21,7 @@
 #include "BaseConfigurationDialog_p.h"
 
 #include "BaseIconNames.h"
+#include "CppUtil.h"
 #include "GridLayout.h"
 #include "CustomDialog.h"
 #include "Debug.h"
@@ -46,8 +47,64 @@
 #include <QLayout>
 #include <QLabel>
 
+namespace Private
+{
+
+    //_________________________________________________________
+    IconThemeDialog::IconThemeDialog( QWidget* parent ):
+        CustomDialog( parent, OkButton ),
+        OptionWidgetList( this )
+    {
+
+        OptionCheckBox* checkBox;
+        mainLayout().addWidget( checkBox = new OptionCheckBox( tr( "Use custom icon theme" ), this, "USE_ICON_THEME" ) );
+        addOptionWidget( checkBox );
+
+        auto box = new QWidget( this );
+        mainLayout().addWidget( box );
+
+        auto gridLayout = new GridLayout;
+        gridLayout->setMaxCount(2);
+        gridLayout->setMargin(0);
+        gridLayout->setSpacing(5);
+        box->setLayout( gridLayout );
+
+        QLabel* label;
+        gridLayout->addWidget( label = new QLabel( tr( "Theme name:" ), box ) );
+
+        {
+            OptionLineEditor* editor;
+            gridLayout->addWidget( editor = new OptionLineEditor( box, "ICON_THEME" ) );
+            addOptionWidget( editor );
+            label->setBuddy( editor );
+            label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );
+        }
+
+        gridLayout->addWidget( label = new QLabel( tr( "Path:" ), box ) );
+        {
+            OptionBrowsedLineEditor* editor;
+            gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ICON_THEME_PATH" ) );
+            addOptionWidget( editor );
+            label->setBuddy( editor );
+            label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );
+
+            editor->setFileMode( QFileDialog::Directory );
+            editor->setAcceptMode( QFileDialog::AcceptOpen );
+        }
+
+        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignCenter );
+
+        box->setEnabled( false );
+        connect( checkBox, SIGNAL(toggled(bool)), box, SLOT(setEnabled(bool)) );
+
+        read( XmlOptions::get() );
+
+    }
+
+}
+
 //_________________________________________________________
-BaseConfigurationDialog::BaseConfigurationDialog( QWidget* parent, ConfigurationFlags flags ):
+BaseConfigurationDialog::BaseConfigurationDialog( QWidget* parent, Flags flags ):
     TabbedDialog( parent ),
     OptionWidgetList(this),
     backupOptions_( XmlOptions::get() )
@@ -116,7 +173,7 @@ BaseConfigurationDialog::BaseConfigurationDialog( QWidget* parent, Configuration
 }
 
 //__________________________________________________
-QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, ConfigurationFlags flags )
+QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Flags flags )
 {
 
     Debug::Throw( "BaseConfigurationDialog::baseConfiguration.\n" );
@@ -127,35 +184,27 @@ QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Configurat
         tr( "General application settings" ) );
 
     // base
-    QWidget* out(0);
-    if( flags&Base )
+    QWidget* out( nullptr );
+    if( flags&Flag::Base )
     {
 
         // base
-        QGroupBox* box;
-        box = new QGroupBox( tr( "General" ), parent );
+        auto box = new QGroupBox( tr( "General" ), parent );
         parent->layout()->addWidget( box );
 
         {
-            QGridLayout* gridLayout = new QGridLayout();
+            auto gridLayout = new QGridLayout;
             box->setLayout( gridLayout );
 
             // widget style
             int row = 0;
-            #if defined(Q_OS_WIN)
-            {
-              OptionCheckBox* checkbox = new OptionCheckBox( tr( "Use plastique widget style" ), box, "FORCE_PLASTIQUE_STYLE" );
-              gridLayout->addWidget( checkbox, ++row, 1, 1, 1 );
-              addOptionWidget( checkbox );
-            }
-            #endif
 
             // pixmap path
             QLabel* label;
             gridLayout->addWidget( label = new QLabel( tr( "Pixmaps:" ), box ), ++row, 0, 1, 1 );
             label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );
 
-            QPushButton *button = new QPushButton( IconEngine::get( IconNames::Edit ), tr( "Edit Pixmap Path" ), box );
+            auto button = new QPushButton( IconEngine::get( IconNames::Edit ), tr( "Edit Pixmap Path" ), box );
             connect( button, SIGNAL(clicked()), SLOT(_editPixmapPathList()) );
             gridLayout->addWidget( button, row, 1, 1, 1 );
 
@@ -173,7 +222,7 @@ QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Configurat
             gridLayout->addWidget( label = new QLabel( tr( "Verbosity:" ), box ), ++row, 0, 1, 1 );
             label->setAlignment( Qt::AlignVCenter|Qt::AlignRight );
 
-            OptionSpinBox* spinbox = new OptionSpinBox( box, "DEBUG_LEVEL" );
+            auto spinbox = new OptionSpinBox( box, "DEBUG_LEVEL" );
             spinbox->setSpecialValueText( tr( " Silent" ) );
             spinbox->setMinimum( 0 );
             spinbox->setMaximum( 5 );
@@ -190,14 +239,14 @@ QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Configurat
         parent->layout()->addWidget( box );
 
         // icon pixmap
-        QVBoxLayout* vLayout = new QVBoxLayout();
+        auto vLayout = new QVBoxLayout;
         box->setLayout( vLayout );
 
-        OptionCheckBox* checkbox( new OptionCheckBox( tr( "Use system font" ), box, "USE_SYSTEM_FONT" ) );
+        auto checkbox( new OptionCheckBox( tr( "Use system font" ), box, "USE_SYSTEM_FONT" ) );
         vLayout->addWidget( checkbox );
         addOptionWidget( checkbox );
 
-        GridLayout* gridLayout = new GridLayout();
+        auto gridLayout = new GridLayout;
         gridLayout->setMargin(0);
         gridLayout->setMaxCount(2);
         vLayout->addLayout( gridLayout );
@@ -206,7 +255,7 @@ QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Configurat
         QLabel* label;
         gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
         gridLayout->addWidget( label = new QLabel( tr( "Default font:" ), box ) );
-        OptionFontEditor *edit = new OptionFontEditor( box, "FONT_NAME" );
+        auto edit = new OptionFontEditor( box, "FONT_NAME" );
         edit->setToolTip( tr( "Default font name for all widgets" ) );
         gridLayout->addWidget( edit );
         addOptionWidget( edit );
@@ -229,10 +278,10 @@ QWidget* BaseConfigurationDialog::baseConfiguration( QWidget* parent, Configurat
     }
 
     // list
-    if( flags&List ) { out = listConfiguration( parent ); }
+    if( flags&Flag::List ) { out = listConfiguration( parent ); }
 
     // edition
-    if( flags&TextEdition ) { out = textEditConfiguration( parent ); }
+    if( flags&Flag::TextEdition ) { out = textEditConfiguration( parent ); }
 
     return out;
 
@@ -245,7 +294,7 @@ QWidget* BaseConfigurationDialog::listConfiguration( QWidget* parent )
     Debug::Throw( "BaseConfigurationDialog::listConfiguration.\n" );
 
     // make sure parent is valid
-    QWidget* box(0);
+    QWidget* box( nullptr );
     if( !parent )
     {
 
@@ -259,35 +308,31 @@ QWidget* BaseConfigurationDialog::listConfiguration( QWidget* parent )
         box = new QGroupBox( tr( "Lists" ), parent );
     }
 
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    auto vLayout = new QVBoxLayout;
     box->setLayout( vLayout );
     parent->layout()->addWidget( box );
 
     {
-        OptionCheckBox* checkbox;
-        checkbox = new OptionCheckBox( tr( "Use alternate color for items in list" ), box, "USE_ALTERNATE_COLOR" );
+        auto checkbox = new OptionCheckBox( tr( "Use alternate color for items in list" ), box, "USE_ALTERNATE_COLOR" );
         vLayout->addWidget( checkbox );
         addOptionWidget( checkbox );
 
-        const QPalette palette( this->palette() );
+        const auto palette( this->palette() );
         if( palette.color( QPalette::AlternateBase ) == palette.color( QPalette::Base ) )
         { checkbox->setEnabled( false ); }
-
     }
 
     {
-        OptionCheckBox* checkbox;
-        checkbox = new OptionCheckBox( tr( "Use different backround for selected column" ), box, "USE_SELECTED_COLUMN_COLOR" );
+        auto checkbox = new OptionCheckBox( tr( "Use different backround for selected column" ), box, "USE_SELECTED_COLUMN_COLOR" );
         vLayout->addWidget( checkbox );
         addOptionWidget( checkbox );
-
     }
 
     QLabel* label;
     OptionSpinBox* spinbox;
 
     // icon size in lists
-    GridLayout* gridLayout = new GridLayout();
+    auto gridLayout = new GridLayout;
     gridLayout->setMargin(0);
     gridLayout->setMaxCount(2);
     vLayout->addLayout( gridLayout );
@@ -303,7 +348,6 @@ QWidget* BaseConfigurationDialog::listConfiguration( QWidget* parent )
         spinbox->setMaximum(96);
         addOptionWidget( spinbox );
         label->setBuddy( spinbox );
-
     }
 
 
@@ -324,7 +368,7 @@ QWidget* BaseConfigurationDialog::listConfiguration( QWidget* parent )
 }
 
 //__________________________________________________
-QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, ConfigurationFlags flags )
+QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Flags flags )
 {
 
     Debug::Throw( "BaseConfigurationDialog::textEditConfiguration.\n" );
@@ -335,27 +379,27 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
         tr( "Text Edition" ),
         tr( "Settings for text display and edition" ) );
 
-    QWidget* out(0);
+    QWidget* out = nullptr;
 
     // tab emulation
-    if( flags&TabEmulation )
+    if( flags&Flag::TabEmulation )
     {
-        QGroupBox* box = new QGroupBox( tr( "Tab Emulation" ), parent );
-        QVBoxLayout* layout = new QVBoxLayout();
+        auto box = new QGroupBox( tr( "Tab Emulation" ), parent );
+        auto layout = new QVBoxLayout;
         box->setLayout( layout );
         parent->layout()->addWidget( box );
 
-        QHBoxLayout* hLayout = new QHBoxLayout();
+        auto hLayout = new QHBoxLayout;
         hLayout->setMargin(0);
         layout->addLayout( hLayout );
 
-        OptionCheckBox* checkbox = new OptionCheckBox( tr( "Emulate tabs" ), box, "TAB_EMULATION" );
+        auto checkbox = new OptionCheckBox( tr( "Emulate tabs" ), box, "TAB_EMULATION" );
         checkbox->setToolTip( tr( "Turn on/off tab emulation using space characters" ) );
         layout->addWidget( checkbox );
         addOptionWidget( checkbox );
 
         hLayout->addWidget(new QLabel( tr( "Tab size:" ), box ) );
-        OptionSpinBox* spinbox = new OptionSpinBox( box, "TAB_SIZE" );
+        auto spinbox = new OptionSpinBox( box, "TAB_SIZE" );
         spinbox->setMinimum( 2 );
         spinbox->setMaximum( 20 );
         spinbox->setToolTip( tr( "Tab size (in unit of space characters)." ) );
@@ -367,14 +411,14 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
     }
 
     // paragraph highlighting
-    if( flags&ParagraphHighlight )
+    if( flags&Flag::ParagraphHighlight )
     {
-        QGroupBox* box = new QGroupBox( tr( "Paragraph Highlighting" ), parent );
-        QVBoxLayout* layout = new QVBoxLayout();
+        auto box = new QGroupBox( tr( "Paragraph Highlighting" ), parent );
+        auto layout = new QVBoxLayout;
         box->setLayout( layout );
         parent->layout()->addWidget( box );
 
-        OptionCheckBox* checkbox = new OptionCheckBox( tr( "Highlight current paragraph" ), box, "HIGHLIGHT_PARAGRAPH" );
+        auto checkbox = new OptionCheckBox( tr( "Highlight current paragraph" ), box, "HIGHLIGHT_PARAGRAPH" );
         checkbox->setToolTip( tr( "Turn on/off current paragraph highlighting" ) );
         layout->addWidget( checkbox );
         addOptionWidget( checkbox );
@@ -384,10 +428,10 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
     }
 
     // box selection
-    if( false )
+    if( flags&Flag::BoxSelection )
     {
-        QGroupBox* box = new QGroupBox( tr( "Box Selection" ), parent );
-        GridLayout* gridLayout = new GridLayout();
+        auto box = new QGroupBox( tr( "Box Selection" ), parent );
+        auto gridLayout = new GridLayout;
         gridLayout->setMaxCount(2);
         box->setLayout( gridLayout );
         parent->layout()->addWidget( box );
@@ -409,43 +453,16 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
         out = box;
     }
 
-    // margins
-    if( flags&Margins )
-    {
-        QGroupBox* box;
-        parent->layout()->addWidget( box = new QGroupBox( tr( "Margin" ), parent ) );
-
-        GridLayout* gridLayout = new GridLayout();
-        gridLayout->setMaxCount(2);
-        gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );
-        box->setLayout( gridLayout );
-
-        QLabel* label;
-        OptionColorDisplay* colorDisplay;
-        gridLayout->addWidget( label = new QLabel( tr( "Foreground:" ), box ) );
-        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "MARGIN_FOREGROUND" ) );
-        addOptionWidget( colorDisplay );
-        colorDisplay->setToolTip( tr( "Margins foreground color" ) );
-        label->setBuddy( colorDisplay );
-
-        gridLayout->addWidget( label = new QLabel( tr( "Background:" ), box ) );
-        gridLayout->addWidget( colorDisplay = new OptionColorDisplay( box, "MARGIN_BACKGROUND" ) );
-        addOptionWidget( colorDisplay );
-        colorDisplay->setToolTip( tr( "Margins background color" ) );
-        label->setBuddy( colorDisplay );
-        out = box;
-    }
-
-    if( flags&TextEditionFlags )
+    if( flags&Flag::TextEditionFlags )
     {
 
         // misc
         QGroupBox* box;
         parent->layout()->addWidget( box = new QGroupBox( tr( "Options" ), parent ) );
-        QVBoxLayout* layout = new QVBoxLayout();
+        auto layout = new QVBoxLayout;
         box->setLayout( layout );
 
-        OptionCheckBox* checkbox = new OptionCheckBox( tr( "Wrap text " ), box, "WRAP_TEXT" );
+        auto checkbox = new OptionCheckBox( tr( "Wrap text " ), box, "WRAP_TEXT" );
         checkbox->setToolTip( tr( "Turn on/off line wrapping at editor border" ) );
         layout->addWidget( checkbox );
         addOptionWidget( checkbox );
@@ -455,7 +472,7 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
 
         QLabel* label;
         OptionSpinBox* spinbox;
-        QHBoxLayout* hLayout = new QHBoxLayout();
+        auto hLayout = new QHBoxLayout;
         layout->addLayout( hLayout );
         hLayout->setMargin(0);
         hLayout->addWidget( label = new QLabel( tr( "Automatically hide mouse cursor after: " ), box ) );
@@ -475,17 +492,7 @@ QWidget* BaseConfigurationDialog::textEditConfiguration( QWidget* parent, Config
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::debugModification( void )
-{
-    QObject* sender( this->sender() );
-    Debug::Throw(0)
-        << "BaseConfigurationDialog::debugModification -"
-        << " sender: " << ( sender ? sender->metaObject()->className() : "none" )
-        << endl;
-}
-
-//__________________________________________________
-void BaseConfigurationDialog::_editPixmapPathList( void )
+void BaseConfigurationDialog::_editPixmapPathList()
 {
 
     Debug::Throw( "BaseConfigurationDialog::_editPixmapPathList.\n" );
@@ -493,7 +500,7 @@ void BaseConfigurationDialog::_editPixmapPathList( void )
     if( !pixmapPathDialog_ )
     {
         pixmapPathDialog_ = new CustomDialog( this, CustomDialog::CloseButton );
-        OptionListBox *listbox = new OptionListBox( pixmapPathDialog_, "PIXMAP_PATH" );
+        auto listbox = new OptionListBox( pixmapPathDialog_, "PIXMAP_PATH" );
         listbox->setBrowsable( true );
         listbox->setFileMode( QFileDialog::Directory );
         pixmapPathDialog_->mainLayout().addWidget( listbox );
@@ -513,12 +520,12 @@ void BaseConfigurationDialog::_editPixmapPathList( void )
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_editIconTheme( void )
+void BaseConfigurationDialog::_editIconTheme()
 {
     Debug::Throw( "BaseConfigurationDialog::_editIconTheme.\n" );
     if( !iconThemeDialog_ )
     {
-        iconThemeDialog_ = new IconThemeDialog( this );
+        iconThemeDialog_ = new Private::IconThemeDialog( this );
         iconThemeDialog_->read( XmlOptions::get() );
         addOptionWidget( iconThemeDialog_ );
     }
@@ -528,10 +535,15 @@ void BaseConfigurationDialog::_editIconTheme( void )
 }
 
 //__________________________________________________
-bool BaseConfigurationDialog::_checkModified( void )
+bool BaseConfigurationDialog::_checkModified()
 {
-    Options modifiedOptions( XmlOptions::get() );
+    // make a copy of current options
+    auto modifiedOptions( XmlOptions::get() );
+
+    // update with current settings
     OptionWidgetList::write( modifiedOptions );
+
+    // check modifications
     const bool modified( !(modifiedOptions == XmlOptions::get() ) );
 
     // update button state
@@ -558,7 +570,7 @@ bool BaseConfigurationDialog::_findModification( const Options& first, const Opt
 
     // this is a slightly modified version of XmlOptions::_differs
     // check special options
-    for( Options::SpecialMap::const_iterator firstIter = first.specialOptions().constBegin(); firstIter != first.specialOptions().constEnd(); ++firstIter )
+    for( auto&& firstIter = first.specialOptions().constBegin(); firstIter != first.specialOptions().constEnd(); ++firstIter )
     {
 
         // get matching options in the second set
@@ -569,8 +581,8 @@ bool BaseConfigurationDialog::_findModification( const Options& first, const Opt
         }
 
         // loop over options in first list
-        const Options::List options( second.specialOptions( firstIter.key() ) );
-        foreach( const Option& option, firstIter.value() )
+        auto&& options( second.specialOptions( firstIter.key() ) );
+        for( const auto& option:firstIter.value() )
         {
             // find in second list
             if( options.indexOf( option ) < 0 )
@@ -588,10 +600,10 @@ bool BaseConfigurationDialog::_findModification( const Options& first, const Opt
     }
 
     // loop over options and check existence in other map
-    for( Options::Map::const_iterator firstIter = first.options().constBegin(); firstIter != first.options().constEnd(); ++firstIter )
+    for( auto&& firstIter = first.options().constBegin(); firstIter != first.options().constEnd(); ++firstIter )
     {
 
-        const Options::Map::const_iterator secondIter( second.options().constFind( firstIter.key() ) );
+        auto&& secondIter( second.options().constFind( firstIter.key() ) );
         if( secondIter == second.options().constEnd() )
         {
 
@@ -613,7 +625,7 @@ bool BaseConfigurationDialog::_findModification( const Options& first, const Opt
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_apply( void )
+void BaseConfigurationDialog::_apply()
 {
     Debug::Throw( "BaseConfigurationDialog::_apply.\n" );
     if( _checkModified() )
@@ -634,7 +646,7 @@ void BaseConfigurationDialog::_apply( void )
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_save( void )
+void BaseConfigurationDialog::_save()
 {
     Debug::Throw( "BaseConfigurationDialog::_save.\n" );
     _apply();
@@ -645,7 +657,7 @@ void BaseConfigurationDialog::_save( void )
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_cancel( void )
+void BaseConfigurationDialog::_cancel()
 {
     Debug::Throw( "BaseConfigurationDialog::_cancel.\n" );
     if( XmlOptions::get() == backupOptions_ ) return;
@@ -661,7 +673,7 @@ void BaseConfigurationDialog::_cancel( void )
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_reset( void )
+void BaseConfigurationDialog::_reset()
 {
     Debug::Throw( "BaseConfigurationDialog::_reset.\n" );
 
@@ -671,14 +683,14 @@ void BaseConfigurationDialog::_reset( void )
 }
 
 //__________________________________________________
-void BaseConfigurationDialog::_restoreDefaults( void )
+void BaseConfigurationDialog::_restoreDefaults()
 {
     Debug::Throw( "BaseConfigurationDialog::_restoreDefaults.\n" );
 
     // list options that have no default values
-    const Options::Map& options( XmlOptions::get().options() );
     OptionModel::List local;
-    for( Options::Map::const_iterator iter = options.begin(); iter != options.end(); ++iter )
+    auto&& options( XmlOptions::get().options() );
+    for( auto&& iter = options.begin(); iter != options.end(); ++iter )
     { if( iter.value().defaultValue().isEmpty() ) local << OptionPair( iter.key(), iter.value() ); }
 
     QuestionDialog dialog( this );
@@ -687,8 +699,8 @@ void BaseConfigurationDialog::_restoreDefaults( void )
     {
 
         dialog.setText( tr( "Following options have no default values. Restore default anyway ? " ) );
-        TreeView* view = new TreeView( &dialog );
-        OptionModel* model = new OptionModel( &dialog );
+        auto view = new TreeView( &dialog );
+        auto model = new OptionModel( &dialog );
         model->add( local );
         view->setModel( model );
         view->setMask( (1<<OptionModel::Name) | (1<<OptionModel::Value) );
