@@ -27,7 +27,11 @@
 #include <QLayout>
 
 class CustomDialog;
-class IconThemeDialog;
+
+namespace Private
+{
+    class IconThemeDialog;
+};
 
 //* configuration dialog
 class BaseConfigurationDialog: public TabbedDialog, public OptionWidgetList
@@ -38,7 +42,7 @@ class BaseConfigurationDialog: public TabbedDialog, public OptionWidgetList
     public:
 
     //* flag bitset for the Base configuration
-    enum ConfigurationFlag
+    enum Flag
     {
 
         None = 0,
@@ -47,87 +51,83 @@ class BaseConfigurationDialog: public TabbedDialog, public OptionWidgetList
         TextEdition = 1<<3,
         TabEmulation = 1<<4,
         ParagraphHighlight = 1<<5,
-        Margins = 1<<6,
-        TextEditionFlags = 1<<7,
+        TextEditionFlags = 1<<6,
+        BoxSelection = 1<<7,
         Default = Base|List,
-        AllTextEdition = TabEmulation|ParagraphHighlight|Margins|TextEditionFlags
+        AllTextEdition = TabEmulation|ParagraphHighlight|TextEditionFlags
 
     };
 
-    Q_DECLARE_FLAGS( ConfigurationFlags, ConfigurationFlag );
+    Q_DECLARE_FLAGS( Flags, Flag );
 
     //* constructor
-    BaseConfigurationDialog( QWidget* = nullptr, ConfigurationFlags = None );
+    explicit BaseConfigurationDialog( QWidget* = nullptr, Flags = Flag::None );
 
     // read
     using OptionWidgetList::read;
-    virtual void read( void )
+    void read()
     {
         OptionWidgetList::read( XmlOptions::get() );
         _checkModified();
     }
 
     //* adds configuration box for base options used in all appications
-    QWidget* baseConfiguration( QWidget* = nullptr, ConfigurationFlags = Default );
+    QWidget* baseConfiguration( QWidget* = nullptr, Flags = Flag::Default );
 
     //* list configuration box
     QWidget* listConfiguration( QWidget* = nullptr );
 
     //* TextEdit configuration box
-    QWidget* textEditConfiguration( QWidget* = nullptr, ConfigurationFlags = AllTextEdition );
+    QWidget* textEditConfiguration( QWidget* = nullptr, Flags = Flag::AllTextEdition );
 
     Q_SIGNALS:
 
     //* modified
-    void modified( void );
+    void modified();
 
     //* apply button pressed
-    void apply( void );
+    void apply();
 
     //* ok button pressed
-    void ok( void );
+    void ok();
 
     //* canceled button pressed
-    void cancel( void );
+    void cancel();
 
     //* reset button pressed
-    void reset( void );
+    void reset();
 
     //* restore defaults button pressed
-    void restoreDefaults( void );
+    void restoreDefaults();
 
     //* emitted when configuration is changed
     void configurationChanged();
 
-    public Q_SLOTS:
-
-    virtual void debugModification( void );
-
     protected Q_SLOTS:
 
     //* show pixmap path dialog
-    virtual void _editPixmapPathList( void );
+    void _editPixmapPathList();
 
     //* show icon path dialog
-    virtual void _editIconTheme( void );
+    void _editIconTheme();
 
     //* check options changed
-    bool _checkModified( void );
+    bool _checkModified();
 
     //* update configuration
-    virtual void _apply();
+    void _apply();
 
     //* save configuration from options
-    virtual void _save();
+    void _save();
 
     //* restore configuration
-    virtual void _cancel();
+    void _cancel();
 
     //* reset
-    virtual void _reset( void );
+    void _reset();
 
     //* restore default options
-    virtual void _restoreDefaults( void );
+    void _restoreDefaults();
 
     protected:
 
@@ -147,10 +147,10 @@ class BaseConfigurationDialog: public TabbedDialog, public OptionWidgetList
     CustomDialog* pixmapPathDialog_ = nullptr;
 
     //* icon theme dialog
-    IconThemeDialog* iconThemeDialog_ = nullptr;
+    Private::IconThemeDialog* iconThemeDialog_ = nullptr;
 
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS( BaseConfigurationDialog::ConfigurationFlags )
+Q_DECLARE_OPERATORS_FOR_FLAGS( BaseConfigurationDialog::Flags )
 
 #endif
