@@ -26,19 +26,19 @@
 #include <QMenu>
 
 // implements context menu, installable on widgets
-class BaseContextMenu: public QMenu, public Counter
+class BaseContextMenu: public QMenu, private Base::Counter<BaseContextMenu>
 {
 
     public:
 
     //* contructor
-    BaseContextMenu( QWidget* );
+    explicit BaseContextMenu( QWidget* );
 
     //*@name accessors
     //@{
 
     //* return true if the menu has no visible action
-    bool isEmpty( void ) const
+    bool isEmpty() const
     { return isEmpty_; }
 
     //@}
@@ -51,14 +51,14 @@ class BaseContextMenu: public QMenu, public Counter
     { hideDisabledActions_ = value; }
 
     //* clear
-    void clear( void )
+    void clear()
     {
         QMenu::clear();
         needSeparator_ = false;
     }
 
     //* add separator
-    QAction* addSeparator( void );
+    QAction* addSeparator();
 
     //* add menu
     QAction* addMenu( QMenu* );
@@ -73,7 +73,7 @@ class BaseContextMenu: public QMenu, public Counter
 
     protected:
 
-    bool _hideDisabledActions( void ) const
+    bool _hideDisabledActions() const
     { return hideDisabledActions_; }
 
     private:
