@@ -19,6 +19,7 @@
 
 #include "BaseDialog.h"
 #include "Debug.h"
+#include "IconSize.h"
 #include "QtUtil.h"
 #include "Util.h"
 #include "XmlOptions.h"
@@ -31,12 +32,26 @@
 BaseDialog::BaseDialog( QWidget* parent, Qt::WindowFlags flags ):
     QDialog( parent, flags ),
     monitor_( this ),
-    iconSize_( 64, 64 )
+    iconSize_( IconSize::get( IconSize::VeryHuge ) )
 {
     Debug::Throw( "BaseDialog::BaseDialog.\n" );
     setSizeGripEnabled(false);
 }
 
+//__________________________________________________
+QSize BaseDialog::minimumSizeHint() const
+{
+    auto&& out( monitor_.sizeHint() );
+    return out.isValid() ? out:QDialog::minimumSizeHint();
+}
+
+//__________________________________________________
+QSize BaseDialog::sizeHint() const
+{
+    auto&& out( monitor_.sizeHint() );
+    return out.isValid() ? out:QDialog::sizeHint();
+}
+
 //__________________________________________________
 BaseDialog& BaseDialog::setWindowTitle( const QString& title )
 {
@@ -47,22 +62,8 @@ BaseDialog& BaseDialog::setWindowTitle( const QString& title )
 
 }
 
-//__________________________________________________
-QSize BaseDialog::minimumSizeHint( void ) const
-{
-    QSize out( monitor_.sizeHint() );
-    return out.isValid() ? out:QDialog::minimumSizeHint();
-}
-
-//__________________________________________________
-QSize BaseDialog::sizeHint( void ) const
-{
-    QSize out( monitor_.sizeHint() );
-    return out.isValid() ? out:QDialog::sizeHint();
-}
-
 //________________________________________________________________
-BaseDialog& BaseDialog::centerOnPointer( void )
+BaseDialog& BaseDialog::centerOnPointer()
 {
 
     Debug::Throw( "BaseDialog::centerOnPointer.\n" );
@@ -71,7 +72,7 @@ BaseDialog& BaseDialog::centerOnPointer( void )
 }
 
 //________________________________________________________________
-BaseDialog& BaseDialog::centerOnDesktop( void )
+BaseDialog& BaseDialog::centerOnDesktop()
 {
 
     Debug::Throw( "BaseDialog::centerOnDesktop.\n" );
@@ -91,14 +92,14 @@ BaseDialog& BaseDialog::centerOnWidget( QWidget* parent )
 }
 
 //________________________________________________________________
-BaseDialog& BaseDialog::uniconify( void )
+BaseDialog& BaseDialog::uniconify()
 {
 
     Debug::Throw( "BaseDialog::uniconify.\n" );
     if( isMinimized() )
     {
 
-        if( _wasMaximized() ) showMaximized();
+        if( wasMaximized_ ) showMaximized();
         else showNormal();
 
     } else if( isHidden() ) show();
@@ -110,7 +111,7 @@ BaseDialog& BaseDialog::uniconify( void )
 }
 
 //__________________________________________________________
-void BaseDialog::toggleSticky( bool state )
+BaseDialog& BaseDialog::toggleSticky( bool state )
 {
 
     Debug::Throw( "BaseDialog::toggleSticky.\n" );
@@ -130,8 +131,7 @@ void BaseDialog::toggleSticky( bool state )
 
     #endif
 
-    return;
-
+    return *this;
 }
 
 //_______________________________________________________
@@ -145,10 +145,10 @@ bool BaseDialog::event( QEvent* event )
         case QEvent::WindowStateChange:
         {
             // cast
-            QWindowStateChangeEvent *state_event( static_cast<QWindowStateChangeEvent*>(event) );
+            QWindowStateChangeEvent *stateEvent( static_cast<QWindowStateChangeEvent*>(event) );
 
             if( windowState() & Qt::WindowMinimized )
-            { _setWasMaximized( state_event->oldState() & Qt::WindowMaximized ); }
+            { _setWasMaximized( stateEvent->oldState() & Qt::WindowMaximized ); }
 
         }
         break;
