@@ -33,69 +33,65 @@ class BaseDialog: public QDialog
 
     public:
 
-    //* dialog centering enumeration
-    enum Centering
-    {
-
-        CenterOnPointer,
-        CenterOnParent,
-        CenterOnDesktop
-
-    };
-
     //* constructor
-    BaseDialog( QWidget* = nullptr, Qt::WindowFlags = 0);
+    explicit BaseDialog( QWidget* = nullptr, Qt::WindowFlags = 0);
+
+    //*@name accessors
+    //@{
+
+    //* restore window size
+    QSize minimumSizeHint() const override;
+
+    //* restore window size
+    QSize sizeHint() const override;
+
+    //* iconsize
+    QSize iconSize() const
+    { return iconSize_; }
+
+    //@}
+
+    //*@name modifiers
+    //@{
 
     //* window title
-    virtual BaseDialog& setWindowTitle( const QString& );
-
-    //* restore window size
-    virtual QSize minimumSizeHint( void ) const;
-
-    //* restore window size
-    virtual QSize sizeHint( void ) const;
+    BaseDialog& setWindowTitle( const QString& );
 
     //* center widget on pointer
-    BaseDialog& centerOnPointer( void );
+    BaseDialog& centerOnPointer();
 
     //* center widget on argument widget
-    BaseDialog& centerOnDesktop( void );
+    BaseDialog& centerOnDesktop();
 
     //* center on parent widget
-    BaseDialog& centerOnParent( void )
+    BaseDialog& centerOnParent()
     { return centerOnWidget( parentWidget() ); }
 
     //* center widget on argument widget
     BaseDialog& centerOnWidget( QWidget* );
 
     //* size option name
-    virtual void setOptionName( const QString& name )
+    void setOptionName( const QString& name )
     { monitor_.setOptionName( name ); }
 
     //* set icon size
-    virtual void setIconSize( const QSize& size )
+    void setIconSize( const QSize& size )
     { iconSize_ = size; }
 
-    //* iconsize
-    virtual QSize iconSize( void ) const
-    { return iconSize_; }
+    //@}
 
     public Q_SLOTS:
 
     //* uniconify
-    BaseDialog& uniconify( void );
+    BaseDialog& uniconify();
 
     //* stickyness
-    void toggleSticky( bool );
+    BaseDialog& toggleSticky( bool );
 
     protected:
 
     //* generic event
-    virtual bool event( QEvent* );
-
-    //* maximize state prior to minimization
-    bool _wasMaximized( void ) const
-    { return wasMaximized_; }
+    bool event( QEvent* ) override;
 
     //* maximize state prior to minimization
     void _setWasMaximized( bool value )
