@@ -28,11 +28,7 @@
 BaseFileIconProvider::BaseFileIconProvider( QObject* parent ):
     QObject( parent ),
     Counter( "BaseFileIconProvider" )
-{
-    // initialize default folders
-    DefaultFolders::get().initializeFolderNames();
-    DefaultFolders::get().initializeIconNames();
-}
+{}
 
 //__________________________________________________________________________
 const QIcon& BaseFileIconProvider::icon( const BaseFileInfo& fileInfo, int type )
@@ -42,19 +38,19 @@ const QIcon& BaseFileIconProvider::icon( const BaseFileInfo& fileInfo, int type
     if( !( type&BaseFileInfo::Folder ) ) return invalid_;
 
     // check whether current map contains key
-    IconCache::const_iterator iter( icons_.find( Key( fileInfo.file(), type ) ) );
+    auto&& iter( icons_.find( Key( fileInfo.file(), type ) ) );
     if( iter != icons_.end() ) return iter.value();
 
     // insert new entry in map
-    const DefaultFolders::Type folderType( DefaultFolders::get().type( fileInfo.file() ) );
-    if( folderType == DefaultFolders::Unknown ) return invalid_;
+    auto&& folderType( DefaultFolders::get().type( fileInfo.file() ) );
+    if( folderType == DefaultFolders::Type::Unknown ) return invalid_;
 
     // get icon name
-    const QString iconName( DefaultFolders::get().iconName( folderType ) );
+    auto&& iconName( DefaultFolders::get().iconName( folderType ) );
     if( iconName.isEmpty() ) return invalid_;
 
     // get corresponding icon from icon engine
-    const QIcon& base( IconEngine::get( iconName ) );
+    auto&& base( IconEngine::get( iconName ) );
     if( base.isNull() ) return invalid_;
 
     // insert in map and return
@@ -64,15 +60,15 @@ const QIcon& BaseFileIconProvider::icon( const BaseFileInfo& fileInfo, int type
 
 
 //____________________________________________________
-QPixmap BaseFileIconProvider::linked( const CustomPixmap& source )
+CustomPixmap BaseFileIconProvider::linked( const CustomPixmap& source )
 {
 
     if( source.isNull() ) return source;
-    QIcon linkOverlay( IconEngine::get( IconNames::SymbolicLink ) );
+    auto linkOverlay( IconEngine::get( IconNames::SymbolicLink ) );
     if( linkOverlay.isNull() ) return source;
 
     // get source size
-    const QSize size( source.size()/source.devicePixelRatio() );
+    auto size( source.size()/source.devicePixelRatio() );
 
     // decide overlay size
     QSize overlaySize;
@@ -84,15 +80,17 @@ QPixmap BaseFileIconProvider::linked( const CustomPixmap& source )
     else if( size.width() <= 128 ) overlaySize = QSize( 48, 48 );
     else overlaySize = QSize( 64, 64 );
 
-    const CustomPixmap overlayPixmap( linkOverlay.pixmap( overlaySize ) );
-    return source.merge( overlayPixmap.scaled( overlaySize*overlayPixmap.devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation ), CustomPixmap::BOTTOM_RIGHT );
+    CustomPixmap overlayPixmap( linkOverlay.pixmap( overlaySize ) );
+    return source.merged(
+        overlayPixmap.scaled( overlaySize*overlayPixmap.devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation ),
+        CustomPixmap::Corner::BottomRight );
 
 }
 
 //____________________________________________________
-QPixmap BaseFileIconProvider::hidden( const CustomPixmap& source )
+CustomPixmap BaseFileIconProvider::hidden( const CustomPixmap& source )
 { return source.transparent( 0.6 ); }
 
 //____________________________________________________
-QPixmap BaseFileIconProvider::clipped( const CustomPixmap& source )
-{ return source.desaturate().transparent( 0.6 ); }
+CustomPixmap BaseFileIconProvider::clipped( const CustomPixmap& source )
+{ return source.desaturated().transparent( 0.6 ); }
