@@ -28,16 +28,15 @@
 #include <QHash>
 #include <QIcon>
 #include <QObject>
-#include <QPixmap>
 
 //* returns icon for a given FileInfo
-class BaseFileIconProvider: public QObject, public Counter
+class BaseFileIconProvider: public QObject, private Base::Counter<BaseFileIconProvider>
 {
 
     public:
 
     //* constructor
-    BaseFileIconProvider( QObject* = nullptr );
+    explicit BaseFileIconProvider( QObject* = nullptr );
 
     //* icon matching given file info
     virtual const QIcon& icon( const BaseFileInfo& fileInfo )
@@ -47,7 +46,7 @@ class BaseFileIconProvider: public QObject, public Counter
     virtual const QIcon& icon( const BaseFileInfo&, int );
 
     //* clear
-    virtual void clear( void )
+    virtual void clear()
     { icons_.clear(); }
 
     //* key, used for hash
@@ -56,18 +55,27 @@ class BaseFileIconProvider: public QObject, public Counter
         public:
 
         //* constructor
-        Key( void )
+        explicit Key()
         {}
 
         //* constructor
-        Key( const QString& file, int type ):
+        explicit Key( const QString& file, int type ):
             file_( file ),
             type_( type )
         {}
 
-        //* equal-to operator
-        bool operator == (const Key& other ) const
-        { return file_ == other.file_ && type_ == other.type_; }
+        //*@name accessors
+        //@{
+
+        //* file
+        const QString file() const { return file_; }
+
+        //* type
+        int type() const { return type_; }
+
+        //@}
+
+        private:
 
         QString file_;
         int type_ = 0;
@@ -78,13 +86,13 @@ class BaseFileIconProvider: public QObject, public Counter
     //@{
 
     //* add link overlay icon
-    static QPixmap linked( const CustomPixmap& );
+    static CustomPixmap linked( const CustomPixmap& );
 
     //* add hidden effect
-    static QPixmap hidden( const CustomPixmap& );
+    static CustomPixmap hidden( const CustomPixmap& );
 
     //* add clipped effect
-    static QPixmap clipped( const CustomPixmap& );
+    static CustomPixmap clipped( const CustomPixmap& );
 
     //@}
 
@@ -92,7 +100,7 @@ class BaseFileIconProvider: public QObject, public Counter
 
     //* icon cache
     using IconCache = QHash<Key, QIcon>;
-    IconCache& _icons( void )
+    IconCache& _icons()
     { return icons_; }
 
     private:
@@ -105,8 +113,12 @@ class BaseFileIconProvider: public QObject, public Counter
 
 };
 
+//* equal-to operator
+inline bool operator == (const BaseFileIconProvider::Key& first, const BaseFileIconProvider::Key& second )
+{ return first.file() == second.file() && first.type() == second.type(); }
+
 //* hash
 inline uint qHash( const BaseFileIconProvider::Key& key )
-{ return qHash( key.file_ )|key.type_; }
+{ return qHash( key.file() )|key.type(); }
 
 #endif
