@@ -20,8 +20,10 @@
 *
 *******************************************************************************/
 
+#include "CppUtil.h"
 #include "Debug.h"
 #include "File.h"
+#include "TimeStamp.h"
 
 #include <QString>
 #include <QTextStream>
@@ -88,118 +90,106 @@ class BaseFileInfo
     {}
 
     //* constructor from DOM element
-    BaseFileInfo( const QDomElement& );
+    explicit BaseFileInfo( const QDomElement& );
+
+    //* destructor
+    virtual ~BaseFileInfo() = default;
 
     //* dump to dom element
     virtual QDomElement domElement( QDomDocument& ) const;
 
-    //* equal to operator
-    virtual bool operator == (const BaseFileInfo& other) const
-    { return file() == other.file() && type() == other.type(); }
-
-    //* equal to operator
-    virtual bool operator != (const BaseFileInfo& other) const
-    { return !( *this == other ); }
-
-    //* less than operator
-    virtual bool operator < (const BaseFileInfo& other) const
-    {
-        if( file() != other.file() ) return file() < other.file();
-        return type() < other.type();
-    }
-
     //*@name accessors
     //@{
 
     //* validity
-    bool isValid( void ) const
+    bool isValid() const
     { return !file_.isEmpty(); }
 
     //* file
-    virtual const File& file( void ) const
+    virtual const File& file() const
     { return file_; }
 
     //* alias
-    virtual bool hasAlias( void ) const
+    virtual bool hasAlias() const
     { return !alias_.isEmpty(); }
 
     //* alias
-    virtual const QString& alias( void ) const
+    virtual const QString& alias() const
     { return alias_; }
 
     //* file type
-    virtual int type( void ) const
+    virtual int type() const
     { return type_; }
 
     //* location
-    virtual TypeFlags location( void ) const
+    virtual TypeFlags location() const
     { return type_ & Remote; }
 
     //* file is local
-    virtual bool isLocal( void ) const
+    virtual bool isLocal() const
     { return !(type_&Remote); }
 
     //* file is remote
-    virtual bool isRemote( void ) const
+    virtual bool isRemote() const
     { return type_&Remote; }
 
     //* file is document
-    virtual bool isDocument( void ) const
+    virtual bool isDocument() const
     { return type_&Document; }
 
     //* file is directory
-    virtual bool isFolder( void ) const
+    virtual bool isFolder() const
     { return type_&Folder; }
 
     //* file is navigator (.|..)
-    virtual bool isNavigator( void ) const
+    virtual bool isNavigator() const
     { return type_&Navigator; }
 
     //* file is link
-    virtual bool isLink( void ) const
+    virtual bool isLink() const
     { return type_&Link; }
 
     //* file is broken link
-    virtual bool isBrokenLink( void ) const
+    virtual bool isBrokenLink() const
     { return (type_&Broken); }
 
     //* file is hidden
-    virtual bool isHidden( void ) const
+    virtual bool isHidden() const
     { return type_&Hidden; }
 
     //* file is clipped
-    virtual bool isClipped( void ) const
+    virtual bool isClipped() const
     { return type_&Clipped; }
 
     //* file size
-    virtual qint64 size( void ) const
+    virtual qint64 size() const
     { return size_; }
 
     //* return true if lastModified_ is valid and smaller than argument
-    virtual bool isOlder( const time_t& time ) const
-    { return ( lastModified_ >= 0 && lastModified_ < time ); }
+    virtual bool isOlder( const TimeStamp& time ) const
+    { return ( lastModified_.isValid() && lastModified_ < time ); }
 
     //* file last modification
-    virtual time_t lastModified( void ) const
+    virtual const TimeStamp& lastModified() const
     { return lastModified_; }
 
     //* user
-    virtual const QString& user( void ) const
+    virtual const QString& user() const
     { return user_; }
 
     //* group
-    virtual const QString& group( void ) const
+    virtual const QString& group() const
     { return group_; }
 
     //* permissions
-    virtual QFile::Permissions permissions( void ) const
+    virtual QFile::Permissions permissions() const
     { return permissions_; }
 
     //* type string
-    virtual QString typeString( void ) const;
+    virtual QString typeString() const;
 
     //* permission string
-    virtual QString permissionsString( void ) const;
+    virtual QString permissionsString() const;
 
     //@}
 
@@ -219,15 +209,15 @@ class BaseFileInfo
     { type_ = type; }
 
     //* set file as local
-    virtual void setLocal( void )
+    virtual void setLocal()
     { type_ &= (~Remote); }
 
     //* set file as remote
-    virtual void setRemote( void )
+    virtual void setRemote()
     { type_ |= Remote; }
 
     //* set file as file
-    virtual void setIsDocument( void )
+    virtual void setIsDocument()
     {
         type_ &= (~Folder);
         type_ &= (~Navigator);
@@ -235,14 +225,14 @@ class BaseFileInfo
     }
 
     //* set file as directory
-    virtual void setIsFolder( void )
+    virtual void setIsFolder()
     {
         type_ &= (~Document);
         type_ |= Folder;
     }
 
     //* set file as file
-    virtual void setIsNavigator( void )
+    virtual void setIsNavigator()
     {
         type_ &= (~Document);
         type_ |= TypeFlags( Folder|Navigator );
@@ -274,7 +264,7 @@ class BaseFileInfo
     { size_ = size; }
 
     //* file last modification
-    virtual void setLastModified( const time_t& time )
+    virtual void setLastModified( const TimeStamp& time )
     { lastModified_ = time; }
 
     //* user
@@ -293,7 +283,7 @@ class BaseFileInfo
     virtual void setPermissions( const QString& );
 
     //* update internal storage from file
-    virtual void update( void );
+    virtual void update();
 
     //* update internal storage from existing file info
     virtual void updateFrom( const BaseFileInfo& );
@@ -306,7 +296,7 @@ class BaseFileInfo
         public:
 
         //* constructor
-        SameTypeFTor( TypeFlags type ):
+        explicit SameTypeFTor( TypeFlags type ):
             type_( type )
         {}
 
@@ -360,18 +350,18 @@ class BaseFileInfo
         public:
 
         //* constructor
-        SameFileFTor( const BaseFileInfo& info ):
-            file_( info.file() )
+        explicit SameFileFTor( const BaseFileInfo& info ):
+            file_( info.file_ )
         {}
 
         //* constructor
-        SameFileFTor( const File& file ):
+        explicit SameFileFTor( const File& file ):
             file_( file )
         {}
 
         //* predicate
         bool operator() (const BaseFileInfo& info ) const
-        { return info.file() == file_; }
+        { return info.file_ == file_; }
 
         private:
 
@@ -381,26 +371,12 @@ class BaseFileInfo
     };
 
     //* file info list
-    template < typename T >
-    class BaseList: public QList<T>
+    class Description
     {
 
         public:
 
-        //* constructor
-        BaseList( void )
-        {}
-
-        //* constructor
-        BaseList( const QList<T>& other ):
-            QList<T>( other )
-        {}
-
-        //* destructor
-        virtual ~BaseList( void )
-        {}
-
-        //* description
+        //* description flags
         enum Flag
         {
             None = 0,
@@ -409,7 +385,21 @@ class BaseFileInfo
             Detail = 1<<2
         };
 
-        QString description( unsigned int = 0 ) const;
+        //* constructor
+        Description( int flags = 0 ):
+            flags_( flags )
+        {}
+
+        //* destructor
+        ~Description() = default;
+
+        template<class T>
+        QString get( const QList<T>& ) const;
+
+        private:
+
+        //* description flags
+        int flags_ = 0;
 
     };
 
@@ -428,7 +418,7 @@ class BaseFileInfo
     qint64 size_;
 
     //* last modification
-    time_t lastModified_;
+    TimeStamp lastModified_;
 
     //* user name
     QString user_;
@@ -442,7 +432,7 @@ class BaseFileInfo
     //* streamer
     friend QTextStream& operator << ( QTextStream& out, const BaseFileInfo& file )
     {
-        out << file.file() << " (";
+        out << file.file_ << " (";
 
         if( file.isNavigator() ) out << "navigator";
         else if( file.isFolder() ) out << "folder";
@@ -464,46 +454,56 @@ class BaseFileInfo
 };
 
 
+//* equal to operator
+inline bool operator == (const BaseFileInfo& first, const BaseFileInfo& second)
+{ return first.file() == second.file() && first.type() == second.type(); }
+
+//* less than operator
+inline bool operator < (const BaseFileInfo& first, const BaseFileInfo& second)
+{
+    if( first.file() != second.file() ) return first.file() < second.file();
+    else return first.type() < second.type();
+}
+
 //________________________________________________________________
 template <typename T>
-QString BaseFileInfo::BaseList<T>::description( unsigned int flags ) const
+QString BaseFileInfo::Description::get( const QList<T>& files ) const
 {
-    Debug::Throw( "BaseFileInfo::BaseList::description.\n" );
+    if( files.empty() ) return QString();
 
-    if( this->empty() ) return QString();
     QString buffer;
-    if( this->size() == 1 )
+    if( files.size() == 1 )
     {
 
 
-        if( this->front().isLink() ) buffer = QString( QObject::tr( "%1 Symbolic Link" ) ).arg( (flags&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
-        else if( this->front().isFolder() ) buffer = QString( QObject::tr( "%1 Folder" ) ).arg( (flags&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
-        else buffer = QString( QObject::tr( "%1 File" ) ).arg( (flags&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
+        if( files.front().isLink() ) buffer = QString( QObject::tr( "%1 Symbolic Link" ) ).arg( (flags_&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
+        else if( files.front().isFolder() ) buffer = QString( QObject::tr( "%1 Folder" ) ).arg( (flags_&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
+        else buffer = QString( QObject::tr( "%1 File" ) ).arg( (flags_&Designate) ? QObject::tr( "This" ): QObject::tr( "One" ) );
 
     } else {
 
-        if( flags & Detail )
+        if( flags_ & Detail )
         {
-            const int nFolders( std::count_if( this->begin(), this->end(), BaseFileInfo::IsFolderFTor() ) );
+            const int nFolders( std::count_if( files.begin(), files.end(), BaseFileInfo::IsFolderFTor() ) );
             if( nFolders == 1 ) buffer = QObject::tr( "one Folder" );
             else if( nFolders > 1 ) buffer = QObject::tr( "%1 Folders" ).arg( nFolders );
 
-            const int nDocuments( std::count_if( this->begin(), this->end(), BaseFileInfo::IsDocumentFTor() ) );
+            const int nDocuments( std::count_if( files.begin(), files.end(), BaseFileInfo::IsDocumentFTor() ) );
             if( nDocuments > 0 && nFolders > 0 ) buffer += ", ";
             if( nDocuments == 1 ) buffer += QObject::tr( "one File" );
             else if( nDocuments > 1 ) buffer += QObject::tr( "%1 Files" ).arg( nDocuments );
 
         } else {
 
-            if( int(std::count_if( this->begin(), this->end(), BaseFileInfo::IsLinkFTor() )) == this->size() ) buffer = QString( QObject::tr( "%1 Symbolic Links" ) ).arg( this->size() );
-            else if( int(std::count_if( this->begin(), this->end(), BaseFileInfo::IsFolderFTor() )) == this->size() ) buffer = QString( QObject::tr( "%1 Folders" ) ).arg( this->size() );
-            else if( int(std::count_if( this->begin(), this->end(), BaseFileInfo::IsDocumentFTor() )) == this->size() ) buffer = QString( QObject::tr( "%1 Files" ) ).arg( this->size() );
-            else buffer = QString( QObject::tr( "%1 Items" ) ).arg( this->size() );
+            if( int(std::count_if( files.begin(), files.end(), BaseFileInfo::IsLinkFTor() )) == files.size() ) buffer = QString( QObject::tr( "%1 Symbolic Links" ) ).arg( files.size() );
+            else if( int(std::count_if( files.begin(), files.end(), BaseFileInfo::IsFolderFTor() )) == files.size() ) buffer = QString( QObject::tr( "%1 Folders" ) ).arg( files.size() );
+            else if( int(std::count_if( files.begin(), files.end(), BaseFileInfo::IsDocumentFTor() )) == files.size() ) buffer = QString( QObject::tr( "%1 Files" ) ).arg( files.size() );
+            else buffer = QString( QObject::tr( "%1 Items" ) ).arg( files.size() );
         }
 
     }
 
-    return (flags&LowerCase) ? buffer.toLower() : buffer;
+    return (flags_&LowerCase) ? buffer.toLower() : buffer;
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( BaseFileInfo::TypeFlags)
