@@ -25,7 +25,7 @@
 
 #include <QWidget>
 #include <QCheckBox>
-#include <QMap>
+#include <QHash>
 
 class BaseFileInfoConfigurationWidget: public QWidget, public OptionWidget
 {
@@ -35,18 +35,18 @@ class BaseFileInfoConfigurationWidget: public QWidget, public OptionWidget
     public:
 
     //* constructor
-    BaseFileInfoConfigurationWidget( QWidget* );
+    explicit BaseFileInfoConfigurationWidget( QWidget* );
 
     //* set widget value from option value
-    virtual void read( const Options& );
+    void read( const Options& ) override;
 
     //* set option value from widget value
-    virtual void write( Options& ) const;
+    void write( Options& ) const override;
 
     Q_SIGNALS:
 
     //* modified
-    void modified( void );
+    void modified();
 
     protected:
 
@@ -56,7 +56,7 @@ class BaseFileInfoConfigurationWidget: public QWidget, public OptionWidget
     private:
 
     //* map mask to checkboxes
-    using CheckBoxMap = QMap<BaseFileInfoToolTipWidget::Type, QCheckBox* >;
+    using CheckBoxMap = QHash<BaseFileInfoToolTipWidget::Type, QCheckBox* >;
     CheckBoxMap checkboxes_;
 
 };
