@@ -30,12 +30,12 @@ class BaseFileInfoIconView: public IconView
     public:
 
     //* constructor
-    BaseFileInfoIconView( QWidget* = nullptr );
+    explicit BaseFileInfoIconView( QWidget* = nullptr );
 
     protected:
 
     //* update item from index
-    virtual void _updateItem( IconViewItem&, const QModelIndex& ) const;
+    void _updateItem( IconViewItem&, const QModelIndex& ) const override;
 
 };
 
