@@ -30,10 +30,10 @@ class BaseFileInfoItemDelegate: public TreeViewItemDelegate
     public:
 
      //* constructor
-    BaseFileInfoItemDelegate( QObject* = nullptr );
+    explicit BaseFileInfoItemDelegate( QObject* = nullptr );
 
     protected:
-    virtual void initStyleOption( QStyleOptionViewItem*, const QModelIndex& ) const;
+    void initStyleOption( QStyleOptionViewItem*, const QModelIndex& ) const override;
 
 
 };
