@@ -47,7 +47,7 @@ class BaseFileInfoModel : public ListModel<T>
     public:
 
     //* constructor
-    BaseFileInfoModel( QObject* parent = nullptr ):
+    explicit BaseFileInfoModel( QObject* parent = nullptr ):
         ListModel<T>( parent )
     {}
 
@@ -56,7 +56,7 @@ class BaseFileInfoModel : public ListModel<T>
     { showIcons_ = value; }
 
     //* show icons
-    bool showIcons( void ) const
+    bool showIcons() const
     { return showIcons_; }
 
     //* column type enumeration
@@ -76,13 +76,13 @@ class BaseFileInfoModel : public ListModel<T>
     //@{
 
     // return data for a given index
-    virtual QVariant data( const QModelIndex&, int ) const;
+    QVariant data( const QModelIndex&, int ) const override;
 
     //* header data
-    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;
+    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;
 
     //* number of columns for a given index
-    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
+    int columnCount( const QModelIndex& = QModelIndex() ) const override
     { return nColumns; }
 
     //@}
@@ -94,7 +94,7 @@ class BaseFileInfoModel : public ListModel<T>
         public:
 
         //* constructor
-        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
+        explicit SortFTor( int type, Qt::SortOrder order ):
             ItemModel::SortFTor( type, order )
             {}
 
@@ -106,7 +106,7 @@ class BaseFileInfoModel : public ListModel<T>
     protected:
 
     //* sort
-    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
+    void _sort( int column, Qt::SortOrder order ) override
     { std::sort( ListModel<T>::_get().begin(), ListModel<T>::_get().end(), SortFTor( (ColumnType) column, order ) ); }
 
     //* icon matching given id
@@ -137,17 +137,17 @@ QVariant BaseFileInfoModel<T>::data( const QModelIndex& index, int role ) const
             // retrieve associated file info
             const T& fileInfo( ListModel<T>::get()[index.row()] );
 
-            if( fileInfo.type() & BaseFileInfo::Navigator ) return (index.column() == Filename ) ? fileInfo.file() : QVariant();
+            if( fileInfo.type() & BaseFileInfo::Navigator ) return (index.column() == Filename ) ? fileInfo.file().get() : QVariant();
 
             switch( index.column() )
             {
-                case Filename: return fileInfo.file().localName();
-                case Path: return fileInfo.file().path();
+                case Filename: return fileInfo.file().localName().get();
+                case Path: return fileInfo.file().path().get();
                 case Size: return (fileInfo.isFolder() || !fileInfo.size() ) ? "" : File::sizeString( fileInfo.size() );
                 case User: return fileInfo.user();
                 case Group: return fileInfo.group();
                 case Permissions: return (fileInfo.type() & BaseFileInfo::Navigator) ? QString():fileInfo.permissionsString();
-                case Modified: return QString( fileInfo.lastModified() ? TimeStamp( fileInfo.lastModified() ).toString() : "" );
+                case Modified: return QString( fileInfo.lastModified().isValid() ? fileInfo.lastModified().toString() : QString() );
 
                 default:
                 return QVariant();
@@ -304,7 +304,7 @@ bool BaseFileInfoModel<T>::SortFTor::operator() ( const T& constFirst, const T&
 
         default:
         case Filename:
-        { return first.file().localName().compare( second.file().localName(), Qt::CaseInsensitive ) < 0; }
+        { return first.file().localName().get().compare( second.file().localName(), Qt::CaseInsensitive ) < 0; }
         break;
 
 
