@@ -37,7 +37,7 @@ BaseFileInfoToolTipWidget::BaseFileInfoToolTipWidget( QWidget* parent ):
     Debug::Throw( "BaseFileInfoToolTipWidget::BaseFileInfoToolTipWidget.\n" );
 
     // layout
-    QHBoxLayout* hLayout = new QHBoxLayout();
+    auto hLayout = new QHBoxLayout;
     hLayout->setMargin( 10 );
     hLayout->setSpacing( 10 );
     setLayout( hLayout );
@@ -45,7 +45,7 @@ BaseFileInfoToolTipWidget::BaseFileInfoToolTipWidget( QWidget* parent ):
     hLayout->addWidget( iconLabel_ = new QLabel( this ) );
     iconLabel_->setAlignment( Qt::AlignHCenter|Qt::AlignTop );
 
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    auto vLayout = new QVBoxLayout;
     vLayout->setMargin( 0 );
     vLayout->setSpacing( 5 );
     hLayout->addLayout( vLayout );
@@ -62,7 +62,7 @@ BaseFileInfoToolTipWidget::BaseFileInfoToolTipWidget( QWidget* parent ):
     separator_->setFrameStyle( QFrame::HLine );
 
     // grid layout
-    GridLayout* gridLayout = new GridLayout();
+    auto gridLayout = new GridLayout;
     gridLayout->setMaxCount( 2 );
     gridLayout->setColumnAlignment( 0, Qt::AlignVCenter|Qt::AlignRight );
     gridLayout->setColumnAlignment( 1, Qt::AlignVCenter|Qt::AlignLeft );
@@ -82,7 +82,7 @@ BaseFileInfoToolTipWidget::BaseFileInfoToolTipWidget( QWidget* parent ):
     vLayout->addStretch( 1 );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
@@ -101,7 +101,7 @@ void BaseFileInfoToolTipWidget::setFileInfo( const BaseFileInfo& fileInfo, const
     {
 
         // get pixmap
-        QPixmap pixmap( icon.pixmap( QSize( pixmapSize_, pixmapSize_ ) ) );
+        CustomPixmap pixmap( icon.pixmap( QSize( pixmapSize_, pixmapSize_ ) ) );
 
         // add effects
         const int type( fileInfo.type() );
@@ -172,9 +172,9 @@ void BaseFileInfoToolTipWidget::setFileInfo( const BaseFileInfo& fileInfo, const
 }
 
 //_____________________________________________
-void BaseFileInfoToolTipWidget::_updateConfiguration( void )
+void BaseFileInfoToolTipWidget::_updateConfiguration()
 {
     Debug::Throw( "BaseFileInfoToolTipWidget::_updateConfiguration.\n" );
-    if( XmlOptions::get().contains( "TOOLTIPS_PIXMAP_SIZE" ) ) setPixmapSize( XmlOptions::get().get<unsigned int>( "TOOLTIPS_PIXMAP_SIZE" ) );
-    if( XmlOptions::get().contains( "TOOLTIPS_MASK" ) ) setMask( Types(XmlOptions::get().get<unsigned int>( "TOOLTIPS_MASK" )) );
+    if( XmlOptions::get().contains( "TOOLTIPS_PIXMAP_SIZE" ) ) setPixmapSize( XmlOptions::get().get<int>( "TOOLTIPS_PIXMAP_SIZE" ) );
+    if( XmlOptions::get().contains( "TOOLTIPS_MASK" ) ) setMask( Types(XmlOptions::get().get<int>( "TOOLTIPS_MASK" )) );
 }
