@@ -37,7 +37,7 @@ class BaseFileInfoToolTipWidget: public BaseToolTipWidget
     public:
 
     //* constructor
-    BaseFileInfoToolTipWidget( QWidget* );
+    explicit BaseFileInfoToolTipWidget( QWidget* = nullptr );
 
     //* set data
     void setFileInfo( const BaseFileInfo&, const QIcon& = QIcon() );
@@ -75,13 +75,13 @@ class BaseFileInfoToolTipWidget: public BaseToolTipWidget
     protected:
 
     //* reload
-    virtual void _reload( void )
+    void _reload()
     { setFileInfo( fileInfo_, icon_ ); }
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
