@@ -42,21 +42,21 @@ class BaseFileInformationDialog: public CustomDialog
     public:
 
     //* constructor
-    BaseFileInformationDialog( QWidget* );
+    explicit BaseFileInformationDialog( QWidget* );
 
     //*@name accessors
     //@{
 
     //* tab widget
-    QTabWidget& tabWidget( void ) const
+    QTabWidget& tabWidget() const
     { return *tabWidget_; }
 
     //* main widget
-    QWidget& mainPage( void ) const
+    QWidget& mainPage() const
     { return *mainPage_; }
 
     //* main layout
-    QVBoxLayout& pageLayout( void ) const
+    QVBoxLayout& pageLayout() const
     { return *pageLayout_; }
 
     //@}
@@ -98,7 +98,7 @@ class BaseFileInformationDialog: public CustomDialog
     void setGroup( const QString& );
 
     //* add a row
-    int addRow( const QString&, const QString& = QString(), GridLayoutItem::ItemFlags = GridLayoutItem::None );
+    int addRow( const QString&, const QString& = QString(), GridLayoutItem::Flags = GridLayoutItem::Flag::None );
 
     //* set custom value
     void setCustomKey( int, const QString& );
