@@ -25,7 +25,7 @@
 #include "Counter.h"
 
 //* find dialog for text editor widgets
-class BaseFindDialog: public BaseDialog, public Counter
+class BaseFindDialog: public BaseDialog, private Base::Counter<BaseFindDialog>
 {
 
     //* Qt meta object declaration
@@ -34,13 +34,13 @@ class BaseFindDialog: public BaseDialog, public Counter
     public:
 
     //* constructor
-    BaseFindDialog( QWidget* parent = nullptr, Qt::WindowFlags WindowFlags = 0 );
+    explicit BaseFindDialog( QWidget* parent = nullptr, Qt::WindowFlags WindowFlags = 0 );
 
     //*@name accessors
     //@{
 
     //* string to find
-    virtual QString text( void ) const
+    QString text() const
     { return baseFindWidget_->text(); }
 
     //* get selection
@@ -48,11 +48,11 @@ class BaseFindDialog: public BaseDialog, public Counter
     { return baseFindWidget_->selection( value ); }
 
     //* find widget
-    BaseFindWidget& baseFindWidget( void ) const
+    BaseFindWidget& baseFindWidget() const
     { return *baseFindWidget_; }
 
     //* retrieve editor
-    virtual CustomComboBox& editor( void ) const
+    CustomComboBox& editor() const
     { return baseFindWidget_->editor(); }
 
     //@}
@@ -61,11 +61,11 @@ class BaseFindDialog: public BaseDialog, public Counter
     //@{
 
     //* string to find
-    virtual void setText( const QString& text )
+    void setText( const QString& text )
     { baseFindWidget_->setText( text ); }
 
     //* synchronize searched strings and ComboBox
-    virtual void synchronize( void )
+    virtual void synchronize()
     { baseFindWidget_->synchronize(); }
 
     //* enable/disable entire word
@@ -89,11 +89,11 @@ class BaseFindDialog: public BaseDialog, public Counter
     public Q_SLOTS:
 
     //* take action when at least one match is found
-    virtual void matchFound( void )
+    void matchFound()
     { baseFindWidget_->matchFound(); }
 
     //* take action when no match is found
-    virtual void noMatchFound( void )
+    void noMatchFound()
     { baseFindWidget_->noMatchFound(); }
 
     private:
