@@ -34,7 +34,7 @@
 #include <QPalette>
 
 //* find dialog for text editor widgets
-class BaseFindWidget: public EmbeddedWidget, public Counter
+class BaseFindWidget: public EmbeddedWidget, private Base::Counter<BaseFindWidget>
 {
 
     //* Qt meta object declaration
@@ -43,28 +43,28 @@ class BaseFindWidget: public EmbeddedWidget, public Counter
     public:
 
     //* constructor
-    BaseFindWidget( QWidget* = nullptr, bool compact = true );
+    explicit BaseFindWidget( QWidget* = nullptr, bool compact = true );
 
     //*@name accessors
     //@{
 
     //* string to find
-    virtual QString text( void ) const
+    virtual QString text() const
     { return editor_->currentText(); }
 
     //* get selection
     virtual TextSelection selection( bool ) const;
 
     //* retrieve editor
-    virtual CustomComboBox& editor( void ) const
+    CustomComboBox& editor() const
     { return *editor_; }
 
     //* close button
-    QAbstractButton& closeButton( void ) const
+    QAbstractButton& closeButton() const
     { return *closeButton_; }
 
     //* list of disabled buttons
-    virtual QList<QAbstractButton*>& disabledButtons( void )
+    QList<QAbstractButton*>& disabledButtons()
     { return buttons_; }
 
     //@}
@@ -82,7 +82,7 @@ class BaseFindWidget: public EmbeddedWidget, public Counter
     virtual void enableRegExp( bool );
 
     //* synchronize searched strings and ComboBox
-    virtual void synchronize( void );
+    virtual void synchronize();
 
     //@}
 
@@ -94,76 +94,76 @@ class BaseFindWidget: public EmbeddedWidget, public Counter
     public Q_SLOTS:
 
     //* take action when at least one match is found
-    virtual void matchFound( void );
+    void matchFound();
 
     //* take action when no match is found
-    virtual void noMatchFound( void );
+    void noMatchFound();
 
     protected Q_SLOTS:
 
     //* update combo box with current text
-    virtual void _updateFindComboBox( void )
+    void _updateFindComboBox()
     { _addSearchedString( editor_->currentText() ); }
 
     //* create Selection object when find button is pressed
-    virtual void _find( void )
+    void _find()
     { emit find( selection( false ) ); }
 
     //* create Selection object when find button is pressed
-    virtual void _findPrevious( void )
+    void _findPrevious()
     {
         findBackward_ = true;
         emit find( selection( false ) );
     }
 
     //* create Selection object when find button is pressed
-    virtual void _findNext( void )
+    void _findNext()
     {
         findBackward_ = false;
         emit find( selection( false ) );
     }
 
     //* create Selection object when find button is pressed
-    virtual void _findNoIncrement( void )
+    void _findNoIncrement()
     { if( !regexpCheckbox_->isChecked() ) emit find( selection( true ) ); }
 
     //* update button state when regexp checkbox is checked
-    virtual void _regExpChecked( bool );
+    void _regExpChecked( bool );
 
     //* update button state depending on the string to find
-    virtual void _updateButtons( const QString& text = QString() );
+    void _updateButtons( const QString& text = QString() );
 
     protected:
 
     //* change event
-    virtual void changeEvent( QEvent* );
+    void changeEvent( QEvent* ) override;
 
     //* "entire word" checkbox
-    QCheckBox& _entireWordCheckBox( void ) const
+    QCheckBox& _entireWordCheckBox() const
     { return *entireWordCheckbox_; }
 
     //* edition layout
-    QGridLayout& _editorLayout( void ) const
+    QGridLayout& _editorLayout() const
     { return *editorLayout_; }
 
     //* find next button
-    QAbstractButton& _findNextButton( void ) const
+    QAbstractButton& _findNextButton() const
     { return *findNextButton_; }
 
     //* find previous button
-    QAbstractButton& _findPreviousButton( void ) const
+    QAbstractButton& _findPreviousButton() const
     { return *findPreviousButton_; }
 
     //* add button to disabled button list
-    virtual void _addDisabledButton( QAbstractButton* );
+    void _addDisabledButton( QAbstractButton* );
 
     //* add string to both combo box and static set
-    virtual void _addSearchedString( const QString& );
+    void _addSearchedString( const QString& );
 
     private:
 
     //* create not found palette
-    void _updateNotFoundPalette( void );
+    void _updateNotFoundPalette();
 
     //* editor layout
     QGridLayout* editorLayout_ = nullptr;
@@ -198,7 +198,7 @@ class BaseFindWidget: public EmbeddedWidget, public Counter
     QPalette notFoundPalette_;
 
     //* set of previously searched strings
-    static QOrderedSet<QString>& _searchedStrings( void );
+    static QOrderedSet<QString>& _searchedStrings();
 
 };
 #endif
