@@ -47,19 +47,19 @@ class BaseMainWindow: public QMainWindow
     public:
 
     //* constructor
-    BaseMainWindow( QWidget*, Qt::WindowFlags = 0);
+    explicit BaseMainWindow( QWidget*, Qt::WindowFlags = 0);
 
     //* restore window size
-    virtual QSize minimumSizeHint( void ) const;
+    QSize minimumSizeHint() const override;
 
     //* restore window size
-    virtual QSize sizeHint( void ) const;
+    QSize sizeHint() const override;
 
     //* center widget on argument widget
-    void centerOnDesktop( void );
+    void centerOnDesktop();
 
     //* center on parent widget
-    void centerOnParent( void )
+    void centerOnParent()
     { centerOnWidget( parentWidget() ); }
 
     //* center widget on argument widget
@@ -75,79 +75,79 @@ class BaseMainWindow: public QMainWindow
     void setStatusBar( QStatusBar* );
 
     //* lock toolbars
-    QAction& lockToolBarsAction( void ) const
+    QAction& lockToolBarsAction() const
     { return *lockToolBarsAction_; }
 
     //* lock panels
-    QAction& lockPanelsAction( void ) const
+    QAction& lockPanelsAction() const
     { return *lockPanelsAction_; }
 
     //* show menubar
-    QAction& showMenuBarAction( void ) const
+    QAction& showMenuBarAction() const
     { return *showMenuBarAction_; }
 
     //* show status bar
-    QAction& showStatusBarAction( void ) const
+    QAction& showStatusBarAction() const
     { return *showStatusBarAction_; }
 
     //* create context menu (overloaded)
-    virtual QMenu* createPopupMenu( void );
+    QMenu* createPopupMenu() override;
 
     //* toolbar menu
-    virtual ToolBarMenu& toolBarMenu( QWidget* = nullptr );
+    ToolBarMenu& toolBarMenu( QWidget* = nullptr );
 
     //* option name
-    virtual void setOptionName( const QString& name );
+    void setOptionName( const QString& name );
 
     //* menu option name
-    bool hasOptionName( void ) const
+    bool hasOptionName() const
     { return !lockToolBarsOptionName().isEmpty(); }
 
     //* lock toolbar option name
-    const QString& lockToolBarsOptionName( void ) const
+    const QString& lockToolBarsOptionName() const
     { return lockToolBarsOptionName_; }
 
     //* lock panels option name
-    const QString& lockPanelsOptionName( void ) const
+    const QString& lockPanelsOptionName() const
     { return lockPanelsOptionName_; }
 
     //* menu option name
-    const QString& showMenuBarOptionName( void ) const
+    const QString& showMenuBarOptionName() const
     { return showMenuBarOptionName_; }
 
     //* status bar option name
-    const QString& showStatusBarOptionName( void ) const
+    const QString& showStatusBarOptionName() const
     { return showStatusBarOptionName_; }
 
     Q_SIGNALS:
 
     //* toolbar configuration changed
-    void toolbarConfigurationChanged( void );
+    void toolbarConfigurationChanged();
 
     public Q_SLOTS:
 
     //* uniconify
-    void uniconify( void );
+    void uniconify();
 
     protected:
 
     //* generic event
-    virtual bool event( QEvent* );
+    bool event( QEvent* ) override;
 
     //* true if main window has menu
-    virtual bool _hasMenuBar( void ) const;
+    bool _hasMenuBar() const;
 
     //* true if main window has menu
-    virtual bool _hasStatusBar( void ) const;
+    bool _hasStatusBar() const;
 
     //* true if main window has toolbars
-    virtual bool _hasToolBars( void ) const;
+    bool _hasToolBars() const;
 
     //* returns true if lockable toolbars are found
-    virtual bool _hasLockableToolBars( void ) const;
+    bool _hasLockableToolBars() const;
 
     //* true if main window has dock widgets
-    virtual bool _hasPanels( void ) const;
+    bool _hasPanels() const;
 
     //* action list
     using ActionList = QVector<QAction*>;
@@ -156,7 +156,7 @@ class BaseMainWindow: public QMainWindow
     ActionList _toolBarsActions( QMenu* );
 
     //* maximize state prior to minimization
-    bool _wasMaximized( void ) const
+    bool _wasMaximized() const
     { return wasMaximized_; }
 
     //* maximize state prior to minimization
@@ -166,7 +166,7 @@ class BaseMainWindow: public QMainWindow
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     //* toolbar text position
     void _updateToolButtonStyle( int );
