@@ -34,18 +34,12 @@ class BasePrintHelper: public QObject
     Q_OBJECT
 
     public:
+
     //* constructor
-    BasePrintHelper( QObject* parent = nullptr ):
-        QObject( parent ),
-        orientation_( QPrinter::Portrait ),
-        pageMode_( SinglePage ),
-        pageNumber_(0),
-        sheetNumber_(0),
-        now_( TimeStamp::now() )
-    {}
+    explicit BasePrintHelper( QObject* = nullptr );
 
     //* multipage mode
-    enum PageMode
+    enum class PageMode
     {
         SinglePage,
         TwoPages,
@@ -58,23 +52,23 @@ class BasePrintHelper: public QObject
     //*@name accessors
     //@{
         //* orientation
-    QPrinter::Orientation orientation( void ) const
+    QPrinter::Orientation orientation() const
     { return orientation_; }
 
     //* page mode
-    PageMode pageMode( void ) const
+    PageMode pageMode() const
     { return pageMode_; }
 
     //* page number
-    int pageNumber( void ) const
+    int pageNumber() const
     { return pageNumber_; }
 
     //* page number
-    int sheetNumber( void ) const
+    int sheetNumber() const
     { return sheetNumber_; }
 
     //* file
-    const File& file( void ) const
+    const File& file() const
     { return file_; }
 
     //@}
@@ -114,7 +108,7 @@ class BasePrintHelper: public QObject
     protected:
 
     //* return pageRect
-    const QRect& _pageRect( void ) const
+    const QRect& _pageRect() const
     { return pageRect_; }
 
     //* increment page
@@ -126,7 +120,7 @@ class BasePrintHelper: public QObject
     QPrinter::Orientation orientation_ = QPrinter::Portrait;
 
     //* page mode
-    PageMode pageMode_ = SinglePage;
+    PageMode pageMode_ = PageMode::SinglePage;
 
     //* rects
     QRect pageRect_;
