@@ -33,12 +33,12 @@ class BaseProgressBar:public QProgressBar
     public:
 
     //* constructor
-    BaseProgressBar( QWidget* parent = nullptr ):
+    explicit BaseProgressBar( QWidget* parent = nullptr ):
         QProgressBar( parent )
     { setTextVisible( true ); }
 
     //* reset
-    virtual void reset( void )
+    virtual void reset()
     {
         text_ = QString();
         QProgressBar::reset();
@@ -56,7 +56,7 @@ class BaseProgressBar:public QProgressBar
     protected:
 
     //* paint
-    void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     private:
 
