@@ -33,13 +33,13 @@ class BaseReplaceDialog: public BaseFindDialog
     public:
 
     //* constructor
-    BaseReplaceDialog( QWidget* = nullptr, Qt::WindowFlags = 0 );
+    explicit BaseReplaceDialog( QWidget* = nullptr, Qt::WindowFlags = 0 );
 
     //*@name accessors
     //@{
 
     //* string to replace
-    QString replaceText( void ) const
+    QString replaceText() const
     { return static_cast<BaseReplaceWidget*>(&baseFindWidget())->replaceText(); }
 
     //* get selection
