@@ -34,34 +34,41 @@ class BaseReplaceWidget: public BaseFindWidget
     public:
 
     //* constructor
-    BaseReplaceWidget( QWidget* = nullptr, bool compact = true );
+    explicit BaseReplaceWidget( QWidget* = nullptr, bool compact = true );
 
     //*@name accessors
     //@{
 
     //* string to replace
-    QString replaceText( void ) const
+    QString replaceText() const
     { return replaceEditor_->currentText(); }
 
     //* retrieve text selection from dialog
-    virtual TextSelection selection( bool ) const;
+    TextSelection selection( bool ) const override;
 
     //@}
 
     //*@name modifiers
     //@{
 
+    //* enable replace in selection
+    void enableReplaceInSelection( bool value )
+    { replaceInSelectionAction_->setEnabled( value ); }
+
     //* string to replace
     void setReplaceText( const QString& text )
     { replaceEditor_->setEditText( text ); }
 
     //* synchronize searched strings and ComboBox
-    virtual void synchronize( void );
+    void synchronize() override;
 
     //@}
 
     Q_SIGNALS:
 
+    //* emitted when replace all menu is about to show
+    void menuAboutToShow();
+
     //* emitted when Replace is pressed
     void replace( TextSelection );
 
@@ -77,31 +84,31 @@ class BaseReplaceWidget: public BaseFindWidget
     protected Q_SLOTS:
 
     //* update combo box with current text
-    void _updateReplaceComboBox( void )
+    void _updateReplaceComboBox()
     { _addReplacedString( replaceEditor_->currentText() ); }
 
     //* create Selection object when replace button is pressed
-    void _replace( void )
+    void _replace()
     { emit replace( selection( false ) ); }
 
     //* create Selection object when replace button is pressed
-    void _replaceInWindow( void );
+    void _replaceInWindow();
 
     //* create Selection object when replace button is pressed
-    void _replaceInSelection( void );
+    void _replaceInSelection();
 
     protected:
 
     //* replace editor
-    virtual CustomComboBox& _replaceEditor( void ) const
+    CustomComboBox& _replaceEditor() const
     { return *replaceEditor_; }
 
     //* replace all menu
-    virtual QMenu& _replaceAllMenu( void ) const
+    QMenu& _replaceAllMenu() const
     { return *replaceAllMenu_; }
 
     //* add string to both combo box and static set
-    virtual void _addReplacedString( const QString& );
+    void _addReplacedString( const QString& );
 
     private:
 
@@ -114,6 +121,9 @@ class BaseReplaceWidget: public BaseFindWidget
     //* replace all menu
     QMenu* replaceAllMenu_ = nullptr;
 
+    //* replace in selection action
+    QAction* replaceInSelectionAction_ = nullptr;
+
     //* replaced strings
     static QOrderedSet<QString>& _replacedStrings();
 
