@@ -38,14 +38,14 @@ class StatusBarLabel: public QLabel
     public:
 
     //* constructor
-    StatusBarLabel( QWidget* parent = nullptr ):
+    explicit StatusBarLabel( QWidget* parent = nullptr ):
         QLabel( parent )
     {}
 
     public Q_SLOTS:
 
     //* set text
-    virtual void setText( const QString& message, bool alsoUpdate = true )
+    void setText( const QString& message, bool alsoUpdate = true )
     {
         if( alsoUpdate ) setTextAndUpdate( message );
         else QLabel::setText( message );
@@ -57,19 +57,19 @@ class StatusBarLabel: public QLabel
 };
 
 //* custom status bar
-class BaseStatusBar: public QStatusBar, public Counter
+class BaseStatusBar: public QStatusBar, private Base::Counter<BaseStatusBar>
 {
 
     public:
 
     //* constructor
-    BaseStatusBar( QWidget* );
+    explicit BaseStatusBar( QWidget* );
 
     //* add clock
-    void addClock( void );
+    void addClock();
 
     //* add label
-    void addLabel( int = 0 );
+    void addLabel( int stretch = 0 );
 
     //* add labels
     void addLabels( int n, int stretch = 0 )
@@ -82,7 +82,7 @@ class BaseStatusBar: public QStatusBar, public Counter
     protected:
 
     //* context menu
-    virtual void contextMenuEvent( QContextMenuEvent* );
+    void contextMenuEvent( QContextMenuEvent* ) override;
 
     private:
 
