@@ -52,7 +52,7 @@ BaseToolTipWidget::BaseToolTipWidget( QWidget* parent ):
     setForegroundRole( QPalette::ToolTipText );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
@@ -90,30 +90,28 @@ bool BaseToolTipWidget::eventFilter( QObject* object, QEvent* event )
 }
 
 //_______________________________________________________
-void BaseToolTipWidget::hide( void )
+void BaseToolTipWidget::setVisible( bool visible )
 {
     Debug::Throw( "BaseToolTipWidget::hide.\n" );
     timer_.stop();
-    if( isVisible() )
-    { hiddenTimer_.start( 200, this ); }
-    QWidget::hide();
-}
 
-//_______________________________________________________
-void BaseToolTipWidget::show( void )
-{
+    if( !visible )
+    {
 
-    Debug::Throw( "BaseToolTipWidget::show.\n" );
+        if( isVisible() )
+        { hiddenTimer_.start( 200, this ); }
 
-    // stop timer
-    timer_.stop();
+    } else {
 
-    // check mouse is still in relevant rect
-    if( !_checkMousePosition() ) return;
+        // check mouse is still in relevant rect
+        if( !_checkMousePosition() ) return;
 
-    // adjust position and show
-    _adjustPosition();
-    QWidget::show();
+        // adjust position and show
+        _adjustPosition();
+
+    }
+
+    QWidget::setVisible( visible );
 }
 
 //_______________________________________________________
@@ -179,11 +177,11 @@ void BaseToolTipWidget::timerEvent( QTimerEvent* event )
 }
 
 //_______________________________________________________
-bool BaseToolTipWidget::_checkMousePosition( void ) const
+bool BaseToolTipWidget::_checkMousePosition() const
 { return rect_.contains( QCursor::pos() ); }
 
 //_______________________________________________________
-void BaseToolTipWidget::_adjustPosition( void )
+void BaseToolTipWidget::_adjustPosition()
 {
 
     // get tooltip size
@@ -198,13 +196,13 @@ void BaseToolTipWidget::_adjustPosition( void )
     int top(0);
     int left(0);
     const int margin = 5;
-    if( preferredPosition_ == Top || preferredPosition_ == Bottom )
+    if( preferredPosition_ == Position::Top || preferredPosition_ == Position::Bottom )
     {
         left = followMouse_ ? QCursor::pos().x():rect_.left() + ( rect_.width() - size.width() )/2;
         left = qMax( left, desktopGeometry.left() );
         left = qMin( left, desktopGeometry.right() - size.width() );
 
-        if( preferredPosition_ == Bottom )
+        if( preferredPosition_ == Position::Bottom )
         {
 
             top = rect_.bottom() + margin;
@@ -223,7 +221,7 @@ void BaseToolTipWidget::_adjustPosition( void )
         top = qMax( top, desktopGeometry.top() );
         top = qMin( top, desktopGeometry.bottom() - size.height() );
 
-        if( preferredPosition_ == Right )
+        if( preferredPosition_ == Position::Right )
         {
 
             left = rect_.right()+margin;
@@ -243,7 +241,7 @@ void BaseToolTipWidget::_adjustPosition( void )
 }
 
 //_____________________________________________
-void BaseToolTipWidget::_updateConfiguration( void )
+void BaseToolTipWidget::_updateConfiguration()
 {
     Debug::Throw( "BaseToolTipWidget::_updateConfiguration.\n" );
     if( XmlOptions::get().contains( "SHOW_TOOLTIPS" ) ) setEnabled( XmlOptions::get().get<bool>( "SHOW_TOOLTIPS" ) );
