@@ -20,14 +20,6 @@
 *
 *******************************************************************************/
 
-/**
-  \file BlockHighlight.h
-  \brief handles current block highlighting
-  \author Hugo Pereira
-  \version $Revision$
-  \date $Date$
-*/
-
 #include <QApplication>
 #include <QBasicTimer>
 #include <QTimerEvent>
@@ -38,7 +30,7 @@
 class TextEditor;
 
 //* handles current block highlighting
-class BlockHighlight: public QObject, public Counter
+class BlockHighlight: public QObject, private Base::Counter<BlockHighlight>
 {
 
   Q_OBJECT
@@ -46,36 +38,36 @@ class BlockHighlight: public QObject, public Counter
   public:
 
   //* constructor
-  BlockHighlight( TextEditor* parent );
+  explicit BlockHighlight( TextEditor* parent );
 
   //* enable/disable
   void setEnabled( bool value )
   { enabled_ = value; }
 
   //* enable/disable
-  bool isEnabled( void ) const
+  bool isEnabled() const
   { return enabled_; }
 
   //* clear highlighted block
-  void clear( void );
+  void clear();
 
   public Q_SLOTS:
 
   //* highlight
-  void highlight( void );
+  void highlight();
 
   protected:
 
   //* delayed highlighting
-  virtual void timerEvent( QTimerEvent* event );
+  void timerEvent( QTimerEvent* event ) override;
 
   //* highlight
-  void _highlight( void );
+  void _highlight();
 
   private:
 
   //* trigger update associated editors
-  void _updateEditors( void );
+  void _updateEditors();
 
   //* parent editor
   TextEditor* parent_ = nullptr;
