@@ -24,7 +24,7 @@
 #include <QApplication>
 #include <QMimeData>
 
-static const unsigned int debugLevel = 1;
+static const int debugLevel = 1;
 
 //________________________________________________________________________
 const QString BoxSelection::mimeType = "text/boxSelection";
@@ -38,6 +38,15 @@ BoxSelection::BoxSelection( TextEditor* parent ):
     updateConfiguration();
 }
 
+//________________________________________________________________________
+bool BoxSelection::empty() const
+{
+    return
+        !enabled_ ||
+        state_ == State::Empty ||
+        ( state_ == State::Finished && cursors_.empty() );
+}
+
 //________________________________________________________________________
 void BoxSelection::synchronize( const BoxSelection& box )
 {
@@ -60,8 +69,9 @@ void BoxSelection::synchronize( const BoxSelection& box )
 
 }
 
+
 //________________________________________________________________________
-void BoxSelection::updateConfiguration( void )
+void BoxSelection::updateConfiguration()
 {
 
     Debug::Throw( "BoxSelection::updateConfiguration.\n" );
@@ -80,7 +90,7 @@ void BoxSelection::updateConfiguration( void )
 }
 
 //________________________________________________________________________
-bool BoxSelection::checkEnabled( void )
+bool BoxSelection::checkEnabled()
 {
 
     Debug::Throw( debugLevel, "BoxSelection::checkEnabled.\n" );
@@ -97,8 +107,8 @@ bool BoxSelection::checkEnabled( void )
     if( !isEnabled() ) return false;
 
     // read font attributes
-    fontWidth_ = QFontMetrics( parent_->font() ).width( " " );
-    fontHeight_ = QFontMetrics( parent_->font() ).height();
+    fontWidth_ = parent_->fontMetrics().width( " " );
+    fontHeight_ = parent_->fontMetrics().height();
 
     return true;
 }
@@ -107,7 +117,7 @@ bool BoxSelection::checkEnabled( void )
 bool BoxSelection::start( QPoint point )
 {
     Debug::Throw( debugLevel, "BoxSelection::start.\n" );
-    if( state_ != SelectionEmpty ) return false;
+    if( state_ != State::Empty ) return false;
 
     // store point
     begin_ = end_ = parent_->fromViewport( point );
@@ -118,7 +128,7 @@ bool BoxSelection::start( QPoint point )
     // set parent cursor
     parent_->setTextCursor( parent_->cursorForPosition( cursor_ ) );
 
-    state_ = SelectionStarted;
+    state_ = State::Started;
     return true;
 }
 
@@ -126,7 +136,7 @@ bool BoxSelection::start( QPoint point )
 bool BoxSelection::update( QPoint point )
 {
     Debug::Throw( debugLevel, "BoxSelection::update.\n" );
-    if( state_ != SelectionStarted ) return false;
+    if( state_ != State::Started ) return false;
 
     // store end point
     end_ = parent_->fromViewport( point );
@@ -149,10 +159,10 @@ bool BoxSelection::update( QPoint point )
 bool BoxSelection::finish( QPoint point )
 {
     Debug::Throw( debugLevel, "BoxSelection::finish.\n" );
-    if( state_ != SelectionStarted ) return false;
+    if( state_ != State::Started ) return false;
 
     update( point );
-    state_ = SelectionFinished;
+    state_ = State::Finished;
 
     // store and copy to clipboard
     _store();
@@ -162,13 +172,13 @@ bool BoxSelection::finish( QPoint point )
 }
 
 //________________________________________________________________________
-bool BoxSelection::clear( void )
+bool BoxSelection::clear()
 {
     Debug::Throw( debugLevel, "BoxSelection::clear.\n" );
-    if( state_ != SelectionFinished ) return false;
+    if( state_ != State::Finished ) return false;
 
     // change state and redraw
-    state_ = SelectionEmpty;
+    state_ = State::Empty;
 
     // update parent
     parent_->viewport()->update( parent_->toViewport( rect() ).adjusted( -2, -2, 3, 3 ) );
@@ -183,7 +193,7 @@ bool BoxSelection::clear( void )
 
 
 //________________________________________________________________________
-QString BoxSelection::toString( void ) const
+QString BoxSelection::toString() const
 {
     Debug::Throw( debugLevel, "BoxSelection::toString.\n" );
 
@@ -211,7 +221,7 @@ bool BoxSelection::fromString( QString input )
     Debug::Throw( debugLevel, "BoxSelection::fromString.\n" );
 
     // check state
-    if( state() != SelectionFinished ) return false;
+    if( state() != State::Finished ) return false;
 
     // replace all tab characters by emulated tabs
     input.replace( "\t", parent_->emulatedTabCharacter() );
@@ -280,14 +290,14 @@ bool BoxSelection::toClipboard( const QClipboard::Mode& mode ) const
     if( mode == QClipboard::Selection && !qApp->clipboard()->supportsSelection() ) return false;
 
     // check if state is ok
-    if( state() != SelectionFinished ) return false;
+    if( state() != State::Finished ) return false;
 
     // check if stored text makes sense
     QString selection( toString() );
     if( selection.isEmpty() ) return false;
 
     // store text into MimeData
-    QMimeData *data( new QMimeData() );
+    QMimeData *data( new QMimeData );
     data->setText( selection );
     data->setData( mimeType, qPrintable( selection ) );
 
@@ -321,17 +331,17 @@ bool BoxSelection::fromClipboard( const QClipboard::Mode& mode )
 }
 
 //________________________________________________________________________
-bool BoxSelection::removeSelectedText( void ) const
+bool BoxSelection::removeSelectedText() const
 {
     Debug::Throw( debugLevel, "BoxSelection::removeSelectedText.\n" );
 
     // check if state is ok
-    if( state() != SelectionFinished || cursorList().empty() ) return false;
+    if( state() != State::Finished || cursorList().empty() ) return false;
 
     QTextCursor stored( parent_->textCursor() );
     QTextCursor cursor( parent_->textCursor() );
     cursor.beginEditBlock();
-    foreach( const QTextCursor& savedCursor, cursorList() )
+    for( const auto& savedCursor:cursorList() )
     {
 
         // select line and remove
@@ -356,17 +366,17 @@ bool BoxSelection::removeSelectedText( void ) const
 }
 
 //________________________________________________________________________
-bool BoxSelection::toUpper( void )
+bool BoxSelection::toUpper()
 {
     Debug::Throw( debugLevel, "BoxSelection::toUpper.\n" );
 
     // check if state is ok
-    if( state() != SelectionFinished || cursorList().empty() ) return false;
+    if( state() != State::Finished || cursorList().empty() ) return false;
 
     QTextCursor stored( parent_->textCursor() );
     QTextCursor cursor( parent_->textCursor() );
     cursor.beginEditBlock();
-    foreach( const QTextCursor& savedCursor, cursorList() )
+    for( const auto& savedCursor:cursorList() )
     {
 
         // select line and remove
@@ -394,17 +404,17 @@ bool BoxSelection::toUpper( void )
 }
 
 //________________________________________________________________________
-bool BoxSelection::toLower( void )
+bool BoxSelection::toLower()
 {
     Debug::Throw( debugLevel, "BoxSelection::toLower.\n" );
 
     // check if state is ok
-    if( state() != SelectionFinished || cursorList().empty() ) return false;
+    if( state() != State::Finished || cursorList().empty() ) return false;
 
     QTextCursor stored( parent_->textCursor() );
     QTextCursor cursor( parent_->textCursor() );
     cursor.beginEditBlock();
-    foreach( const QTextCursor& savedCursor, cursorList() )
+    for( const auto& savedCursor:cursorList() )
     {
 
         // select line and remove
@@ -440,12 +450,12 @@ bool BoxSelection::mergeCharFormat( const QTextCharFormat& format ) const
     static QRegExp regexp( "\\s+$" );
 
     // check if state is ok
-    if( state() != SelectionFinished || cursorList().empty() ) return false;
+    if( state() != State::Finished || cursorList().empty() ) return false;
 
     QTextCursor stored( parent_->textCursor() );
     QTextCursor cursor( parent_->textCursor() );
     cursor.beginEditBlock();
-    foreach( const QTextCursor& savedCursor, cursorList() )
+    for( const auto& savedCursor:cursorList() )
     {
 
         // select line and remove
@@ -476,7 +486,7 @@ bool BoxSelection::mergeCharFormat( const QTextCharFormat& format ) const
 }
 
 //________________________________________________________________________
-void BoxSelection::_updateRect( void )
+void BoxSelection::_updateRect()
 {
     Debug::Throw( debugLevel, "BoxSelection::_updateRect.\n" );
     int xMin( qMin( begin_.x(), end_.x() ) );
@@ -501,20 +511,20 @@ void BoxSelection::_updateRect( void )
 }
 
 //________________________________________________________________________
-void BoxSelection::_store( void )
+void BoxSelection::_store()
 {
     Debug::Throw( debugLevel, "BoxSelection::_store.\n" );
 
     // retrieve box selection size
-    int first_column = rect().left() / fontWidth_;
+    int firstColumn = rect().left() / fontWidth_;
     int columns = rect().width() / fontWidth_;
     int rows = rect().height() / fontHeight_ + 1;
 
-    Debug::Throw() << "BoxSelection::_store - [" << first_column << "," << columns << "," << rows << "]" << endl;
+    Debug::Throw() << "BoxSelection::_store - [" << firstColumn << "," << columns << "," << rows << "]" << endl;
 
     // translate rect
     QRect local( parent_->toViewport( rect() ) );
-    cursors_ = CursorList( first_column, columns );
+    cursors_ = CursorList( firstColumn, columns );
     for( int row = 0; row < rows; row ++ )
     {
 
