@@ -35,7 +35,7 @@ BrowseIconButton::BrowseIconButton( QWidget* parent, const QString& file):
     CustomToolButton( parent )
 {
 
-    setIconSize( IconSize( IconSize::Huge ) );
+    setIconSize( IconSize::get( IconSize::Huge ) );
     setAutoRaise( false );
     setFile( file, false );
     connect( this, SIGNAL(clicked()), SLOT(_browse()) );
@@ -65,8 +65,8 @@ bool BrowseIconButton::setFile( const QString& file, bool check )
     {
 
         // resize pixmap
-        if( pixmap.size() != IconSize( IconSize::Huge ) )
-            pixmap = pixmap.scaled( IconSize( IconSize::Huge ), Qt::KeepAspectRatio, Qt::SmoothTransformation );
+        if( pixmap.size() != IconSize::get( IconSize::Huge ) )
+        { pixmap = CustomPixmap( pixmap.scaled( IconSize::get( IconSize::Huge ), Qt::KeepAspectRatio, Qt::SmoothTransformation ) ); }
 
         setIcon( pixmap );
         return true;
@@ -78,7 +78,7 @@ bool BrowseIconButton::setFile( const QString& file, bool check )
 
     // if file, set pixmap to empty
     if( noIconPixmap_.isNull() ) {
-        noIconPixmap_ = CustomPixmap( IconSize( IconSize::Huge ), CustomPixmap::Transparent );
+        noIconPixmap_ = CustomPixmap( IconSize::get( IconSize::Huge ), CustomPixmap::Flag::Transparent );
         setIcon( noIconPixmap_ );
     }
 
@@ -87,7 +87,7 @@ bool BrowseIconButton::setFile( const QString& file, bool check )
 }
 
 //_____________________________________________
-void BrowseIconButton::_browse( void )
+void BrowseIconButton::_browse()
 {
     Debug::Throw( "BrowseIconButton::_Browse.\n" );
 
@@ -103,7 +103,7 @@ void BrowseIconButton::_browse( void )
         // warning: inneficient
         File path( File( file_ ).path() );
         if( path.exists() && path.isDirectory() ) dialog.setDirectory( path );
-        dialog.selectFile( file_ );
+        dialog.selectFile( File( file_ ) );
 
     }
 
@@ -147,7 +147,7 @@ void BrowseIconButton::dropEvent( QDropEvent *event )
     if( !event->mimeData()->hasUrls() ) return;
 
     // loop over event URLs
-    foreach( const QUrl& url, event->mimeData()->urls() )
+    for( const auto& url:event->mimeData()->urls() )
     {
         QFileInfo fileInfo( url.toLocalFile() );
         if( fileInfo.exists() && setFile( fileInfo.filePath(), true ) ) event->acceptProposedAction();
