@@ -36,30 +36,27 @@ class BrowseIconButton: public CustomToolButton
     public:
 
     //* creator
-    BrowseIconButton(
-        QWidget* parent,
-        const QString& file = QString()
-        );
+    explicit BrowseIconButton( QWidget*, const QString& = QString() );
 
     //* iconFile
-    virtual const QString& file( void ) const
+    const QString& file() const
     { return file_; }
 
     //* iconFile
-    virtual bool setFile( const QString& file, bool check );
+    bool setFile( const QString&, bool );
 
     protected:
 
     //* drag enter event
-    virtual void dragEnterEvent( QDragEnterEvent* );
+    void dragEnterEvent( QDragEnterEvent* ) override;
 
     //* drop event
-    virtual void dropEvent( QDropEvent* );
+    void dropEvent( QDropEvent* ) override;
 
     protected Q_SLOTS:
 
     //* opens file dialog to browse icon file
-    virtual void _browse( void );
+    void _browse();
 
     private:
 
