@@ -21,13 +21,14 @@
 *******************************************************************************/
 
 #include "Counter.h"
+#include "File.h"
 
 #include <QFileDialog>
 #include <QWidget>
 
 class LineEditor;
 
-class BrowsedLineEditor: public QWidget, public Counter
+class BrowsedLineEditor: public QWidget, private Base::Counter<BrowsedLineEditor>
 {
 
     //* Qt meta object declaration
@@ -38,42 +39,57 @@ class BrowsedLineEditor: public QWidget, public Counter
     using Editor = LineEditor;
 
     //* constructor;
-    BrowsedLineEditor( QWidget* parent );
+    explicit BrowsedLineEditor( QWidget* parent );
 
-    //* destructor
-    virtual ~BrowsedLineEditor( void ) = default;
+    //*@name accessors
+    //@{
 
     //* retrieve line editor
-    virtual Editor& editor( void ) const
+    Editor& editor() const
     { return *lineEditor_; }
 
+    //*}
+
+    //*@name modifiers
+    //@{
+
+
+    //* set target application
+    /** it is used to browse application path and update, if not found */
+    void setTargetApplication( File );
+
     //* open mode
-    virtual void setAcceptMode( const QFileDialog::AcceptMode mode )
+    void setAcceptMode( const QFileDialog::AcceptMode mode )
     { acceptMode_ = mode; }
 
     //* file mode
-    virtual void setFileMode( const QFileDialog::FileMode& mode )
+    void setFileMode( const QFileDialog::FileMode& mode )
     { fileMode_ = mode; }
 
+    //@}
+
     public Q_SLOTS:
 
     //* set lineEditor_file
-    virtual void setFile( const QString& file );
+    void setFile( const QString& file );
 
     protected:
 
     //* accept mode
-    virtual QFileDialog::AcceptMode _acceptMode( void ) const
+    QFileDialog::AcceptMode _acceptMode() const
     { return acceptMode_; }
 
     //* file mode
-    virtual QFileDialog::FileMode _fileMode( void ) const
+    QFileDialog::FileMode _fileMode() const
     { return fileMode_; }
 
     protected Q_SLOTS:
 
     //* opens a file dialog, stores result in line edit
-    virtual void _browse( void );
+    virtual void _browse();
+
+    //* target
+    void _findTargetApplication();
 
     private:
 
@@ -86,6 +102,12 @@ class BrowsedLineEditor: public QWidget, public Counter
     //* File dialog mode
     QFileDialog::FileMode fileMode_ = QFileDialog::ExistingFile;
 
+    //* target application
+    File targetApplication_;
+
+    //* update target button
+    QWidget* findTargetButton_ = nullptr;
+
 };
 
 #endif
