@@ -103,7 +103,7 @@ bool BusyWidget::eventFilter( QObject* object, QEvent* event )
 }
 
 //__________________________________________________________________________
-void BusyWidget::start( void )
+void BusyWidget::start()
 {
     Debug::Throw( "BusyWidget::start.\n" );
     if( timer_.isActive() ) return;
@@ -118,7 +118,7 @@ void BusyWidget::start( void )
 }
 
 //__________________________________________________________________________
-void BusyWidget::stop( void )
+void BusyWidget::stop()
 {
     Debug::Throw( "BusyWidget::stop.\n" );
     if( timer_.isActive() ) timer_.stop();
@@ -162,20 +162,18 @@ void BusyWidget::timerEvent( QTimerEvent* event )
 }
 
 //_____________________________________________________________
-void BusyWidget::_adjustPosition( void )
+void BusyWidget::_adjustPosition()
 {
     QWidget* parent( parentWidget() );
     if( !parent ) return;
 
     switch( location_ )
     {
-
-        case Center: move( (parent->width()-width())/2, (parent->height()-height())/2 ); break;
-        case TopLeft: move( margin_, margin_ ); break;
-        case TopRight: move( parent->width()-width()-margin_, margin_ ); break;
-        case BottomLeft: move( margin_, parent->height()-height()-margin_ ); break;
-        case BottomRight: move( parent->width()-width()-margin_, parent->height()-height()-margin_ ); break;
-
+        case Location::Center: move( (parent->width()-width())/2, (parent->height()-height())/2 ); break;
+        case Location::TopLeft: move( margin_, margin_ ); break;
+        case Location::TopRight: move( parent->width()-width()-margin_, margin_ ); break;
+        case Location::BottomLeft: move( margin_, parent->height()-height()-margin_ ); break;
+        case Location::BottomRight: move( parent->width()-width()-margin_, parent->height()-height()-margin_ ); break;
     }
 
 }
