@@ -29,7 +29,7 @@
 #include <QPaintEvent>
 #include <QPainterPath>
 
-class BusyWidget: public QWidget, public Counter
+class BusyWidget: public QWidget, private Base::Counter<BusyWidget>
 {
 
     Q_OBJECT
@@ -39,7 +39,7 @@ class BusyWidget: public QWidget, public Counter
     public:
 
     //* position
-    enum Location
+    enum class Location
     {
         Center,
         TopLeft,
@@ -49,25 +49,25 @@ class BusyWidget: public QWidget, public Counter
     };
 
     //* constructor
-    BusyWidget( QWidget* = nullptr, Location = Center );
+    explicit BusyWidget( QWidget* = nullptr, Location = Location::Center );
 
     //*@name accessors
     //@{
 
     //* angle
-    virtual qreal angle( void ) const
+    qreal angle() const
     { return angle_; }
 
     //* opacity
-    int opacity( void ) const
+    int opacity() const
     { return opacity_; }
 
     //* size
-    virtual QSize minimumSizeHint( void ) const
+    QSize minimumSizeHint() const override
     { return QSize( 2*radius_+border_, 2*radius_+border_ ); }
 
     //* size
-    virtual QSize sizeHint( void ) const
+    QSize sizeHint() const override
     { return minimumSizeHint(); }
 
     //@}
@@ -76,11 +76,11 @@ class BusyWidget: public QWidget, public Counter
     //@{
 
     //* delay
-    virtual void setDelay( int value )
+    void setDelay( int value )
     { delay_ = value; }
 
     //* angle
-    virtual void setAngle( qreal value )
+    void setAngle( qreal value )
     {
         if( angle_ == value ) return;
         angle_ = value;
@@ -88,31 +88,31 @@ class BusyWidget: public QWidget, public Counter
     }
 
     //* opacity
-    virtual void setOpacity( int );
+    void setOpacity( int );
 
     //@}
 
     //* event filter
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     public Q_SLOTS:
 
     //* start
-    virtual void start( void );
+    void start();
 
     //* stop
-    virtual void stop( void );
+    void stop();
 
     protected:
 
     //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //* timer event
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     //* adjust position based on parent
-    void _adjustPosition( void );
+    void _adjustPosition();
 
     private:
 
@@ -126,7 +126,7 @@ class BusyWidget: public QWidget, public Counter
     QPainterPath path_;
 
     //* location
-    Location location_ = Center;
+    Location location_ = Location::Center;
 
     //* delay
     int delay_ = 200;
