@@ -28,7 +28,7 @@
 #include "TimeStamp.h"
 
 //* clock timer. Emit signal when current time is changed
-class ClockTimer: public QObject, public Counter
+class ClockTimer: public QObject, private Base::Counter<ClockTimer>
 {
 
     //* Qt meta object declaration
@@ -37,7 +37,7 @@ class ClockTimer: public QObject, public Counter
     public:
 
     //* constructor
-    ClockTimer( QWidget *parent );
+    explicit ClockTimer( QWidget *parent );
 
     Q_SIGNALS:
 
@@ -46,16 +46,13 @@ class ClockTimer: public QObject, public Counter
 
     protected:
 
-    virtual void timerEvent( QTimerEvent* );
-
-    //* check current time, generate time string if new; emit TimeChanged
-    //void _checkCurrentTime( void );
+    void timerEvent( QTimerEvent* ) override;
 
     private:
 
     //* get interval (seconds) prior to next update
-    int interval( void ) const
-    { return 60 - (TimeStamp::now() % 60); }
+    int interval() const
+    { return 60 - (TimeStamp::now().unixTime() % 60); }
 
     //* timer
     QBasicTimer timer_;
@@ -72,10 +69,10 @@ class ClockLabel:public QLabel
     public:
 
     //* constructor
-    ClockLabel( QWidget* parent );
+    explicit ClockLabel( QWidget* parent );
 
     //* retrieve timer
-    ClockTimer& timer( void )
+    ClockTimer& timer()
     { return timer_; }
 
     private:
