@@ -28,7 +28,7 @@
 
 #include <QComboBox>
 
-class ColorComboBox: public QComboBox, public Counter
+class ColorComboBox: public QComboBox, private Base::Counter<ColorComboBox>
 {
 
     //* Qt meta object declaration
@@ -38,16 +38,16 @@ class ColorComboBox: public QComboBox, public Counter
 
 
     //* constructor
-    ColorComboBox( QWidget* );
+    explicit ColorComboBox( QWidget* );
 
     //*@name accessors
     //@{
 
     //* retrieve colors
-    Base::Color::Set colors( void ) const;
+    Base::Color::Set colors() const;
 
     //* current color
-    QColor color( void ) const;
+    QColor color() const;
 
     //@}
 
