@@ -25,7 +25,7 @@
 #include <QEvent>
 #include <QWidget>
 
-class ColorGrabObject: public QObject, public Counter
+class ColorGrabObject: public QObject, private Base::Counter<ColorGrabObject>
 {
 
     Q_OBJECT
@@ -33,10 +33,10 @@ class ColorGrabObject: public QObject, public Counter
     public:
 
     //* constructor
-    ColorGrabObject( QWidget* );
+    explicit ColorGrabObject( QWidget* );
 
     //* event filter
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     Q_SIGNALS:
 
@@ -44,7 +44,7 @@ class ColorGrabObject: public QObject, public Counter
 
     protected Q_SLOTS:
 
-    void _grabColor( void );
+    void _grabColor();
 
     private:
 
@@ -52,7 +52,7 @@ class ColorGrabObject: public QObject, public Counter
     void _selectColorFromMouseEvent( QMouseEvent* );
 
     //* clear capture
-    void _clearCapture( void );
+    void _clearCapture();
 
     //* window grabber
     QDialog* captureWidget_ = nullptr;
