@@ -31,7 +31,7 @@
 #include <QMap>
 
 //* Color selection menu
-class ColorMenu: public QMenu, public Counter
+class ColorMenu: public QMenu, private Base::Counter<ColorMenu>
 {
 
     //* Qt meta object declaration
@@ -40,7 +40,7 @@ class ColorMenu: public QMenu, public Counter
     public:
 
     //* constructor
-    ColorMenu( QWidget* );
+    explicit ColorMenu( QWidget* );
 
     //*@name accessors
     //@{
@@ -49,7 +49,7 @@ class ColorMenu: public QMenu, public Counter
     Base::Color::Set colors() const;
 
     //* retrieves last selected color
-    QColor lastColor( void ) const
+    QColor lastColor() const
     { return lastColor_; }
 
     //@}
@@ -58,7 +58,7 @@ class ColorMenu: public QMenu, public Counter
     //@{
 
     //* clear
-    void reset( void )
+    void reset()
     { colors_.clear(); }
 
     //* add
@@ -74,28 +74,25 @@ class ColorMenu: public QMenu, public Counter
     protected:
 
     //* paint event (overloaded)
-    void paintEvent( QPaintEvent* event );
+    void paintEvent( QPaintEvent* event ) override;
 
     private Q_SLOTS:
 
     //* display colors when about to show
-    void _display( void );
+    void _display();
 
     //* adds a new color
-    void _new( void );
+    void _new();
 
     //* select the no color choice
     /** emits colorSelected with an invalid color */
-    void _default( void );
+    void _default();
 
     //* get color associated to action, emit ColorSelected
     void _selected( QAction* );
 
     private:
 
-    //* add a color
-    void add( QString );
-
     //* map colors to display pixmap
     using ColorMap = QMap<Base::Color, QBrush>;
 
