@@ -31,15 +31,15 @@ class ColorOptionListBox: public OptionListBox
     public:
 
     //* constructor
-    ColorOptionListBox( QWidget*, const QString& );
+    explicit ColorOptionListBox( QWidget*, const QString& );
 
     protected Q_SLOTS:
 
     //* add
-    virtual void _add( void );
+    void _add() override;
 
     //* edit
-    virtual void _edit( void );
+    void _edit() override;
 
 };
 
