@@ -24,7 +24,7 @@
 
 #include "Color.h"
 #include <QIcon>
-#include <QMap>
+#include <QHash>
 
 //* Color option model. Stores Color option information for display in lists
 class ColorOptionModel: public OptionModel
@@ -33,12 +33,12 @@ class ColorOptionModel: public OptionModel
     public:
 
     //* constructor
-    ColorOptionModel( QObject* parent = nullptr ):
+    explicit ColorOptionModel( QObject* parent = nullptr ):
         OptionModel( parent )
     {}
 
     // return job for a given index
-    virtual QVariant data( const QModelIndex&, int ) const;
+    QVariant data( const QModelIndex&, int ) const override;
 
     private:
 
@@ -46,7 +46,7 @@ class ColorOptionModel: public OptionModel
     using IconCache = QMap<Base::Color, QIcon>;
 
     //* icon cache
-    static IconCache& _icons( void );
+    static IconCache& _icons();
 
     //* icon matching color
     static QIcon _icon( const Base::Color& );
