@@ -35,15 +35,15 @@ class ContextMenu: public BaseContextMenu
     public:
 
     //* contructor
-    ContextMenu( QWidget* );
+    explicit ContextMenu( QWidget* );
 
     protected Q_SLOTS:
 
     //* add actions
-    void _hideActions( void );
+    void _hideActions();
 
     //* show actions
-    void _showActions( void );
+    void _showActions();
 
     //* raise request
     void _raise( const QPoint& );
