@@ -33,17 +33,17 @@
 //_________________________________________________
 CustomPixmap::CustomPixmap( const QSize& size, Flags flags ):
     #if QT_VERSION >= 0x050300
-    QPixmap( flags&HighDpi ? size*qApp->devicePixelRatio() : size ),
+    QPixmap( flags&Flag::HighDpi ? size*qApp->devicePixelRatio() : size ),
     #else
     QPixmap( size ),
     #endif
     Counter( "CustomPixmap" )
 {
     #if QT_VERSION >= 0x050300
-    if( flags&HighDpi ) setDevicePixelRatio( qApp->devicePixelRatio() );
+    if( flags&Flag::HighDpi ) setDevicePixelRatio( qApp->devicePixelRatio() );
     #endif
 
-    if( flags&Transparent ) fill( Qt::transparent );
+    if( flags&Flag::Transparent ) fill( Qt::transparent );
 
 }
 
@@ -67,8 +67,8 @@ CustomPixmap::CustomPixmap( const QString& file ):
         QIcon icon( QFileIconProvider().icon( file ) );
         if( icon.isNull() ) return;
 
-        const QSize iconSize( IconSize( IconSize::Maximum ) );
-        QPixmap out( icon.pixmap( iconSize ) );
+        const QSize iconSize( IconSize::get( IconSize::Maximum ) );
+        CustomPixmap out( icon.pixmap( iconSize ) );
         *this = out;
 
     }
@@ -87,18 +87,18 @@ CustomPixmap CustomPixmap::find( const QString& file )
 }
 
 //_________________________________________________
-CustomPixmap CustomPixmap::rotate( const CustomPixmap::Rotation& rotation )
+CustomPixmap CustomPixmap::rotated( const CustomPixmap::Rotation& rotation )
 {
-    if( rotation == None ) return *this;
+    if( rotation == Rotation::None ) return *this;
 
     const qreal dpiRatio( devicePixelRatio() );
 
-    CustomPixmap out( QSize( height(), width() ), Transparent );
+    CustomPixmap out( QSize( height(), width() ), Flag::Transparent );
     out.setDevicePixelRatio( dpiRatio );
     QPainter painter( &out );
 
     // rotate the painter
-    if( rotation == CounterClockwise )
+    if( rotation == Rotation::CounterClockwise )
     {
         painter.translate( 0, out.height()/dpiRatio );
         painter.rotate( -90 );
@@ -117,7 +117,7 @@ CustomPixmap CustomPixmap::transparent( qreal intensity ) const
 {
     if( isNull() ) return *this;
 
-    QPixmap out( *this );
+    CustomPixmap out( *this );
     QPainter painter( &out );
 
     QColor color( Qt::black );
@@ -133,7 +133,7 @@ CustomPixmap CustomPixmap::transparent( qreal intensity ) const
 }
 
 //_________________________________________________
-CustomPixmap CustomPixmap::desaturate( void ) const
+CustomPixmap CustomPixmap::desaturated() const
 {
     if( isNull() ) return *this;
 
@@ -161,43 +161,65 @@ CustomPixmap CustomPixmap::desaturate( void ) const
 }
 
 //_________________________________________________
-CustomPixmap CustomPixmap::merge( const CustomPixmap& pixmap, Corner corner ) const
+CustomPixmap CustomPixmap::colorized( const QColor& color ) const
+{
+
+    CustomPixmap out( desaturated() );
+    QPainter painter( &out );
+    painter.setCompositionMode(QPainter::CompositionMode_Screen);
+    painter.fillRect(rect(), color);
+
+    // copy alpha channel from source
+    painter.setCompositionMode( QPainter::CompositionMode_DestinationIn );
+    painter.drawPixmap( out.rect(), *this );
+
+    painter.end();
+    return out;
+}
+
+
+//_________________________________________________
+CustomPixmap CustomPixmap::merged( const QPixmap& pixmap, Corner corner ) const
 {
     if( isNull() ) return *this;
 
     QSize size( this->size()/devicePixelRatio() );
+
+    #if QT_VERSION >= 0x050300
     QSize pixmapSize( pixmap.size()/pixmap.devicePixelRatio() );
+    #else
+    QSize pixmapSize( pixmap.size() );
+    #endif
 
     QImage source( toImage() );
     QPainter painter( &source );
     switch( corner )
     {
 
-        case TOP_RIGHT:
+        case Corner::TopRight:
         painter.drawPixmap( QPoint( size.width()-pixmapSize.width(), 0 ), pixmap );
         break;
 
-        case BOTTOM_LEFT:
+        case Corner::BottomLeft:
         painter.drawPixmap( QPoint( 0, size.height()-pixmapSize.height() ), pixmap );
         break;
 
-        case BOTTOM_RIGHT:
+        case Corner::BottomRight:
         painter.drawPixmap( QPoint( size.width()-pixmapSize.width(), size.height()-pixmapSize.height() ), pixmap );
         break;
 
-        case CENTER:
+        case Corner::Center:
         painter.drawPixmap(  QPoint( (size.width()-pixmapSize.width())/2, (size.height()-pixmapSize.height())/2 ), pixmap );
         break;
 
-        default:
-        case TOP_LEFT:
+        case Corner::TopLeft:
         painter.drawPixmap( QPoint( 0, 0 ), pixmap );
         break;
 
     }
 
     painter.end();
-    return CustomPixmap().fromImage( source );
+    return CustomPixmap( fromImage( source ) );
 }
 
 //_________________________________________________
@@ -209,7 +231,7 @@ CustomPixmap CustomPixmap::highlighted( qreal opacity ) const
     opacity = qMin<qreal>( opacity, 1.0 );
 
     // compute mask
-    QPixmap mask( *this );
+    CustomPixmap mask( *this );
     {
         QPainter painter( &mask );
 
@@ -229,7 +251,7 @@ CustomPixmap CustomPixmap::highlighted( qreal opacity ) const
     if( opacity == 1.0 ) return mask;
 
     // apply highlight
-    QPixmap out( *this );
+    CustomPixmap out( *this );
     {
         QPainter painter( &out );
         painter.drawPixmap( QPoint(0,0), mask );
@@ -241,7 +263,7 @@ CustomPixmap CustomPixmap::highlighted( qreal opacity ) const
 }
 
 //______________________________________________________________________________________
-qreal CustomPixmap::devicePixelRatio( void ) const
+qreal CustomPixmap::devicePixelRatio() const
 {
     #if QT_VERSION >= 0x050300
     return QPixmap::devicePixelRatio();
