@@ -25,7 +25,7 @@
 #include <QPixmap>
 
 //* customized QPixmap to look for icon of given name in list of directory
-class CustomPixmap: public QPixmap, public Counter
+class CustomPixmap: public QPixmap, private Base::Counter<CustomPixmap>
 {
 
     public:
@@ -34,38 +34,45 @@ class CustomPixmap: public QPixmap, public Counter
     {
         Transparent = 0x1,
         HighDpi = 0x2,
-        AllFlags = 0x3
+        All = Transparent|HighDpi
     };
 
     Q_DECLARE_FLAGS( Flags, Flag )
 
     //* constructor
-    CustomPixmap( const QSize&, Flags flags = 0 );
+    explicit CustomPixmap( const QSize&, Flags flags = 0 );
 
     //* constructor
-    CustomPixmap( const QPixmap& pixmap ):
+    explicit CustomPixmap( const QPixmap& pixmap ):
         QPixmap( pixmap ),
         Counter( "CustomPixmap" )
     {}
 
     //* constructor
-    CustomPixmap( const QImage& image ):
-        Counter( "CustomPixmap" )
-    { *this = fromImage( image ); }
-
-    //* constructor
-    CustomPixmap( void ):
+    explicit CustomPixmap( QPixmap&& pixmap ):
+        QPixmap( std::move(pixmap) ),
         Counter( "CustomPixmap" )
     {}
 
     //* constructor
-    CustomPixmap( const QString& );
+    explicit CustomPixmap( const QImage& image ):
+        QPixmap( fromImage(image) ),
+        Counter( "CustomPixmap" )
+    {}
+
+    //* constructor
+    explicit CustomPixmap():
+        Counter( "CustomPixmap" )
+    {}
+
+    //* constructor
+    explicit CustomPixmap( const QString& );
 
     //* find first file matching name in list of path
-    virtual CustomPixmap find( const QString& );
+    CustomPixmap find( const QString& );
 
     //* rotation
-    enum Rotation
+    enum class Rotation
     {
         None,
         Clockwise,
@@ -73,36 +80,39 @@ class CustomPixmap: public QPixmap, public Counter
     };
 
     //* rotation
-    CustomPixmap rotate( const Rotation& value );
+    CustomPixmap rotated( const Rotation& value );
 
     //* returns a transparent pixmap
-    virtual CustomPixmap transparent( qreal ) const;
+    CustomPixmap transparent( qreal ) const;
 
     //* returns a desaturated pixmap
-    virtual CustomPixmap desaturate( void ) const;
+    CustomPixmap desaturated() const;
+
+    //* colorize
+    CustomPixmap colorized( const QColor& ) const;
 
     //* corner enumeration for merging pixmap
-    enum Corner
+    enum class Corner
     {
-        TOP_LEFT,
-        TOP_RIGHT,
-        BOTTOM_LEFT,
-        BOTTOM_RIGHT,
-        CENTER
+        TopLeft,
+        TopRight,
+        BottomLeft,
+        BottomRight,
+        Center
     };
 
     //* merge pixmap, using the specified corner as an anchor
-    virtual CustomPixmap merge( const CustomPixmap&, Corner corner = TOP_LEFT ) const;
+    CustomPixmap merged( const QPixmap&, Corner = Corner::TopLeft ) const;
 
     //* return highlighted pixmap
-    virtual CustomPixmap highlighted( qreal opacity ) const;
+    CustomPixmap highlighted( qreal opacity ) const;
 
     //* return highlighted (active) pixmap, build from the current
-    virtual CustomPixmap active( void ) const
+    CustomPixmap active() const
     { return highlighted( 0.2 ); }
 
     //* device pixel ratio
-    qreal devicePixelRatio( void ) const;
+    qreal devicePixelRatio() const;
 
     //* device pixel ratio
     void setDevicePixelRatio( qreal );
