@@ -28,7 +28,7 @@
 #include <QSpinBox>
 
 //* customized QSlider associated to a QSpinBox
-class CustomSlider: public QWidget, public Counter
+class CustomSlider: public QWidget, private Base::Counter<CustomSlider>
 {
 
     //* Qt meta object declaration
@@ -37,13 +37,13 @@ class CustomSlider: public QWidget, public Counter
     public:
 
     //* creator
-    CustomSlider( QWidget* parent );
+    explicit CustomSlider( QWidget* parent );
 
     //*@name accessors
     //@{
 
     //* retrieves value
-    int value( void ) const
+    int value() const
     { return slider_->value(); }
 
     //@}
@@ -89,15 +89,15 @@ class CustomSlider: public QWidget, public Counter
     protected:
 
     //* retrieve QSlider
-    QSlider& slider( void )
+    QSlider& slider()
     { return *slider_; }
 
     //* retrieve QSlider
-    const QSlider& slider( void ) const
+    const QSlider& slider() const
     { return *slider_; }
 
     //* retrieve QSpinBox
-    QSpinBox& spinBox( void )
+    QSpinBox& spinBox()
     { return *spinBox_; }
 
     private Q_SLOTS:
