@@ -18,15 +18,22 @@
 *******************************************************************************/
 
 #include "BaseMainWindow.h"
+#include "CppUtil.h"
 #include "CustomToolBar.h"
 #include "CustomToolButton.h"
 #include "Singleton.h"
 #include "XmlOptions.h"
 
 //_______________________________________________________________
-CustomToolBar::AreaMap& CustomToolBar::_toolbarAreas( void )
+CustomToolBar::AreaMap& CustomToolBar::_toolbarAreas()
 {
-    static AreaMap areas = _initializeAreas();
+    static AreaMap areas = Base::makeT<AreaMap>( {
+        { tr( "None" ), Qt::NoToolBarArea },
+        { tr( "Left" ), Qt::LeftToolBarArea },
+        { tr( "Right" ), Qt::RightToolBarArea },
+        { tr( "Top" ), Qt::TopToolBarArea },
+        { tr( "Bottom" ), Qt::BottomToolBarArea }
+    });
     return areas;
 }
 
@@ -45,7 +52,7 @@ CustomToolBar::CustomToolBar( const QString& title, QWidget* parent, const QStri
     _installActions();
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 }
 
@@ -107,7 +114,7 @@ void CustomToolBar::_toggleVisibility( bool state )
 }
 
 //_______________________________________________________________
-void CustomToolBar::_updateConfiguration( void )
+void CustomToolBar::_updateConfiguration()
 {
     Debug::Throw( "CustomToolBar::_updateConfiguration.\n" );
 
@@ -193,7 +200,7 @@ void CustomToolBar::_updateConfiguration( void )
 }
 
 //_______________________________________________________________
-void CustomToolBar::_installActions( void )
+void CustomToolBar::_installActions()
 {
     Debug::Throw( "CustomToolBar::_installActions.\n" );
     QString buffer;
@@ -210,15 +217,3 @@ void CustomToolBar::_installActions( void )
 
     connect( visibilityAction_, SIGNAL(toggled(bool)), SLOT(_toggleVisibility(bool)) );
 }
-
-//_______________________________________________________________
-CustomToolBar::AreaMap CustomToolBar::_initializeAreas( void )
-{
-    AreaMap out;
-    out.insert( tr( "None" ), Qt::NoToolBarArea );
-    out.insert( tr( "Left" ), Qt::LeftToolBarArea );
-    out.insert( tr( "Right" ), Qt::RightToolBarArea );
-    out.insert( tr( "Top" ), Qt::TopToolBarArea );
-    out.insert( tr( "Bottom" ), Qt::BottomToolBarArea );
-    return out;
-}
