@@ -28,11 +28,11 @@
 #include <QPaintEvent>
 #include <QShowEvent>
 #include <QToolBar>
-#include <QMap>
+#include <QHash>
 
 
 //* customized tool bar to handle position and visibility from Options
-class CustomToolBar: public QToolBar, public Counter
+class CustomToolBar: public QToolBar, private Base::Counter<CustomToolBar>
 {
 
     Q_OBJECT
@@ -40,17 +40,17 @@ class CustomToolBar: public QToolBar, public Counter
     public:
 
     //* constructor
-    CustomToolBar( const QString& = QString(), QWidget* = nullptr, const QString& = QString() );
+    explicit CustomToolBar( const QString& = QString(), QWidget* = nullptr, const QString& = QString() );
 
     // map toolbar area and name
-    using AreaMap = QMap< QString, Qt::ToolBarArea>;
+    using AreaMap = QHash<QString, Qt::ToolBarArea>;
 
     //*@name convenience
     //@{
     //* get area from name
     static Qt::ToolBarArea nameToArea( const QString& name )
     {
-        AreaMap::iterator iter = _toolbarAreas().find( name );
+        auto&& iter( _toolbarAreas().find( name ) );
         return iter == _toolbarAreas().end() ? (Qt::ToolBarArea) 0 :iter.value();
     }
 
@@ -58,10 +58,10 @@ class CustomToolBar: public QToolBar, public Counter
     static QString areaToName( const Qt::ToolBarArea& value )
     {
 
-        for( AreaMap::iterator iter = _toolbarAreas().begin(); iter != _toolbarAreas().end(); iter++ )
+        for( auto&& iter = _toolbarAreas().begin(); iter != _toolbarAreas().end(); iter++ )
         { if( iter.value() == value ) return iter.key(); }
 
-        return "";
+        return QString();
 
     }
     //@}
@@ -70,20 +70,20 @@ class CustomToolBar: public QToolBar, public Counter
     //@{
 
     //* lock from options
-    bool lockFromOptions( void ) const
+    bool lockFromOptions() const
     { return lockFromOptions_; }
 
     //* lock from options
-    bool sizeFromOptions( void ) const
+    bool sizeFromOptions() const
     { return sizeFromOptions_; }
 
     //* true if visible in menu
     /** the flag is ignored if parent is MainWindow */
-    bool appearsInMenu( void ) const
+    bool appearsInMenu() const
     { return appearsInMenu_; }
 
     //* visibility action
-    QAction& visibilityAction( void ) const
+    QAction& visibilityAction() const
     { return *visibilityAction_; }
 
     //@}
@@ -126,7 +126,7 @@ class CustomToolBar: public QToolBar, public Counter
         public:
 
         //* constructor
-        LocationComboBox( QWidget* parent, const QString& option ):
+        explicit LocationComboBox( QWidget* parent, const QString& option ):
             OptionComboBox( parent, option )
         {
             addItem( CustomToolBar::areaToName( Qt::TopToolBarArea ) );
@@ -140,31 +140,31 @@ class CustomToolBar: public QToolBar, public Counter
     protected:
 
     //* paint events
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //* show event
-    virtual void showEvent( QShowEvent* );
+    void showEvent( QShowEvent* ) override;
 
     //* hide event
-    virtual void hideEvent( QHideEvent* );
+    void hideEvent( QHideEvent* ) override;
 
     //* move event
-    virtual void moveEvent( QMoveEvent* );
+    void moveEvent( QMoveEvent* ) override;
 
     protected Q_SLOTS:
 
     //* toggle visibility
-    virtual void _toggleVisibility( bool );
+    void _toggleVisibility( bool );
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
     //* install actions
-    void _installActions( void );
+    void _installActions();
 
     //* assocated option name
     QString optionName_;
@@ -186,11 +186,8 @@ class CustomToolBar: public QToolBar, public Counter
     /** the flag is ignored if parent is MainWindow */
     bool appearsInMenu_ = false;
 
-    //* initialize area map
-    static AreaMap _initializeAreas( void );
-
     //* map name and toolbar are
-    static AreaMap& _toolbarAreas( void );
+    static AreaMap& _toolbarAreas();
 
 };
 
