@@ -27,7 +27,7 @@
 #include <QLabel>
 #include <QToolButton>
 
-class CustomToolButton: public QToolButton, public Counter
+class CustomToolButton: public QToolButton, private Base::Counter<CustomToolButton>
 {
 
     Q_OBJECT
@@ -35,7 +35,7 @@ class CustomToolButton: public QToolButton, public Counter
     public:
 
     //* default constructor
-    CustomToolButton( QWidget* = nullptr );
+    explicit CustomToolButton( QWidget* = nullptr );
 
     //* update configuration from options
     void setUpdateFromOptions( bool value )
@@ -45,17 +45,21 @@ class CustomToolButton: public QToolButton, public Counter
     bool rotate( const CustomPixmap::Rotation& );
 
     //* size hint
-    virtual QSize sizeHint( void ) const;
+    QSize sizeHint() const override;
+
+    //* size hint
+    QSize minimumSizeHint() const override
+    { return sizeHint(); }
 
     protected:
 
     //* painting
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     private Q_SLOTS:
 
     //* tool button configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
@@ -63,7 +67,7 @@ class CustomToolButton: public QToolButton, public Counter
     bool updateFromOptions_ = true;
 
     //* rotation
-    CustomPixmap::Rotation rotation_ = CustomPixmap::None;
+    CustomPixmap::Rotation rotation_ = CustomPixmap::Rotation::None;
 
 };
 
