@@ -23,13 +23,12 @@
 #include "Counter.h"
 
 #include <QMenu>
-#include <QDialog>
 
 class CounterDialog;
 class IconCacheDialog;
 
 //* some basic runtime debuging
-class DebugMenu: public QMenu, public Counter
+class DebugMenu: public QMenu, private Base::Counter<DebugMenu>
 {
 
     //* Qt meta object declaration
@@ -50,24 +49,24 @@ class DebugMenu: public QMenu, public Counter
     Q_DECLARE_FLAGS( Flags, Flag );
 
     //* constructor
-    DebugMenu( QWidget*, Flags = Default );
+    explicit DebugMenu( QWidget*, Flags = Flag::Default );
 
     //* needed to toggle visibility
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     private Q_SLOTS:
 
     //* print object counters
-    void _showCounterDialog( void );
+    void _showCounterDialog();
 
     //* icon cache dialog
-    void _showIconCacheDialog( void );
+    void _showIconCacheDialog();
 
     //* show system environment
-    void _showSystemEnvironment( void );
+    void _showSystemEnvironment();
 
     //* show options
-    void _showOptions( void );
+    void _showOptions();
 
     private:
 
