@@ -18,7 +18,7 @@
 *******************************************************************************/
 
 #include "DefaultFolders.h"
-
+#include "CppUtil.h"
 #include "Debug.h"
 #include "Util.h"
 
@@ -38,92 +38,84 @@
 #endif
 
 //__________________________________________________________________________
-DefaultFolders& DefaultFolders::get( void )
+DefaultFolders& DefaultFolders::get()
 {
     static DefaultFolders singleton_;
     return singleton_;
 }
 
 //__________________________________________________________________________
-DefaultFolders::DefaultFolders( void )
+DefaultFolders::DefaultFolders()
 {
 
-    // fill folder map
-    folders_.insert( Util::home(), Home );
+
+    // folder names map
+    names_ = Base::makeT<NameMap>(
+    {
+        { Type::Home, tr( "Home" ) },
+        { Type::Desktop, tr( "Desktop" ) },
+        { Type::Documents, tr( "Documents" ) },
+        { Type::Downloads, tr( "Downloads" ) },
+        { Type::Music, tr( "Music" ) },
+        { Type::Pictures, tr( "Pictures" ) },
+        { Type::Templates, tr( "Templates" ) },
+        { Type::Videos, tr( "Video" ) }
+    });
+
+
+    // icons map
+    iconNames_ = Base::makeT<IconMap>(
+    {
+        { Type::Home, "user-home.png" },
+        { Type::Desktop, "user-desktop" },
+        { Type::Documents, "folder-documents" },
+        { Type::Music, "folder-sound" }
+    });
+
+    // there are discrepencies for folder icon names between icon themes
+    // try to deal with major ones
+    if( QIcon::hasThemeIcon( "folder-download" ) ) iconNames_.insert( Type::Downloads, "folder-download" );
+    else iconNames_.insert( Type::Downloads, "folder-downloads" );
+
+    if( QIcon::hasThemeIcon( "folder-pictures" ) ) iconNames_.insert( Type::Pictures, "folder-pictures" );
+    else iconNames_.insert( Type::Pictures, "folder-image" );
+
+    if( QIcon::hasThemeIcon( "folder-videos" ) ) iconNames_.insert( Type::Videos, "folder-videos" );
+    else iconNames_.insert( Type::Videos, "folder-video" );
+
+    // path map
+    folders_.insert( Util::home(), Type::Home );
 
     #if QT_VERSION >= 0x050000
-    _insert( QStandardPaths::writableLocation( QStandardPaths::DesktopLocation ), Desktop );
-    _insert( QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation ), Documents );
-    _insert( QStandardPaths::writableLocation( QStandardPaths::MusicLocation ), Music );
-    _insert( QStandardPaths::writableLocation( QStandardPaths::PicturesLocation ), Pictures );
-    _insert( QStandardPaths::writableLocation( QStandardPaths::TempLocation ), Templates );
-    _insert( QStandardPaths::writableLocation( QStandardPaths::MoviesLocation ), Videos );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::DesktopLocation ), Type::Desktop );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation ), Type::Documents );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::MusicLocation ), Type::Music );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::PicturesLocation ), Type::Pictures );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::TempLocation ), Type::Templates );
+    _insert( QStandardPaths::writableLocation( QStandardPaths::MoviesLocation ), Type::Videos );
     #else
-    _insert( QDesktopServices::storageLocation( QDesktopServices::DesktopLocation ), Desktop );
-    _insert( QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation ), Documents );
-    _insert( QDesktopServices::storageLocation( QDesktopServices::MusicLocation ), Music );
-    _insert( QDesktopServices::storageLocation( QDesktopServices::PicturesLocation ), Pictures );
-    _insert( QDesktopServices::storageLocation( QDesktopServices::TempLocation ), Templates );
-    _insert( QDesktopServices::storageLocation( QDesktopServices::MoviesLocation ), Videos );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::DesktopLocation ), Type::Desktop );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation ), Type::Documents );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::MusicLocation ), Type::Music );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::PicturesLocation ), Type::Pictures );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::TempLocation ), Type::Templates );
+    _insert( QDesktopServices::storageLocation( QDesktopServices::MoviesLocation ), Type::Videos );
     #endif
 
     #if defined( Q_OS_LINUX )
     // use QSettings to get standard directories from XDG
     QSettings settings( QString( "%1/.config/user-dirs.dirs" ).arg( Util::home() ), QSettings::IniFormat );
     settings.sync();
-    _insert( settings.value( "XDG_DOWNLOAD_DIR", "$HOME/Downloads" ).value<QString>().replace( "$HOME", Util::home() ), Downloads );
+    _insert( settings.value( "XDG_DOWNLOAD_DIR", "$HOME/Downloads" ).value<QString>().replace( "$HOME", Util::home() ), Type::Downloads );
     #endif
 
 }
 
-//__________________________________________________________________________
-void DefaultFolders::initializeFolderNames( void )
-{
-    if( folderNamesInitialized_ ) return;
-
-    // fill icons map
-    names_.insert( Home, tr( "Home" ) );
-    names_.insert( Desktop, tr( "Desktop" ) );
-    names_.insert( Documents, tr( "Documents" ) );
-    names_.insert( Downloads, tr( "Downloads" ) );
-    names_.insert( Music, tr( "Music" ) );
-    names_.insert( Pictures, tr( "Pictures" ) );
-    names_.insert( Templates, tr( "Templates" ) );
-    names_.insert( Videos, tr( "Video" ) );
-
-    folderNamesInitialized_ = true;
-}
-
-//__________________________________________________________________________
-void DefaultFolders::initializeIconNames( void )
-{
-    if( iconNamesInitialized_ ) return;
-
-    // fill icons map
-    iconNames_.insert( Home, "user-home.png" );
-    iconNames_.insert( Desktop, "user-desktop" );
-    iconNames_.insert( Documents, "folder-documents" );
-    iconNames_.insert( Music, "folder-sound" );
-
-    // there are discrepencies for folder icon names between icon themes
-    // try to deal with major ones
-    if( QIcon::hasThemeIcon( "folder-download" ) ) iconNames_.insert( Downloads, "folder-download" );
-    else iconNames_.insert( Downloads, "folder-downloads" );
-
-    if( QIcon::hasThemeIcon( "folder-pictures" ) ) iconNames_.insert( Pictures, "folder-pictures" );
-    else iconNames_.insert( Pictures, "folder-image" );
-
-    if( QIcon::hasThemeIcon( "folder-videos" ) ) iconNames_.insert( Videos, "folder-videos" );
-    else iconNames_.insert( Videos, "folder-video" );
-
-    iconNamesInitialized_ = true;
-}
-
 //__________________________________________________________________________
 DefaultFolders::Type DefaultFolders::type( const File& file ) const
 {
-    auto iter( allFolders_.find( file ) );
-    return iter == allFolders_.end() ? Unknown:iter.value();
+    auto&& iter( allFolders_.find( file ) );
+    return iter == allFolders_.end() ? Type::Unknown:iter.value();
 }
 
 //__________________________________________________________________________
@@ -152,8 +144,8 @@ QString DefaultFolders::iconName( Type type ) const
 //__________________________________________________________________________
 void DefaultFolders::_insert( const QStringList& keys, Type value )
 {
-    foreach( auto key, keys ) allFolders_.insert( key, value );
-    if( !keys.isEmpty() ) folders_.insert( keys.front(), value );
+    for( const auto& key:keys ) allFolders_.insert( File( key ), value );
+    if( !keys.isEmpty() ) folders_.insert( File( keys.front() ), value );
 }
 
 //__________________________________________________________________________
@@ -161,7 +153,7 @@ void DefaultFolders::_insert( const QString& key, Type value )
 {
     if( !key.isEmpty() )
     {
-        allFolders_.insert( key, value );
-        folders_.insert( key, value );
+        allFolders_.insert( File( key ), value );
+        folders_.insert( File( key ), value );
     }
 }
