@@ -22,6 +22,8 @@
 
 #include "File.h"
 
+#include "CppUtil.h"
+
 #include <QHash>
 #include <QMap>
 #include <QObject>
@@ -34,13 +36,13 @@ class DefaultFolders: public QObject
     public:
 
     //* return singleton
-    static DefaultFolders& get( void );
+    static DefaultFolders& get();
 
     //*@name accessors
     //@{
 
     //* folder type
-    enum Type
+    enum class Type
     {
         Unknown,
         Home,
@@ -56,7 +58,7 @@ class DefaultFolders: public QObject
     //* folders
     using FolderMap = QMap<File, Type>;
     using FolderMapIterator = QMapIterator<File, Type>;
-    const FolderMap& folders( void ) const
+    const FolderMap& folders() const
     { return folders_; }
 
     //* return type for a given folder
@@ -73,18 +75,6 @@ class DefaultFolders: public QObject
 
     //@}
 
-
-    //*@name modifiers
-    //@{
-
-    //* initialize folder names
-    void initializeFolderNames( void );
-
-    //* initialize icon names
-    void initializeIconNames( void );
-
-    //@}
-
     protected:
 
     //* insert folder in map
@@ -96,7 +86,7 @@ class DefaultFolders: public QObject
     private:
 
     //* constructor
-    DefaultFolders( void );
+    explicit DefaultFolders();
 
     //* map folder and type
     /* this list keeps only one folder per type */
@@ -108,12 +98,10 @@ class DefaultFolders: public QObject
     FolderHash allFolders_;
 
     //* folder names
-    bool folderNamesInitialized_ = false;
     using NameMap = QHash<Type, QString>;
     NameMap names_;
 
     //* icon names
-    bool iconNamesInitialized_ = false;
     using IconMap = QHash<Type, QString>;
     IconMap iconNames_;
 
