@@ -34,26 +34,26 @@ class DetailsDialog: public CustomDialog
     public:
 
     //* constructor
-    DetailsDialog( QWidget* parent,
+    explicit DetailsDialog( QWidget* parent,
         CustomDialog::Flags flags = CustomDialog::Flags( OkButton | CancelButton ),
         Qt::WindowFlags WindowFlags = 0 ):
         CustomDialog( parent, flags, WindowFlags )
     {}
 
     //* set text details
-    virtual void setDetails( const QString& );
+    void setDetails( const QString& );
 
     //* set details widget
-    virtual void setDetails( QWidget* );
+    void setDetails( QWidget* );
 
     public Q_SLOTS:
 
     //* show details
-    void showDetails( void )
+    void showDetails()
     { toggleDetails( true ); }
 
     //* hide details
-    void hideDetails( void )
+    void hideDetails()
     { toggleDetails( false ); }
 
     //* toggle details
