@@ -33,8 +33,17 @@
 #include <QLayout>
 #include <QPixmap>
 
+#include <memory>
+
+// forward declaration
+namespace Private
+{
+    class LocalDockWidget;
+    class LocalWidget;
+}
+
 //* detachable generic panel
-class DockPanel: public QWidget, public Counter
+class DockPanel: public QWidget, private Base::Counter<DockPanel>
 {
 
     //* Qt meta object declaration
@@ -43,20 +52,19 @@ class DockPanel: public QWidget, public Counter
     public:
 
     //* constructor
-    DockPanel( QWidget* parent );
+    explicit DockPanel( QWidget* parent );
 
-    //* destructor
-    virtual ~DockPanel();
+    //* destructor (needed because of unique_ptr member
+    ~DockPanel() override;
 
     //*@name accessors
     //@{
 
     //* get panel (to add contents)
-    virtual QWidget& panel( void )
-    { return *panel_; }
+    QWidget& panel();
 
     //* true if detached
-    bool isDetached( void ) const;
+    bool isDetached() const;
 
     //@}
 
@@ -67,11 +75,7 @@ class DockPanel: public QWidget, public Counter
     void setOptionName( QString );
 
     //* set detachable group panel title
-    void setTitle( const QString& title )
-    {
-        dock_->setWindowTitle( title );
-        dockTitleLabel_->setText( title );
-    }
+    void setTitle( QString );
 
     //@}
 
@@ -81,23 +85,15 @@ class DockPanel: public QWidget, public Counter
     void attached( bool state );
 
     //* emitted when panel is attached
-    void attached( void );
+    void attached();
 
     //* emitted when panel is detached
-    void detached( void );
-
-    //* visibility changed
-    void visibilityChanged( bool );
+    void detached();
 
     protected Q_SLOTS:
 
     //* toggle dock
-    virtual void _toggleDock( void );
-
-    protected:
-
-    //* hide event
-    virtual void hideEvent( QHideEvent* );
+    void _toggleDock();
 
     private:
 
@@ -108,10 +104,10 @@ class DockPanel: public QWidget, public Counter
     QLabel* dockTitleLabel_ = nullptr;
 
     //* dock
-    QWidget* dock_ = nullptr;
+    std::unique_ptr<Private::LocalDockWidget> dock_;
 
     //* contents panel
-    QWidget* panel_ = nullptr;
+    Private::LocalWidget* panel_ = nullptr;
 
 };
 
