@@ -30,25 +30,36 @@
 //* local dock widget
 namespace Private
 {
-    class LocalDockWidget: public QWidget, public Counter
+    class LocalDockWidget: public QWidget, private Base::Counter<LocalDockWidget>
     {
         Q_OBJECT
 
         public:
 
         //* constructor
-        LocalDockWidget( QWidget* );
+        explicit LocalDockWidget( QWidget* );
+
+        Q_SIGNALS:
+
+        //* emitted when close event is received
+        void closeEventRequest();
 
         protected:
 
         //* paint event
-        virtual void paintEvent( QPaintEvent* );
+        void paintEvent( QPaintEvent* ) override;
+
+        //* closeEvent
+        void closeEvent( QCloseEvent* event ) override;
+
+        //* resize event
+        void resizeEvent( QResizeEvent* ) override;
 
     };
 
 
     //* local widget
-    class LocalWidget: public QFrame, public Counter
+    class LocalWidget: public QFrame, private Base::Counter<LocalWidget>
     {
 
         Q_OBJECT
@@ -56,17 +67,17 @@ namespace Private
         public:
 
         //* constructor
-        LocalWidget( QWidget* );
+        explicit LocalWidget( QWidget* );
 
         //*@name accessors
         //@{
 
         //* true if attached
-        bool isDetached( void ) const
+        bool isDetached() const
         { return widgetDragMonitor_.isEnabled(); }
 
         //* widget drag monitor
-        const WidgetDragMonitor& widgetDragMonitor( void ) const
+        const WidgetDragMonitor& widgetDragMonitor() const
         { return widgetDragMonitor_; }
 
         //@}
@@ -75,7 +86,7 @@ namespace Private
         //@{
 
         //* widget drag monitor
-        WidgetDragMonitor& widgetDragMonitor( void )
+        WidgetDragMonitor& widgetDragMonitor()
         { return widgetDragMonitor_; }
 
         //* option name (needed to store sticky and stays-on-top state)
@@ -95,40 +106,34 @@ namespace Private
         //@{
 
         //* detach action
-        QAction& detachAction( void ) const
+        QAction& detachAction() const
         { return *detachAction_; }
 
         //* stay on top
-        QAction& staysOnTopAction( void ) const
+        QAction& staysOnTopAction() const
         { return *staysOnTopAction_; }
 
         //* widget is hidden from taskbar
-        QAction& stickyAction( void ) const
+        QAction& stickyAction() const
         { return *stickyAction_; }
 
         //@}
 
         protected:
 
-        //* closeEvent
-        virtual void closeEvent( QCloseEvent* event );
-
-        //* resize event
-        virtual void resizeEvent( QResizeEvent* );
-
         //* update actions
-        void _updateActions( void );
+        void _updateActions();
 
         //* true if option name is set
-        bool _hasOptionName( void ) const
+        bool _hasOptionName() const
         { return !(_stickyOptionName().isEmpty() || _staysOnTopOptionName().isEmpty() ); }
 
         //* option name
-        const QString& _stickyOptionName( void ) const
+        const QString& _stickyOptionName() const
         { return stickyOptionName_; }
 
         //* option name
-        const QString& _staysOnTopOptionName( void ) const
+        const QString& _staysOnTopOptionName() const
         { return staysOnTopOptionName_; }
 
         protected Q_SLOTS:
@@ -145,12 +150,12 @@ namespace Private
         private Q_SLOTS:
 
         //* configuration
-        void _updateConfiguration( void );
+        void _updateConfiguration();
 
         private:
 
         //* actions
-        void _installActions( void );
+        void _installActions();
 
         //*@name actions
         //@{
