@@ -26,25 +26,6 @@
 #include <QLayout>
 #include <QStyle>
 
-//_________________________________________________________
-namespace Private
-{
-    class TitleBarWidget: public QWidget
-    {
-        public:
-
-        //* minimum size hint
-        virtual QSize minimumSizeHint( void ) const
-        { return QSize( 1, 2 ); }
-
-        //* minimum size hint
-        virtual QSize sizeHint( void ) const
-        { return minimumSizeHint(); }
-
-    };
-
-}
-
 //_________________________________________________________
 DockWidget::DockWidget(const QString& title, QWidget* parent, const QString& optionName ):
     QDockWidget(title, parent ),
@@ -60,10 +41,10 @@ DockWidget::DockWidget(const QString& title, QWidget* parent, const QString& opt
     _installActions();
 
     // setup container
-    MainWidget* main = new MainWidget();
-    main->windowMonitor().setMode( WidgetMonitor::Size );
+    Private::MainWidget* main = new Private::MainWidget();
+    main->windowMonitor().setMode( WidgetMonitor::Mode::Size );
     main->windowMonitor().setOptionName( optionName );
-    main->setLayout( new QVBoxLayout() );
+    main->setLayout( new QVBoxLayout );
     main->layout()->setMargin(0);
     main->layout()->setSpacing(0);
     setWidget( main );
@@ -72,7 +53,7 @@ DockWidget::DockWidget(const QString& title, QWidget* parent, const QString& opt
     setUseScrollArea( false );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
@@ -90,7 +71,7 @@ void DockWidget::setUseScrollArea( bool value )
     if( useScrollArea_ )
     {
 
-        ContainerScrollArea* container = new ContainerScrollArea( widget() );
+        Private::ContainerScrollArea* container = new Private::ContainerScrollArea( widget() );
 
         if( mainWidget_ ) container->setWidget( mainWidget_ );
         if( container_ )
@@ -104,7 +85,7 @@ void DockWidget::setUseScrollArea( bool value )
 
     } else {
 
-        ContainerWidget* container = new ContainerWidget( widget() );
+        Private::ContainerWidget* container = new Private::ContainerWidget( widget() );
         if( mainWidget_ )
         {
             mainWidget_->setParent( container );
@@ -167,7 +148,7 @@ void DockWidget::setMainWidget( QWidget* mainWidget )
     if( container_ )
     {
 
-        if( useScrollArea_ ) static_cast<ContainerScrollArea*>( container_ )->setWidget( mainWidget_ );
+        if( useScrollArea_ ) qobject_cast<Private::ContainerScrollArea*>( container_ )->setWidget( mainWidget_ );
         else {
 
             mainWidget_->setParent( container_ );
@@ -186,7 +167,7 @@ void DockWidget::setAutoHideTitleBar( bool value )
 }
 
 //_________________________________________________________
-void DockWidget::_updateTitleBarWidget( void )
+void DockWidget::_updateTitleBarWidget()
 {
     Debug::Throw( "DockWidget::_updateTitleBarWidget.\n" );
 
@@ -223,7 +204,7 @@ void DockWidget::_toggleVisibility( bool state )
 }
 
 //_______________________________________________________________
-void DockWidget::_updateConfiguration( void )
+void DockWidget::_updateConfiguration()
 {
     Debug::Throw( "DockWidget::_updateConfiguration.\n" );
 
@@ -247,7 +228,7 @@ void DockWidget::_updateConfiguration( void )
 }
 
 //_______________________________________________________________
-void DockWidget::_installActions( void )
+void DockWidget::_installActions()
 {
     Debug::Throw( "DockWidget::_installActions.\n" );
 
