@@ -33,17 +33,17 @@ class DockWidget: public QDockWidget
     public:
 
     //* constructor
-    DockWidget( const QString&, QWidget* = nullptr, const QString& = QString() );
+    explicit DockWidget( const QString&, QWidget* = nullptr, const QString& = QString() );
 
     //*@name accessors
     //@{
 
     //* lock
-    virtual bool isLocked( void ) const
+    bool isLocked() const
     { return locked_; }
 
     //* visibility action
-    QAction& visibilityAction( void ) const
+    QAction& visibilityAction() const
     { return *visibilityAction_; }
 
     //@}
@@ -55,7 +55,7 @@ class DockWidget: public QDockWidget
     void setUseScrollArea( bool );
 
     //* lock
-    virtual void setLocked( bool );
+    void setLocked( bool );
 
     //* set main widget
     void setMainWidget( QWidget* );
@@ -68,20 +68,20 @@ class DockWidget: public QDockWidget
     protected Q_SLOTS:
 
     //* toggle visibility
-    virtual void _toggleVisibility( bool );
+    void _toggleVisibility( bool );
 
     //* update title bar
-    virtual void _updateTitleBarWidget( void );
+    void _updateTitleBarWidget();
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
     //* install actions
-    void _installActions( void );
+    void _installActions();
 
     //* assocated option name
     QString optionName_;
