@@ -26,7 +26,7 @@
 #include <QWidget>
 
 //* used to install
-class DragMonitor: public QObject, public Counter
+class DragMonitor: public QObject, private Base::Counter<DragMonitor>
 {
 
     Q_OBJECT
@@ -34,21 +34,21 @@ class DragMonitor: public QObject, public Counter
     public:
 
     //* constructor
-    DragMonitor( QWidget* );
+    explicit DragMonitor( QWidget* );
 
     //*@name accessors
     //@{
 
     //* enabled
-    bool isDragEnabled( void ) const
+    bool isDragEnabled() const
     { return dragEnabled_; }
 
     //* in progress
-    bool isDragInProgress( void ) const
+    bool isDragInProgress() const
     { return dragInProgress_; }
 
     //* position
-    QPoint dragOrigin( void ) const
+    QPoint dragOrigin() const
     { return dragOrigin_; }
 
     //@}
@@ -66,7 +66,7 @@ class DragMonitor: public QObject, public Counter
     //@}
 
     //* event filter
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     Q_SIGNALS:
 
