@@ -133,17 +133,17 @@ void ElidedLabel::resizeEvent( QResizeEvent* e )
 }
 
 //___________________________________________________
-void ElidedLabel::updateElidedText( void )
+void ElidedLabel::updateElidedText()
 {
     if( fullText_.isEmpty() ) return;
 
-    QFontMetrics fm(fontMetrics());
+    auto fontMetrics( this->fontMetrics() );
     int labelWidth = size().width();
 
     QStringList elidedLines;
     bool elided = false;
 
-    foreach( const QString& fullLine, fullText_.split( '\n' ) )
+    for( const auto& fullLine:fullText_.split( '\n' ) )
     {
 
         // attempt at dealing with rich text
@@ -176,11 +176,11 @@ void ElidedLabel::updateElidedText( void )
             default: break;
         }
 
-        int lineWidth = fm.width(line);
+        int lineWidth = fontMetrics.width(line);
         if (lineWidth > labelWidth)
         {
             elided = true;
-            elidedLines << prefix + fm.elidedText(line, elideMode_, labelWidth ) + suffix;
+            elidedLines << prefix + fontMetrics.elidedText(line, elideMode_, labelWidth ) + suffix;
 
         } else {
 
