@@ -26,7 +26,7 @@
 #include <QResizeEvent>
 
 //* label with automatically elided text
-class ElidedLabel: public QLabel, public Counter
+class ElidedLabel: public QLabel, private Base::Counter<ElidedLabel>
 {
 
     Q_OBJECT
@@ -34,20 +34,20 @@ class ElidedLabel: public QLabel, public Counter
     public:
 
     //* constructor
-    ElidedLabel( QWidget* = nullptr );
+    explicit ElidedLabel( QWidget* = nullptr );
 
     //* constructor
-    ElidedLabel( const QString&, QWidget* = nullptr);
+    explicit ElidedLabel( const QString&, QWidget* = nullptr);
 
     //*@name accessors
     //@{
 
     //* elision mode
-    Qt::TextElideMode elideMode( void ) const
+    Qt::TextElideMode elideMode() const
     { return elideMode_; }
 
     //* text
-    QString text( void )
+    QString text()
     { return fullText_; }
 
     //@}
@@ -71,21 +71,21 @@ class ElidedLabel: public QLabel, public Counter
     //@}
 
     //* minimum size hint
-    virtual QSize minimumSizeHint( void ) const;
+    QSize minimumSizeHint() const override;
 
     //* size hint
-    virtual QSize sizeHint( void ) const;
+    QSize sizeHint() const override;
 
     protected:
 
     //* mouse release
-    void mouseReleaseEvent(QMouseEvent *);
+    void mouseReleaseEvent(QMouseEvent *) override;
 
     //* resize event
-    virtual void resizeEvent( QResizeEvent* );
+    void resizeEvent( QResizeEvent* ) override;
 
     //* update text based on object size
-    void updateElidedText( void );
+    void updateElidedText();
 
     private:
 
