@@ -21,6 +21,7 @@
 *******************************************************************************/
 
 #include "Counter.h"
+#include "File.h"
 
 #include <QFileDialog>
 #include <QObject>
@@ -28,30 +29,30 @@
 #include <QStringList>
 
 //* customized file selection dialog, to store last selected directory
-class FileDialog: public QObject, public Counter
+class FileDialog: public QObject, private Base::Counter<FileDialog>
 {
 
     public:
 
     //* creator
-    FileDialog( QWidget* parent );
+    explicit FileDialog( QWidget* parent );
 
     //* open mode
-    virtual FileDialog& setAcceptMode( const QFileDialog::AcceptMode mode )
+    FileDialog& setAcceptMode( const QFileDialog::AcceptMode mode )
     {
         acceptMode_ = mode;
         return *this;
     }
 
     //* file mode
-    virtual FileDialog& setFileMode( const QFileDialog::FileMode mode )
+    FileDialog& setFileMode( const QFileDialog::FileMode mode )
     {
         fileMode_ = mode;
         return *this;
     }
 
     //* caption
-    virtual FileDialog& setCaption( const QString& caption )
+    FileDialog& setCaption( const QString& caption )
     {
         caption_ = caption;
         return *this;
@@ -59,60 +60,60 @@ class FileDialog: public QObject, public Counter
 
     //* default file/directory
     /** it is used as a starting selection when file dialog is opened */
-    virtual FileDialog& selectFile( const QString& file );
+    FileDialog& selectFile( const File& file );
 
     //* filter
-    virtual FileDialog& setFilter( const QString& filter )
+    FileDialog& setFilter( const QString& filter )
     {
         filter_ = filter;
         return *this;
     }
 
     //* options
-    virtual FileDialog& setOptions( const QFileDialog::Options& options )
+    FileDialog& setOptions( const QFileDialog::Options& options )
     {
         options_ = options;
         return *this;
     }
 
     //* get file
-    virtual QString getFile( void );
+    File getFile();
 
     //* get list of files
-    virtual QStringList getFiles( void );
+    File::List getFiles();
 
     //* reference to statically scoped working directory
-    virtual const QString& workingDirectory() const
+    const File& workingDirectory() const
     { return _workingDirectory(); }
 
     protected:
 
     //* reference to statically scoped working directory
-    static QString& _workingDirectory();
+    static File& _workingDirectory();
 
     //* accept mode
-    virtual QFileDialog::AcceptMode _acceptMode( void ) const
+    QFileDialog::AcceptMode _acceptMode() const
     { return acceptMode_; }
 
     //* file mode
-    virtual QFileDialog::FileMode _fileMode( void ) const
+    QFileDialog::FileMode _fileMode() const
     { return fileMode_; }
 
     //* caption
-    virtual const QString& _caption( void ) const
+    const QString& _caption() const
     { return caption_; }
 
     //* selected file
     /** it is used as a starting selection when file dialog is opened */
-    virtual const QString& _selectedFile( void ) const
+    const File& _selectedFile() const
     { return selectedFile_; }
 
     //* filter
-    virtual const QString& _filter( void ) const
+    const QString& _filter() const
     { return filter_; }
 
     //* options
-    virtual QFileDialog::Options _options( void ) const
+    QFileDialog::Options _options() const
     { return options_; }
 
     private:
@@ -127,7 +128,7 @@ class FileDialog: public QObject, public Counter
     QString caption_;
 
     //* default file
-    QString selectedFile_;
+    File selectedFile_;
 
     //* filter
     QString filter_;
