@@ -17,6 +17,7 @@
 *
 *******************************************************************************/
 
+#include "CppUtil.h"
 #include "Debug.h"
 #include "FileList.h"
 #include "File.h"
@@ -30,18 +31,18 @@ FileList::FileList( QObject* parent ):
     thread_( this )
 {
     // thread connection
-    connect( &thread_, SIGNAL(recordsAvailable(const FileRecord::List&,bool)), this, SLOT(_processRecords(const FileRecord::List&,bool)) );
+    connect( &thread_, SIGNAL(recordsAvailable(const FileRecord::List&,bool)), SLOT(_processRecords(const FileRecord::List&,bool)) );
 }
 
 //_______________________________________________
 bool FileList::contains( const File& file ) const
-{ return std::find_if( _records().begin(), _records().end(), FileRecord::SameFileFTor( file ) ) != _records().end(); }
+{ return std::find_if( records_.begin(), records_.end(), FileRecord::SameFileFTor( file ) ) != records_.end(); }
 
 //_______________________________________________
 void FileList::remove( const File& file )
 {
     Debug::Throw() << "FileList::remove - " << file << endl;
-    _records().erase(std::remove_if( _records().begin(), _records().end(), FileRecord::SameFileFTor( file ) ), _records().end() );
+    records_.erase(std::remove_if( records_.begin(), records_.end(), FileRecord::SameFileFTor( file ) ), records_.end() );
     return;
 }
 
@@ -50,33 +51,33 @@ void FileList::set( const FileRecord::List& records )
 {
 
     Debug::Throw( "FileList::set.\n" );
-    _records() = records;
+    records_ = records;
     emit contentsChanged();
 
 }
 
 //___________________________________________________
-File::List FileList::files( void ) const
+File::List FileList::files() const
 {
     Debug::Throw( "FileList::files.\n" );
 
-    FileRecord::List records( _truncatedList( _records() ) );
+    FileRecord::List records( _truncatedList( records_ ) );
     File::List out;
-    foreach( const FileRecord& record, records )
+    for( const auto& record:records )
     { out << record.file(); }
 
     return out;
 }
 
 //_______________________________________________
-FileRecord FileList::lastValidFile( void )
+FileRecord FileList::lastValidFile()
 {
 
     Debug::Throw( "FileList::lastValidFile.\n" );
 
     // sort list
-    std::sort( _records().begin(), _records().end(), FileRecord::FirstOpenFTor() );
-    FileRecord::ListIterator iter( _records() );
+    std::sort( records_.begin(), records_.end(), FileRecord::FirstOpenFTor() );
+    FileRecord::ListIterator iter( records_ );
     iter.toBack();
     while( iter.hasPrevious() )
     {
@@ -89,12 +90,12 @@ FileRecord FileList::lastValidFile( void )
 }
 
 //_______________________________________________
-void FileList::checkValidFiles( void )
+void FileList::checkValidFiles()
 {
     Debug::Throw( "FileList::checkValidFiles.\n" );
     if( !check() ) return;
     if( thread_.isRunning() ) return;
-    thread_.setRecords( _records() );
+    thread_.setRecords( records_ );
     thread_.start();
 }
 
@@ -103,12 +104,11 @@ void FileList::_processRecords( const FileRecord::List& records, bool hasInvalid
 {
 
     // set file records validity
-    FileRecord::List& currentRecords( _records() );
-    for( FileRecord::List::iterator iter = currentRecords.begin(); iter != currentRecords.end(); ++iter )
+    for( auto& record:records_ )
     {
-        FileRecord::List::const_iterator found = std::find_if( records.begin(), records.end(), FileRecord::SameFileFTor( iter->file() ) );
+        FileRecord::List::const_iterator found = std::find_if( records.begin(), records.end(), FileRecord::SameFileFTor( record.file() ) );
         if( found == records.end() ) continue;
-        iter->setValid( found->isValid() );
+        record.setValid( found->isValid() );
     }
 
     _setCleanEnabled( hasInvalidRecords );
@@ -118,37 +118,37 @@ void FileList::_processRecords( const FileRecord::List& records, bool hasInvalid
 }
 
 //___________________________________________________
-void FileList::clean( void )
+void FileList::clean()
 {
     Debug::Throw( "FileList::clean" );
 
     if( !check() )
     {
-        _records().clear();
+        records_.clear();
         return;
     }
 
     // remove invalid files
-    _records().erase(
-        std::remove_if( _records().begin(), _records().end(), FileRecord::InvalidFTor() ),
-        _records().end() );
+    records_.erase(
+        std::remove_if( records_.begin(), records_.end(), FileRecord::InvalidFTor() ),
+        records_.end() );
 
     return;
 }
 
 //___________________________________________________
-void FileList::clear( void )
+void FileList::clear()
 {
     Debug::Throw( "FileList::clear" );
-    _records().clear();
+    records_.clear();
     return;
 }
 
 //_______________________________________________
-void FileList::_setMaxSize( int value )
+void FileList::setMaxSize( int value )
 {
 
-    Debug::Throw( "FileList::_setMaxSize.\n" );
+    Debug::Throw( "FileList::setMaxSize.\n" );
     maxSize_ = value;
     return;
 
@@ -164,14 +164,14 @@ FileRecord& FileList::_add(
     // do not add empty files
     Q_ASSERT( !record.file().isEmpty() );
 
-    FileRecord::List::iterator iter = std::find_if( _records().begin(), _records().end(), FileRecord::SameFileFTor( record.file() ) );
-    if( iter != _records().end() )
+    auto iter = std::find_if( records_.begin(), records_.end(), FileRecord::SameFileFTor( record.file() ) );
+    if( iter != records_.end() )
     {
 
         Debug::Throw() << "FileList::_add - updating: " << record.file() << endl;
         if( updateTimeStamp && iter->time() != record.time() )
         {
-            iter->setTime( qMax( iter->time(), record.time() ) );
+            iter->setTime( TimeStamp(qMax( iter->time(), record.time() ) ) );
             if( emitSignal ) emit contentsChanged();
         }
 
@@ -180,10 +180,10 @@ FileRecord& FileList::_add(
     } else {
 
         Debug::Throw() << "FileList::_add - adding: " << record.file() << endl;
-        _records() << record;
+        records_ << record;
 
         if( emitSignal ) emit contentsChanged();
-        return _records().back();
+        return records_.back();
 
     }
 
@@ -202,7 +202,7 @@ FileRecord::List FileList::_truncatedList( FileRecord::List records ) const
 
             while( int(records.size()) > maxSize_ )
             {
-                FileRecord::List::iterator iter( std::find_if( records.begin(), records.end(), FileRecord::InvalidFTor() ) );
+                auto iter( std::find_if( records.begin(), records.end(), FileRecord::InvalidFTor() ) );
                 if( iter != records.end() ) records.erase( iter );
                 else break;
             }
