@@ -30,7 +30,7 @@
 #include <QObject>
 
 //* handles list of files saved into resource file for later reopening
-class FileList: public QObject, public Counter
+class FileList: public QObject, private Base::Counter<FileList>
 {
 
     //* Qt meta object declaration
@@ -39,99 +39,113 @@ class FileList: public QObject, public Counter
     public:
 
     //* constructor
-    FileList( QObject* );
+    explicit FileList( QObject* );
+
+    //*@name accessors
+    //@{
 
     //* returns true if file is found in list
-    virtual bool contains( const File& ) const;
+    bool contains( const File& ) const;
+
+    //* empty
+    bool isEmpty() const
+    { return records_.isEmpty(); }
+
+    //* file list size
+    int size() const
+    { return records_.size(); }
+
+    //* file list max size
+    int maxSize() const
+    { return maxSize_; }
+
+    //* all records
+    FileRecord::List records() const
+    { return _truncatedList( records_ ); }
+
+    //* all files
+    File::List files() const;
+
+    //* returns true if file list can be cleaned
+    bool cleanEnabled() const
+    { return (check()) ? cleanEnabled_ : !isEmpty(); }
+
+    //* check flag
+    bool check() const
+    { return check_; }
+
+    //@}
+
+    //*@name modifiers
+    //@{
 
     //* remove file from database
-    virtual void remove( const File& );
+    void remove( const File& );
 
     //* get filerecord associated to a name
     /** creates new fileRecord if not found */
-    virtual FileRecord& get( const File& file )
+    FileRecord& get( const File& file )
     { return _add( FileRecord( file ), false ); }
 
-    //* empty
-    virtual bool isEmpty( void ) const
-    { return _records().isEmpty(); }
-
-    //* gets file list size
-    virtual int size( void ) const
-    { return _records().size(); }
-
-    //* all records
-    FileRecord::List records( void ) const
-    { return _truncatedList( _records() ); }
-
     //* set record
-    virtual void set( const FileRecord::List& );
-
-    //* all files
-    File::List files( void ) const;
+    void set( const FileRecord::List& );
 
     //* get last valid file
-    virtual FileRecord lastValidFile( void );
-
-    //* returns true if file list can be cleaned
-    virtual bool cleanEnabled( void ) const
-    { return (check()) ? cleanEnabled_ : !isEmpty(); }
+    FileRecord lastValidFile();
 
     //* clean files. Remove either invalid or all files, depending on check_
-    virtual void clean( void );
+    void clean();
 
     //* clear files. Remove all
-    virtual void clear( void );
-
-    //* check flag
-    virtual bool check( void ) const
-    { return check_; }
+    void clear();
 
     //* check_ flag
-    virtual void setCheck( bool value )
+    void setCheck( bool value )
     { check_ = value; }
 
+    //* maximum Size
+    void setMaxSize( int );
+
+    //@}
+
     Q_SIGNALS:
 
     //* emitted when thread has completed validity check
-    void validFilesChecked( void );
+    void validFilesChecked();
 
     //* emitted when contents is changed
-    void contentsChanged( void );
+    void contentsChanged();
 
     public Q_SLOTS:
 
     //* add file.
-    virtual FileRecord& add( const File& file )
+    FileRecord& add( const File& file )
     { return _add( FileRecord( file ) ); }
 
     //* run thread to check file validity
-    void checkValidFiles( void );
+    void checkValidFiles();
 
     protected:
 
-    //* maximum Size
-    virtual void _setMaxSize( int );
-
     //* maximum size
-    virtual const int& _maxSize( void ) const
+    int _maxSize() const
     { return maxSize_; }
 
     //* add record to current list
-    virtual FileRecord& _add(
+    FileRecord& _add(
         const FileRecord&,
         bool = true,
         bool = true );
 
     //* truncate list if larger than maxSize_
-    virtual FileRecord::List _truncatedList( FileRecord::List ) const;
+    FileRecord::List _truncatedList( FileRecord::List ) const;
 
     //* list of files records
-    virtual const FileRecord::List& _records( void ) const
+    const FileRecord::List& _records() const
     { return records_; }
 
     //* list of files records
-    virtual FileRecord::List& _records( void )
+    FileRecord::List& _records()
     { return records_; }
 
     protected Q_SLOTS:
