@@ -27,7 +27,7 @@
 #include <QWidget>
 #include <QCheckBox>
 
-class FilePermissionsWidget: public QWidget, public Counter
+class FilePermissionsWidget: public QWidget, private Base::Counter<FilePermissionsWidget>
 {
 
     Q_OBJECT
@@ -35,10 +35,10 @@ class FilePermissionsWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    FilePermissionsWidget( QWidget*, QFile::Permissions = QFile::Permissions() );
+    explicit FilePermissionsWidget( QWidget*, QFile::Permissions = QFile::Permissions() );
 
     //* set permissions
-    virtual void setPermissions( QFile::Permissions );
+    void setPermissions( QFile::Permissions );
 
     private:
 
