@@ -19,6 +19,7 @@
 
 #include "FileRecordModel.h"
 
+#include "CppUtil.h"
 #include "FileRecordBaseProperties.h"
 #include "IconEngine.h"
 #include "Singleton.h"
@@ -29,7 +30,7 @@
 #include <algorithm>
 
 //__________________________________________________________________
-FileRecordModel::IconCache& FileRecordModel::_icons( void )
+FileRecordModel::IconCache& FileRecordModel::_icons()
 {
     static IconCache cache;
     return cache;
@@ -47,7 +48,7 @@ FileRecordModel::FileRecordModel( QObject* parent ):
     columnTitles_ << tr( "Path" );
     columnTitles_ << tr( "Last Accessed" );
 
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
 
 }
 
@@ -105,7 +106,7 @@ QVariant FileRecordModel::data( const QModelIndex& index, int role ) const
                 const QString localName( useLocalNames_ ? record.file().localName(): record.file() );
 
                 // loop over previous rows to find a match and increment version number
-                unsigned int version( 0 );
+                int version( 0 );
                 for( int row = 0; row < index.row(); row++ )
                 {
                     const QString rowName( useLocalNames_ ?
@@ -123,7 +124,7 @@ QVariant FileRecordModel::data( const QModelIndex& index, int role ) const
                 return buffer;
             }
 
-            case Path: return record.file().path();
+            case Path: return record.file().path().get();
             case Time: return TimeStamp( record.time() ).toString();
             default:
             if( index.column() < (int) columnTitles_.size() && record.hasProperty( columnTitles_[index.column()] ) )
@@ -165,7 +166,7 @@ QMimeData* FileRecordModel::mimeData(const QModelIndexList &indexes) const
 
     // get selected filenames
     QOrderedSet<QString> filenames;
-    foreach( const QModelIndex& index, indexes )
+    for( const auto& index:indexes )
     {
 
         if( !index.isValid() ) continue;
@@ -177,13 +178,13 @@ QMimeData* FileRecordModel::mimeData(const QModelIndexList &indexes) const
     if( filenames.empty() ) return nullptr;
     else {
 
-        QMimeData* mimeData = new QMimeData();
+        QMimeData* mimeData = new QMimeData;
 
         // fill text data
         {
             QString fullText;
             QTextStream buffer( &fullText );
-            foreach( const QString& filename, filenames )
+            for( const auto& filename:filenames )
             { buffer << QString( "file://%1" ).arg(filename) << endl; }
             mimeData->setText( fullText );
         }
@@ -191,7 +192,7 @@ QMimeData* FileRecordModel::mimeData(const QModelIndexList &indexes) const
         // fill url list
         {
             QList<QUrl> urlList;
-            foreach( const QString& filename, filenames )
+            for( const auto& filename:filenames )
             { urlList.append( QUrl( QString( "file://%1" ).arg(filename) ) ); }
             mimeData->setUrls( urlList );
         }
@@ -214,7 +215,7 @@ void FileRecordModel::_add( const ValueType& value )
 }
 
 //____________________________________________________________
-void FileRecordModel::_updateConfiguration( void )
+void FileRecordModel::_updateConfiguration()
 {
     Debug::Throw( "FileRecordModel::_updateConfiguration.\n" );
     _icons().clear();
@@ -228,7 +229,7 @@ void FileRecordModel::_updateColumns( const ValueType& value )
 
     // loop over available properties
     const FileRecord::PropertyMap& properties( value.properties() );
-    for( FileRecord::PropertyMap::const_iterator iter = properties.begin(); iter != properties.end(); ++iter )
+    for( auto iter = properties.begin(); iter != properties.end(); ++iter )
     {
         // look for property name in list of columns
         if( std::find( columnTitles_.begin(), columnTitles_.end(), FileRecord::PropertyId::get( iter.key() ) ) == columnTitles_.end() )
@@ -247,7 +248,7 @@ bool FileRecordModel::SortFTor::operator () ( FileRecord first, FileRecord secon
     switch( type_ )
     {
 
-        case Filename: return first.file().localName().compare( second.file().localName(), Qt::CaseInsensitive ) < 0;
+        case Filename: return first.file().localName().get().compare( second.file().localName(), Qt::CaseInsensitive ) < 0;
         case Path: return first.file().path() < second.file().path();
         case Time: return (first.time() != second.time() ) ? (first.time() < second.time()):first.file().localName() < second.file().localName();
         default:
