@@ -30,7 +30,7 @@
 #include <QStringList>
 
 //* qlistview for object counters
-class FileRecordModel: public ListModel<FileRecord>, public Counter
+class FileRecordModel: public ListModel<FileRecord>, private Base::Counter<FileRecordModel>
 {
 
     Q_OBJECT
@@ -46,32 +46,32 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
     };
 
     //* constructor
-    FileRecordModel( QObject* = nullptr );
+    explicit FileRecordModel( QObject* = nullptr );
 
     //*@name accessors
     //@{
 
     //* show icons
-    virtual bool showIcons( void ) const
+    bool showIcons() const
     { return showIcons_; }
 
     //* flags
-    virtual Qt::ItemFlags flags( const QModelIndex& ) const;
+    Qt::ItemFlags flags( const QModelIndex& ) const override;
 
     // return data for a given index
-    virtual QVariant data( const QModelIndex &, int ) const;
+    QVariant data( const QModelIndex &, int ) const override;
 
     //* header data
-    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;
+    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;
 
     //* number of columns for a given index
-    virtual int columnCount( const QModelIndex& = QModelIndex() ) const;
+    int columnCount( const QModelIndex& = QModelIndex() ) const override;
 
     //* column matching given name, if any
-    virtual int findColumn( const QString& ) const;
+    int findColumn( const QString& ) const;
 
     //* mime data
-    virtual QMimeData* mimeData(const QModelIndexList& ) const;
+    QMimeData* mimeData(const QModelIndexList& ) const override;
 
     //@}
 
@@ -94,7 +94,7 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
     }
 
     //* set values (overloaded)
-    void update( const List& values )
+    void update( List values )
     {
         _updateColumns( values );
         ListModel<FileRecord>::update( values );
@@ -105,15 +105,15 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
     protected:
 
     //* sort
-    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder );
+    void _sort( int, Qt::SortOrder ) override;
 
     //* add, without update
-    virtual void _add( const ValueType& );
+    void _add( const ValueType& ) override;
 
     private Q_SLOTS:
 
     //* configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
@@ -124,7 +124,7 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
         public:
 
         //* constructor
-        SortFTor( const int& type, Qt::SortOrder order, const QStringList& columnTitles ):
+        explicit SortFTor( int type, Qt::SortOrder order, const QStringList& columnTitles ):
             ItemModel::SortFTor( type, order ),
             columnTitles_( columnTitles )
         {}
@@ -144,7 +144,7 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
     {
 
         // update columns
-        foreach( const FileRecord& record, values )
+        for( const auto& record:values )
         { _updateColumns( record ); }
 
     }
@@ -159,7 +159,7 @@ class FileRecordModel: public ListModel<FileRecord>, public Counter
     using IconCache = QHash<QString, QIcon>;
 
     //* type icon cache
-    static IconCache& _icons( void );
+    static IconCache& _icons();
 
     //* local names
     bool useLocalNames_ = true;
