@@ -28,14 +28,14 @@
 #include <QStringList>
 #include <QTimerEvent>
 
-class FileSystemWatcher: public QFileSystemWatcher, public Counter
+class FileSystemWatcher: public QFileSystemWatcher, private Base::Counter<FileSystemWatcher>
 {
     Q_OBJECT
 
     public:
 
     //* constructor
-    FileSystemWatcher( QObject* parent = nullptr ):
+    explicit FileSystemWatcher( QObject* parent = nullptr ):
         QFileSystemWatcher( parent ),
         Counter( "FileSystemWatcher" )
     {
@@ -55,7 +55,7 @@ class FileSystemWatcher: public QFileSystemWatcher, public Counter
     protected:
 
     //* timer event
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     protected Q_SLOTS:
 
