@@ -23,7 +23,7 @@
 #include "TextFormat.h"
 
 #include <QCheckBox>
-#include <QHash>
+#include <QMap>
 
 //! font formating
 class FontInfo: public QWidget
@@ -34,23 +34,23 @@ class FontInfo: public QWidget
     public:
 
     //! constructor
-    FontInfo( QWidget* parent );
+    explicit FontInfo( QWidget* parent );
 
     //! set checkboxes from from
     void setFormat( Format::TextFormatFlags format );
 
     //! get format
-    Format::TextFormatFlags format( void ) const;
+    Format::TextFormatFlags format() const;
 
     Q_SIGNALS:
 
     //! modified
-    void modified( void );
+    void modified();
 
     private:
 
     //! checkbox map
-    using CheckBoxMap = QHash<Format::TextFormat, QCheckBox*>;
+    using CheckBoxMap = QMap<Format::TextFormat, QCheckBox*>;
 
     //! checkboxes
     CheckBoxMap checkBoxes_;
