@@ -26,13 +26,15 @@
 #include <QGridLayout>
 #include <QList>
 
-class GridLayout: public QGridLayout, public Counter
+class GridLayout: public QGridLayout, private Base::Counter<GridLayout>
 {
 
+    Q_OBJECT
+
     public:
 
     //* constructor
-    GridLayout( void ):
+    explicit GridLayout():
         QGridLayout(),
         Counter( "GridLayout" )
     {}
@@ -44,11 +46,11 @@ class GridLayout: public QGridLayout, public Counter
     //@{
 
     //* current row
-    int currentRow( void ) const
+    int currentRow() const
     { return row_; }
 
     //* current column
-    int currentColumn( void ) const
+    int currentColumn() const
     { return column_; }
 
     //@}
@@ -57,7 +59,7 @@ class GridLayout: public QGridLayout, public Counter
     //@{
 
     //* set columns
-    void setMaxCount( const int& maxCount )
+    void setMaxCount( int maxCount )
     {
         maxCount_ = maxCount;
         columnAlignments_.clear();
@@ -69,7 +71,7 @@ class GridLayout: public QGridLayout, public Counter
     }
 
     //* set column alignment
-    void setColumnAlignment( const int& column, const Qt::Alignment alignment )
+    void setColumnAlignment( int column, const Qt::Alignment alignment )
     { columnAlignments_[column] = alignment; }
 
     //* set orientation
@@ -147,7 +149,7 @@ class GridLayout: public QGridLayout, public Counter
     }
 
     //* set current position in grid
-    void setLocation( const int& row, const int& column )
+    void setLocation( int row, int column )
     { row_ = row; column_ = column; }
 
     //@}
@@ -155,7 +157,7 @@ class GridLayout: public QGridLayout, public Counter
     private:
 
     //* bound check
-    bool _boundCheck( const int& column ) const
+    bool _boundCheck( int column ) const
     { return column >= 0 && column < int( columnAlignments_.size() ); }
 
     //* orientation
