@@ -23,20 +23,27 @@
 #include "GridLayout.h"
 
 //____________________________________________________________________________
-GridLayoutItem::GridLayoutItem( QWidget* parent, GridLayout* layout, ItemFlags flags ):
+GridLayoutItem::GridLayoutItem( QWidget* parent, GridLayout* layout, Flags flags ):
     QObject( parent ),
     Counter( "GridLayoutItem" ),
     flags_( flags )
 {
+
     layout->addWidget( key_ = new QLabel( parent ), layout->currentRow(), layout->currentColumn(), Qt::AlignRight|Qt::AlignTop );
 
+    auto palette( key_->palette() );
+    auto color( palette.color( QPalette::WindowText ) );
+    color.setAlpha( 0.8*color.alpha() );
+    palette.setColor( QPalette::WindowText, color );
+    key_->setPalette( palette );
+
     // create correct value label
-    if( flags & Elide ) value_ = new ElidedLabel( parent );
+    if( flags & Flag::Elide ) value_ = new ElidedLabel( parent );
     else value_ = new QLabel( parent );
 
-    if( flags & Selectable )
+    if( flags & Flag::Selectable )
     {
-        const Qt::TextInteractionFlags defaultFlags( QLabel().textInteractionFlags() );
+        auto defaultFlags( QLabel().textInteractionFlags() );
         value_->setTextInteractionFlags( Qt::TextSelectableByMouse | defaultFlags );
     }
 
@@ -76,7 +83,7 @@ void GridLayoutItem::setVisible( bool value )
 }
 
 //____________________________________________________________________________
-void GridLayoutItem::show( void )
+void GridLayoutItem::show()
 {
     key_->show();
     value_->show();
@@ -88,7 +95,7 @@ void GridLayoutItem::show( void )
 }
 
 //____________________________________________________________________________
-void GridLayoutItem::hide( void )
+void GridLayoutItem::hide()
 {
     key_->hide();
     value_->hide();
