@@ -29,7 +29,7 @@
 class GridLayout;
 
 //_______________________________________________________
-class GridLayoutItem: public QObject, public Counter
+class GridLayoutItem: public QObject, private Base::Counter<GridLayoutItem>
 {
 
     Q_OBJECT
@@ -37,38 +37,36 @@ class GridLayoutItem: public QObject, public Counter
     public:
 
     //* flags
-    enum ItemFlag
+    enum Flag
     {
         None = 0,
         Elide = 1<<0,
-        Bold = 1<<1,
-        Title = Bold,
         Selectable = 1<<2,
-        All = Elide|Bold|Selectable
+        All = Elide|Selectable
     };
 
-    Q_DECLARE_FLAGS( ItemFlags, ItemFlag );
+    Q_DECLARE_FLAGS( Flags, Flag );
 
     //* constructor
-    GridLayoutItem( QWidget*, GridLayout*, ItemFlags = None );
+    explicit GridLayoutItem( QWidget*, GridLayout*, Flags = Flag::None );
 
     //*@name accessors
     //@{
 
     //* visibility
-    bool isVisible( void ) const
+    bool isVisible() const
     { return visible_; }
 
     //* key
-    QString key( void ) const
+    QString key() const
     { return key_->text(); }
 
     //* value
-    QString text( void ) const
+    QString text() const
     { return value_->text(); }
 
     //* value label
-    QLabel& label( void ) const
+    QLabel& label() const
     { return *value_; }
 
     //*@}
@@ -91,10 +89,10 @@ class GridLayoutItem: public QObject, public Counter
     void setVisible( bool value );
 
     //* show
-    void show( void );
+    void show();
 
     //* hide
-    void hide( void );
+    void hide();
 
     //@}
 
@@ -107,14 +105,14 @@ class GridLayoutItem: public QObject, public Counter
 
     private:
 
-    ItemFlags flags_ = None;
-    QLabel* key_;
-    QLabel* value_;
+    Flags flags_ = Flag::None;
+    QLabel* key_ = nullptr;
+    QLabel* value_ = nullptr;
 
     bool visible_ = true;
 
 };
 
-Q_DECLARE_OPERATORS_FOR_FLAGS( GridLayoutItem::ItemFlags )
+Q_DECLARE_OPERATORS_FOR_FLAGS( GridLayoutItem::Flags )
 
 #endif
