@@ -20,6 +20,8 @@
 *
 *******************************************************************************/
 
+#include "Counter.h"
+
 #include <QString>
 #include <QStringList>
 #include <QHash>
@@ -29,18 +31,26 @@
 namespace Base
 {
     //* cache item
-    class IconCacheItem: public QIcon
+    class IconCacheItem: public QIcon, private Counter<IconCacheItem>
     {
 
         public:
 
         //* constructor
-        IconCacheItem( void )
+        explicit IconCacheItem():
+            Counter( "Base::IconCacheItem" )
         {}
 
         //* copy constructor
-        IconCacheItem( const QIcon& other ):
-            QIcon( other )
+        explicit IconCacheItem( const QIcon& other ):
+            QIcon( other ),
+            Counter( "Base::IconCacheItem" )
+        {}
+
+        //* copy constructor
+        explicit IconCacheItem( QIcon&& other ):
+            QIcon( std::move( other ) ),
+            Counter( "Base::IconCacheItem" )
         {}
 
         //* flags
@@ -59,11 +69,11 @@ namespace Base
         //@{
 
         //* flags
-        Flags flags( void ) const
+        Flags flags() const
         { return flags_; }
 
         //* files
-        const QStringList& files( void ) const
+        const QStringList& files() const
         { return files_; }
 
         //@}
@@ -76,7 +86,7 @@ namespace Base
         { flags_ = value; }
 
         //* clear files
-        void clearFiles( void )
+        void clearFiles()
         { files_.clear(); }
 
         //* add file
@@ -88,7 +98,7 @@ namespace Base
         private:
 
         //* flags
-        Flags flags_;
+        Flags flags_ = Flag::None;
 
         //* associated files
         QStringList files_;
@@ -96,53 +106,14 @@ namespace Base
     };
 
     //* cache
-    class IconCache: public QHash<QString, IconCacheItem>
-    {
+    using IconCache = QHash<QString, IconCacheItem>;
+    using IconPair =  QPair<QString, IconCacheItem >;
 
-        public:
+    inline bool operator == ( const IconPair& first, const IconPair& second )
+    { return first.first == second.first; }
 
-        //* constructor
-        IconCache( void )
-        {}
-
-        //* destructor
-        virtual ~IconCache( void )
-        {}
-
-        //* pair
-        class Pair: public QPair<QString, IconCacheItem >
-        {
-            public:
-
-            //* constructor
-            Pair( void )
-            {}
-
-            //* constructor
-            Pair( const QString& name, const IconCacheItem& icon ):
-                QPair<QString, IconCacheItem >( name, icon )
-            {}
-
-            //* constructor
-            Pair( const QPair<QString, IconCacheItem >& other ):
-                QPair<QString, IconCacheItem >( other )
-            {}
-
-            //* destructor
-            virtual ~Pair( void )
-            {}
-
-            //* equal to operator
-            bool operator == ( const Pair& other ) const
-            { return first == other.first; }
-
-            //* less than operator
-            bool operator < ( const Pair& other ) const
-            { return first < other.first; }
-
-        };
-
-    };
+    inline bool operator < ( const IconPair& first, const IconPair& second )
+    { return first.first < second.first; }
 
     Q_DECLARE_OPERATORS_FOR_FLAGS( IconCacheItem::Flags )
 
