@@ -19,14 +19,6 @@
 
 #include "IconCacheModel.h"
 
-//_______________________________________________
-const QString IconCacheModel::columnTitles_[ IconCacheModel::nColumns ] =
-{
-    tr( "Icon" ),
-    tr( "Files" ),
-    tr( "Sizes" )
-};
-
 //__________________________________________________________________
 QVariant IconCacheModel::data( const QModelIndex& index, int role ) const
 {
@@ -35,7 +27,7 @@ QVariant IconCacheModel::data( const QModelIndex& index, int role ) const
     if( !contains( index ) ) return QVariant();
 
     // associated icon pair
-    const Base::IconCache::Pair& iconPair( get(index) );
+    const Base::IconPair& iconPair( get(index) );
 
     if( role == Qt::DisplayRole )
     {
@@ -76,13 +68,13 @@ QVariant IconCacheModel::headerData(int section, Qt::Orientation orientation, in
 }
 
 //________________________________________________________
-QString IconCacheModel::_availableSizes( const Base::IconCache::Pair& iconPair )
+QString IconCacheModel::_availableSizes( const Base::IconPair& iconPair )
 {
 
     QString buffer;
     QTextStream what( &buffer );
     bool first( true );
-    foreach( const QSize& size, iconPair.second.availableSizes() )
+    for( const auto& size:iconPair.second.availableSizes() )
     {
         if( first ) first = false;
         else what << ", ";
@@ -93,7 +85,7 @@ QString IconCacheModel::_availableSizes( const Base::IconCache::Pair& iconPair )
 }
 
 //________________________________________________________
-bool IconCacheModel::SortFTor::operator () ( Base::IconCache::Pair first, Base::IconCache::Pair second ) const
+bool IconCacheModel::SortFTor::operator () ( Base::IconPair first, Base::IconPair second ) const
 {
 
     if( order_ == Qt::DescendingOrder ) std::swap( first, second );
