@@ -23,7 +23,7 @@
 #include <QFileInfo>
 
 //__________________________________________________________
-IconEngine& IconEngine::get( void )
+IconEngine& IconEngine::get()
 {
     //* singleton
     static IconEngine singleton_;
@@ -31,33 +31,40 @@ IconEngine& IconEngine::get( void )
 }
 
 //__________________________________________________________
-IconEngine::IconEngine( void ):
+IconEngine::IconEngine():
     Counter( "IconEngine" )
 { Debug::Throw( "IconEngine::IconEngine.\n" ); }
 
 //__________________________________________________________
-bool IconEngine::reload( void )
+bool IconEngine::reload()
 {
     Debug::Throw( "IconEngine::reload.\n" );
 
     // load path from options
-    QStringList pathList( XmlOptions::get().specialOptions<QString>( "PIXMAP_PATH" ) );
+    auto pathList( XmlOptions::get().specialOptions<File>( "PIXMAP_PATH" ) );
     if( pathList == pixmapPath_ ) return false;
 
     pixmapPath_ = pathList;
 
-    for( Base::IconCache::iterator iter = cache_.begin(); iter != cache_.end(); ++iter )
-    { cache_[iter.key()] = _get( iter.key(), iter.value().flags()&~Base::IconCacheItem::FromCache ); }
+    for( auto&& iter = cache_.begin(); iter != cache_.end(); ++iter )
+    { cache_[iter.key()] = _get( iter.key(), iter.value().flags()&~static_cast<Base::IconCacheItem::Flags>(Base::IconCacheItem::Flag::FromCache) ); }
 
     return true;
 }
 
+//__________________________________________________________
+void IconEngine::clear()
+{
+    Debug::Throw( "IconEngine::clear.\n" );
+    cache_.clear();
+}
+
 //__________________________________________________________
 const Base::IconCacheItem& IconEngine::_get( const QString& file, Base::IconCacheItem::Flags flags )
 {
 
     // try find file in cache
-    if( flags & Base::IconCacheItem::FromCache )
+    if( flags & Base::IconCacheItem::Flag::FromCache )
     {
         Base::IconCache::iterator iter( cache_.find( file ) );
         if( iter != cache_.end() ) return iter.value();
@@ -83,10 +90,10 @@ const Base::IconCacheItem& IconEngine::_get( const QString& file, Base::IconCach
 
         #if QT_VERSION >= 0x040600
         QString truncatedName( File( file ).truncatedName() );
-        if( (flags&Base::IconCacheItem::FromTheme) && QIcon::hasThemeIcon( truncatedName ) )
+        if( (flags&Base::IconCacheItem::Flag::FromTheme) && QIcon::hasThemeIcon( truncatedName ) )
         {
 
-            out = QIcon::fromTheme( truncatedName );
+            out = Base::IconCacheItem( QIcon::fromTheme( truncatedName ) );
             out.addFile( QObject::tr( "from theme" ) );
 
         } else
@@ -94,11 +101,11 @@ const Base::IconCacheItem& IconEngine::_get( const QString& file, Base::IconCach
         {
 
             // make sure pixmap path is initialized
-            if( pixmapPath_.empty() ) pixmapPath_ = XmlOptions::get().specialOptions<QString>( "PIXMAP_PATH" );
+            if( pixmapPath_.empty() ) pixmapPath_ = XmlOptions::get().specialOptions<File>( "PIXMAP_PATH" );
 
             // store list of loaded sizes
             QList<QSize> sizes;
-            foreach( const QString& path, pixmapPath_ )
+            for( const auto& path:pixmapPath_ )
             {
 
                 // skip empty path
@@ -109,7 +116,7 @@ const Base::IconCacheItem& IconEngine::_get( const QString& file, Base::IconCach
 
                 // see if path is internal resource path
                 if( path.startsWith( ':' ) ) pixmapFile = File( file ).addPath( path );
-                else pixmapFile = File( path ).find( file );
+                else pixmapFile = File( path ).find( File( file ) );
 
                 // load pixmap
                 if( pixmapFile.isEmpty() ) continue;
