@@ -22,30 +22,33 @@
 
 #include "Counter.h"
 #include "Debug.h"
+#include "File.h"
 #include "IconCache.h"
-
-#include <QStringList>
+#include "NonCopyable.h"
 
 //* customized Icon factory to provide better looking disabled icons
-class IconEngine: public Counter
+class IconEngine final: private Base::Counter<IconEngine>, private Base::NonCopyable<IconEngine>
 {
 
     public:
 
     //* retrieve singleton
-    static IconEngine& get( void );
+    static IconEngine& get();
 
     //* create icon
     /*! the file is stored into a cache to avoid all pixmaps manipulations */
-    static const QIcon& get( const QString& file, Base::IconCacheItem::Flags flags = Base::IconCacheItem::Any )
+    static const QIcon& get( const QString& file, Base::IconCacheItem::Flags flags = Base::IconCacheItem::Flag::Any )
     { return get()._get( file, flags ); }
 
     //* return cache
-    static const Base::IconCache& cache( void )
+    static const Base::IconCache& cache()
     { return get().cache_; }
 
     //* reload all icons set in cache from new path list
-    bool reload( void );
+    bool reload();
+
+    //* clear
+    void clear();
 
     private:
 
@@ -53,16 +56,16 @@ class IconEngine: public Counter
     //@{
 
     //* constructor
-    IconEngine( void );
+    explicit IconEngine();
 
     //* create icon
     /*! the file is stored into a cache to avoid all pixmaps manipulations */
-    const Base::IconCacheItem& _get( const QString&, Base::IconCacheItem::Flags = Base::IconCacheItem::Any );
+    const Base::IconCacheItem& _get( const QString&, Base::IconCacheItem::Flags = Base::IconCacheItem::Flag::Any );
 
     //@}
 
     //* pixmap path
-    QStringList pixmapPath_;
+    File::List pixmapPath_;
 
     //* map files and QIcon
     Base::IconCache cache_;
