@@ -25,12 +25,11 @@
 #include <QMap>
 
 //* default icon sizes
-class IconSize: public QSize
+class IconSize final
 {
 
     public:
 
-
     //* icon sizes
     enum Size
     {
@@ -39,18 +38,30 @@ class IconSize: public QSize
         Medium = 22,
         Large = 32,
         Huge = 48,
+        VeryHuge = 64,
         Oversized = 128,
         Maximum = 256
     };
 
     //* constructor
-    IconSize( Size size );
+    explicit IconSize( Size );
+
+    //* static accessor
+    static QSize get( Size );
+
+    //* accessor
+    const QSize& get() const { return size_; }
 
     //* map text to icon size
     using Map = QMap<Size, QString>;
 
     //* text to icon size
-    static Map& map( void );
+    static Map& map();
+
+    private:
+
+    //* size
+    QSize size_;
 
 };
 
