@@ -29,7 +29,7 @@
 #include <QHash>
 
 //! provides icon size selection menu
-class IconSizeMenu: public QMenu, public Counter
+class IconSizeMenu: public QMenu, private Base::Counter<IconSizeMenu>
 {
 
     Q_OBJECT
@@ -37,7 +37,7 @@ class IconSizeMenu: public QMenu, public Counter
     public:
 
     //! constructor
-    IconSizeMenu( QWidget* parent = 0, bool custom = false );
+    explicit IconSizeMenu( QWidget* parent = 0, bool custom = false );
 
     //! select size
     void select( IconSize::Size );
