@@ -65,7 +65,7 @@ IconView::IconView( QWidget* parent ):
     setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 }
 
@@ -95,7 +95,7 @@ void IconView::setFindEnabled( bool value )
 }
 
 //______________________________________________________________________
-TextSelection IconView::selection( void ) const
+TextSelection IconView::selection() const
 {
 
     Debug::Throw( "IconView::selection.\n" );
@@ -166,7 +166,7 @@ QModelIndex IconView::indexAt( const QPoint& constPosition ) const
     QPoint position( constPosition + _scrollBarPosition() );
 
     // find matching item
-    for( IconViewItem::Map::const_iterator iter = items_.begin(); iter != items_.end(); ++iter )
+    for( auto&& iter = items_.begin(); iter != items_.end(); ++iter )
     {
         if( iter.value().boundingRect().translated( iter.value().position() ).contains( position ) )
         { return model()->index( iter.key(), 0 ); }
@@ -218,7 +218,7 @@ QRect IconView::visualRect( const QModelIndex&  index ) const
 }
 
 //_____________________________________________________________________
-QSize IconView::minimumSizeHint( void ) const
+QSize IconView::minimumSizeHint() const
 {
     return QSize(
         2*margin_ + 2*IconViewItem::margin + qMax( IconViewItem::maxTextWidth, iconSize().width() ) + verticalScrollBar()->width(),
@@ -226,7 +226,7 @@ QSize IconView::minimumSizeHint( void ) const
 }
 
 //_____________________________________________________________________
-void IconView::updateSortOrder( void )
+void IconView::updateSortOrder()
 {
 
     Debug::Throw( "IconView::updateSortOrder.\n" );
@@ -245,7 +245,7 @@ void IconView::updateSortOrder( void )
 }
 
 //_____________________________________________________________________
-void IconView::saveSortOrder( void )
+void IconView::saveSortOrder()
 {
 
     Debug::Throw( "IconView::saveSortOrder.\n" );
@@ -258,14 +258,13 @@ void IconView::saveSortOrder( void )
 }
 
 //____________________________________________________________________
-void IconView::doItemsLayout( void )
+void IconView::doItemsLayout()
 {
 
     const int rowCount( model()->rowCount() );
 
     // first remove invalid items
-    const QList<int> keys( items_.keys() );
-    foreach( const int& key, keys )
+    for( const auto& key:items_.keys() )
     { if( key >= rowCount ) items_.remove( key ); }
 
     // update existing items and insert new ones
@@ -303,15 +302,15 @@ void IconView::find( TextSelection selection )
 }
 
 //______________________________________________________________________
-void IconView::findAgainForward( void )
+void IconView::findAgainForward()
 { _findForward( TextEditor::lastSelection(), true ); }
 
 //______________________________________________________________________
-void IconView::findAgainBackward( void )
+void IconView::findAgainBackward()
 { _findBackward( TextEditor::lastSelection(), true ); }
 
 //__________________________________________________________
-void IconView::storeSelectedIndexes( void )
+void IconView::storeSelectedIndexes()
 {
     if( selectionModel() )
     {
@@ -321,7 +320,7 @@ void IconView::storeSelectedIndexes( void )
 }
 
 //__________________________________________________________
-void IconView::restoreSelectedIndexes( void )
+void IconView::restoreSelectedIndexes()
 {
 
     if( selectionModel() )
@@ -329,7 +328,7 @@ void IconView::restoreSelectedIndexes( void )
 
         const QModelIndexList selection( model_->selectedIndexes() );
         selectionModel()->clear();
-        foreach( const QModelIndex& index, selection )
+        for( const auto& index:selection )
         { selectionModel()->select( index, QItemSelectionModel::Select|QItemSelectionModel::Rows ); }
 
         selectionModel()->setCurrentIndex( model_->currentIndex(), QItemSelectionModel::Current );
@@ -440,7 +439,7 @@ void IconView::setSelection( const QRect& constRect, QItemSelectionModel::Select
     else {
 
         QItemSelection selection;
-        foreach( const QModelIndex& index, indexes ) selection.select( index, index );
+        for( const auto& index:indexes ) selection.select( index, index );
         selectionModel()->select( selection, flags );
 
     }
@@ -455,7 +454,7 @@ void IconView::startDrag( Qt::DropActions supportedActions )
 
     // get list of dragable indexes
     QModelIndexList indexes;
-    foreach( const QModelIndex& index, selectionModel()->selectedIndexes() )
+    for( const auto& index:selectionModel()->selectedIndexes() )
     { if( model()->flags( index ) & Qt::ItemIsDragEnabled ) indexes << index; }
     if( indexes.isEmpty() ) return;
 
@@ -488,11 +487,11 @@ void IconView::scrollContentsBy( int dx, int dy )
 }
 
 //____________________________________________________________________
-int IconView::horizontalOffset( void ) const
+int IconView::horizontalOffset() const
 { return horizontalScrollBar()->value(); }
 
 //____________________________________________________________________
-int IconView::verticalOffset( void ) const
+int IconView::verticalOffset() const
 { return verticalScrollBar()->value(); }
 
 //____________________________________________________________________
@@ -502,9 +501,9 @@ QRegion IconView::visualRegionForSelection( const QItemSelection& selection ) co
     if( selection.empty() ) return QRegion();
 
     QRegion region;
-    foreach( const QItemSelectionRange& range, selection )
+    for( const auto& range:selection )
     {
-        foreach( const QModelIndex& index, range.indexes() )
+        for( const auto& index:range.indexes() )
         { region += visualRect( index ); }
     }
 
@@ -871,13 +870,13 @@ void IconView::_updateItem( IconViewItem& item, const QModelIndex& index ) const
 
     // update pixmap
     QVariant decorationVariant( model()->data( index, Qt::DecorationRole ) );
-    if( decorationVariant.canConvert( QVariant::Icon ) ) item.setPixmap( decorationVariant.value<QIcon>().pixmap( iconSize() ) );
-    else if( decorationVariant.canConvert( QVariant::Pixmap ) ) item.setPixmap( decorationVariant.value<QPixmap>() );
+    if( decorationVariant.canConvert( QVariant::Icon ) ) item.setPixmap( CustomPixmap( decorationVariant.value<QIcon>().pixmap( iconSize() ) ) );
+    else if( decorationVariant.canConvert( QVariant::Pixmap ) ) item.setPixmap( CustomPixmap( decorationVariant.value<QPixmap>() ) );
 
 }
 
 //____________________________________________________________________
-void IconView::_layoutItems( void )
+void IconView::_layoutItems()
 {
 
     // get max width for items
@@ -933,7 +932,7 @@ void IconView::_layoutItems( void )
 
         // compute total width and compare to max
         totalWidth = 0;
-        foreach( const int& width, columnSizes ) totalWidth += width;
+        for( const auto& width:columnSizes ) totalWidth += width;
         totalWidth += (columnSizes.size()-1)*spacing_;
 
         if( totalWidth <= maxWidth || columnCount_ == 1 ) break;
@@ -987,7 +986,7 @@ QPixmap IconView::_pixmap( const QModelIndexList& indexes, QRect& boundingRect )
     if( indexes.isEmpty() ) return QPixmap();
 
     IconViewItem::Map items;
-    foreach( const QModelIndex& index, indexes )
+    for( const auto& index:indexes )
     {
         // find item
         IconViewItem::Map::const_iterator iter( items_.find( index.row() ) );
@@ -1025,7 +1024,7 @@ QPixmap IconView::_pixmap( const QModelIndexList& indexes, QRect& boundingRect )
 }
 
 //______________________________________________________________________
-void IconView::_createFindDialog( void )
+void IconView::_createFindDialog()
 {
 
     Debug::Throw( "IconView::_createFindDialog.\n" );
@@ -1149,9 +1148,7 @@ bool IconView::_findForward( const TextSelection& selection, bool rewind )
 
         } else {
 
-            QModelIndex previous( index );
             index = _indexAfter( index );
-
             if( rewind && !index.isValid() )
             {
                 rewind = false;
@@ -1298,7 +1295,7 @@ QStyleOptionViewItemV4 IconView::_viewOptions( const QModelIndex& index ) const
 }
 
 //____________________________________________________________________
-void IconView::updateGeometries( void )
+void IconView::updateGeometries()
 {
 
     // vertical scrollbar
@@ -1323,7 +1320,7 @@ void IconView::sortByColumn( int column, Qt::SortOrder order)
 }
 
 //_____________________________________________________________________
-void IconView::_findFromDialog( void )
+void IconView::_findFromDialog()
 {
     Debug::Throw( "IconView::_findFromDialog.\n" );
 
@@ -1362,14 +1359,14 @@ void IconView::_findFromDialog( void )
 }
 
 //_____________________________________________________________________
-void IconView::_updateHoverIndex( void )
+void IconView::_updateHoverIndex()
 {
     Debug::Throw( "IconView::_updateHoverIndex.\n" );
     _setHoverIndex(  indexAt( viewport()->mapFromGlobal( QCursor::pos() ) ) );
 }
 
 //_____________________________________________________________________
-void IconView::_updateConfiguration( void )
+void IconView::_updateConfiguration()
 {
     Debug::Throw( "IconView::_updateConfiguration.\n" );
 
@@ -1391,7 +1388,7 @@ void IconView::_updateConfiguration( void )
 }
 
 //__________________________________________________________
-void IconView::_installActions( void )
+void IconView::_installActions()
 {
     Debug::Throw( "IconView::_installActions.\n" );
 
@@ -1429,11 +1426,11 @@ void IconView::_installActions( void )
 
 
 //_________________________________________________________
-QModelIndex IconView::_firstIndex( void ) const
+QModelIndex IconView::_firstIndex() const
 { return items_.empty() ? QModelIndex():model()->index( 0, 0 ); }
 
 //_________________________________________________________
-QModelIndex IconView::_lastIndex( void ) const
+QModelIndex IconView::_lastIndex() const
 { return items_.empty() ? QModelIndex():model()->index( 0, items_.size()-1 ); }
 
 //_________________________________________________________
@@ -1448,7 +1445,7 @@ QModelIndex IconView::_indexBefore( const QModelIndex& current ) const
 IconView::Container::Container( QWidget* parent ):
     QWidget( parent ),
     Counter( "IconView::Container" ),
-    iconView_( new IconView() )
+    iconView_( new IconView )
 { _initialize(); }
 
 //_________________________________________________________
@@ -1459,13 +1456,13 @@ IconView::Container::Container( QWidget* parent, IconView* iconView ):
 { _initialize(); }
 
 //_________________________________________________________
-void IconView::Container::_initialize( void )
+void IconView::Container::_initialize()
 {
     Debug::Throw( "IconView::Container::_initialize.\n" );
     iconView_->setParent( this );
 
     // setup layout
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    QVBoxLayout* vLayout = new QVBoxLayout;
     vLayout->setMargin(0);
     vLayout->setSpacing(2);
     setLayout( vLayout );
