@@ -43,7 +43,7 @@ class BaseFindWidget;
 class ItemModel;
 
 //* icon view
-class IconView: public QAbstractItemView, public Counter
+class IconView: public QAbstractItemView, private Base::Counter<IconView>
 {
 
     Q_OBJECT
@@ -51,38 +51,38 @@ class IconView: public QAbstractItemView, public Counter
     public:
 
     //* constructor
-    IconView( QWidget* = nullptr );
+    explicit IconView( QWidget* = nullptr );
 
     //*@name accessors
     //@{
 
     //* TextSelection object from this selection, or clipboard
-    TextSelection selection( void ) const;
+    TextSelection selection() const;
 
     //* header
-    QHeaderView* header( void ) const
+    QHeaderView* header() const
     { return header_; }
 
     //* option name
-    virtual bool hasOptionName( void ) const
+    bool hasOptionName() const
     { return !sortColumnOptionName().isEmpty(); }
 
     //* sort column option name
-    virtual const QString& sortColumnOptionName( void ) const
+    const QString& sortColumnOptionName() const
     { return sortColumnOptionName_; }
 
     //* sort order option name
-    virtual const QString& sortOrderOptionName( void ) const
+    const QString& sortOrderOptionName() const
     { return sortOrderOptionName_; }
 
     //* return index at a given position
-    virtual QModelIndex indexAt( const QPoint& ) const;
+    QModelIndex indexAt( const QPoint& ) const override;
 
     //* visual rect for given index
-    virtual QRect visualRect( const QModelIndex& ) const;
+    QRect visualRect( const QModelIndex& ) const override;
 
     //* minimum size hind
-    virtual QSize minimumSizeHint( void ) const;
+    QSize minimumSizeHint() const override;
 
     //@}
 
@@ -90,7 +90,7 @@ class IconView: public QAbstractItemView, public Counter
     //@{
 
     //* set model
-    virtual void setModel( QAbstractItemModel* );
+    void setModel( QAbstractItemModel* ) override;
 
     //* enable list finding
     void setFindEnabled( bool value );
@@ -132,10 +132,10 @@ class IconView: public QAbstractItemView, public Counter
     }
 
     //* option name
-    virtual bool setOptionName( const QString& );
+    bool setOptionName( const QString& );
 
     //* scroll to given index
-    virtual void scrollTo( const QModelIndex&, ScrollHint );
+    void scrollTo( const QModelIndex&, ScrollHint ) override;
 
     //@}
 
@@ -143,43 +143,43 @@ class IconView: public QAbstractItemView, public Counter
     //@{
 
     //* select all
-    QAction& selectAllAction( void ) const
+    QAction& selectAllAction() const
     { return *selectAllAction_; }
 
     //* find from dialog
-    QAction& findAction( void ) const
+    QAction& findAction() const
     { return *findAction_; }
 
     //* find selection again
-    QAction& findSelectionAction( void ) const
+    QAction& findSelectionAction() const
     { return *findSelectionAction_; }
 
     //* find again
-    QAction& findAgainAction( void ) const
+    QAction& findAgainAction() const
     { return *findAgainAction_; }
 
     //@}
 
     //* container class for embedded Find dialog
-    class Container: public QWidget, public Counter
+    class Container: public QWidget, private Base::Counter<Container>
     {
 
         public:
 
         //* constructor
-        Container( QWidget* = nullptr );
+        explicit Container( QWidget* = nullptr );
 
         //* constructor
-        Container( QWidget*, IconView* );
+        explicit Container( QWidget*, IconView* );
 
         //*@name accessors
-        IconView& iconView( void ) const
+        IconView& iconView() const
         { return *iconView_; }
 
         private:
 
         //* initialize
-        void _initialize( void );
+        void _initialize();
 
         //* contained iconView
         IconView* iconView_;
@@ -192,10 +192,10 @@ class IconView: public QAbstractItemView, public Counter
     void hovered( const QModelIndex& );
 
     //* emitted when selection could not be found
-    void noMatchFound( void );
+    void noMatchFound();
 
     //* emitted when selection could be found
-    void matchFound( void );
+    void matchFound();
 
     #if QT_VERSION < 0x050000
     //* icon size changed signal
@@ -205,117 +205,117 @@ class IconView: public QAbstractItemView, public Counter
     public Q_SLOTS:
 
     //* sort order
-    virtual void updateSortOrder( void );
+    void updateSortOrder();
 
     //* sort order
-    virtual void saveSortOrder( void );
+    void saveSortOrder();
 
     // items layout
-    virtual void doItemsLayout();
+    void doItemsLayout();
 
     //* find next occurence of TextSelection
-    virtual void find( TextSelection selection );
+    void find( TextSelection selection );
 
     //* find current selection forward
-    virtual void findSelectionForward( void )
+    void findSelectionForward()
     { _findForward( selection(), true ); }
 
     //* find current selection backward
-    virtual void findSelectionBackward( void )
+    void findSelectionBackward()
     { _findBackward( selection(), true ); }
 
     //* find last search forward
-    virtual void findAgainForward( void );
+    void findAgainForward();
 
     //* find last search forward
-    virtual void findAgainBackward( void );
+    void findAgainBackward();
 
     //* store selected indexes in model
-    void storeSelectedIndexes( void );
+    void storeSelectedIndexes();
 
     //* restore selected indexes from model
-    void restoreSelectedIndexes( void );
+    void restoreSelectedIndexes();
 
     protected:
 
-    // true if index is hidden
-    virtual bool isIndexHidden( const QModelIndex& ) const;
+    //* true if index is hidden
+    bool isIndexHidden( const QModelIndex& ) const override;
 
     //* move curesor
-    virtual QModelIndex moveCursor( CursorAction, Qt::KeyboardModifiers );
+    QModelIndex moveCursor( CursorAction, Qt::KeyboardModifiers ) override;
 
     //* selection
-    virtual void setSelection( const QRect&, QItemSelectionModel::SelectionFlags );
+    void setSelection( const QRect&, QItemSelectionModel::SelectionFlags ) override;
 
     //* start drag
-    virtual void startDrag( Qt::DropActions );
+    void startDrag( Qt::DropActions ) override;
 
     //* contents scroll
-    virtual void scrollContentsBy( int, int );
+    void scrollContentsBy( int, int ) override;
 
     //* horizontal offset
-    virtual int horizontalOffset( void ) const;
+    int horizontalOffset() const override;
 
     //* vertical offset
-    virtual int verticalOffset( void ) const;
+    int verticalOffset() const override;
 
     //* region for given selection
-    virtual QRegion visualRegionForSelection( const QItemSelection& ) const;
+    QRegion visualRegionForSelection( const QItemSelection& ) const override;
 
     //* event
-    virtual bool event( QEvent* );
+    bool event( QEvent* ) override;
 
     //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //* resize event
-    virtual void resizeEvent( QResizeEvent* );
+    void resizeEvent( QResizeEvent* ) override;
 
     //* keypress event
-    virtual void keyPressEvent( QKeyEvent* );
+    void keyPressEvent( QKeyEvent* ) override;
 
     //* mouse press
-    virtual void mousePressEvent( QMouseEvent* );
+    void mousePressEvent( QMouseEvent* ) override;
 
     //* mouse move
-    virtual void mouseMoveEvent( QMouseEvent* );
+    void mouseMoveEvent( QMouseEvent* ) override;
 
     //* mouse release
-    virtual void mouseReleaseEvent( QMouseEvent* );
+    void mouseReleaseEvent( QMouseEvent* ) override;
 
     //* drag enter
-    virtual void dragEnterEvent( QDragEnterEvent* );
+    void dragEnterEvent( QDragEnterEvent* ) override;
 
     //* drag move
-    virtual void dragMoveEvent( QDragMoveEvent* );
+    void dragMoveEvent( QDragMoveEvent* ) override;
 
     //* drag leave
-    virtual void dragLeaveEvent( QDragLeaveEvent* );
+    void dragLeaveEvent( QDragLeaveEvent* ) override;
 
     //* drag enter
-    virtual void dropEvent( QDropEvent* );
+    void dropEvent( QDropEvent* ) override;
 
     //* timer event
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     //* selection
     QModelIndexList _selectedIndexes( const QRect& ) const;
 
     //* hover index
-    virtual const QModelIndex& _hoverIndex( void ) const
+    const QModelIndex& _hoverIndex() const
     { return hoverIndex_; }
 
     //* hover index
-    virtual void _setHoverIndex( const QModelIndex& );
+    void _setHoverIndex( const QModelIndex& );
 
     //* update item from index
     virtual void _updateItem( IconViewItem&, const QModelIndex& ) const;
 
     //* layout existing items
-    void _layoutItems( void );
+    void _layoutItems();
 
     //* scrollbar position
-    QPoint _scrollBarPosition( void ) const
+    QPoint _scrollBarPosition() const
     {
         return QPoint(
             horizontalScrollBar()->isVisible() ? horizontalScrollBar()->value():0,
@@ -326,43 +326,43 @@ class IconView: public QAbstractItemView, public Counter
     QPixmap _pixmap( const QModelIndexList&, QRect& );
 
     //* find dialog
-    virtual void _createFindDialog( void );
+    void _createFindDialog();
 
     //* find widget
-    virtual void _createFindWidget( bool compact );
+    void _createFindWidget( bool compact );
 
     //* find selection in forward direction
-    virtual bool _findForward( const TextSelection& selection, bool rewind );
+    bool _findForward( const TextSelection& selection, bool rewind );
 
     //* find selection in backward direction
-    virtual bool _findBackward( const TextSelection& selection, bool rewind );
+    bool _findBackward( const TextSelection& selection, bool rewind );
 
     //* get view options matching a given index
-    virtual QStyleOptionViewItemV4 _viewOptions( const QModelIndex& ) const;
+    QStyleOptionViewItemV4 _viewOptions( const QModelIndex& ) const;
 
     protected Q_SLOTS:
 
     //* update geometries
-    virtual void updateGeometries( void );
+    void updateGeometries();
 
     //* sort order
     void sortByColumn( int, Qt::SortOrder );
 
     //* find text from dialog
-    virtual void _findFromDialog( void );
+    void _findFromDialog();
 
     //* update hover index
-    virtual void _updateHoverIndex( void );
+    void _updateHoverIndex();
 
     private Q_SLOTS:
 
     //* update alternate item color
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
     //* install actions
-    virtual void _installActions( void );
+    void _installActions();
 
     //* return first index
     QModelIndex _firstIndex() const;
