@@ -29,13 +29,13 @@
 #include <QStyleOption>
 
 //* graphics item
-class IconViewItem: public Counter
+class IconViewItem final: private Base::Counter<IconViewItem>
 {
 
     public:
 
     //* constructor
-    IconViewItem( void ):
+    explicit IconViewItem():
         Counter( "IconView::Item" )
     {}
 
@@ -43,27 +43,27 @@ class IconViewItem: public Counter
     //@{
 
     //* icon
-    const CustomPixmap& pixmap( void ) const
+    const CustomPixmap& pixmap() const
     { return pixmap_; }
 
     //* text
-    const QString& text( void ) const
+    const QString& text() const
     { return text_; }
 
     //* position
-    QPoint position( void ) const
+    QPoint position() const
     { return position_; }
 
     //* row
-    int row( void ) const
+    int row() const
     { return row_; }
 
     //* column
-    int column( void ) const
+    int column() const
     { return column_; }
 
     //* bounding rect
-    virtual QRect boundingRect( void ) const;
+    QRect boundingRect() const;
 
     //@}
 
@@ -106,21 +106,19 @@ class IconViewItem: public Counter
     using List = QList<IconViewItem>;
 
     //* paint
-    virtual void paint( QPainter*, const QStyleOption*, QWidget* ) const;
+    void paint( QPainter*, const QStyleOption*, QWidget* ) const;
 
-    //* margin
-    static int margin;
-
-    //* spacing
-    static int spacing;
-
-    //* max text width
-    static int maxTextWidth;
+    //*@name metrics
+    //@{
+    static const int margin;
+    static const int spacing;
+    static const int maxTextWidth;
+    //@}
 
     protected:
 
     //* update bounding rect
-    void _updateBoundingRect( void );
+    void _updateBoundingRect();
 
     private:
 
