@@ -47,15 +47,17 @@ ImageFileDialog::ImageFileDialog( QWidget* parent ):
     if( !FileDialog::_workingDirectory().isEmpty() && QFileInfo( FileDialog::_workingDirectory() ).isDir() )
     { setDirectory( QDir( FileDialog::_workingDirectory() ) ); }
 
-    connect( this, SIGNAL(currentChanged(QString)), SLOT(_saveWorkingDirectory(QString)) );
+    Debug::Throw() << "ImageFileDialog::ImageFileDialog - working directory: " << FileDialog::_workingDirectory() << endl;
+
+    connect( this, SIGNAL(directoryEntered(QString)), SLOT(_saveWorkingDirectory(QString)) );
 
     // add image display
     QSplitter* splitter = findChild<QSplitter*>( "splitter" );
     if( splitter )
     {
-        QWidget *main( new QWidget() );
+        QWidget *main( new QWidget );
         splitter->addWidget( main );
-        QVBoxLayout *vLayout = new QVBoxLayout();
+        QVBoxLayout *vLayout = new QVBoxLayout;
         main->setLayout( vLayout );
         vLayout->setSpacing(5);
         vLayout->setMargin(0);
@@ -63,7 +65,7 @@ ImageFileDialog::ImageFileDialog( QWidget* parent ):
         preview_->setAlignment( Qt::AlignCenter );
         preview_->setFrameStyle( QFrame::StyledPanel|QFrame::Sunken );
 
-        QHBoxLayout *hLayout = new QHBoxLayout();
+        QHBoxLayout *hLayout = new QHBoxLayout;
         hLayout->setSpacing(5);
         hLayout->setMargin(0);
         vLayout->addLayout( hLayout );
@@ -75,7 +77,7 @@ ImageFileDialog::ImageFileDialog( QWidget* parent ):
         hLayout->addWidget( button );
         connect( button, SIGNAL(clicked()), SLOT(_preview()) );
 
-    } else Debug::Throw(0) << "QFileDialog::QFileDialog - unable to find splitter." << endl;
+    } else Debug::Throw(0) << "ImageFileDialog::ImageFileDialog - unable to find splitter." << endl;
 
     connect( this, SIGNAL(currentChanged (QString)), SLOT(_currentChanged(QString)) );
 
@@ -104,7 +106,7 @@ void ImageFileDialog::Label::dropEvent( QDropEvent *event )
     if( !event->mimeData()->hasUrls() ) return;
 
     // loop over event URLs
-    foreach( const QUrl& url, event->mimeData()->urls() )
+    for( const auto& url:event->mimeData()->urls() )
     {
         QFileInfo fileInfo( url.toLocalFile() );
         if( fileInfo.exists() )
@@ -114,8 +116,9 @@ void ImageFileDialog::Label::dropEvent( QDropEvent *event )
             else {
 
                 dialog.setDirectory( fileInfo.path() );
-                dialog.selectFile( fileInfo.fileName() );
-                if( dialog.automaticPreview_->isChecked() ) dialog._currentChanged( fileInfo.filePath() );
+                dialog.selectFile( File( fileInfo.fileName() ) );
+                if( dialog.automaticPreview_ && dialog.automaticPreview_->isChecked() )
+                { dialog._currentChanged( fileInfo.filePath() ); }
 
             }
             event->acceptProposedAction();
@@ -128,24 +131,27 @@ void ImageFileDialog::Label::dropEvent( QDropEvent *event )
 //______________________________________________________________________
 void ImageFileDialog::_saveWorkingDirectory( QString directory )
 {
-    Debug::Throw( "ImageFileDialog::_saveWorkingDirectory.\n" );
-    FileDialog::_workingDirectory() = QFileInfo( directory ).absolutePath();
+    Debug::Throw() << "ImageFileDialog::_saveWorkingDirectory - directory: " << directory << endl;
+    FileDialog::_workingDirectory() = File( QFileInfo( directory ).absolutePath() );
 }
 
 //______________________________________________________________________
 void ImageFileDialog::_currentChanged( const QString& value )
 {
     Debug::Throw( "ImageFileDialog::_currentChanged.\n" );
-    currentPath_ = value;
-    if( automaticPreview_->isChecked() ) _preview();
+    currentPath_ = File( value );
+    if( automaticPreview_ && automaticPreview_->isChecked() ) _preview();
 }
 
 //______________________________________________________________________
-void ImageFileDialog::_preview( void )
+void ImageFileDialog::_preview()
 {
 
     Debug::Throw( "ImageFileDialog::_preview.\n" );
 
+    // nothing if no preview
+    if( !preview_ ) return;
+
     // try load svg
     CustomPixmap pixmap;
 
@@ -153,16 +159,16 @@ void ImageFileDialog::_preview( void )
     {
 
         QSize size( 0.8*preview_->width(), 0.8*preview_->height() );
-        pixmap = QIcon( currentPath_ ).pixmap( size );
+        pixmap = CustomPixmap( QIcon( currentPath_ ).pixmap( size ) );
 
-    } else pixmap = CustomPixmap ( currentPath_ );
+    } else pixmap = CustomPixmap( currentPath_ );
 
     // check and scale
     if( pixmap.isNull() ) preview_->setPixmap( QPixmap() );
     else {
 
         if( pixmap.width() > preview_->width()*0.8 || pixmap.height() > preview_->height()*0.8 )
-        { pixmap = pixmap.scaled( int(preview_->width()*0.8), int(preview_->height()*0.8), Qt::KeepAspectRatio, Qt::SmoothTransformation ); }
+        { pixmap = CustomPixmap( pixmap.scaled( int(preview_->width()*0.8), int(preview_->height()*0.8), Qt::KeepAspectRatio, Qt::SmoothTransformation ) ); }
         preview_->setPixmap( pixmap );
 
     }
