@@ -20,6 +20,7 @@
 *
 *******************************************************************************/
 
+#include "Counter.h"
 #include "File.h"
 
 #include <QCheckBox>
@@ -36,13 +37,10 @@ class ImageFileDialog: public QFileDialog
     public:
 
     //* creator
-    ImageFileDialog( QWidget* );
-
-    //* destructor
-    virtual ~ImageFileDialog( void ) = default;
+    explicit ImageFileDialog( QWidget* );
 
     //* select file
-    void selectFile( const QString& filename )
+    void selectFile( const File& filename )
     {
         emit _currentChanged( filename );
         QFileDialog::selectFile( filename );
@@ -54,11 +52,11 @@ class ImageFileDialog: public QFileDialog
     void _currentChanged( const QString& path );
 
     //* display current image
-    void _preview( void );
+    void _preview();
 
     protected:
 
-    virtual void showEvent( QShowEvent* e )
+    void showEvent( QShowEvent* e ) override
     {
         QFileDialog::showEvent(e);
         _preview();
@@ -75,22 +73,22 @@ class ImageFileDialog: public QFileDialog
     QCheckBox* automaticPreview_ = nullptr;
 
     //* current file
-    QString currentPath_;
+    File currentPath_;
 
-    class Label: public QLabel, public Counter
+    class Label: public QLabel, private Base::Counter<Label>
     {
         public:
 
         //* constructor
-        Label( QWidget* parent );
+        explicit Label( QWidget* parent );
 
         protected:
 
         //* drag enter event
-        virtual void dragEnterEvent( QDragEnterEvent* );
+        void dragEnterEvent( QDragEnterEvent* ) override;
 
         //* drop event
-        virtual void dropEvent( QDropEvent* );
+        void dropEvent( QDropEvent* ) override;
 
     };
 
