@@ -34,7 +34,7 @@ class InformationDialog: public DetailsDialog
     public:
 
     //* constructor
-    InformationDialog( QWidget*, const QString& = QString() );
+    explicit InformationDialog( QWidget*, const QString& = QString() );
 
     //* set text
     void setText( const QString& );
@@ -42,7 +42,7 @@ class InformationDialog: public DetailsDialog
     protected:
 
     //* label
-    QLabel& _label( void ) const
+    QLabel& _label() const
     { return *label_; }
 
     private:
