@@ -21,20 +21,22 @@
 *
 *******************************************************************************/
 
-class InterruptionHandler
+#include "NonCopyable.h"
+
+class InterruptionHandler: private Base::NonCopyable<InterruptionHandler>
 {
     public:
 
     //* singleton
-    static InterruptionHandler& get( void );
+    static InterruptionHandler& get();
 
     //* initialize
-    static void initialize( void );
+    static void initialize();
 
     private:
 
     //* constructor
-    InterruptionHandler( void );
+    explicit InterruptionHandler();
 
     //* interruption handler
     static void _handleInterruption( int );
