@@ -32,36 +32,50 @@ class ItemModel : public QAbstractItemModel
     public:
 
     //* constructor
-    ItemModel(QObject *parent = nullptr);
+    explicit ItemModel(QObject* = nullptr);
+
+    //*@name accessors
+    //@{
 
     //* return all indexes in model starting from parent [recursive]
     QModelIndexList indexes( int column = 0, const QModelIndex& parent = QModelIndex() ) const;
 
-    //*@name sorting
-    //@{
-
-    //* sort
-    virtual void sort( void )
-    { sort( sortColumn(), sortOrder() ); }
-
-    //* sort
-    virtual void sort( int column, Qt::SortOrder order = Qt::AscendingOrder );
-
     //* current sorting column
-    const int& sortColumn( void ) const
+    int sortColumn() const
     { return sortColumn_; }
 
     //* current sort order
-    const Qt::SortOrder& sortOrder( void ) const
+    Qt::SortOrder sortOrder() const
     { return sortOrder_; }
 
+    //* get list of internal selected items
+    virtual QModelIndexList selectedIndexes() const = 0;
+
+    //* restore currentIndex
+    virtual QModelIndex currentIndex() const = 0;
+
+    //* true if expended indexes are supported
+    virtual bool supportsExpandedIndexes() const
+    { return false; }
+
+    //* get list of internal selected items
+    virtual QModelIndexList expandedIndexes() const
+    { return QModelIndexList(); }
+
     //@}
 
-    //*@name selected indexes
+    //*@name modifiers
     //@{
 
+    //* sort
+    virtual void sort()
+    { sort( sortColumn(), sortOrder() ); }
+
+    //* sort
+    void sort( int column, Qt::SortOrder order ) override;
+
     //* clear internal list selected items
-    virtual void clearSelectedIndexes( void ) = 0;
+    virtual void clearSelectedIndexes() = 0;
 
     //* set selected indexes
     virtual void setSelectedIndexes( const QModelIndexList& ) = 0;
@@ -69,34 +83,14 @@ class ItemModel : public QAbstractItemModel
     //* store index internal selection state
     virtual void setIndexSelected( const QModelIndex&, bool ) = 0;
 
-    //* get list of internal selected items
-    virtual QModelIndexList selectedIndexes( void ) const = 0;
-
-    //@}
-
-    //*@name current index
-    //@{
-
     //* current index;
-    virtual void clearCurrentIndex( void ) = 0;
+    virtual void clearCurrentIndex() = 0;
 
     //* store current index
     virtual void setCurrentIndex( const QModelIndex& ) = 0;
 
-    //* restore currentIndex
-    virtual QModelIndex currentIndex( void ) const = 0;
-
-    //@}
-
-    //*@name expanded indexes
-    //@{
-
-    //* true if expended indexes are supported
-    virtual bool supportsExpandedIndexes( void ) const
-    { return false; }
-
     //* clear internal list of expanded items
-    virtual void clearExpandedIndexes( void )
+    virtual void clearExpandedIndexes()
     {}
 
     //* set selected indexes
@@ -107,20 +101,17 @@ class ItemModel : public QAbstractItemModel
     virtual void setIndexExpanded( const QModelIndex&, bool )
     {}
 
-    //* get list of internal selected items
-    virtual QModelIndexList expandedIndexes( void ) const
-    { return QModelIndexList(); }
-
     //@}
 
     protected:
 
     //* this sort columns without calling the layout changed callbacks
-    virtual void _sort( void )
+    virtual void _sort()
     { _sort( sortColumn(), sortOrder() ); }
 
     //* private sort, with no signals emitted
-    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder ) = 0;
+    virtual void _sort( int column, Qt::SortOrder order )
+    {}
 
     //* used to sort items in list
     class SortFTor
@@ -129,11 +120,14 @@ class ItemModel : public QAbstractItemModel
         public:
 
         //* constructor
-        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
+        explicit SortFTor( int type, Qt::SortOrder order ):
             type_( type ),
             order_( order )
         {}
 
+        //* destructor
+        virtual ~SortFTor() {};
+
         protected:
 
         //* column
