@@ -28,10 +28,10 @@ class KeyModifier
   public:
 
   //! constructor
-  KeyModifier( const Qt::Key& );
+  explicit KeyModifier( const Qt::Key& );
 
   //! state
-  enum State
+  enum class State
   {
     Off,
     On,
@@ -39,7 +39,7 @@ class KeyModifier
   };
 
   //! get state
-  State state( void ) const;
+  State state() const;
 
   private:
 
