@@ -24,6 +24,7 @@
 #include "BaseIconNames.h"
 #include "Debug.h"
 #include "IconEngine.h"
+#include "StandardAction.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -140,7 +141,7 @@ LineEditor::LineEditor( QWidget* parent ):
 }
 
 //_____________________________________________________________________
-int LineEditor::clearButtonWidth( void ) const
+int LineEditor::clearButtonWidth() const
 {
     // adjust contents size
     QStyleOptionFrame option;
@@ -230,7 +231,7 @@ void LineEditor::installContextMenuActions( BaseContextMenu* menu )
 }
 
 //_____________________________________________________________________
-void LineEditor::lowerCase( void )
+void LineEditor::lowerCase()
 {
 
     // do nothing if object is read only
@@ -246,7 +247,7 @@ void LineEditor::lowerCase( void )
 }
 
 //_____________________________________________________________________
-void LineEditor::upperCase( void )
+void LineEditor::upperCase()
 {
 
     // do nothing if object is read only
@@ -329,7 +330,7 @@ void LineEditor::keyPressEvent( QKeyEvent* event )
 }
 
 //____________________________________________________________
-void LineEditor::_updateClearButton( void ) const
+void LineEditor::_updateClearButton() const
 {
     if( !clearButton_ ) return;
 
@@ -397,7 +398,7 @@ void LineEditor::paintEvent( QPaintEvent* event )
         const Qt::Alignment alignment( QStyle::visualAlignment( frameOption.direction, this->alignment() ) );
 
         // font metrics
-        const QFontMetrics fontMetrics( this->fontMetrics() );
+        auto fontMetrics( this->fontMetrics() );
 
         // adjust text rect
         const int minBearing = qMax(0, -fontMetrics.minLeftBearing());
@@ -421,35 +422,28 @@ void LineEditor::paintEvent( QPaintEvent* event )
 }
 
 //__________________________________________________________
-void LineEditor::_installActions( void )
+void LineEditor::_installActions()
 {
     Debug::Throw( "LineEditor::_installActions.\n" );
 
     // create actions
-    addAction( undoAction_ = new QAction( IconEngine::get( IconNames::Undo ), tr( "Undo" ), this ) );
-    undoAction_->setShortcut( QKeySequence::Undo );
+    addAction( undoAction_ = new StandardAction( StandardAction::Type::Undo, this ) );
     undoAction_->setShortcutContext( Qt::WidgetShortcut );
-    undoAction_->setEnabled( isUndoAvailable() );
     connect( undoAction_, SIGNAL(triggered()), SLOT(undo()) );
 
-    addAction( redoAction_ = new QAction( IconEngine::get( IconNames::Redo ), tr( "Redo" ), this ) );
-    redoAction_->setShortcut( QKeySequence::Redo );
-    redoAction_->setEnabled( isRedoAvailable() );
+    addAction( redoAction_ = new StandardAction( StandardAction::Type::Redo, this ) );
     redoAction_->setShortcutContext( Qt::WidgetShortcut );
     connect( redoAction_, SIGNAL(triggered()), SLOT(redo()) );
 
-    addAction( cutAction_ = new QAction( IconEngine::get( IconNames::Cut ), tr( "Cut" ), this ) );
-    cutAction_->setShortcut( QKeySequence::Cut );
+    addAction( cutAction_ = new StandardAction( StandardAction::Type::Cut, this ) );
     cutAction_->setShortcutContext( Qt::WidgetShortcut );
     connect( cutAction_, SIGNAL(triggered()), SLOT(cut()) );
 
-    addAction( copyAction_ = new QAction( IconEngine::get( IconNames::Copy ), tr( "Copy" ), this ) );
-    copyAction_->setShortcut( QKeySequence::Copy );
+    addAction( copyAction_ = new StandardAction( StandardAction::Type::Copy, this ) );
     copyAction_->setShortcutContext( Qt::WidgetShortcut );
     connect( copyAction_, SIGNAL(triggered()), SLOT(copy()) );
 
-    addAction( pasteAction_ = new QAction( IconEngine::get( IconNames::Paste ), tr( "Paste" ), this ) );
-    pasteAction_->setShortcut( QKeySequence::Paste );
+    addAction( pasteAction_ = new StandardAction( StandardAction::Type::Paste, this ) );
     pasteAction_->setShortcutContext( Qt::WidgetShortcut );
     connect( pasteAction_, SIGNAL(triggered()), SLOT(paste()) );
     connect( qApp->clipboard(), SIGNAL(dataChanged()), SLOT(_updatePasteAction()) );
@@ -480,7 +474,7 @@ void LineEditor::_installActions( void )
 }
 
 //________________________________________________
-void LineEditor::_updateUndoRedoActions( void )
+void LineEditor::_updateUndoRedoActions()
 {
     Debug::Throw( "LineEditor::_updateUndoRedoActions.\n" );
     undoAction_->setEnabled( isUndoAvailable() );
@@ -504,7 +498,7 @@ void LineEditor::_updateSelectionActions()
 }
 
 //________________________________________________
-void LineEditor::_updatePasteAction( void )
+void LineEditor::_updatePasteAction()
 {
 
     Debug::Throw( "LineEditor::_updatePasteAction.\n" );
