@@ -31,7 +31,7 @@
 
 class BaseContextMenu;
 
-class LineEditor: public QLineEdit, public Counter
+class LineEditor: public QLineEdit, private Base::Counter<LineEditor>
 {
 
     //* Qt meta object declaration
@@ -40,23 +40,23 @@ class LineEditor: public QLineEdit, public Counter
     public:
 
     //* constructor
-    LineEditor( QWidget* parent );
+    explicit LineEditor( QWidget* parent );
 
     //* destructor
-    virtual ~LineEditor( void )
+    ~LineEditor() override
     { delete proxyStyle_.data(); }
 
     //@!name accessors
     //@{
 
-    bool hasClearButton( void ) const
+    bool hasClearButton() const
     { return clearButton_ && clearButton_->isVisible(); }
 
     //* return clear button width
-    int clearButtonWidth( void ) const;
+    int clearButtonWidth() const;
 
     //* modification state
-    bool isModified( void ) const
+    bool isModified() const
     { return modified_; }
 
     //@}
@@ -87,7 +87,7 @@ class LineEditor: public QLineEdit, public Counter
     void modificationChanged( bool );
 
     //* emitted when clear button is pressed
-    void cleared( void );
+    void cleared();
 
     public Q_SLOTS:
 
@@ -98,14 +98,29 @@ class LineEditor: public QLineEdit, public Counter
 
     //* clear
     /** copy base class method to make it virtual */
-    virtual void clear( void )
+    virtual void clear()
     { QLineEdit::clear(); }
 
     //* changes selection to uppercase
-    void lowerCase( void );
+    void lowerCase();
 
     //* changes selection to uppercase
-    void upperCase( void );
+    void upperCase();
+
+    protected Q_SLOTS:
+
+    //* update modification state
+    void _modified( const QString& text );
+
+    //* update action status
+    void _updateSelectionActions();
+
+    //* update paste action
+    /** depends on clipboard status and editability */
+    void _updatePasteAction();
+
+    //* update undo/redo actions
+    void _updateUndoRedoActions();
 
     protected:
 
@@ -113,43 +128,26 @@ class LineEditor: public QLineEdit, public Counter
     //@{
 
     //* generic event
-    virtual bool event( QEvent* );
+    bool event( QEvent* ) override;
 
     //* context menu (overloaded)
-    virtual void contextMenuEvent( QContextMenuEvent* );
+    void contextMenuEvent( QContextMenuEvent* ) override;
 
     //* overloaded key press event
-    virtual void keyPressEvent( QKeyEvent* );
+    void keyPressEvent( QKeyEvent* ) override;
+
+    //* paint event
+    void paintEvent( QPaintEvent* ) override;
 
     //@}
 
     //* toggle clear button
-    virtual void _updateClearButton( void ) const;
-
-    protected Q_SLOTS:
-
-    //* update modification state
-    virtual void _modified( const QString& text );
-
-    //* update action status
-    virtual void _updateSelectionActions( void );
-
-    //* update paste action
-    /** depends on clipboard status and editability */
-    virtual void _updatePasteAction( void );
-
-    //* update undo/redo actions
-    virtual void _updateUndoRedoActions( void );
-
-    protected:
-
-    //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void _updateClearButton() const;
 
     private:
 
     //* install actions
-    void _installActions( void );
+    void _installActions();
 
     //* modification state
     bool modified_ = false;
