@@ -64,7 +64,7 @@ void LineNumberDisplay::synchronize( LineNumberDisplay* display )
 }
 
 //__________________________________________
-bool LineNumberDisplay::updateWidth( const int& count )
+bool LineNumberDisplay::updateWidth( int count )
 {
     Debug::Throw( "LineNumberDisplay::updateWidth.\n" );
 
@@ -77,7 +77,7 @@ bool LineNumberDisplay::updateWidth( const int& count )
 }
 
 //__________________________________________
-void LineNumberDisplay::clear( void )
+void LineNumberDisplay::clear()
 {
     Debug::Throw( "LineNumberDisplay::clear.\n" );
     lineNumberData_.clear();
@@ -92,7 +92,7 @@ void LineNumberDisplay::paint( QPainter& painter )
     needsUpdate_ = false;
 
     // font metric and offset
-    const QFontMetrics metric( editor_->fontMetrics() );
+    auto metric( editor_->fontMetrics() );
 
     // calculate dimensions
     int yOffset = editor_->verticalScrollBar()->value() - editor_->frameWidth();
@@ -107,26 +107,26 @@ void LineNumberDisplay::paint( QPainter& painter )
 
     // loop over data
     QTextBlock block( editor_->document()->begin() );
-    unsigned int id( 0 );
+    int id( 0 );
 
-    for( LineNumberData::List::iterator iter = lineNumberData_.begin(); iter != lineNumberData_.end(); ++iter )
+    for( auto& data:lineNumberData_ )
     {
 
         // skip if block is not (yet) in window
-        if( iter->cursor() < firstIndex ) continue;
+        if( data.cursor() < firstIndex ) continue;
 
         // stop if block is outside (below) window
-        if( iter->cursor() > lastIndex ) break;
+        if( data.cursor() > lastIndex ) break;
 
         // check validity
-        if( !iter->isValid() ) _updateLineNumberData( block, id, *iter );
+        if( !data.isValid() ) _updateLineNumberData( block, id, data );
 
         // check position
-        if( iter->isValid() && iter->position() > height ) continue;
+        if( data.isValid() && data.position() > height ) continue;
 
-        QString numtext( QString::number( iter->lineNumber() ) );
+        QString numtext( QString::number( data.lineNumber() ) );
         painter.drawText(
-            0, iter->position(), width_-8,
+            0, data.position(), width_-8,
             metric.lineSpacing(),
             Qt::AlignRight | Qt::AlignTop,
             numtext );
@@ -136,7 +136,7 @@ void LineNumberDisplay::paint( QPainter& painter )
 }
 
 //________________________________________________________
-void LineNumberDisplay::_contentsChanged( void )
+void LineNumberDisplay::_contentsChanged()
 {
 
     // if text is wrapped, line number data needs update at next update
@@ -147,7 +147,7 @@ void LineNumberDisplay::_contentsChanged( void )
 }
 
 //________________________________________________________
-void LineNumberDisplay::_blockCountChanged( void )
+void LineNumberDisplay::_blockCountChanged()
 {
 
     // nothing to be done if wrap mode is not NoWrap, because
@@ -158,16 +158,16 @@ void LineNumberDisplay::_blockCountChanged( void )
 }
 
 //________________________________________________________
-void LineNumberDisplay::_updateLineNumberData( void )
+void LineNumberDisplay::_updateLineNumberData()
 {
 
     lineNumberData_.clear();
 
     // get document
-    unsigned int id( 0 );
-    unsigned int block_count( 1 );
+    int id( 0 );
+    int block_count( 1 );
     QTextDocument &document( *editor_->document() );
-    for( QTextBlock block = document.begin(); block.isValid(); block = block.next(), id++ )
+    for( auto&& block = document.begin(); block.isValid(); block = block.next(), id++ )
     {
 
         // insert new data
@@ -183,7 +183,7 @@ void LineNumberDisplay::_updateLineNumberData( void )
 }
 
 //________________________________________________________
-void LineNumberDisplay::_updateLineNumberData( QTextBlock& block, unsigned int& id, LineNumberDisplay::LineNumberData& data ) const
+void LineNumberDisplay::_updateLineNumberData( QTextBlock& block, int& id, LineNumberDisplay::LineNumberData& data ) const
 {
     Q_ASSERT( !data.isValid() );
 
