@@ -34,7 +34,7 @@
 class TextEditor;
 
 //* display line number of a text editor
-class LineNumberDisplay: public QObject, public Counter
+class LineNumberDisplay: public QObject, private Base::Counter<LineNumberDisplay>
 {
 
     //* Qt meta object
@@ -43,42 +43,42 @@ class LineNumberDisplay: public QObject, public Counter
     public:
 
     //* constructor
-    LineNumberDisplay(TextEditor*);
+    explicit LineNumberDisplay(TextEditor*);
 
     //* synchronization
     void synchronize( LineNumberDisplay* );
 
     //* width
-    virtual bool updateWidth( const int& );
+    bool updateWidth( int );
 
     //* width
-    virtual const int& width( void ) const
+    int width() const
     { return width_; }
 
     //* clear everything
     void clear();
 
     //* paint
-    virtual void paint( QPainter& );
+    void paint( QPainter& );
 
     public Q_SLOTS:
 
     //* need update
-    void needUpdate( void )
+    void needUpdate()
     { needsUpdate_ = true; }
 
     private Q_SLOTS:
 
     //* contents changed
-    void _contentsChanged( void );
+    void _contentsChanged();
 
     //* block count changed
-    void _blockCountChanged( void );
+    void _blockCountChanged();
 
     private:
 
     //* map block number and position
-    class LineNumberData
+    class LineNumberData final
     {
 
         public:
@@ -87,52 +87,48 @@ class LineNumberDisplay: public QObject, public Counter
         using List = QList<LineNumberData>;
 
         //* constructor
-        LineNumberData( const unsigned int& id = 0, const unsigned int& line_number = 0, const int& cursor = 0):
+        explicit LineNumberData( int id = 0, int lineNumber = 0, int cursor = 0):
             id_( id ),
-            lineNumber_( line_number ),
+            lineNumber_( lineNumber ),
             cursor_( cursor ),
             position_( -1 ),
             valid_( false )
         {}
 
-        //* equal to operator
-        bool operator == (const LineNumberData& data )
-        { return id() == data.id(); }
-
         //* id
-        const unsigned int& id( void ) const
+        int id() const
         { return id_; }
 
         //* line number
-        const unsigned int& lineNumber( void ) const
+        int lineNumber() const
         { return lineNumber_; }
 
         //* y
-        const int& cursor( void ) const
+        int cursor() const
         { return cursor_; }
 
         //* position
-        void setPosition( const int& position )
+        void setPosition( int position )
         {
             valid_ = (position >= 0);
             position_ = position;
         }
 
         //* position
-        const int& position( void ) const
+        int position() const
         { return position_; }
 
         //* validity
-        bool isValid( void ) const
+        bool isValid() const
         { return valid_; }
 
         private:
 
         //* block id
-        unsigned int id_;
+        int id_;
 
         //* line number
-        unsigned int lineNumber_;
+        int lineNumber_;
 
         //* position
         int cursor_;
@@ -143,13 +139,17 @@ class LineNumberDisplay: public QObject, public Counter
         //* validity
         bool valid_;
 
+        //* equal to operator
+        friend bool operator == (const LineNumberData& first, const LineNumberData& second )
+        { return first.id() == second.id(); }
+
     };
 
     //* update line number data
-    void _updateLineNumberData( void );
+    void _updateLineNumberData();
 
     //* update invalid data
-    void _updateLineNumberData( QTextBlock&, unsigned int&, LineNumberData& ) const;
+    void _updateLineNumberData( QTextBlock&, int&, LineNumberData& ) const;
 
     //* associated editor
     TextEditor* editor_ = nullptr;
