@@ -27,19 +27,19 @@
 #include <QIcon>
 
 //* FileInfo model. Stores file information for display in lists
-class MimeTypeIconProvider : public QObject, public Counter
+class MimeTypeIconProvider : public QObject, private Base::Counter<MimeTypeIconProvider>
 {
 
     public:
 
     //* constructor
-    MimeTypeIconProvider( QObject* = nullptr );
+    explicit MimeTypeIconProvider( QObject* = nullptr );
 
     //*@name accessors
     //@{
 
     //* icon matching given model index
-    virtual const QIcon& icon( const QString& );
+    const QIcon& icon( const QString& );
 
     //@}
 
@@ -47,11 +47,11 @@ class MimeTypeIconProvider : public QObject, public Counter
     //@{
 
     //* insert item in map
-    virtual void insert( const QString& key, const QString& value )
+    void insert( const QString& key, const QString& value )
     { iconNames_.insert( key, value ); }
 
     //* clear
-    virtual void clear( void )
+    void clear()
     { icons_.clear(); }
 
     //@}
