@@ -27,7 +27,7 @@
 #include "Debug.h"
 
 //* handles multiple clicks and timeout
-class MultipleClickCounter: public QObject, public Counter
+class MultipleClickCounter: public QObject, private Base::Counter<MultipleClickCounter>
 {
 
     Q_OBJECT
@@ -35,19 +35,19 @@ class MultipleClickCounter: public QObject, public Counter
     public:
 
     //* constructor
-    MultipleClickCounter( QObject*, int maxCount );
+    explicit MultipleClickCounter( QObject*, int maxCount );
 
     //* increment counter and return current value
     void increment( int = 0 );
 
     //* returns current counts
-    int counts( void ) const
+    int counts() const
     { return count_; }
 
     protected:
 
     //* timerEvent
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     private:
 
