@@ -36,17 +36,17 @@ class OptionDialog: public CustomDialog
     public:
 
     //* constructor
-    OptionDialog( QWidget* );
+    explicit OptionDialog( QWidget* );
 
     Q_SIGNALS:
 
     //* emitted when options are modified
-    void configurationChanged( void );
+    void configurationChanged();
 
     protected Q_SLOTS:
 
     //* reload options from backup
-    void _reload( void );
+    void _reload();
 
     //* option modified
     void _optionModified( OptionPair );
