@@ -41,14 +41,14 @@ class EditDialog: public CustomDialog
     public:
 
     //! constructor
-    EditDialog( QWidget*, bool, QFileDialog::FileMode );
+    explicit EditDialog( QWidget*, bool, QFileDialog::FileMode );
 
     //! editor
-    BrowsedLineEditor::Editor& editor( void ) const
+    BrowsedLineEditor::Editor& editor() const
     { return *editor_; }
 
     //! checkbox
-    QCheckBox& checkbox( void ) const
+    QCheckBox& checkbox() const
     { return *checkbox_; }
 
     private:
@@ -67,7 +67,7 @@ EditDialog::EditDialog( QWidget* parent, bool browsable, QFileDialog::FileMode m
 {
 
     setOptionName( "OPTIONLISTBOX_EDIT" );
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    QVBoxLayout* vLayout = new QVBoxLayout;
     vLayout->setMargin(0);
     vLayout->setSpacing(5);
     mainLayout().addLayout( vLayout );
@@ -102,7 +102,7 @@ OptionListBox::OptionListBox( QWidget* parent, const QString& name ):
 
     Debug::Throw( "OptionListBox::OptionListBox.\n" );
 
-    QHBoxLayout* layout( new QHBoxLayout() );
+    QHBoxLayout* layout( new QHBoxLayout );
     layout->setSpacing(5);
     layout->setMargin(0);
     setLayout( layout );
@@ -124,10 +124,10 @@ OptionListBox::OptionListBox( QWidget* parent, const QString& name ):
     if( list_->itemDelegate() ) list_->itemDelegate()->deleteLater();
     list_->setItemDelegate( new TextEditionDelegate( this ) );
 
-    list_->setIconSize( IconSize( IconSize::Small ) );
+    list_->setIconSize( IconSize::get( IconSize::Small ) );
     layout->addWidget( list_, 1 );
 
-    QVBoxLayout* buttonLayout = new QVBoxLayout();
+    QVBoxLayout* buttonLayout = new QVBoxLayout;
     buttonLayout->setMargin(0);
     buttonLayout->setSpacing( 5 );
     layout->addLayout( buttonLayout, 0 );
@@ -218,12 +218,12 @@ void OptionListBox::read( const Options& options )
     Options::List values( options.specialOptions( optionName() ) );
 
     // check if one option is default, set first otherwise
-    if( !values.empty() && std::find_if( values.begin(), values.end(), Option::HasFlagFTor( Option::Current ) ) == values.end() )
+    if( !values.empty() && std::find_if( values.begin(), values.end(), Option::HasFlagFTor( Option::Flag::Current ) ) == values.end() )
     { values.front().setCurrent( true ); }
 
     // add to model.
     OptionModel::List optionList;
-    foreach( const Option& option, values )
+    for( const auto& option:values )
     { optionList << OptionPair( optionName(), option ); }
 
     model_->set( optionList );
@@ -241,27 +241,27 @@ void OptionListBox::write( Options& options ) const
     options.clearSpecialOptions( optionName() );
     options.keep( optionName() );
 
-    foreach( const OptionPair& optionPair, model_->children() )
+    for( const auto& optionPair:model_->children() )
     { options.add( optionPair.first, optionPair.second ); }
 
 }
 
 //______________________________________________________________________
-void OptionListBox::_updateButtons( void )
+void OptionListBox::_updateButtons()
 {
     Debug::Throw( "OptionListBox::_updateButtons.\n" );
 
     QModelIndex current( list_->selectionModel()->currentIndex() );
-    edit_->setEnabled( current.isValid() && model_->get( current ).second.hasFlag( Option::Recordable ) );
-    editAction_->setEnabled( current.isValid() && model_->get( current ).second.hasFlag( Option::Recordable ) );
+    edit_->setEnabled( current.isValid() && model_->get( current ).second.hasFlag( Option::Flag::Recordable ) );
+    editAction_->setEnabled( current.isValid() && model_->get( current ).second.hasFlag( Option::Flag::Recordable ) );
 
     default_->setEnabled( current.isValid() );
     defaultAction_->setEnabled( current.isValid() );
 
     bool removeEnabled( false );
-    foreach( const OptionPair& optionPair, model_->get( list_->selectionModel()->selectedRows() ) )
+    for( const auto& optionPair:model_->get( list_->selectionModel()->selectedRows() ) )
     {
-        if( optionPair.second.hasFlag( Option::Recordable ) )
+        if( optionPair.second.hasFlag( Option::Flag::Recordable ) )
         {
             removeEnabled = true;
             break;
@@ -274,7 +274,7 @@ void OptionListBox::_updateButtons( void )
 }
 
 //_______________________________________________________
-void OptionListBox::_add( void )
+void OptionListBox::_add()
 {
     Debug::Throw( "OptionListBox::_add.\n" );
 
@@ -286,7 +286,7 @@ void OptionListBox::_add( void )
     if( dialog.editor().text().isEmpty() ) return;
 
     // create new item
-    const Options::Pair option( optionName(), dialog.editor().text() );
+    OptionPair option( optionName(), Option(dialog.editor().text()) );
     model_->add( option );
 
     // make sure item is selected
@@ -312,16 +312,13 @@ void OptionListBox::_add( void )
 }
 
 //_______________________________________________________
-void OptionListBox::_edit( void )
+void OptionListBox::_edit()
 {
     Debug::Throw( "OptionListBox::_edit.\n" );
 
     // retrieve selection
     QModelIndex current( list_->selectionModel()->currentIndex() );
-    Q_ASSERT( current.isValid() );
-
-    Options::Pair source( model_->get( current ) );
-    Q_ASSERT( source.second.hasFlag( Option::Recordable ) );
+    auto source( model_->get( current ) );
 
     // create dialog
     EditDialog dialog( this, browsable_, fileMode_ );
@@ -337,7 +334,7 @@ void OptionListBox::_edit( void )
     if( dialog.editor().text().isEmpty() ) return;
 
     // modify value
-    Options::Pair destination( source );
+    auto destination( source );
     destination.second.setRaw( dialog.editor().text() );
 
     // re-add to model
@@ -368,14 +365,14 @@ void OptionListBox::_edit( void )
 }
 
 //_______________________________________________________
-void OptionListBox::_remove( void )
+void OptionListBox::_remove()
 {
     Debug::Throw( "OptionListBox::_remove.\n" );
 
     // retrieve selected items; retrieve only recordable options
     OptionModel::List removed;
-    foreach( const OptionPair& optionPair, model_->get( list_->selectionModel()->selectedRows() ) )
-    { if( optionPair.second.hasFlag( Option::Recordable ) ) removed << optionPair; }
+    for( const auto& optionPair:model_->get( list_->selectionModel()->selectedRows() ) )
+    { if( optionPair.second.hasFlag( Option::Flag::Recordable ) ) removed << optionPair; }
 
     // remove
     model_->remove( removed );
@@ -386,7 +383,7 @@ void OptionListBox::_remove( void )
 }
 
 //_______________________________________________________
-void OptionListBox::_setDefault( void )
+void OptionListBox::_setDefault()
 {
     Debug::Throw( "OptionListBox::_setDefault.\n" );
 
@@ -395,11 +392,10 @@ void OptionListBox::_setDefault( void )
     Q_ASSERT( current.isValid() );
 
     // get matching option
-    Options::Pair currentOption( model_->get( current ) );
+    auto currentOption( model_->get( current ) );
 
     OptionModel::List options( model_->children() );
-    for( OptionModel::List::iterator iter = options.begin(); iter != options.end(); ++iter )
-    { iter->second.setCurrent( false ); }
+    for( auto& option:options ) option.second.setCurrent( false );
 
     model_->set( options );
 
