@@ -25,43 +25,24 @@
 #include "Options.h"
 #include "TreeModel.h"
 
-class OptionPair: public Options::Pair
+#include <array>
+
+using OptionPair = Options::Pair;
+
+//___________________________________________________________________
+inline bool operator == ( const OptionPair& first, const OptionPair& second )
+{ return first.first == second.first && first.second.raw() == second.second.raw(); }
+
+//___________________________________________________________________
+namespace Base
 {
+    //* isChild operator, needed for TreeModel
+    template<> bool isChild<OptionPair>( const OptionPair&, const OptionPair& );
 
-    public:
+}
 
-    //* constructor
-    OptionPair( void )
-    {}
-
-    //* constructor
-    OptionPair( const Options::Pair& option ):
-        Options::Pair( option )
-     {}
-
-    //* constructor
-    OptionPair( const QString& name, const Option& option ):
-        Options::Pair( name, option )
-    {}
-
-    //* equal to operator
-    bool operator == ( const OptionPair& other ) const
-    { return first == other.first && second.raw() == other.second.raw(); }
-
-    //* returns true if this record is a child of argument
-    bool isChild( const OptionPair& other ) const
-    { return other.first == first && other.second.raw().isEmpty(); }
-
-    //* write to stream
-    friend QTextStream& operator << (QTextStream& out, const OptionPair& pair )
-    {
-        out << pair.first << " " << pair.second.raw();
-        return out;
-    }
-
-};
-
-class OptionModel: public TreeModel<OptionPair>, public Counter
+//___________________________________________________________________
+class OptionModel: public TreeModel<OptionPair>, private Base::Counter<OptionModel>
 {
 
     Q_OBJECT
@@ -80,7 +61,7 @@ class OptionModel: public TreeModel<OptionPair>, public Counter
     };
 
     //* constructor
-    OptionModel( QObject* parent = nullptr ):
+    explicit OptionModel( QObject* parent = nullptr ):
         TreeModel<OptionPair>( parent ),
         Counter( "OptionModel" )
     {}
@@ -90,26 +71,26 @@ class OptionModel: public TreeModel<OptionPair>, public Counter
     { readOnly_ = value; }
 
     //* is read only
-    bool isReadOnly( void ) const
+    bool isReadOnly() const
     { return readOnly_; }
 
     //*@name methods reimplemented from base class
     //@{
 
     //* flags
-    virtual Qt::ItemFlags flags( const QModelIndex& ) const;
+    Qt::ItemFlags flags( const QModelIndex& ) const override;
 
     // return data for a given index
-    virtual QVariant data( const QModelIndex&, int ) const;
+    QVariant data( const QModelIndex&, int ) const override;
 
     // modify data
-    virtual bool setData( const QModelIndex&, const QVariant&, int = Qt::EditRole );
+    bool setData( const QModelIndex&, const QVariant&, int = Qt::EditRole ) override;
 
     //* header data
-    virtual QVariant headerData( int, Qt::Orientation, int role = Qt::DisplayRole ) const;
+    QVariant headerData( int, Qt::Orientation, int role = Qt::DisplayRole ) const override;
 
     //* number of columns for a given index
-    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
+    int columnCount( const QModelIndex& = QModelIndex() ) const override
     { return nColumns; }
 
     //@}
@@ -125,7 +106,7 @@ class OptionModel: public TreeModel<OptionPair>, public Counter
     protected:
 
     //* sorting
-    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
+    void _sort( int column, Qt::SortOrder order ) override
     { _root().sort( SortFTor( column, order ) ); }
 
     private:
@@ -137,7 +118,7 @@ class OptionModel: public TreeModel<OptionPair>, public Counter
         public:
 
         //* constructor
-        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
+        explicit SortFTor( int type, Qt::SortOrder order ):
             ItemModel::SortFTor( type, order )
         {}
 
@@ -154,7 +135,14 @@ class OptionModel: public TreeModel<OptionPair>, public Counter
     bool readOnly_ = true;
 
     //* column titles
-    static const QString columnTitles_[ nColumns ];
+    const std::array<QString, nColumns> columnTitles_ =
+    {{
+        tr( "Name" ),
+        "",
+        tr( "Current Value" ),
+        tr( "Default Value" ),
+        tr( "Flags" )
+    }};
 
 };
 
