@@ -34,7 +34,7 @@ class OptionSlider: public CustomSlider, public OptionWidget
     public:
 
     //* constructor
-    OptionSlider( QWidget* parent, const QString& optionName ):
+    explicit OptionSlider( QWidget* parent, const QString& optionName ):
         CustomSlider( parent ),
         OptionWidget( optionName, this )
     {}
@@ -44,7 +44,7 @@ class OptionSlider: public CustomSlider, public OptionWidget
     { scale_ = scale; }
 
     //* read value from option
-    void read( const Options& options )
+    void read( const Options& options ) override
     {
         setValue( static_cast<int>(round(scale_*options.get<double>( optionName() ))));
         if( !_connected() )
@@ -55,13 +55,13 @@ class OptionSlider: public CustomSlider, public OptionWidget
     }
 
     //* write value to option
-    void write( Options& options ) const
+    void write( Options& options ) const override
     { options.set<double>( optionName(), static_cast<double>(slider().value())/scale_ ); }
 
     Q_SIGNALS:
 
     //* modified
-    void modified( void );
+    void modified();
 
     private:
 
