@@ -36,7 +36,7 @@ class OptionSpinBox: public QWidget, public OptionWidget
     public:
 
     //* constructor
-    OptionSpinBox( QWidget* parent, const QString& optionName, bool addStretch = true ):
+    explicit OptionSpinBox( QWidget* parent, const QString& optionName, bool addStretch = true ):
         QWidget( parent ),
         OptionWidget( optionName, this )
     {
@@ -52,7 +52,7 @@ class OptionSpinBox: public QWidget, public OptionWidget
     { scale_ = scale; }
 
     //* read value from option
-    void read( const Options& options )
+    void read( const Options& options ) override
     {
         setValue( static_cast<int>(round(scale_*options.get<double>( optionName() ))));
         if( !_connected() )
@@ -63,7 +63,7 @@ class OptionSpinBox: public QWidget, public OptionWidget
     }
 
     //* write value to option
-    void write( Options& options ) const
+    void write( Options& options ) const override
     { options.set<double>( optionName(), static_cast<double>(value())/scale_ ); }
 
     //* special value text
@@ -80,7 +80,7 @@ class OptionSpinBox: public QWidget, public OptionWidget
     void setValue( int value )
     { spinBox_->setValue( value ); }
 
-    int value( void ) const
+    int value() const
     { return spinBox_->value(); }
 
     void setMinimum( int value )
@@ -97,7 +97,7 @@ class OptionSpinBox: public QWidget, public OptionWidget
     Q_SIGNALS:
 
     //* modified
-    void modified( void );
+    void modified();
 
     private:
 
