@@ -30,11 +30,14 @@ class OptionWidget
     public:
 
     //* constructor
-    OptionWidget( const QString& name, QObject* budy = 0 ):
+    explicit OptionWidget( const QString& name, QObject* budy = nullptr ):
         optionName_( name ),
         buddy_( budy )
     {}
 
+    //* destructor
+    virtual ~OptionWidget() = default;
+
     //* set widget value from option value
     virtual void read( const Options& ) = 0;
 
@@ -42,25 +45,25 @@ class OptionWidget
     virtual void write( Options& ) const = 0;
 
     //* true if has buddy
-    bool hasBuddy( void ) const
+    bool hasBuddy() const
     { return buddy_; }
 
     //* buddy
-    QObject& buddy( void ) const
+    QObject& buddy() const
     { return *buddy_; }
 
     //* option name
-    const QString& optionName( void ) const
+    const QString& optionName() const
     { return optionName_; }
 
     protected:
 
     //* set buddy
-    virtual void _setBuddy( QObject* buddy )
+    void _setBuddy( QObject* buddy )
     { buddy_ = buddy; }
 
     //* true when connected
-    bool _connected( void ) const
+    bool _connected() const
     { return connected_; }
 
     //* set connected
