@@ -50,7 +50,7 @@ void OptionWidgetList::read( const Options& options )
 {
 
     Debug::Throw( "OptionWidgetList::read.\n" );
-    foreach( OptionWidget* widget, optionWidgets_ )
+    for( const auto& widget:optionWidgets_ )
     {
         widget->read( options );
         if( !_connected() && hasBuddy() && widget->hasBuddy() )
@@ -70,12 +70,12 @@ void OptionWidgetList::read( const Options& options )
 void OptionWidgetList::write( Options& options ) const
 {
     Debug::Throw( "OptionWidgetList::write\n" );
-    foreach( OptionWidget* widget, optionWidgets_ )
+    for( const auto& widget:optionWidgets_ )
     { widget->write( options ); }
 }
 
 //__________________________________________________
-int OptionWidgetList::_checkBoxSpacing( void ) const
+int OptionWidgetList::_checkBoxSpacing() const
 {
     QStyleOption option;
     option.rect = QRect( 0, 0, 50, 50 );
