@@ -44,251 +44,255 @@
 #include <QToolButton>
 
 //___________________________________________________________________
-const qreal PathEditorButton::BorderWidth = 1.5;
 const QString PathEditor::MimeType( "internal/path-editor-item" );
 
-//____________________________________________________________________________
-bool PathEditorButton::event( QEvent* event )
+namespace Private
 {
 
-    switch( event->type() )
+    //___________________________________________________________________
+    const qreal PathEditorButton::BorderWidth = 1.5;
+
+    //____________________________________________________________________________
+    bool PathEditorButton::event( QEvent* event )
     {
 
-        case QEvent::HoverEnter: mouseOver_ = true; break;
-        case QEvent::HoverLeave: mouseOver_ = false; break;
-        default: break;
-    }
+        switch( event->type() )
+        {
 
-    return QAbstractButton::event( event );
+            case QEvent::HoverEnter: mouseOver_ = true; break;
+            case QEvent::HoverLeave: mouseOver_ = false; break;
+            default: break;
+        }
 
-}
-
-//____________________________________________________________________________
-PathEditorItem::PathEditorItem( QWidget* parent ):
-    PathEditorButton( parent ),
-    Counter( "PathEditorItem" ),
-    isLocal_( true ),
-    isSelectable_( true ),
-    isLast_( false )
-{
-    Debug::Throw( "PathEditorItem::PathEditorItem.\n" );
-    dragMonitor_ = new DragMonitor( this );
-    dragMonitor_->setDragEnabled( false );
-    connect( dragMonitor_, SIGNAL(dragStarted(QPoint)), this, SLOT(_startDrag(QPoint)));
-}
-
-//____________________________________________________________________________
-void PathEditorItem::setPath( const File& path, const QString& name )
-{
-
-    Debug::Throw( "PathEditorItem::setPath.\n" );
-
-    path_ = path;
-
-    if( name.isEmpty() )
-    {
-
-        // get local name
-        File localName( path.localName() );
-        if( localName.endsWith( "/" ) ) localName = localName.left( localName.size()-1 );
-        Q_ASSERT( !localName.isEmpty() );
-
-        setText( localName );
-
-    } else setText( name );
-
-    updateMinimumSize();
-
-}
-
-//____________________________________________________________________________
-void PathEditorItem::updateMinimumSize( void )
-{
-    Debug::Throw( "PathEditorItem::updateMinimumSize.\n" );
-    QFont adjustedFont(font());
-    adjustedFont.setBold( isLast_ );
-
-    // text size
-    QSize size( QFontMetrics( adjustedFont ).boundingRect( text() ).size() );
-
-    // margins
-    size.rwidth() += 2*BorderWidth;
-    size.rheight() += 4*BorderWidth;
-
-    // arrow width
-    const int arrowWidth( _arrowWidth() );
-    if( arrowWidth > 0 ) size.rwidth() += arrowWidth + 2*BorderWidth;
-
-    // update
-    setMinimumSize( size );
-}
-
-//_______________________________________________
-void PathEditorItem::_startDrag( QPoint dragOrigin )
-{
-
-    Debug::Throw( "PathEditorItem::_startDrag.\n" );
-
-    // start drag
-    QDrag *drag = new QDrag(this);
-    QMimeData *mimeData = new QMimeData;
-
-    // fill Drag data. Use XML
-    QDomDocument document;
-    QDomElement top = document.appendChild( document.createElement( Xml::FileInfoList ) ).toElement();
-
-    BaseFileInfo fileInfo( path_ );
-    fileInfo.setAlias( text() );
-    fileInfo.setIsFolder();
-    if( isLocal_ )
-    {
-
-        fileInfo.setLocal();
-        fileInfo.update();
-        if( path_.isLink() ) fileInfo.setIsLink();
-        if( path_.isBrokenLink() ) fileInfo.setIsBrokenLink();
-        if( path_.isHidden() ) fileInfo.setIsHidden();
-
-    } else fileInfo.setRemote();
-
-    top.appendChild( fileInfo.domElement( document ) );
-
-    const QString value( prefix_.isEmpty() ? path_ : prefix_ + "//" + path_ );
-    mimeData->setText( value );
-    mimeData->setData( PathEditor::MimeType, document.toByteArray() );
-    drag->setMimeData( mimeData );
-
-    // create drag pixmap
-    QPixmap pixmap( size() );
-    pixmap.fill( Qt::transparent );
-    QPainter painter( &pixmap );
-    _paint( &painter );
-
-    drag->setPixmap( pixmap );
-    drag->setHotSpot( QPoint( (dragOrigin-rect().topLeft()).x(), 0 ) );
-
-    drag->start();
-
-}
-
-//____________________________________________________________________________
-void PathEditorItem::paintEvent( QPaintEvent* event )
-{
-    QPainter painter( this );
-    painter.setClipRegion( event->region() );
-
-    _paint( &painter );
-    painter.end();
-}
-
-//____________________________________________________________________________
-void PathEditorItem::_paint( QPainter* painter )
-{
-
-    // render mouse over
-    if( _mouseOver() && isSelectable() )
-    {
-
-        QStyleOptionViewItemV4 option;
-        option.initFrom( this );
-        option.showDecorationSelected = true;
-        option.rect = rect();
-        option.state |= QStyle::State_MouseOver;
-        style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, painter, _itemView() );
+        return QAbstractButton::event( event );
 
     }
 
-    // save layout direction
-    const bool isRightToLeft( qApp->isRightToLeft() );
-
-    // render text
-    QRect textRect( rect().adjusted( 0, 2*BorderWidth, 0, -2*BorderWidth ) );
-    if( !isLast_ )
+    //____________________________________________________________________________
+    PathEditorItem::PathEditorItem( QWidget* parent ):
+        PathEditorButton( parent ),
+        Counter( "PathEditorItem" ),
+        isLocal_( true ),
+        isSelectable_( true ),
+        isLast_( false )
     {
-        if( isRightToLeft ) textRect.adjust(_arrowWidth()-2*BorderWidth, 0, 0, 0 );
-        else textRect.adjust( 0, 0, -_arrowWidth()-2*BorderWidth, 0 );
+        Debug::Throw( "PathEditorItem::PathEditorItem.\n" );
+        dragMonitor_ = new DragMonitor( this );
+        dragMonitor_->setDragEnabled( false );
+        connect( dragMonitor_, SIGNAL(dragStarted(QPoint)), SLOT(_startDrag(QPoint)));
     }
 
-    QFont adjustedFont(font());
-    adjustedFont.setBold( isLast_ );
-    painter->setFont( adjustedFont );
-    painter->drawText( QRectF( textRect ), Qt::AlignHCenter|Qt::AlignBottom|Qt::TextHideMnemonic, text() );
-
-    // render arrow
-    if( !isLast_ )
+    //____________________________________________________________________________
+    void PathEditorItem::setPath( const File& path, const QString& name )
     {
-        QStyleOption option;
-        option.initFrom(this);
 
-        if( isRightToLeft ) option.rect = QRect( 0, 0, textRect.left()+BorderWidth, rect().height() );
-        else option.rect = QRect( textRect.width(), 0, rect().width()-textRect.width()-BorderWidth, rect().height() );
+        Debug::Throw( "PathEditorItem::setPath.\n" );
 
-        option.palette = palette();
-        style()->drawPrimitive( isRightToLeft ? QStyle::PE_IndicatorArrowLeft:QStyle::PE_IndicatorArrowRight, &option, painter, this );
-    }
+        path_ = path;
 
-}
+        if( name.isEmpty() )
+        {
 
-//____________________________________________________________________________
-void PathEditorMenuButton::paintEvent( QPaintEvent* event )
-{
-    QPainter painter( this );
-    painter.setClipRegion( event->region() );
+            // get local name
+            File localName( path.localName().removeTrailingSlash() );
+            setText( localName );
 
-    if( _mouseOver() )
-    {
-        // mouse over
-        QStyleOptionViewItemV4 option;
-        option.initFrom( this );
-        option.showDecorationSelected = true;
-        option.rect = rect();
-        option.state |= QStyle::State_MouseOver;
-        style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, &painter, _itemView() );
+        } else setText( name );
+
+        updateMinimumSize();
 
     }
 
+    //____________________________________________________________________________
+    void PathEditorItem::updateMinimumSize()
     {
-        // arrow
-        QStyleOption option;
-        option.initFrom(this);
-        option.rect = rect();
-        option.palette = palette();
-        const bool isRightToLeft( qApp->isRightToLeft() );
-        style()->drawPrimitive( isRightToLeft ? QStyle::PE_IndicatorArrowLeft:QStyle::PE_IndicatorArrowRight, &option, &painter, this);
+        Debug::Throw( "PathEditorItem::updateMinimumSize.\n" );
+        QFont adjustedFont(font());
+        adjustedFont.setBold( isLast_ );
+
+        // text size
+        QSize size( QFontMetrics( adjustedFont ).boundingRect( text() ).size() );
+
+        // margins
+        size.rwidth() += 2*BorderWidth;
+        size.rheight() += 4*BorderWidth;
+
+        // arrow width
+        const int arrowWidth( _arrowWidth() );
+        if( arrowWidth > 0 ) size.rwidth() += arrowWidth + 2*BorderWidth;
+
+        // update
+        setMinimumSize( size );
     }
 
-    painter.end();
+    //_______________________________________________
+    void PathEditorItem::_startDrag( QPoint dragOrigin )
+    {
 
-}
+        Debug::Throw( "PathEditorItem::_startDrag.\n" );
 
-//____________________________________________________________________________
-void PathEditorMenuButton::updateMinimumSize( void )
-{
-    Debug::Throw( "PathEditorMenuButton::updateMinimumSize.\n" );
-    QFont adjustedFont(font());
-    adjustedFont.setBold( true );
+        // start drag
+        QDrag *drag = new QDrag(this);
+        QMimeData *mimeData = new QMimeData;
 
-    QFontMetrics metrics( adjustedFont );
-    QSize size( metrics.height(), metrics.height() );
-    size.rwidth() += 2*BorderWidth;
-    size.rheight() += 4*BorderWidth;
+        // fill Drag data. Use XML
+        QDomDocument document;
+        QDomElement top = document.appendChild( document.createElement( Xml::FileInfoList ) ).toElement();
 
-    // update
-    setMinimumSize( size );
-}
+        BaseFileInfo fileInfo( path_ );
+        fileInfo.setAlias( text() );
+        fileInfo.setIsFolder();
+        if( isLocal_ )
+        {
 
-//________________________________________________________________________
-void PathEditorSwitch::paintEvent( QPaintEvent* event )
-{
+            fileInfo.setLocal();
+            fileInfo.update();
+            if( path_.isLink() ) fileInfo.setIsLink();
+            if( path_.isBrokenLink() ) fileInfo.setIsBrokenLink();
+            if( path_.isHidden() ) fileInfo.setIsHidden();
 
-    if( _mouseOver() && isEnabled() )
+        } else fileInfo.setRemote();
+
+        top.appendChild( fileInfo.domElement( document ) );
+
+        const QString value( prefix_.isEmpty() ? path_ : prefix_ + "//" + path_ );
+        mimeData->setText( value );
+        mimeData->setData( PathEditor::MimeType, document.toByteArray() );
+        drag->setMimeData( mimeData );
+
+        // create drag pixmap
+        QPixmap pixmap( size() );
+        pixmap.fill( Qt::transparent );
+        QPainter painter( &pixmap );
+        _paint( &painter );
+
+        drag->setPixmap( pixmap );
+        drag->setHotSpot( QPoint( (dragOrigin-rect().topLeft()).x(), 0 ) );
+
+        drag->start();
+
+    }
+
+    //____________________________________________________________________________
+    void PathEditorItem::paintEvent( QPaintEvent* event )
     {
         QPainter painter( this );
         painter.setClipRegion( event->region() );
 
-        painter.setPen( QPen( palette().color( foregroundRole() ), 2 ) );
-        painter.setBrush( Qt::NoBrush );
-        painter.drawLine( rect().topLeft() + QPoint( 1, 2*BorderWidth ), rect().bottomLeft() + QPoint( 1, -2*BorderWidth ) );
+        _paint( &painter );
+        painter.end();
+    }
+
+    //____________________________________________________________________________
+    void PathEditorItem::_paint( QPainter* painter )
+    {
+
+        // render mouse over
+        if( _mouseOver() && isSelectable() )
+        {
+
+            QStyleOptionViewItemV4 option;
+            option.initFrom( this );
+            option.showDecorationSelected = true;
+            option.rect = rect();
+            option.state |= QStyle::State_MouseOver;
+            style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, painter, _itemView() );
+
+        }
+
+        // save layout direction
+        const bool isRightToLeft( qApp->isRightToLeft() );
+
+        // render text
+        QRect textRect( rect().adjusted( 0, 2*BorderWidth, 0, -2*BorderWidth ) );
+        if( !isLast_ )
+        {
+            if( isRightToLeft ) textRect.adjust(_arrowWidth()-2*BorderWidth, 0, 0, 0 );
+            else textRect.adjust( 0, 0, -_arrowWidth()-2*BorderWidth, 0 );
+        }
+
+        QFont adjustedFont(font());
+        adjustedFont.setBold( isLast_ );
+        painter->setFont( adjustedFont );
+        painter->drawText( QRectF( textRect ), Qt::AlignHCenter|Qt::AlignBottom|Qt::TextHideMnemonic, text() );
+
+        // render arrow
+        if( !isLast_ )
+        {
+            QStyleOption option;
+            option.initFrom(this);
+
+            if( isRightToLeft ) option.rect = QRect( 0, 0, textRect.left()+BorderWidth, rect().height() );
+            else option.rect = QRect( textRect.width(), 0, rect().width()-textRect.width()-BorderWidth, rect().height() );
+
+            option.palette = palette();
+            style()->drawPrimitive( isRightToLeft ? QStyle::PE_IndicatorArrowLeft:QStyle::PE_IndicatorArrowRight, &option, painter, this );
+        }
+
+    }
+
+    //____________________________________________________________________________
+    void PathEditorMenuButton::paintEvent( QPaintEvent* event )
+    {
+        QPainter painter( this );
+        painter.setClipRegion( event->region() );
+
+        if( _mouseOver() )
+        {
+            // mouse over
+            QStyleOptionViewItemV4 option;
+            option.initFrom( this );
+            option.showDecorationSelected = true;
+            option.rect = rect();
+            option.state |= QStyle::State_MouseOver;
+            style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, &painter, _itemView() );
+
+        }
+
+        {
+            // arrow
+            QStyleOption option;
+            option.initFrom(this);
+            option.rect = rect();
+            option.palette = palette();
+            const bool isRightToLeft( qApp->isRightToLeft() );
+            style()->drawPrimitive( isRightToLeft ? QStyle::PE_IndicatorArrowLeft:QStyle::PE_IndicatorArrowRight, &option, &painter, this);
+        }
+
+        painter.end();
+
+    }
+
+    //____________________________________________________________________________
+    void PathEditorMenuButton::updateMinimumSize()
+    {
+        Debug::Throw( "PathEditorMenuButton::updateMinimumSize.\n" );
+        QFont adjustedFont(font());
+        adjustedFont.setBold( true );
+
+        QFontMetrics metrics( adjustedFont );
+        QSize size( metrics.height(), metrics.height() );
+        size.rwidth() += 2*BorderWidth;
+        size.rheight() += 4*BorderWidth;
+
+        // update
+        setMinimumSize( size );
+    }
+
+    //________________________________________________________________________
+    void PathEditorSwitch::paintEvent( QPaintEvent* event )
+    {
+
+        if( _mouseOver() && isEnabled() )
+        {
+            QPainter painter( this );
+            painter.setClipRegion( event->region() );
+
+            painter.setPen( QPen( palette().color( foregroundRole() ), 2 ) );
+            painter.setBrush( Qt::NoBrush );
+            painter.drawLine( rect().topLeft() + QPoint( 1, 2*BorderWidth ), rect().bottomLeft() + QPoint( 1, -2*BorderWidth ) );
+        }
+
     }
 
 }
@@ -314,33 +318,33 @@ PathEditor::PathEditor( QWidget* parent ):
         itemView_ = new QListView( this );
         itemView_->hide();
 
-        browserContainer_ = new QWidget();
+        browserContainer_ = new QWidget;
         browserContainer_->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
 
-        QHBoxLayout* hLayout = new QHBoxLayout();
+        QHBoxLayout* hLayout = new QHBoxLayout;
         hLayout->setSpacing(0);
         hLayout->setMargin(0);
         browserContainer_->setLayout( hLayout );
 
         // prefix label
         prefixLabel_ = new QLabel( browserContainer_ );
-        prefixLabel_->setMargin( 2*PathEditorButton::BorderWidth );
+        prefixLabel_->setMargin( 2*Private::PathEditorButton::BorderWidth );
         hLayout->addWidget( prefixLabel_ );
         prefixLabel_->hide();
 
         // menu button
-        hLayout->addWidget( menuButton_ = new PathEditorMenuButton( browserContainer_ ) );
+        hLayout->addWidget( menuButton_ = new Private::PathEditorMenuButton( browserContainer_ ) );
         menuButton_->setItemView( itemView_ );
         menuButton_->hide();
         connect( menuButton_, SIGNAL(clicked()), SLOT(_menuButtonClicked()) );
 
         // button layout
-        hLayout->addLayout( buttonLayout_ = new QHBoxLayout() );
+        hLayout->addLayout( buttonLayout_ = new QHBoxLayout );
         buttonLayout_->setSpacing(0);
         buttonLayout_->setMargin(0);
 
         // switch
-        PathEditorSwitch* editorSwitch = new PathEditorSwitch( browserContainer_ );
+        Private::PathEditorSwitch* editorSwitch = new Private::PathEditorSwitch( browserContainer_ );
         hLayout->addWidget( editorSwitch, 1 );
         connect( editorSwitch, SIGNAL(clicked()), SLOT(_showEditor()) );
 
@@ -354,10 +358,10 @@ PathEditor::PathEditor( QWidget* parent ):
 
     {
         // editor
-        editorContainer_ = new QWidget();
+        editorContainer_ = new QWidget;
         editorContainer_->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
 
-        QHBoxLayout* hLayout = new QHBoxLayout();
+        QHBoxLayout* hLayout = new QHBoxLayout;
         hLayout->setSpacing(0);
         hLayout->setMargin(0);
         editorContainer_->setLayout( hLayout );
@@ -371,7 +375,7 @@ PathEditor::PathEditor( QWidget* parent ):
         button->setIcon( IconEngine::get( IconNames::DialogOk ) );
         button->setAutoRaise( true );
         button->setToolButtonStyle( Qt::ToolButtonIconOnly );
-        button->setIconSize( IconSize( IconSize::Small ) );
+        button->setIconSize( IconSize::get( IconSize::Small ) );
         button->setFixedSize( QSize( editor_->height(), editor_->height() ) );
         hLayout->addWidget( button );
 
@@ -398,13 +402,13 @@ PathEditor::PathEditor( QWidget* parent ):
     setCurrentWidget( browserContainer_ );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
 
 //____________________________________________________________________________
-File PathEditor::path( void ) const
+File PathEditor::path() const
 {
     Debug::Throw( "PathEditor::path.\n" );
     QString path( editor_->currentText() );
@@ -415,11 +419,11 @@ File PathEditor::path( void ) const
         { path = path.mid( prefix.size() ); }
     }
 
-    return path;
+    return File( path );
 }
 
 //____________________________________________________________________________
-bool PathEditor::hasParent( void ) const
+bool PathEditor::hasParent() const
 {
     if( items_.isEmpty() ) return false;
     else if( items_.back()->isSelectable() ) return items_.size() >= 2;
@@ -427,15 +431,15 @@ bool PathEditor::hasParent( void ) const
 }
 
 //____________________________________________________________________________
-bool PathEditor::hasPrevious( void ) const
+bool PathEditor::hasPrevious() const
 { return history_->previousAvailable(); }
 
 //____________________________________________________________________________
-bool PathEditor::hasNext( void ) const
+bool PathEditor::hasNext() const
 { return history_->nextAvailable(); }
 
 //____________________________________________________________________________
-QSize PathEditor::minimumSizeHint( void ) const
+QSize PathEditor::minimumSizeHint() const
 {
     int minWidth( 0 );
 
@@ -491,7 +495,7 @@ void PathEditor::setIsLocal( bool value )
 
     // assign to this widget, and children
     isLocal_ = value;
-    foreach( PathEditorItem* item, items_ )
+    for( const auto& item:items_ )
     { item->setIsLocal( value ); }
 
 }
@@ -503,7 +507,7 @@ void PathEditor::setDragEnabled( bool value )
 
     // assign to this widget, and children
     dragEnabled_ = value;
-    foreach( PathEditorItem* item, items_ )
+    for( const auto& item:items_ )
     { item->dragMonitor().setDragEnabled( value ); }
 
 }
@@ -518,10 +522,10 @@ void PathEditor::setPath( const File& constPath, const File& file )
     {
 
         // search proper root path
-        File root( "/" );
-        File path( constPath );
+        QString root( "/" );
+        QString path( constPath );
 
-        foreach( const File& file, rootPathList_ )
+        for( const auto& file:rootPathList_ )
         {
             if( path.startsWith( file ) )
             {
@@ -540,7 +544,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
         // create root item
         int index = 0;
-        PathEditorItem* item(0);
+        Private::PathEditorItem* item(0);
         if( index < items_.size() ) {
 
             item = items_[index];
@@ -548,7 +552,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
         } else {
 
-            item = new PathEditorItem( browserContainer_ );
+            item = new Private::PathEditorItem( browserContainer_ );
             item->setPrefix( prefix_ );
             item->setIsLocal( isLocal_ );
             item->setItemView( itemView_ );
@@ -559,8 +563,8 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
         }
 
-        if( hasHome && root == home_ ) item->setPath( root, "Home" );
-        else item->setPath( root, "Root" );
+        if( hasHome && root == home_ ) item->setPath( File( root ), "Home" );
+        else item->setPath( File( root ), "Root" );
         index++;
 
         // create path items
@@ -579,7 +583,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
             } else {
 
-                item = new PathEditorItem( browserContainer_ );
+                item = new Private::PathEditorItem( browserContainer_ );
                 item->setPrefix( prefix_ );
                 item->setIsLocal( isLocal_ );
                 item->setItemView( itemView_ );
@@ -590,8 +594,8 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
             }
 
-            if( hasHome && section == home_ ) item->setPath( section, "Home" );
-            else item->setPath( section );
+            if( hasHome && section == home_ ) item->setPath( File( section ), "Home" );
+            else item->setPath( File( section ) );
             index++;
         }
 
@@ -607,7 +611,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
             } else {
 
-                item = new PathEditorItem( browserContainer_ );
+                item = new Private::PathEditorItem( browserContainer_ );
                 item->setPrefix( prefix_ );
                 item->setIsLocal( isLocal_ );
                 item->setItemView( itemView_ );
@@ -618,7 +622,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
             }
 
-            item->setPath( file.addPath( path ) );
+            item->setPath( File( file ).addPath( File( path ) ) );
             item->setIsSelectable( false );
             index++;
 
@@ -648,13 +652,13 @@ void PathEditor::setPath( const File& constPath, const File& file )
 
     // update editor
     {
-        File path( file.isEmpty() ? constPath:file.addPath( constPath ) );
+        File path( file.isEmpty() ? constPath: File( file ).addPath( constPath ) );
         if( editor_->currentText() != path )
         {
 
             const bool usePrefix( usePrefix_ && !prefix_.isEmpty() );
             const QString prefix( prefix_+"//" );
-            if( usePrefix && !path.startsWith( prefix ) ) path.prepend( prefix );
+            if( usePrefix && !path.startsWith( prefix ) ) path.get().prepend( prefix );
 
             int id( editor_->findText( path ) );
             if( id < 0 )
@@ -676,7 +680,7 @@ void PathEditor::setPath( const File& constPath, const File& file )
 }
 
 //____________________________________________________________________________
-void PathEditor::selectParent( void )
+void PathEditor::selectParent()
 {
     if( !hasParent() ) return;
     const File path( (items_.back()->isSelectable() ? items_[items_.size()-2]:items_[items_.size()-3])->path() );
@@ -685,7 +689,7 @@ void PathEditor::selectParent( void )
 }
 
 //____________________________________________________________________________
-void PathEditor::selectPrevious( void )
+void PathEditor::selectPrevious()
 {
     Debug::Throw( "PathEditor::selectPrevious.\n" );
     if( !hasPrevious() ) return;
@@ -695,7 +699,7 @@ void PathEditor::selectPrevious( void )
 }
 
 //____________________________________________________________________________
-void PathEditor::selectNext( void )
+void PathEditor::selectNext()
 {
     Debug::Throw( "PathEditor::selectNext.\n" );
     if( !hasNext() ) return;
@@ -725,7 +729,7 @@ void PathEditor::resizeEvent( QResizeEvent* event )
 }
 
 //____________________________________________________________________________
-void PathEditor::_updatePrefix( void )
+void PathEditor::_updatePrefix()
 {
 
     Debug::Throw( "PathEditor::_updatePrefix.\n" );
@@ -775,7 +779,7 @@ void PathEditor::_setUseTruncation( bool value )
 }
 
 //____________________________________________________________________________
-void PathEditor::_returnPressed( void )
+void PathEditor::_returnPressed()
 {
     const File path( this->path() );
     setPath( path );
@@ -783,12 +787,12 @@ void PathEditor::_returnPressed( void )
 }
 
 //____________________________________________________________________________
-void PathEditor::_menuButtonClicked( void )
+void PathEditor::_menuButtonClicked()
 {
 
     // get list of hidden buttons
     File::List pathList;
-    foreach( PathEditorItem* item, items_ )
+    for( const auto& item:items_ )
     {
         if( item->isHidden() ) pathList << item->path();
         else {
@@ -812,7 +816,7 @@ void PathEditor::_menuButtonClicked( void )
     if( rootPathList_.size() > 1 )
     {
         // add root path list
-        foreach( const File& path, rootPathList_ )
+        for( const auto& path:rootPathList_ )
         {
 
             QAction* action = menu->addAction( path );
@@ -832,12 +836,12 @@ void PathEditor::_menuButtonClicked( void )
     }
 
     // add path
-    foreach( const File& path, pathList )
+    for( const auto& path:pathList )
     { menu->addAction( path ); }
 
     connect( menu, SIGNAL(triggered(QAction*)), SLOT(_updatePath(QAction*)) );
     menu->exec( menuButton_->mapToGlobal( menuButton_->rect().bottomLeft() ) );
-    static_cast<PathEditorButton*>(menuButton_)->setMouseOver( false );
+    static_cast<Private::PathEditorButton*>(menuButton_)->setMouseOver( false );
 
 }
 
@@ -854,7 +858,7 @@ void PathEditor::_buttonClicked( QAbstractButton* button )
 {
 
     // cast button
-    PathEditorItem* item( static_cast<PathEditorItem*>( button ) );
+    Private::PathEditorItem* item( static_cast<Private::PathEditorItem*>( button ) );
 
     // check selectable test
     if( !item->isSelectable() ) return;
@@ -866,7 +870,7 @@ void PathEditor::_buttonClicked( QAbstractButton* button )
 }
 
 //____________________________________________________________________________
-void PathEditor::_updateButtonVisibility( void )
+void PathEditor::_updateButtonVisibility()
 {
 
     Debug::Throw() << "PathEditor::_updateButtonVisibility - path: " << path() << endl;
@@ -891,7 +895,7 @@ void PathEditor::_updateButtonVisibility( void )
     bool hasHomePath( false );
     if( truncate_ && !home_.isEmpty() )
     {
-        foreach( PathEditorItem* item, items_ )
+        for( const auto& item:items_ )
         {
             if( item->path() == home_ )
             {
@@ -907,7 +911,7 @@ void PathEditor::_updateButtonVisibility( void )
     if( !hasHiddenButtons )
     {
         int width( 0 );
-        foreach( PathEditorItem* item, items_ )
+        for( const auto& item:items_ )
         {
             width += item->sizeHint().width();
             if( width > maxWidth )
@@ -932,12 +936,12 @@ void PathEditor::_updateButtonVisibility( void )
     {
         int width = 0;
         bool homeFound( false );
-        PathEditorItem::ListIterator iterator( items_ );
+        Private::PathEditorItem::ListIterator iterator( items_ );
         iterator.toBack();
         while( iterator.hasPrevious() )
         {
             // get item
-            PathEditorItem* item( iterator.previous() );
+            Private::PathEditorItem* item( iterator.previous() );
 
             // update width
             width += item->sizeHint().width();
@@ -953,14 +957,14 @@ void PathEditor::_updateButtonVisibility( void )
 }
 
 //____________________________________________________________________________
-void PathEditor::_updatePathMenus( void )
+void PathEditor::_updatePathMenus()
 {
     Debug::Throw( "PathEditor::_updatePathMenus.\n" );
 
     // previous
     int index = 0;
     previousPathMenu_->clear();
-    foreach( const FileRecord& record, history_->previousPathList() )
+    for( const auto& record:history_->previousPathList() )
     {
         QAction* action( previousPathMenu_->addAction( record.file() ) );
         action->setData( index );
@@ -970,7 +974,7 @@ void PathEditor::_updatePathMenus( void )
     // next
     ++index;
     nextPathMenu_->clear();
-    foreach( const FileRecord& record, history_->nextPathList() )
+    for( const auto& record:history_->nextPathList() )
     {
         QAction* action( nextPathMenu_->addAction( record.file() ) );
         action->setData( index );
@@ -980,7 +984,7 @@ void PathEditor::_updatePathMenus( void )
 }
 
 //____________________________________________________________________________
-void PathEditor::_updateConfiguration( void )
+void PathEditor::_updateConfiguration()
 {
     Debug::Throw( "PathEditor::_updateConfiguration.\n" );
 
