@@ -36,12 +36,16 @@
 #include <QWidget>
 
 // forward declaration
-class PathEditorItem;
-class PathEditorMenuButton;
+namespace Private
+{
+    class PathEditorItem;
+    class PathEditorMenuButton;
+}
+
 class PathHistory;
 
 //* path editor
-class PathEditor: public QStackedWidget, public Counter
+class PathEditor: public QStackedWidget, private Base::Counter<PathEditor>
 {
 
     Q_OBJECT
@@ -52,36 +56,36 @@ class PathEditor: public QStackedWidget, public Counter
     static const QString MimeType;
 
     //* constructor
-    PathEditor( QWidget* );
+    explicit PathEditor( QWidget* );
 
     //*@name accessors
     //@{
 
     //* path
-    File path( void ) const;
+    File path() const;
 
     //* true if parent directory is available
-    bool hasParent( void ) const;
+    bool hasParent() const;
 
     //* true if previous path is available in history
-    bool hasPrevious( void ) const;
+    bool hasPrevious() const;
 
     //* true if next path available in history
-    bool hasNext( void ) const;
+    bool hasNext() const;
 
     //* minimum size hint
-    virtual QSize minimumSizeHint( void ) const;
+    QSize minimumSizeHint() const override;
 
     //* size hint
-    virtual QSize sizeHint( void ) const
+    QSize sizeHint() const override
     { return minimumSizeHint(); }
 
     //* previous path menu
-    QMenu& previousPathMenu( void ) const
+    QMenu& previousPathMenu() const
     { return *previousPathMenu_; }
 
     //* next path menu
-    QMenu& nextPathMenu( void ) const
+    QMenu& nextPathMenu() const
     { return *nextPathMenu_; }
 
     //@}
@@ -120,13 +124,13 @@ class PathEditor: public QStackedWidget, public Counter
     public Q_SLOTS:
 
     //* select parent path
-    void selectParent( void );
+    void selectParent();
 
     //* select previous path in history
-    void selectPrevious( void );
+    void selectPrevious();
 
     //* select next path in history
-    void selectNext( void );
+    void selectNext();
 
     //* select from action
     void selectFromMenu( QAction* );
@@ -134,7 +138,7 @@ class PathEditor: public QStackedWidget, public Counter
     protected:
 
     //* resize events
-    virtual void resizeEvent( QResizeEvent* );
+    void resizeEvent( QResizeEvent* ) override;
 
     //* prefix
     void _setUsePrefix( bool value )
@@ -145,30 +149,30 @@ class PathEditor: public QStackedWidget, public Counter
     }
 
     //* update prefix
-    void _updatePrefix( void );
+    void _updatePrefix();
 
     //* truncation
     void _setUseTruncation( bool );
 
     //* reload
-    void _reload( void )
+    void _reload()
     { setPath( path() ); }
 
     protected Q_SLOTS:
 
     //* show browser
-    void _showBrowser( void )
+    void _showBrowser()
     { setCurrentWidget( browserContainer_ ); }
 
     //* show editor
-    void _showEditor( void )
+    void _showEditor()
     { setCurrentWidget( editorContainer_ ); }
 
     //* return pressed in editor
-    void _returnPressed( void );
+    void _returnPressed();
 
     //* menu button clicked
-    void _menuButtonClicked( void );
+    void _menuButtonClicked();
 
     //* update path from menu action
     void _updatePath( QAction* );
@@ -177,15 +181,15 @@ class PathEditor: public QStackedWidget, public Counter
     void _buttonClicked( QAbstractButton* );
 
     //* update button visibility
-    void _updateButtonVisibility( void );
+    void _updateButtonVisibility();
 
     //* update previous and next path menus
-    void _updatePathMenus( void );
+    void _updatePathMenus();
 
     private Q_SLOTS:
 
     //* configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
@@ -237,7 +241,7 @@ class PathEditor: public QStackedWidget, public Counter
     File::List rootPathList_;
 
     //* menu button
-    PathEditorMenuButton* menuButton_ = nullptr;
+    Private::PathEditorMenuButton* menuButton_ = nullptr;
 
     //* previous path menu
     QMenu* previousPathMenu_ = nullptr;
@@ -246,7 +250,7 @@ class PathEditor: public QStackedWidget, public Counter
     QMenu* nextPathMenu_ = nullptr;
 
     //* item buttons
-    QList<PathEditorItem*> items_;
+    QList<Private::PathEditorItem*> items_;
 
     //* path history
     PathHistory* history_ = nullptr;
