@@ -26,7 +26,7 @@
 #include <QWidget>
 
 //! configure files in recent files menu
-class PathHistoryConfiguration: public QWidget, public OptionWidgetList, public Counter
+class PathHistoryConfiguration: public QWidget, public OptionWidgetList, private Base::Counter<PathHistoryConfiguration>
 {
 
     Q_OBJECT
@@ -34,12 +34,12 @@ class PathHistoryConfiguration: public QWidget, public OptionWidgetList, public
     public:
 
     //! constructor
-    PathHistoryConfiguration( QWidget* );
+    explicit PathHistoryConfiguration( QWidget* );
 
     Q_SIGNALS:
 
     //! modified
-    void modified( void );
+    void modified();
 
 };
 
