@@ -40,13 +40,17 @@
 #include <QWidget>
 
 // forward declaration
-class PlacesToolTipWidget;
-class PlacesWidgetItem;
+namespace Private
+{
+    class PlacesToolTipWidget;
+    class PlacesWidgetItem;
+}
+
 class BaseFileIconProvider;
 class IconSizeMenu;
 
 //* places widget
-class PlacesWidget: public QWidget, public Counter
+class PlacesWidget: public QWidget, private Base::Counter<PlacesWidget>
 {
 
     Q_OBJECT
@@ -54,23 +58,23 @@ class PlacesWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    PlacesWidget( QWidget* = nullptr );
+    explicit PlacesWidget( QWidget* = nullptr );
 
     //* set icon provider
     void setIconProvider( BaseFileIconProvider* );
 
     //* true if empty
-    bool isEmpty( void ) const
+    bool isEmpty() const
     { return group_->buttons().isEmpty(); }
 
     //* list of items
-    QList<BaseFileInfo> items( void ) const;
+    QList<BaseFileInfo> items() const;
 
     //* set item enabled
     bool setItemIsValid( const BaseFileInfo&, bool );
 
     //* event filter
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
     Q_SIGNALS:
 
@@ -83,7 +87,7 @@ class PlacesWidget: public QWidget, public Counter
     public Q_SLOTS:
 
     //* clear all items
-    void clear( void );
+    void clear();
 
     //* add item
     void add( const BaseFileInfo& );
@@ -118,22 +122,22 @@ class PlacesWidget: public QWidget, public Counter
     void _updateIconSize( IconSize::Size );
 
     //* add item
-    void _addItem( void );
+    void _addItem();
 
     //* add separator
-    void _addSeparator( void );
+    void _addSeparator();
 
     //* add separator
-    void _insertSeparator( void );
+    void _insertSeparator();
 
     //* edit item
-    void _editItem( void );
+    void _editItem();
 
     //* remove item
-    void _removeItem( void );
+    void _removeItem();
 
     //* update item state
-    void _updateItems( void );
+    void _updateItems();
 
     //* hide item
     void _toggleHideItem( bool );
@@ -147,39 +151,39 @@ class PlacesWidget: public QWidget, public Counter
     //@{
 
     //* drag enter event
-    virtual void dragEnterEvent( QDragEnterEvent* );
+    void dragEnterEvent( QDragEnterEvent* ) override;
 
     //* drag move
-    virtual void dragMoveEvent( QDragMoveEvent* );
+    void dragMoveEvent( QDragMoveEvent* ) override;
 
     //* drag leave
-    virtual void dragLeaveEvent( QDragLeaveEvent* );
+    void dragLeaveEvent( QDragLeaveEvent* ) override;
 
     //* drop
-    virtual void dropEvent( QDropEvent* );
+    void dropEvent( QDropEvent* ) override;
 
     //* mouse press
-    virtual void mousePressEvent( QMouseEvent* );
+    void mousePressEvent( QMouseEvent* ) override;
 
     //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //@}
 
     //* Read fileList from file
-    bool _read( void );
+    bool _read();
 
     //* write fileList to file
-    bool _write( void );
+    bool _write();
 
     //* install default folders
-    void _addDefaultPlaces( void );
+    void _addDefaultPlaces();
 
     //* set db file
     bool _setDBFile( const File& );
 
     //* update drag state
-    void _updateDragState( void ) const;
+    void _updateDragState() const;
 
     //* drag target
     QPoint _updateDragTarget( const QPoint& ) const;
@@ -194,20 +198,20 @@ class PlacesWidget: public QWidget, public Counter
     QList<BaseFileInfo> _decode( const QMimeData* ) const;
 
     //* return item that have focus or none
-    PlacesWidgetItem* _focusItem( void ) const;
+    Private::PlacesWidgetItem* _focusItem() const;
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     //* save configuration
-    void _saveConfiguration( void );
+    void _saveConfiguration();
 
     private:
 
     //* install actions
-    void _installActions( void );
+    void _installActions();
 
     //* dummy treeview, needed for rendering items
     QAbstractItemView* itemView_ = nullptr;
@@ -222,16 +226,16 @@ class PlacesWidget: public QWidget, public Counter
     IconSizeMenu* iconSizeMenu_ = nullptr;
 
     //* tooltip widget
-    PlacesToolTipWidget* toolTipWidget_ = nullptr;
+    Private::PlacesToolTipWidget* toolTipWidget_ = nullptr;
 
     //* list of items
-    QList<PlacesWidgetItem*> items_;
+    QList<Private::PlacesWidgetItem*> items_;
 
     //* focus item (for context menu actions)
-    PlacesWidgetItem* focusItem_ = nullptr;
+    Private::PlacesWidgetItem* focusItem_ = nullptr;
 
     //* drag item
-    PlacesWidgetItem* dragItem_ = nullptr;
+    Private::PlacesWidgetItem* dragItem_ = nullptr;
 
     //* icon provider
     BaseFileIconProvider* iconProvider_ = nullptr;
