@@ -28,7 +28,7 @@
 #include <QLabel>
 #include <QIntValidator>
 
-namespace Print
+namespace Private
 {
     class OptionMenu;
     class NavigationWidget;
@@ -42,35 +42,35 @@ class PrintPreviewDialog: public CustomDialog
     public:
 
     //* constructor
-    PrintPreviewDialog( QWidget* = nullptr, CustomDialog::Flags = 0 );
+    explicit PrintPreviewDialog( QWidget* = nullptr, CustomDialog::Flags = 0 );
 
     //* set print helper
     void setHelper( QObject* );
 
     //* return preview widget
-    QPrintPreviewWidget& previewWidget( void ) const
+    QPrintPreviewWidget& previewWidget() const
     { return *previewWidget_; }
 
     public Q_SLOTS:
 
     //* show/hide menu
-    void showMenu( void );
+    void showMenu();
 
     //* show/hide menu
-    void hideMenu( void );
+    void hideMenu();
 
     protected Q_SLOTS:
 
     //* update page
-    void _updatePage( void );
+    void _updatePage();
 
     private:
 
     //* option widget
-    Print::OptionMenu* optionMenu_ = nullptr;
+    Private::OptionMenu* optionMenu_ = nullptr;
 
     //* navigation widget
-    Print::NavigationWidget* navigationWidget_ = nullptr;
+    Private::NavigationWidget* navigationWidget_ = nullptr;
 
     //* preview widget
     QPrintPreviewWidget* previewWidget_ = nullptr;
