@@ -22,7 +22,7 @@
 #include "BasePrintHelper.h"
 #include "CustomDialog.h"
 
-#include <QMap>
+#include <QHash>
 #include <QIntValidator>
 #include <QLabel>
 #include <QLineEdit>
@@ -30,11 +30,11 @@
 #include <QPrintPreviewWidget>
 #include <QToolButton>
 
-namespace Print
+namespace Private
 {
 
     //* handles page orientation and page mode
-    class OptionMenu: public QMenuBar, public Counter
+    class OptionMenu: public QMenuBar, private Base::Counter<OptionMenu>
     {
 
         Q_OBJECT
@@ -42,7 +42,7 @@ namespace Print
         public:
 
         //* constructor
-        OptionMenu( QWidget* );
+        explicit OptionMenu( QWidget* );
 
         //* set orientation
         void setOrientation( QPrinter::Orientation ) const;
@@ -67,17 +67,17 @@ namespace Print
         private:
 
         //* actions maps
-        using OrientationActionMap = QMap<QAction*, QPrinter::Orientation>;
+        using OrientationActionMap = QHash<QAction*, QPrinter::Orientation>;
         OrientationActionMap orientationActions_;
 
         //* actions map
-        using PageModeActionMap = QMap<QAction*, BasePrintHelper::PageMode>;
+        using PageModeActionMap = QHash<QAction*, BasePrintHelper::PageMode>;
         PageModeActionMap pageModeActions_;
 
     };
 
     //* handles page navigation
-    class NavigationWidget: public QWidget, public Counter
+    class NavigationWidget: public QWidget, private Base::Counter<NavigationWidget>
     {
 
         Q_OBJECT
@@ -85,9 +85,9 @@ namespace Print
         public:
 
         //* constructor
-        NavigationWidget( QWidget* );
+        explicit NavigationWidget( QWidget* );
 
-        int pages( void )
+        int pages()
         { return pages_; }
 
         //* set page
@@ -109,16 +109,16 @@ namespace Print
         protected Q_SLOTS:
 
         //* previous page
-        void _previousPage( void );
+        void _previousPage();
 
         //* next page
-        void _nextPage( void );
+        void _nextPage();
 
         //* update page
-        void _updatePage( void );
+        void _updatePage();
 
         //* update buttons
-        void _updateButtons( void );
+        void _updateButtons();
 
         private:
 
