@@ -22,13 +22,13 @@
 #include "Counter.h"
 #include "BasePrintHelper.h"
 
-#include <QMap>
+#include <QHash>
 #include <QAbstractButton>
 #include <QPrinter>
 #include <QPushButton>
 #include <QWidget>
 
-class PrinterOptionWidget: public QWidget, public Counter
+class PrinterOptionWidget: public QWidget, private Base::Counter<PrinterOptionWidget>
 {
 
     Q_OBJECT
@@ -36,14 +36,14 @@ class PrinterOptionWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    PrinterOptionWidget( QWidget* = nullptr );
+    explicit PrinterOptionWidget( QWidget* = nullptr );
 
     //* orientation
-    QPrinter::Orientation orientation( void ) const
+    QPrinter::Orientation orientation() const
     { return orientation_; }
 
     //* page mode
-    BasePrintHelper::PageMode pageMode( void ) const
+    BasePrintHelper::PageMode pageMode() const
     { return pageMode_; }
 
     //* helper
@@ -66,28 +66,28 @@ class PrinterOptionWidget: public QWidget, public Counter
     void _setPageMode( QAbstractButton* );
 
     //* preview
-    void _preview( void );
+    void _preview();
 
     private:
 
     //* helper
-    BasePrintHelper* helper_;
+    BasePrintHelper* helper_ = nullptr;
 
     //* orientation
-    QPrinter::Orientation orientation_;
+    QPrinter::Orientation orientation_ = QPrinter::Portrait;
 
     //* page mode
-    BasePrintHelper::PageMode pageMode_;
+    BasePrintHelper::PageMode pageMode_ = BasePrintHelper::PageMode::SinglePage;
 
     //* preview button
     QPushButton* previewButton_;
 
     //* Buttons maps
-    using OrientationButtonMap = QMap<QAbstractButton*, QPrinter::Orientation>;
+    using OrientationButtonMap = QHash<QAbstractButton*, QPrinter::Orientation>;
     OrientationButtonMap orientationButtons_;
 
     //* Buttons map
-    using PageModeButtonMap = QMap<QAbstractButton*, BasePrintHelper::PageMode>;
+    using PageModeButtonMap = QHash<QAbstractButton*, BasePrintHelper::PageMode>;
     PageModeButtonMap pageModeButtons_;
 
 };
