@@ -35,30 +35,30 @@ class ProgressStatusBar: public BaseStatusBar
     public:
 
     //* constructor
-    ProgressStatusBar( QWidget* );
+    explicit ProgressStatusBar( QWidget* );
 
     //* progress bar
-    QProgressBar& progressBar( void ) const
+    QProgressBar& progressBar() const
     { return *progress_; }
 
     //* set progress bar
     void setProgressBar( QProgressBar* );
 
     //* retrieves label with given index
-    virtual StatusBarLabel& label( const unsigned int& i = 0  ) const
+    StatusBarLabel& label( int i = 0  ) const override
     { return (i==0) ? *label_:BaseStatusBar::label(i); }
 
     public Q_SLOTS:
 
     //* show progress bar as visible widget
-    void showProgressBar( void );
+    void showProgressBar();
 
     //* hide progress bar
-    void hideProgressBar( void )
+    void hideProgressBar()
     { showLabel(); }
 
     //* show label as visible widget
-    void showLabel( void );
+    void showLabel();
 
     private:
 
