@@ -27,28 +27,33 @@
 #include <QString>
 #include <QLabel>
 
-//! simplified question dialog
+//* simplified question dialog
 class QuestionDialog: public DetailsDialog
 {
 
     public:
 
-    //! constructor
-    QuestionDialog( QWidget* parent, const QString& = QString() );
+    //* constructor
+    explicit QuestionDialog( QWidget*, const QString& = QString() );
 
-    //! set text
+    //*@name modifiers
+    //@{
+
+    //* set text
     void setText( const QString& );
 
+    //@}
+
     protected:
 
-    //! label
-    QLabel& _label( void ) const
+    //* label
+    QLabel& _label() const
     { return *label_; }
 
     private:
 
-    //! main label
-    QLabel *label_;
+    //* main label
+    QLabel *label_ = nullptr;
 
 };
 
