@@ -55,7 +55,7 @@ RecentFilesMenu::RecentFilesMenu( QWidget *parent, FileList& files ):
 }
 
 //______________________________________
-bool RecentFilesMenu::openLastValidFile( void )
+bool RecentFilesMenu::openLastValidFile()
 {
     Debug::Throw( "RecentFilesMenu::openLastValidFile.\n" );
     const FileRecord record( fileList_->lastValidFile() );
@@ -68,17 +68,17 @@ bool RecentFilesMenu::openLastValidFile( void )
 
 //______________________________________
 void RecentFilesMenu::setCurrentFile( const File& file )
-{ if( !file.isEmpty() )  setCurrentFile( fileList_->add( file.expand() ) ); }
+{ if( !file.isEmpty() )  setCurrentFile( fileList_->add( file.expanded() ) ); }
 
 //______________________________________
-void RecentFilesMenu::_updateActions( void )
+void RecentFilesMenu::_updateActions()
 {
 
     Debug::Throw( "RecentFilesMenu::_updateActions.\n" );
 
     // set actions enability
     FileRecord::List records( fileList_->records() );
-    for( ActionMap::iterator iter = actions_.begin(); iter != actions_.end(); ++iter )
+    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
     {
 
         FileRecord::List::const_iterator found = std::find_if(
@@ -96,7 +96,7 @@ void RecentFilesMenu::_updateActions( void )
 }
 
 //______________________________________
-void RecentFilesMenu::_clean( void )
+void RecentFilesMenu::_clean()
 {
     if( !fileList_->check() && !QuestionDialog( this, tr( "Clear list ?" ) ).exec() ) return;
     else if( fileList_->check() && !QuestionDialog( this, tr( "Remove invalid or duplicated files from list ?" ) ).exec() ) return;
@@ -117,7 +117,7 @@ void RecentFilesMenu::_open( QAction* action )
 }
 
 //_______________________________________________
-void RecentFilesMenu::_loadFiles( void )
+void RecentFilesMenu::_loadFiles()
 {
     Debug::Throw( "RecentFilesMenu::_loadFiles.\n" );
 
@@ -125,7 +125,7 @@ void RecentFilesMenu::_loadFiles( void )
     cleanAction_->setEnabled( fileList_->cleanEnabled() );
 
     // clear menu an actions map
-    for( ActionMap::iterator iter = actions_.begin(); iter != actions_.end(); ++iter )
+    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
     { delete iter.key(); }
     actions_.clear();
 
@@ -135,7 +135,7 @@ void RecentFilesMenu::_loadFiles( void )
     else { std::sort( records.begin(), records.end(), FileRecord::FileFTor() ); }
 
     // retrieve stored file record
-    foreach( const FileRecord& record, records )
+    for( const auto& record:records )
     {
 
         QString label( record.file() );
@@ -149,7 +149,7 @@ void RecentFilesMenu::_loadFiles( void )
         action->setChecked( record.file() == currentFile().file() );
         actionGroup_->addAction( action );
 
-        if( fileList_->check() ) action->setEnabled( record.file().size() && record.isValid() );
+        if( fileList_->check() ) action->setEnabled( !record.file().isEmpty() && record.isValid() );
         actions_.insert( action, record );
     }
 
