@@ -31,7 +31,7 @@
 \class   RecentFilesMenu
 \brief   customized popup menu to open a previously opened file
 */
-class RecentFilesMenu: public QMenu, public Counter
+class RecentFilesMenu: public QMenu, private Base::Counter<RecentFilesMenu>
 {
 
     //* Qt meta object declaration
@@ -40,24 +40,24 @@ class RecentFilesMenu: public QMenu, public Counter
     public:
 
     //* constructor
-    RecentFilesMenu( QWidget*, FileList& );
+    explicit RecentFilesMenu( QWidget*, FileList& );
 
     //* check if a file is in database, removes it if yes
-    virtual void remove( const QString& file )
+    void remove( const QString& file )
     { fileList_->remove( File( file ).expand() ); }
 
     //* check if a file is in database, adds it if not, select the file
-    virtual void select( const QString& file )
+    void select( const QString& file )
     {
         File newFile( File( file ).expand() );
         emit fileSelected( fileList_->add( newFile ) );
     }
 
     //* open last valid file, returns true if any
-    bool openLastValidFile( void );
+    bool openLastValidFile();
 
     //* current file
-    const FileRecord& currentFile( void ) const
+    const FileRecord& currentFile() const
     { return currentFile_; }
 
     Q_SIGNALS:
@@ -75,27 +75,27 @@ class RecentFilesMenu: public QMenu, public Counter
     { currentFile_ = file; }
 
     //* check if a file is in database, adds it if not
-    virtual FileRecord& add( const QString& file )
+    FileRecord& add( const QString& file )
     { return fileList_->add( File( file ) ); }
 
     //* check if a file is in database, adds it if not
-    virtual FileRecord& add( File file )
+    FileRecord& add( File file )
     { return fileList_->add( file.expand() ); }
 
     private Q_SLOTS:
 
     //* update actions
     /** this is trigger by the fileList valid file check completion */
-    void _updateActions( void );
+    void _updateActions();
 
     //* remove unfound files from file list
-    void _clean( void );
+    void _clean();
 
     //* open file
     void _open( QAction* );
 
     //* display files from internal list
-    void _loadFiles( void );
+    void _loadFiles();
 
     private:
 
