@@ -27,7 +27,7 @@
 #include <QObject>
 
 //* used to automatically
-class ScratchFileMonitor: public QObject, public Counter
+class ScratchFileMonitor: public QObject, private Base::Counter<ScratchFileMonitor>
 {
 
     Q_OBJECT
@@ -35,7 +35,7 @@ class ScratchFileMonitor: public QObject, public Counter
     public:
 
     //* constructor
-    ScratchFileMonitor( QObject* parent = nullptr ):
+    explicit ScratchFileMonitor( QObject* parent = nullptr ):
         QObject( parent ),
         Counter( "ScratchFileMonitor" )
     {}
@@ -46,7 +46,7 @@ class ScratchFileMonitor: public QObject, public Counter
     void add( const File& file );
 
     //* delete all scratch files
-    void deleteScratchFiles( void );
+    void deleteScratchFiles();
 
     private:
 
