@@ -25,7 +25,7 @@
 #include "SelectLineWidget.h"
 
 //* find_text dialog for text editor widgets
-class SelectLineDialog: public BaseDialog, public Counter
+class SelectLineDialog: public BaseDialog, private Base::Counter<SelectLineDialog>
 {
 
     //* Qt meta object declaration
@@ -34,13 +34,13 @@ class SelectLineDialog: public BaseDialog, public Counter
     public:
 
     //* constructor
-    SelectLineDialog( QWidget* parent = nullptr, Qt::WindowFlags WindowFlags = 0 );
+    explicit SelectLineDialog( QWidget* parent = nullptr, Qt::WindowFlags WindowFlags = 0 );
 
     //*@name accessors
     //@{
 
     //* retrieve editor
-    LineEditor& editor( void ) const
+    LineEditor& editor() const
     { return selectLineWidget_->editor(); }
 
     //@}
