@@ -30,7 +30,7 @@
 class LineEditor;
 
 //* find_text dialog for text editor widgets
-class SelectLineWidget: public EmbeddedWidget, public Counter
+class SelectLineWidget: public EmbeddedWidget, private Base::Counter<SelectLineWidget>
 {
 
     //* Qt meta object declaration
@@ -39,18 +39,18 @@ class SelectLineWidget: public EmbeddedWidget, public Counter
     public:
 
     //* constructor
-    SelectLineWidget( QWidget* = nullptr, bool compact = true );
+    explicit SelectLineWidget( QWidget* = nullptr, bool compact = true );
 
     //* retrieve editor
-    LineEditor& editor( void ) const
+    LineEditor& editor() const
     { return *editor_; }
 
     //* ok button
-    QAbstractButton& okButton( void ) const
+    QAbstractButton& okButton() const
     { return *okButton_; }
 
     //* close button
-    QAbstractButton& closeButton( void ) const
+    QAbstractButton& closeButton() const
     { return *closeButton_; }
 
     Q_SIGNALS:
@@ -61,25 +61,25 @@ class SelectLineWidget: public EmbeddedWidget, public Counter
     public Q_SLOTS:
 
     //* take action when at least one match is found
-    virtual void matchFound( void );
+    void matchFound();
 
     //* take action when no match is found
-    virtual void noMatchFound( void );
+    void noMatchFound();
 
     protected:
 
     //* change event
-    virtual void changeEvent( QEvent* );
+    void changeEvent( QEvent* ) override;
 
     private Q_SLOTS:
 
     //* retrieve line number and emit signal
-    void _selectLine( void );
+    void _selectLine();
 
     private:
 
     //* create not found palette
-    void _updateNotFoundPalette( void );
+    void _updateNotFoundPalette();
 
     //* line editor for text to find
     LineEditor* editor_ = nullptr;
