@@ -30,13 +30,13 @@ class SimpleListView: public QListView
     public:
 
     //* constructor
-    SimpleListView( QWidget* = nullptr );
+    explicit SimpleListView( QWidget* = nullptr );
 
     //* orientation
     void setOrientation( Qt::Orientation );
 
     //* model
-    virtual void setModel( QAbstractItemModel* );
+    void setModel( QAbstractItemModel* ) override;
 
     Q_SIGNALS:
 
@@ -51,24 +51,24 @@ class SimpleListView: public QListView
     protected Q_SLOTS:
 
     //* adjust size
-    void _adjustSize( void );
+    void _adjustSize();
 
     //* hover index
-    virtual void _indexEntered( const QModelIndex& );
+    void _indexEntered( const QModelIndex& );
 
     protected:
 
     //* generic event
-    virtual bool event( QEvent* );
+    bool event( QEvent* ) override;
 
     //* mouse move event
-    virtual void mouseMoveEvent( QMouseEvent* );
+    void mouseMoveEvent( QMouseEvent* ) override;
 
     //* mouse press event
-    virtual void mousePressEvent( QMouseEvent* );
+    void mousePressEvent( QMouseEvent* ) override;
 
     //* hover index
-    virtual void _setHoverIndex( const QModelIndex& );
+    void _setHoverIndex( const QModelIndex& );
 
     private:
 
