@@ -24,7 +24,7 @@
 
 #include <QAction>
 
-class StandardAction: public QAction, public Counter
+class StandardAction: public QAction, private Base::Counter<StandardAction>
 {
 
     Q_OBJECT
@@ -32,7 +32,7 @@ class StandardAction: public QAction, public Counter
     public:
 
     //* action type
-    enum ActionType
+    enum class Type
     {
         New,
         Open,
@@ -54,7 +54,7 @@ class StandardAction: public QAction, public Counter
     };
 
     //* constructor
-    StandardAction( ActionType, QObject* );
+    explicit StandardAction( Type, QObject* );
 
 };
 
