@@ -32,11 +32,16 @@
 #include <QSizeGrip>
 #include <QTabWidget>
 
+#include <memory>
+
 // forward declaration
-class TabWidget;
+namespace Private
+{
+    class LocalTabWidget;
+}
 
 //* Tab Child container
-class TabWidget: public QWidget, public Counter
+class TabWidget: public QWidget, private Base::Counter<TabWidget>
 {
 
     //* Qt meta object declaration
@@ -45,87 +50,72 @@ class TabWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    TabWidget( QTabWidget* parent );
+    explicit TabWidget( QTabWidget* parent );
 
-    //* set tab title
-    void setTitle( const QString& title )
-    {
-        title_ = title;
-        titleLabel_->setText( title );
-    }
+    //* destructor (needed because of std::unique_ptr
+    ~TabWidget() override;
+
+    //*@name accessors
+    //@{
 
     //* title
-    const QString& title( void ) const
+    const QString& title() const
     { return title_; }
 
     //* get parent TabWidget
-    QTabWidget& parentTabWidget( void )
+    QTabWidget& parentTabWidget()
     { return *parent_; }
 
-    //* get box
-    QWidget& box( void )
-    { return *box_; }
+    //* true if attached
+    bool isDetached() const
+    { return widgetDragMonitor_.isEnabled(); }
+
+    //* detach action
+    QAction& detachAction() const
+    { return *detachAction_; }
+
+    //* stay on top
+    QAction& staysOnTopAction() const
+    { return *staysOnTopAction_; }
+
+    //* widget is hidden from taskbar
+    QAction& stickyAction() const
+    { return *stickyAction_; }
+
+    //@}
+
+    //*@name modifiers
+    //@{
+
+    //* change title
+    void setTitle( QString );
 
     //* update actions
     void updateActions( bool );
 
-    //* detach action
-    QAction& detachAction( void ) const
-    { return *detachAction_; }
-
-    //* stay on top
-    QAction& staysOnTopAction( void ) const
-    { return *staysOnTopAction_; }
-
-    //* widget is hidden from taskbar
-    QAction& stickyAction( void ) const
-    { return *stickyAction_; }
+    //@}
 
     Q_SIGNALS:
 
+    //* emitted when state is changed
+    void attached( bool state );
+
     //* emitted when box is detached
-    void detached( void );
+    void detached();
 
     //* emitted when box is attached
-    void attached( void );
-
-    protected:
-
-    //* close event
-    virtual void closeEvent( QCloseEvent* );
-
-    //* resize
-    virtual void resizeEvent( QResizeEvent* );
-
-    //* paint
-    virtual void paintEvent( QPaintEvent* );
-
-    //* has size grip
-    bool _hasSizeGrip( void ) const
-    { return (bool)sizeGrip_; }
-
-    //* size grip
-    QSizeGrip& _sizeGrip( void ) const
-    { return *sizeGrip_; }
-
-    //* show size grip
-    void _showSizeGrip( void )
-    { if( _hasSizeGrip() ) _sizeGrip().show(); }
-
-    //* hide size grip
-    void _hideSizeGrip( void )
-    { if( _hasSizeGrip() ) _sizeGrip().hide(); }
+    void attached();
 
     protected Q_SLOTS:
 
     //* toggle dock
-    virtual void _toggleDock( void );
+    void _toggleDock();
 
     //* stays on top
-    virtual void _toggleStaysOnTop( bool );
+    void _toggleStaysOnTop( bool );
 
     //* toggle window stickyness
-    virtual void _toggleSticky( bool );
+    void _toggleSticky( bool );
 
     //* update context menu
     void _updateContextMenu( const QPoint& );
@@ -133,43 +123,19 @@ class TabWidget: public QWidget, public Counter
     private:
 
     //* actions
-    void _installActions( void );
+    void _installActions();
 
-    //* flags
-    unsigned int flags_;
+    //* parent TabWidget
+    QTabWidget* parent_ = nullptr;
 
     //* title
     QString title_;
 
     //* dock title
-    QLabel* titleLabel_ = nullptr;
+    QLabel* dockTitleLabel_ = nullptr;
 
-    //* parent TabWidget
-    QTabWidget* parent_ = nullptr;
-
-    //* vertical layout
-    QVBoxLayout* mainLayout_ = nullptr;
-
-    //* contents vbox
-    QWidget* box_ = nullptr;
-
-    class SizeGrip: public QSizeGrip
-    {
-        public:
-
-        SizeGrip( QWidget* parent ):
-            QSizeGrip( parent )
-        {}
-
-        protected:
-
-        virtual void paintEvent( QPaintEvent* )
-        {}
-
-    };
-
-    //* size grip
-    SizeGrip* sizeGrip_ = nullptr;
+    //* dock
+    std::unique_ptr<Private::LocalTabWidget> dock_;
 
     //* index in parent tab
     int index_ = 0;
