@@ -41,12 +41,12 @@ TabbedDialog::TabbedDialog( QWidget* parent ):
 
     Debug::Throw( "TabbedDialog::TabbedDialog.\n" );
 
-    QVBoxLayout* layout( new QVBoxLayout() );
+    QVBoxLayout* layout( new QVBoxLayout );
     layout->setMargin(0);
     setLayout( layout );
 
     // horizontal layout
-    QHBoxLayout* hLayout = new QHBoxLayout();
+    QHBoxLayout* hLayout = new QHBoxLayout;
     layout->addLayout( hLayout );
 
     // add widgets
@@ -63,7 +63,7 @@ TabbedDialog::TabbedDialog( QWidget* parent ):
 
     // connections
     connect( list_->selectionModel(), SIGNAL(currentRowChanged(QModelIndex,QModelIndex)), SLOT(_display(QModelIndex)) );
-    connect( new QShortcut( QKeySequence::Quit, this ), SIGNAL(activated()), SLOT(close()) );
+    new QShortcut( QKeySequence::Quit, this, SLOT(close()) );
 
 
 }
@@ -73,12 +73,12 @@ QWidget& TabbedDialog::addPage( const QIcon& icon, const QString& title, const Q
 {
 
     // base widget
-    QWidget* base = new QWidget();
-    base->setLayout( new QVBoxLayout() );
+    QWidget* base = new QWidget;
+    base->setLayout( new QVBoxLayout );
     base->layout()->setMargin(0);
     base->layout()->setSpacing(10);
 
-    QHBoxLayout* hLayout = new QHBoxLayout();
+    QHBoxLayout* hLayout = new QHBoxLayout;
     hLayout->setMargin(0);
     hLayout->setSpacing(5);
     base->layout()->addItem( hLayout );
@@ -95,14 +95,14 @@ QWidget& TabbedDialog::addPage( const QIcon& icon, const QString& title, const Q
     hLayout->addWidget( label, 1 );
 
     // create scroll area
-    QScrollArea* scrollArea = new QScrollArea();
+    QScrollArea* scrollArea = new QScrollArea;
     scrollArea->setWidgetResizable ( true );
     scrollArea->setFrameStyle( QFrame::NoFrame );
 
     base->layout()->addWidget( scrollArea );
 
     // create main widget
-    QWidget* main( new QWidget() );
+    QWidget* main( new QWidget );
     scrollArea->setWidget( main );
 
     // add to stack
@@ -117,7 +117,7 @@ QWidget& TabbedDialog::addPage( const QIcon& icon, const QString& title, const Q
     if( (!list_->selectionModel()->currentIndex().isValid()) && _model().hasIndex(0,0) )
     { list_->selectionModel()->setCurrentIndex( _model().index(0,0), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows ); }
 
-    QVBoxLayout* layout( new QVBoxLayout() );
+    QVBoxLayout* layout( new QVBoxLayout );
     layout->setSpacing( 5 );
     layout->setMargin( 0 );
     main->setLayout( layout );
@@ -130,7 +130,7 @@ QWidget& TabbedDialog::addPage( const QIcon& icon, const QString& title, const Q
         // a widget is created inside main, and a stretch is added at the bottom
         // the created widget is return
         QWidget* contents( new QWidget( main ) );
-        contents->setLayout( new QVBoxLayout() );
+        contents->setLayout( new QVBoxLayout );
         contents->layout()->setSpacing(5);
         contents->layout()->setMargin(0);
 
@@ -149,11 +149,6 @@ void TabbedDialog::_display( const QModelIndex& index )
     stackedWidget_->setCurrentWidget( _model().get( index ).widget() );
 }
 
-//_______________________________________________
-const QString TabbedDialog::Model::columnTitles_[ TabbedDialog::Model::nColumns ] =
-{ "" };
-
-
 //_______________________________________________________________________________________
 QVariant TabbedDialog::Model::data( const QModelIndex& index, int role ) const
 {
