@@ -36,7 +36,7 @@ class SimpleListView;
 
 //* tabbed dialog
 /** a list of tab names appear on the left. The contents of the corresponding tag appear on the right */
-class TabbedDialog: public BaseDialog, public Counter
+class TabbedDialog: public BaseDialog, private Base::Counter<TabbedDialog>
 {
 
     Q_OBJECT
@@ -44,50 +44,49 @@ class TabbedDialog: public BaseDialog, public Counter
     public:
 
     //* creator
-    TabbedDialog( QWidget* );
+    explicit TabbedDialog( QWidget* );
 
     //* adds a new Item, returns associated Box
-    virtual QWidget& addPage( const QString& title, const QString& tooltip = QString(), bool expand = false )
+    QWidget& addPage( const QString& title, const QString& tooltip = QString(), bool expand = false )
     { return addPage( QIcon(), title, tooltip, expand ); }
 
     //* adds a new Item, returns associated Box
-    virtual QWidget& addPage( const QIcon&, const QString&, const QString& tooltip = QString(), bool expand = false );
+    QWidget& addPage( const QIcon&, const QString&, const QString& tooltip = QString(), bool expand = false );
 
     protected Q_SLOTS:
 
     //* display item page
-    virtual void _display( const QModelIndex& );
+    void _display( const QModelIndex& );
 
     protected:
 
     //* retrieve list
-    virtual SimpleListView& _list( void )
+    SimpleListView& _list()
     { return *list_; }
 
     //* retrieve stack
-    virtual QStackedWidget& _stackedWidget( void )
+    QStackedWidget& _stackedWidget()
     { return *stackedWidget_; }
 
     //* button box
-    QDialogButtonBox& _buttonBox( void ) const
+    QDialogButtonBox& _buttonBox() const
     { return *buttonBox_; }
 
     private:
 
     //* item model
-    class Item: public Counter
+    class Item final: private Base::Counter<Item>
     {
 
         public:
 
         //* constructor
-        Item( void ):
-            Counter( "TabbedDialog::Item" ),
-            widget_( 0L )
+        explicit Item():
+            Counter( "TabbedDialog::Item" )
         {}
 
         //* constructor
-        Item( const QString& name, QWidget* widget ):
+        explicit Item( const QString& name, QWidget* widget ):
             Counter( "TabbedDialog::Item" ),
             name_( name ),
             widget_( widget )
@@ -106,36 +105,37 @@ class TabbedDialog: public BaseDialog, public Counter
         { icon_ = icon; }
 
         //* name
-        const QString& name( void ) const
+        const QString& name() const
         { return name_; }
 
         //* widget
-        QWidget* widget( void ) const
+        QWidget* widget() const
         { return widget_; }
 
         //* icon
-        const QIcon& icon( void ) const
+        const QIcon& icon() const
         { return icon_; }
 
-        //* equal to operator
-        bool operator == (const Item& other ) const
-        { return widget_ == other.widget_;  }
-
-        //* less than operator
-        bool operator < (const Item& other ) const
-        { return widget_ < other.widget_; }
-
         private:
 
         //* name
         QString name_;
 
         //* associated widget
-        QWidget* widget_;
+        QWidget* widget_ = nullptr;
 
         //* icon
         QIcon icon_;
 
+
+        //* equal to operator
+        friend bool operator == (const Item& first, const Item& second)
+        { return first.widget_ == second.widget_;  }
+
+        //* less than operator
+        friend bool operator < (const Item& first, const Item& second)
+        { return first.widget_ < second.widget_; }
+
     };
 
     //* model
@@ -151,42 +151,26 @@ class TabbedDialog: public BaseDialog, public Counter
         //@{
 
         //* flags
-        virtual Qt::ItemFlags flags(const QModelIndex& ) const
+        Qt::ItemFlags flags(const QModelIndex& ) const override
         { return Qt::ItemIsEnabled |  Qt::ItemIsSelectable; }
 
         //* return data
-        virtual QVariant data(const QModelIndex &index, int role) const;
+        QVariant data(const QModelIndex &index, int role) const override;
 
         //* header data
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const
-        {
-            if( orientation == Qt::Horizontal && role == Qt::DisplayRole && section >= 0 && section < nColumns )
-            { return columnTitles_[section]; }
-
-            // return empty
-            return QVariant();
-
-        }
+        QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override
+        { return QVariant(); }
 
         //* number of columns for a given index
-        virtual int columnCount(const QModelIndex& = QModelIndex()) const
+        int columnCount(const QModelIndex& = QModelIndex()) const override
         { return nColumns; }
 
         //@}
 
-        protected:
-
-        //* sort
-        virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
-        {}
-
-        //* list column names
-        static const QString columnTitles_[nColumns];
-
     };
 
     //* model
-    Model& _model( void )
+    Model& _model()
     { return model_; }
 
     //* model
