@@ -27,32 +27,32 @@
 #include <QTextBlockUserData>
 
 //* TextBlock data
-class TextBlockData: public QTextBlockUserData, public Counter
+class TextBlockData: public QTextBlockUserData, private Base::Counter<TextBlockData>
 {
 
     public:
 
     //* constructor
-    TextBlockData():
+    explicit TextBlockData():
         QTextBlockUserData(),
         Counter( "TextBlockData" ),
         flags_( TextBlock::None )
     {}
 
     //* flags
-    const int& flags( void ) const
+    int flags() const
     { return flags_; }
 
     //* flags
-    void setFlags( const int& flags )
+    void setFlags( int flags )
     { flags_ = flags; }
 
     //* flags
-    bool hasFlag( const int& flag ) const
+    bool hasFlag( int flag ) const
     { return flags_ & flag; }
 
     //* flags
-    void setFlag( const int& flag, bool value )
+    void setFlag( int flag, bool value )
     {
         if( value ) flags_ |= flag;
         else flags_ &= (~flag);
@@ -71,7 +71,7 @@ class TextBlockData: public QTextBlockUserData, public Counter
     }
 
     //* block background
-    const QColor& background( void ) const
+    const QColor& background() const
     { return background_; }
 
     private:
