@@ -30,7 +30,7 @@
 class TextEditor;
 
 // margin widget
-class TextEditorMarginWidget: public QWidget, public Counter
+class TextEditorMarginWidget: public QWidget, private Base::Counter<TextEditorMarginWidget>
 {
 
     Q_OBJECT
@@ -38,29 +38,35 @@ class TextEditorMarginWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    TextEditorMarginWidget( TextEditor* );
+    explicit TextEditorMarginWidget( TextEditor* );
+
+    //*@name accessors
+    //@{
 
     //* vertical line
-    bool drawVerticalLine( void ) const
+    bool drawVerticalLine() const
     { return true; }
 
+    //* background color
+    QColor backgroundColor() const;
+
+    //* foreground color
+    QColor foregroundColor() const;
+
+    //@}
+
     public Q_SLOTS:
 
     //* dirty
-    void setDirty( void );
-
-    private Q_SLOTS:
-
-    //* configuration
-    void _updateConfiguration( void );
+    void setDirty();
 
     protected:
 
     //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //* parent editor
-    TextEditor& _editor( void ) const
+    TextEditor& _editor() const
     { return *editor_; }
 
     private:
