@@ -33,12 +33,12 @@ class TextEncodingDialog: public CustomDialog
 
 
     //* constructor
-    TextEncodingDialog( QWidget* = nullptr );
+    explicit TextEncodingDialog( QWidget* = nullptr );
 
     //*@name accessors
     //@{
 
-    TextEncodingWidget& encodingWidget( void ) const
+    TextEncodingWidget& encodingWidget() const
     { return *textEncodingWidget_; }
 
     //@}
