@@ -39,7 +39,7 @@ class TextEncodingModel: public ListModel<TextEncodingString>
     public:
 
     //! constructor
-    TextEncodingModel( QObject* parent ):
+    explicit TextEncodingModel( QObject* parent ):
         ListModel<TextEncodingString>( parent )
         {}
 
@@ -61,7 +61,7 @@ class TextEncodingModel: public ListModel<TextEncodingString>
         if( index.isValid() && role == Qt::DisplayRole )
         {
 
-            return get()[index.row()];
+            return get()[index.row()].get();
 
         } else return QVariant();
 
@@ -83,12 +83,12 @@ class TextEncodingModel: public ListModel<TextEncodingString>
         public:
 
         //! constructor
-        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
+        explicit SortFTor( int type, Qt::SortOrder order = Qt::AscendingOrder ):
             ItemModel::SortFTor( type, order )
             {}
 
         //! destructor
-        virtual ~SortFTor( void )
+        virtual ~SortFTor()
         {}
 
         //! prediction
@@ -117,7 +117,7 @@ TextEncodingWidget::TextEncodingWidget( QWidget* parent ):
     model_( new TextEncodingModel( this ) )
 {
     // layout
-    QVBoxLayout* layout( new QVBoxLayout() );
+    QVBoxLayout* layout( new QVBoxLayout );
     layout->setMargin( 0 );
     setLayout( layout );
 
@@ -151,7 +151,7 @@ void TextEncodingWidget::setEncoding( const QByteArray& constValue )
     // get 'standard name'
     QByteArray value( codec->name() );
 
-    QModelIndex index( model_->index( value ) );
+    QModelIndex index( model_->index( TextEncodingString( value ) ) );
     list_->selectionModel()->select( index,  QItemSelectionModel::Clear|QItemSelectionModel::Select|QItemSelectionModel::Rows );
     list_->selectionModel()->setCurrentIndex( index,  QItemSelectionModel::Current|QItemSelectionModel::Rows );
     editor_->setText( value );
@@ -159,16 +159,15 @@ void TextEncodingWidget::setEncoding( const QByteArray& constValue )
 }
 
 //______________________________________________________________________
-void TextEncodingWidget::_loadTextCodecs( void )
+void TextEncodingWidget::_loadTextCodecs()
 {
 
     // use MIBs to get rid of aliases
-    const QList<int> codecIds( QTextCodec::availableMibs() );
     QList<TextEncodingString> codecStrings;
-    foreach( const int& codecId, codecIds )
+    for( const auto& codecId:QTextCodec::availableMibs() )
     {
         QTextCodec* codec( QTextCodec::codecForMib( codecId ) );
-        if( codec ) codecStrings.append( codec->name() );
+        if( codec ) codecStrings.append( TextEncodingString( codec->name() ) );
     }
 
     model_->set( codecStrings );
@@ -176,7 +175,7 @@ void TextEncodingWidget::_loadTextCodecs( void )
 }
 
 //______________________________________________________________________
-void TextEncodingWidget::_updateSelection( void )
+void TextEncodingWidget::_updateSelection()
 {
 
     // do nothing if locked
@@ -186,7 +185,7 @@ void TextEncodingWidget::_updateSelection( void )
     QModelIndex current( list_->selectionModel()->currentIndex() );
     if( !current.isValid() ) return;
     const TextEncodingString& codec( model_->get(current) );
-    editor_->setText( codec );
+    editor_->setText( codec.get() );
 
 }
 
