@@ -27,7 +27,7 @@
 
 class TreeView;
 class TextEncodingModel;
-class TextEncodingWidget: public QWidget, public Counter
+class TextEncodingWidget: public QWidget, private Base::Counter<TextEncodingWidget>
 {
 
 
@@ -36,12 +36,12 @@ class TextEncodingWidget: public QWidget, public Counter
     public:
 
     //* constructor
-    TextEncodingWidget( QWidget* = nullptr );
+    explicit TextEncodingWidget( QWidget* = nullptr );
 
     //*@name accessors
     //@{
 
-    QByteArray encoding( void ) const
+    QByteArray encoding() const
     { return qPrintable( editor_->text() ); }
 
     //@}
@@ -57,12 +57,12 @@ class TextEncodingWidget: public QWidget, public Counter
     protected:
 
     //* load text codecs
-    virtual void _loadTextCodecs( void );
+    void _loadTextCodecs();
 
     protected Q_SLOTS:
 
     //* update selection
-    void _updateSelection( void );
+    void _updateSelection();
 
     //* find
     void _find(QString);
