@@ -26,71 +26,41 @@
 #include <QTextDocument>
 
 //* stores paragraph and index (in paragraph) into unique structure
-class TextPosition: public Counter
+class TextPosition final: private Base::Counter<TextPosition>
 {
     public:
 
     //* default constructor
-    TextPosition( int paragraph = 0, int index = 0 ):
+    explicit TextPosition( int paragraph = 0, int index = 0 ):
         Counter( "TextPosition" ),
         paragraph_( paragraph ),
         index_( index )
     {}
 
     //* construct from document and absolute index
-    TextPosition( QTextDocument*, int index );
+    explicit TextPosition( QTextDocument*, int index );
 
     //* paragraph
-    const int& paragraph( void ) const
+    int paragraph() const
     { return paragraph_; }
 
     //* paragraph
-    int& paragraph( void )
+    int& paragraph()
     { return paragraph_; }
 
     //* index
-    const int& index( void ) const
+    int index() const
     { return index_; }
 
     //* index
-    int& index( void )
+    int& index()
     { return index_; }
 
     //* get absolute index for given document
     int index( QTextDocument* ) const;
 
-    //* lower than operater
-    bool operator < (const TextPosition& position ) const
-    {
-        if( paragraph() != position.paragraph() ) return paragraph() < position.paragraph();
-        else return index() < position.index();
-    }
-
-    //* greater than operator
-    bool operator > (const TextPosition& position ) const
-    {
-        if( paragraph() != position.paragraph() ) return paragraph() > position.paragraph();
-        else return index() > position.index();
-    }
-
-    //* lower than operater
-    bool operator <= (const TextPosition& position ) const
-    { return !(*this > position ); }
-
-    //* larger than operater
-    bool operator >= (const TextPosition& position ) const
-    { return !(*this < position ); }
-
-    //* equal operator
-    bool operator == (const TextPosition& position ) const
-    { return (paragraph() == position.paragraph() && index() == position.index()); }
-
-    //* equal operator
-    bool operator != (const TextPosition& position ) const
-    { return !( *this == position ); }
-
     //* validity
-    bool isValid( void ) const
+    bool isValid() const
     { return (paragraph() >= 0 && index() >= 0 ); }
 
     private:
@@ -110,4 +80,15 @@ class TextPosition: public Counter
 
 };
 
+//* lower than operater
+inline bool operator < (const TextPosition& first, const TextPosition& second)
+{
+    if( first.paragraph() != second.paragraph() ) return first.paragraph() < second.paragraph();
+    else return first.index() < second.index();
+}
+
+//* equal operator
+inline bool operator == (const TextPosition& first, const TextPosition& second)
+{ return (first.paragraph() == second.paragraph() && first.index() == second.index()); }
+
 #endif
