@@ -28,20 +28,20 @@ class ToolButtonStyleMenu;
 class IconSizeMenu;
 
 //* provides toolbar manipulation menu
-class ToolBarMenu: public QMenu, public Counter
+class ToolBarMenu: public QMenu, private Base::Counter<ToolBarMenu>
 {
 
     public:
 
     //* constructor
-    ToolBarMenu( QWidget* = nullptr );
+    explicit ToolBarMenu( QWidget* = nullptr );
 
     //* tool button style menu
-    ToolButtonStyleMenu &toolButtonStyleMenu( void ) const
+    ToolButtonStyleMenu &toolButtonStyleMenu() const
     { return *toolButtonStyleMenu_; }
 
     //* icon size menu
-    IconSizeMenu &iconSizeMenu( void ) const
+    IconSizeMenu &iconSizeMenu() const
     { return *iconSizeMenu_; }
 
     private:
