@@ -24,10 +24,10 @@
 #include "Debug.h"
 
 #include <QMenu>
-#include <QMap>
+#include <QHash>
 
 //* provides tool button style selection menu
-class ToolButtonStyleMenu: public QMenu, public Counter
+class ToolButtonStyleMenu: public QMenu, private Base::Counter<ToolButtonStyleMenu>
 {
 
     Q_OBJECT
@@ -35,7 +35,7 @@ class ToolButtonStyleMenu: public QMenu, public Counter
     public:
 
     //* constructor
-    ToolButtonStyleMenu( QWidget* = nullptr );
+    explicit ToolButtonStyleMenu( QWidget* = nullptr );
 
     //* select size
     void select( int );
@@ -43,7 +43,7 @@ class ToolButtonStyleMenu: public QMenu, public Counter
     Q_SIGNALS:
 
     //* emitted when default size is selected
-    void defaultStyleSelected( void );
+    void defaultStyleSelected();
 
     //* emitted when a new size is selected
     void styleSelected( int );
@@ -56,7 +56,7 @@ class ToolButtonStyleMenu: public QMenu, public Counter
     private:
 
     //* action map
-    using ActionMap = QMap< QAction*, int >;
+    using ActionMap = QHash< QAction*, int >;
 
     //* toolbar text action map
     ActionMap actions_;
