@@ -23,9 +23,19 @@
 #include "TreeItemBase.h"
 
 #include <QList>
-#include <QMap>
+#include <QHash>
 #include <algorithm>
 
+//* generic "isChild" method
+/** can be specialized for objects to which one cannot add an "isChild" member function */
+
+namespace Base
+{
+    template<class T>
+    bool isChild( const T& first, const T& second )
+    { return first.isChild( second ); }
+}
+
 //* used to wrap object T into tree structure
 template<class T> class TreeItem: public TreeItemBase
 {
@@ -51,7 +61,7 @@ template<class T> class TreeItem: public TreeItemBase
     using List = QList<TreeItem>;
 
     //* map items to internal id
-    using Map = QMap<int, TreeItem*>;
+    using Map = QHash<int, TreeItem*>;
 
     //* root constructor
     TreeItem( Map& itemMap ):
@@ -82,6 +92,9 @@ template<class T> class TreeItem: public TreeItemBase
     TreeItem& operator = ( const TreeItem& item )
     {
 
+        // check for identity
+        if( this == &item ) return *this;
+
         parent_ = item.parent_;
         value_ = item.value_;
         children_ = item.children_;
@@ -100,23 +113,15 @@ template<class T> class TreeItem: public TreeItemBase
     }
 
     //* destructor
-    virtual ~TreeItem( void )
+    ~TreeItem() override
     { _eraseFromMap(); }
 
-    //* less than operator
-    bool operator < (const TreeItem& item ) const
-    { return get() < item.get(); }
-
-    //* equal to operator
-    bool operator == (const TreeItem& item ) const
-    { return get() == item.get(); }
-
     //* clear children
-    void clear( void )
+    void clear()
     { children_.clear(); }
 
     //* value
-    const ValueType& get( void ) const
+    const ValueType& get() const
     { return value_; }
 
     //* value
@@ -124,15 +129,15 @@ template<class T> class TreeItem: public TreeItemBase
     { value_ = value; }
 
     //* parent
-    bool hasParent( void ) const
+    bool hasParent() const
     { return parent_; }
 
     //* parent
-    const TreeItem& parent( void ) const
+    const TreeItem& parent() const
     { return *parent_; }
 
     //* child count
-    int childCount( void ) const
+    int childCount() const
     { return children_.size(); }
 
     //* get child at given row
@@ -163,11 +168,11 @@ template<class T> class TreeItem: public TreeItemBase
     }
 
     //* retrieve all children in list [recursive]
-    ValueList childValues( void ) const
+    ValueList childValues() const
     {
 
         ValueList out;
-        foreach( const TreeItem& item, children_ )
+        for( const auto& item:children_ )
         {
             out << item.get();
             out << item.childValues();
@@ -194,7 +199,7 @@ template<class T> class TreeItem: public TreeItemBase
     {
 
         // try add to this list of children
-        if( value.isChild( get() ) )
+        if( Base::isChild( value, get() ) )
         {
             children_ << TreeItem( map_, this, value );
             return true;
@@ -241,7 +246,7 @@ template<class T> class TreeItem: public TreeItemBase
         {
             int found( values.indexOf( child(row).get() ) );
             if( found < 0 ) remove( row );
-            else if( values.at(found).isChild( get() ) )
+            else if( Base::isChild( values.at(found), get() ) )
             {
 
                 // update child
@@ -285,7 +290,7 @@ template<class T> class TreeItem: public TreeItemBase
             {
 
                 // make sure parent has not changed
-                if( values.at(found).isChild( get() ) )
+                if( Base::isChild( values.at(found), get() ) )
                 {
 
                     // re-assign and remove from list
@@ -313,7 +318,7 @@ template<class T> class TreeItem: public TreeItemBase
     }
 
     //* sorting (recursive)
-    void sort( void )
+    void sort()
     {
         if( children_.empty() ) return;
         std::sort( children_.begin(), children_.end() );
@@ -350,11 +355,11 @@ template<class T> class TreeItem: public TreeItemBase
     { map_[id()] = this; }
 
     //* value
-    Reference _get( void )
+    Reference _get()
     { return value_; }
 
     //* erase from map
-    void _eraseFromMap( void )
+    void _eraseFromMap()
     {
         typename Map::iterator iter( map_.find( id() ) );
         if( iter != map_.end() && iter.value() == this )
@@ -400,4 +405,14 @@ template<class T> class TreeItem: public TreeItemBase
 
 };
 
+//* less than operator
+template<class T>
+inline bool operator < (const TreeItem<T>& first, const TreeItem<T>& second)
+{ return first.get() < second.get(); }
+
+//* equal to operator
+template<class T>
+inline bool operator == (const TreeItem<T>& first, const TreeItem<T>& second)
+{ return first.get() == second.get(); }
+
 #endif
