@@ -59,18 +59,18 @@ template<class T> class TreeModel : public ItemModel
         root_( map_ )
     {}
 
-    //*@name methods reimplemented from base class
+    //*@name accessors
     //@{
 
     //* flags
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const
+    Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         if (!index.isValid()) return 0;
         return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
     }
 
     //* unique index for given row, column and parent index
-    virtual QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
     {
 
         // check if index is valid
@@ -87,7 +87,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* index of parent
-    virtual QModelIndex parent(const QModelIndex &index) const
+    QModelIndex parent(const QModelIndex &index) const override
     {
 
         // check index validity
@@ -114,7 +114,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* number of rows below given index
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
 
         // check column
@@ -126,13 +126,8 @@ template<class T> class TreeModel : public ItemModel
 
     }
 
-    //@}
-
-    //*@name value to index matching
-    //@{
-
     //* return index associated to a given value, starting from parent [recursive]
-    virtual QModelIndex index( ConstReference value, const QModelIndex& parent = QModelIndex() ) const
+    QModelIndex index( ConstReference value, const QModelIndex& parent = QModelIndex() ) const
     {
 
         // return parent index if job match
@@ -152,7 +147,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* return all values [recursive]
-    virtual List children( const QModelIndex& parent = QModelIndex() ) const
+    List children( const QModelIndex& parent = QModelIndex() ) const
     {
 
         // retrieve parent item
@@ -162,7 +157,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* return all values [recursive]
-    virtual List children( ConstReference value ) const
+    List children( ConstReference value ) const
     {
 
         const QModelIndex& index( this->index( value ) );
@@ -170,7 +165,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* return value associated to given model index
-    virtual ValueType get( const QModelIndex& index ) const
+    ValueType get( const QModelIndex& index ) const
     {
         if( !index.isValid() ) return ValueType();
         else return _find( index.internalId() ).get();
@@ -180,41 +175,16 @@ template<class T> class TreeModel : public ItemModel
     List get( const QModelIndexList& indexes ) const
     {
         List out;
-        foreach( const QModelIndex& index, indexes )
+        for( const auto& index:indexes )
         { if( index.isValid() ) out << get( index ); }
         return out;
     }
 
-    //@}
-
-    //*@name selection
-    //@{
-
-    //* clear internal list selected items
-    virtual void clearSelectedIndexes( void )
-    { selectedItems_.clear(); }
-
-    //* set selected indexes
-    virtual void setSelectedIndexes( const QModelIndexList& indexes )
-    {
-        selectedItems_.clear();
-        foreach( const QModelIndex& index, indexes )
-        { if( index.isValid() ) selectedItems_ << get( index ); }
-    }
-
-    //* store index internal selection state
-    virtual void setIndexSelected( const QModelIndex& index, bool value )
-    {
-        if( !index.isValid() ) return;
-        if( value ) selectedItems_ << get( index );
-        else { selectedItems_.removeAll( get( index ) ); }
-    }
-
     //* get list of internal selected items
-    virtual QModelIndexList selectedIndexes( void ) const
+    QModelIndexList selectedIndexes() const override
     {
         QModelIndexList out;
-        foreach( const ValueType& value, selectedItems_ )
+        for( const auto& value:selectedItems_ )
         {
             QModelIndex index( this->index( value ) );
             if( index.isValid() ) out << index;
@@ -222,17 +192,61 @@ template<class T> class TreeModel : public ItemModel
         return out;
     }
 
+    //* restore currentIndex
+    QModelIndex currentIndex() const override
+    { return hasCurrentItem_ ? this->index( currentItem_ ) : QModelIndex(); }
+
+    //* true if expended indexes are supported
+    bool supportsExpandedIndexes() const override
+    { return true; }
+
+    //* get list of internal selected items
+    QModelIndexList expandedIndexes() const override
+    {
+        QModelIndexList out;
+        for( const auto& value:expandedItems_ )
+        {
+            QModelIndex index( this->index( value ) );
+            if( index.isValid() ) out << index;
+        }
+        return out;
+    }
+
+    //* root item
+    const Item& root() const
+    { return root_; }
+
     //@}
 
-    //*@name current index
+    //*@name modifiers
     //@{
 
+    //* clear internal list selected items
+    void clearSelectedIndexes() override
+    { selectedItems_.clear(); }
+
+    //* set selected indexes
+    void setSelectedIndexes( const QModelIndexList& indexes ) override
+    {
+        selectedItems_.clear();
+        for( const auto& index:indexes )
+        { if( index.isValid() ) selectedItems_ << get( index ); }
+    }
+
+    //* store index internal selection state
+    void setIndexSelected( const QModelIndex& index, bool value ) override
+    {
+        if( !index.isValid() ) return;
+        if( value ) selectedItems_ << get( index );
+        else { selectedItems_.removeAll( get( index ) ); }
+    }
+
     //* current index;
-    virtual void clearCurrentIndex( void )
+    void clearCurrentIndex() override
     { hasCurrentItem_ = false; }
 
     //* store current index
-    virtual void setCurrentIndex( const QModelIndex& index )
+    void setCurrentIndex( const QModelIndex& index ) override
     {
         if( index.isValid() )
         {
@@ -243,53 +257,26 @@ template<class T> class TreeModel : public ItemModel
         } else hasCurrentItem_ = false;
     }
 
-    //* restore currentIndex
-    virtual QModelIndex currentIndex( void ) const
-    { return hasCurrentItem_ ? this->index( currentItem_ ) : QModelIndex(); }
-
-    //@}
-
-    //*@name expansion
-    //@{
-
-    //* true if expended indexes are supported
-    virtual bool supportsExpandedIndexes( void ) const
-    { return true; }
-
     //* clear internal list of expanded items
-    virtual void clearExpandedIndexes( void )
+    void clearExpandedIndexes() override
     { expandedItems_.clear(); }
 
     //* set selected indexes
-    virtual void setExpandedIndexes( const QModelIndexList& indexes )
+    void setExpandedIndexes( const QModelIndexList& indexes ) override
     {
         expandedItems_.clear();
-        foreach( const QModelIndex& index, indexes )
+        for( const auto& index:indexes )
         { if( index.isValid() ) expandedItems_ << get( index ); }
     }
 
     //* store index internal selection state
-    virtual void setIndexExpanded( const QModelIndex& index, bool value )
+    void setIndexExpanded( const QModelIndex& index, bool value ) override
     {
         if( !index.isValid() ) return;
         if( value ) expandedItems_ << get( index );
         else { expandedItems_.removeAll( get( index ) ); }
     }
 
-    //* get list of internal selected items
-    virtual QModelIndexList expandedIndexes( void ) const
-    {
-        QModelIndexList out;
-        foreach( const ValueType& value, expandedItems_ )
-        {
-            QModelIndex index( this->index( value ) );
-            if( index.isValid() ) out << index;
-        }
-        return out;
-    }
-
-    //@}
-
     //* add values
     void add( ConstReference value )
     { add( List() << value ); }
@@ -383,16 +370,12 @@ template<class T> class TreeModel : public ItemModel
         emit layoutChanged();
     }
 
-    //* root item
-    const Item& root( void ) const
-    { return root_; }
-
     //* remove
-    virtual void remove( ConstReference value )
+    void remove( ConstReference value )
     { remove( List() << value ); }
 
     //* remove
-    virtual void remove( List values )
+    void remove( List values )
     {
 
         // check if not empty
@@ -408,7 +391,7 @@ template<class T> class TreeModel : public ItemModel
     }
 
     //* reset tree
-    void resetTree( void )
+    void resetTree()
     {
         emit layoutAboutToBeChanged();
         _resetTree();
@@ -417,7 +400,7 @@ template<class T> class TreeModel : public ItemModel
 
 
     //* clear
-    void clear( void )
+    void clear()
     {
 
         emit layoutAboutToBeChanged();
@@ -431,16 +414,18 @@ template<class T> class TreeModel : public ItemModel
     void setSortValues( bool value )
     { sortValues_ = value; }
 
+    //@}
+
     protected:
 
     //* root item
-    Item& _root( void )
+    Item& _root()
     { return root_; }
 
     //* add
     void _add( Item& item, List values )
     {
-        foreach( ConstReference value, values )
+        for( const auto& value:values )
         { item.add( value ); }
     }
 
@@ -456,7 +441,7 @@ template<class T> class TreeModel : public ItemModel
     {
 
         // remove all values from selection
-        foreach( const ValueType& value, values )
+        for( const auto& value:values )
         { selectedItems_.removeAll( value ); }
 
         // remove children that are found in list, and remove from list
@@ -482,7 +467,7 @@ template<class T> class TreeModel : public ItemModel
 
     //* reset tree
     /** private version, with no signal emitted */
-    void _resetTree( void )
+    void _resetTree()
     {
         List children( TreeModel::children() );
         map_.clear();
