@@ -49,7 +49,7 @@ TreeView::TreeView( QWidget* parent ):
 
     // replace item delegate
     if( itemDelegate() ) itemDelegate()->deleteLater();
-    TreeViewItemDelegate* delegate = new TreeViewItemDelegate( this );
+    auto delegate = new TreeViewItemDelegate( this );
     setItemDelegate( delegate );
 
     // actions
@@ -75,7 +75,7 @@ TreeView::TreeView( QWidget* parent ):
     connect( this, SIGNAL(entered(QModelIndex)), SLOT(_indexEntered(QModelIndex)) );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
@@ -147,13 +147,13 @@ void TreeView::setFindEnabled( bool value )
 }
 
 //______________________________________________________________________
-TextSelection TreeView::selection( void ) const
+TextSelection TreeView::selection() const
 {
 
     Debug::Throw( "TreeView::selection.\n" );
 
     // copy last selection
-    TextSelection out( "" );
+    TextSelection out;
     out.setFlag( TextSelection::CaseSensitive, TextEditor::lastSelection().flag( TextSelection::CaseSensitive ) );
     out.setFlag( TextSelection::EntireWord, TextEditor::lastSelection().flag( TextSelection::EntireWord ) );
 
@@ -201,7 +201,7 @@ bool TreeView::isVisible( const QModelIndex& index ) const
 }
 
 //_______________________________________________
-int TreeView::visibleColumnCount( void ) const
+int TreeView::visibleColumnCount() const
 {
     int out(0);
     for( int index=0; model() && index < model()->columnCount(); index++ )
@@ -277,17 +277,17 @@ bool TreeView::setOptionName( const QString& value )
 }
 
 //_______________________________________________
-unsigned int TreeView::mask( void ) const
+int TreeView::mask() const
 {
     Debug::Throw( "TreeView::mask.\n" );
-    unsigned int mask = 0;
+    int mask = 0;
     for( int index=0; model() && index < model()->columnCount(); index++ )
-        if( !isColumnHidden( index ) ) mask |= (1<<index);
+    { if( !isColumnHidden( index ) ) mask |= (1<<index); }
     return mask;
 }
 
 //_______________________________________________
-void TreeView::setMask( const unsigned int& mask )
+void TreeView::setMask( int mask )
 {
 
     Debug::Throw( "TreeView::setMask.\n" );
@@ -308,21 +308,21 @@ void TreeView::setMask( const unsigned int& mask )
 }
 
 //______________________________________________________
-void TreeView::storeScrollBarPosition( void )
+void TreeView::storeScrollBarPosition()
 {
     if( verticalScrollBar() ) vertical_ = verticalScrollBar()->value();
     if( horizontalScrollBar() ) horizontal_ = horizontalScrollBar()->value();
 }
 
 //______________________________________________________
-void TreeView::restoreScrollBarPosition( void )
+void TreeView::restoreScrollBarPosition()
 {
     if( verticalScrollBar() ) verticalScrollBar()->setValue( vertical_ );
     if( horizontalScrollBar() ) horizontalScrollBar()->setValue( horizontal_ );
 }
 
 //______________________________________________________
-void TreeView::resizeColumns( const unsigned int& mask )
+void TreeView::resizeColumns( int mask )
 {
 
     // if no items present, do nothing
@@ -342,7 +342,7 @@ void TreeView::toggleShowHeader( bool value )
 }
 
 //_______________________________________________
-void TreeView::updateMask( void )
+void TreeView::updateMask()
 {
 
     Debug::Throw( "TreeView::updateMask.\n" );
@@ -353,23 +353,23 @@ void TreeView::updateMask( void )
     if( !XmlOptions::get().contains( maskOptionName() ) ) return;
 
     // assign mask from options
-    setMask( XmlOptions::get().get<unsigned int>( maskOptionName() ) );
+    setMask( XmlOptions::get().get<int>( maskOptionName() ) );
     resizeColumns();
 
 }
 
 //_______________________________________________
-void TreeView::saveMask( void )
+void TreeView::saveMask()
 {
 
     Debug::Throw( "TreeView::saveMask.\n" );
     if( !hasOptionName() ) return;
-    XmlOptions::get().set<unsigned int>( maskOptionName(), mask() );
+    XmlOptions::get().set<int>( maskOptionName(), mask() );
 
 }
 
 //_____________________________________________________________________
-void TreeView::updateSortOrder( void )
+void TreeView::updateSortOrder()
 {
 
     Debug::Throw( "TreeView::updateSortOrder.\n" );
@@ -388,7 +388,7 @@ void TreeView::updateSortOrder( void )
 }
 
 //_____________________________________________________________________
-void TreeView::saveSortOrder( void )
+void TreeView::saveSortOrder()
 {
 
     Debug::Throw( "TreeView::saveSortOrder.\n" );
@@ -410,11 +410,11 @@ void TreeView::find( TextSelection selection )
 }
 
 //______________________________________________________________________
-void TreeView::findAgainForward( void )
+void TreeView::findAgainForward()
 { _findForward( TextEditor::lastSelection(), true ); }
 
 //______________________________________________________________________
-void TreeView::findAgainBackward( void )
+void TreeView::findAgainBackward()
 { _findBackward( TextEditor::lastSelection(), true ); }
 
 //__________________________________________________________
@@ -439,7 +439,7 @@ void TreeView::_setItemMargin( int value )
 }
 
 //__________________________________________________________
-void TreeView::storeSelectedIndexes( void )
+void TreeView::storeSelectedIndexes()
 {
     if( selectionModel() )
     {
@@ -449,16 +449,16 @@ void TreeView::storeSelectedIndexes( void )
 }
 
 //__________________________________________________________
-void TreeView::restoreSelectedIndexes( void )
+void TreeView::restoreSelectedIndexes()
 {
 
     if( selectionModel() )
     {
 
-        const QModelIndexList selection( model_->selectedIndexes() );
+        auto selection( model_->selectedIndexes() );
 
         selectionModel()->clear();
-        foreach( const QModelIndex& index, selection )
+        for( const auto& index:selection )
         { selectionModel()->select( index, QItemSelectionModel::Select|QItemSelectionModel::Rows ); }
 
         selectionModel()->setCurrentIndex( model_->currentIndex(), QItemSelectionModel::Current );
@@ -470,14 +470,14 @@ void TreeView::restoreSelectedIndexes( void )
 
 
 //__________________________________________________________
-void TreeView::storeExpandedIndexes( void )
+void TreeView::storeExpandedIndexes()
 {
 
     // clear
     model_->clearExpandedIndexes();
 
     // retrieve selected indexes in list
-    foreach( const QModelIndex& index, model_->indexes() )
+    for( const auto& index:model_->indexes() )
     { if( isExpanded( index ) ) model_->setIndexExpanded( index, true ); }
 
     storeScrollBarPosition();
@@ -485,13 +485,13 @@ void TreeView::storeExpandedIndexes( void )
 }
 
 //________________________________________
-void TreeView::restoreExpandedIndexes( void )
+void TreeView::restoreExpandedIndexes()
 {
 
-    QModelIndexList indexes( model_->expandedIndexes() );
+    auto indexes( model_->expandedIndexes() );
 
     collapseAll();
-    foreach( const QModelIndex& index, indexes )
+    for( const auto& index:indexes )
     { setExpanded( index, true ); }
 
     restoreScrollBarPosition();
@@ -523,10 +523,22 @@ bool TreeView::event( QEvent* event )
 void TreeView::mouseMoveEvent( QMouseEvent *event )
 {
 
-    if( !indexAt( event->pos() ).isValid() )
-    { _setHoverIndex( QModelIndex() ); }
+    if( hasMouseTracking() && event->buttons() == Qt::NoButton )
+    {
+
+        // when mouse tracking is no, need to intercept mouseMoveEvents
+        // because they break drag and drop
+        _setHoverIndex( indexAt( event->pos() ) );
+
+    } else {
+
+        if( !indexAt( event->pos() ).isValid() )
+        { _setHoverIndex( QModelIndex() ); }
+
+        return QTreeView::mouseMoveEvent( event );
+
+    }
 
-    return QTreeView::mouseMoveEvent( event );
 }
 
 //__________________________________________________________
@@ -571,7 +583,7 @@ void TreeView::paintEvent( QPaintEvent* event )
 }
 
 //______________________________________________________________________
-void TreeView::_createFindDialog( void )
+void TreeView::_createFindDialog()
 {
 
     Debug::Throw( "TreeView::_createFindDialog.\n" );
@@ -707,14 +719,11 @@ bool TreeView::_findForward( const TextSelection& selection, bool rewind )
 
         } else {
 
-            QModelIndex previous( index );
             index = _indexAfter( index );
-
             if( rewind && !index.isValid() )
             {
                 rewind = false;
                 index = _firstIndex();
-
             }
 
         }
@@ -833,7 +842,7 @@ bool TreeView::_findBackward( const TextSelection& selection, bool rewind )
 }
 
 //__________________________________________________________
-void TreeView::_installActions( void )
+void TreeView::_installActions()
 {
     Debug::Throw( "TreeView::_installActions.\n" );
 
@@ -886,6 +895,7 @@ void TreeView::_raiseHeaderMenu( const QPoint & pos )
 
     // create menu and raise.
     ColumnSelectionMenu menu( this, this );
+    menu.setCurrentColumn( header()->logicalIndexAt( pos ) );
     if( isSortingEnabled() )
     {
         menu.addSeparator();
@@ -893,7 +903,7 @@ void TreeView::_raiseHeaderMenu( const QPoint & pos )
     }
 
     menu.adjustSize();
-    menu.exec( QCursor::pos() );
+    menu.exec( header()->mapToGlobal( pos ) );
 
     // save mask after menu execution,
     // to keep visible columns in sync with option
@@ -902,7 +912,7 @@ void TreeView::_raiseHeaderMenu( const QPoint & pos )
 }
 
 //_____________________________________________________________________
-void TreeView::_findFromDialog( void )
+void TreeView::_findFromDialog()
 {
     Debug::Throw( "TreeView::_findFromDialog.\n" );
 
@@ -956,7 +966,7 @@ void TreeView::_setHoverIndex( const QModelIndex& index )
 }
 
 //_____________________________________________________________________
-void TreeView::_updateConfiguration( void )
+void TreeView::_updateConfiguration()
 {
     Debug::Throw( "TreeView::_updateConfiguration.\n" );
 
@@ -992,11 +1002,11 @@ void TreeView::_updateConfiguration( void )
 }
 
 //_________________________________________________________
-QModelIndex TreeView::_firstIndex( void ) const
+QModelIndex TreeView::_firstIndex() const
 { return model()->index( 0, 0 ); }
 
 //_________________________________________________________
-QModelIndex TreeView::_lastIndex( void ) const
+QModelIndex TreeView::_lastIndex() const
 {
 
     if( !model()->rowCount() ) return QModelIndex();
@@ -1088,7 +1098,7 @@ QModelIndex TreeView::_indexBefore( const QModelIndex& current ) const
 TreeView::Container::Container( QWidget* parent ):
     QWidget( parent ),
     Counter( "TreeView::Container" ),
-    treeView_( new TreeView() )
+    treeView_( new TreeView )
 { _initialize(); }
 
 //_________________________________________________________
@@ -1099,13 +1109,13 @@ TreeView::Container::Container( QWidget* parent, TreeView* treeView ):
 { _initialize(); }
 
 //_________________________________________________________
-void TreeView::Container::_initialize( void )
+void TreeView::Container::_initialize()
 {
     Debug::Throw( "TreeView::Container::_initialize.\n" );
     treeView_->setParent( this );
 
     // setup layout
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    QVBoxLayout* vLayout = new QVBoxLayout;
     vLayout->setMargin(0);
     vLayout->setSpacing(2);
     setLayout( vLayout );
