@@ -34,7 +34,7 @@ class BaseFindWidget;
 class ItemModel;
 
 //* customized tree view
-class TreeView: public QTreeView, public Counter
+class TreeView: public QTreeView, private Base::Counter<TreeView>
 {
 
     //* Qt meta object declaration
@@ -43,48 +43,45 @@ class TreeView: public QTreeView, public Counter
     public:
 
     //* constructor
-    TreeView( QWidget* = nullptr );
+    explicit TreeView( QWidget* = nullptr );
 
     //*@name accessors
     //@{
 
     //* TextSelection object from this selection, or clipboard
-    TextSelection selection( void ) const;
+    TextSelection selection() const;
 
     //* true if given index is visible
     bool isVisible( const QModelIndex& index ) const;
 
     //* number of visible columns
-    virtual int visibleColumnCount( void ) const;
+    int visibleColumnCount() const;
 
     //* option name
-    virtual bool hasOptionName( void ) const
+    bool hasOptionName() const
     { return !maskOptionName().isEmpty(); }
 
     //* option name
-    virtual const QString& maskOptionName( void ) const
+    const QString& maskOptionName() const
     { return maskOptionName_; }
 
     //* sort column option name
-    virtual const QString& sortColumnOptionName( void ) const
+    const QString& sortColumnOptionName() const
     { return sortColumnOptionName_; }
 
     //* sort order option name
-    virtual const QString& sortOrderOptionName( void ) const
+    const QString& sortOrderOptionName() const
     { return sortOrderOptionName_; }
 
     //* sort order option name
-    virtual const QString& showHeaderOptionName( void ) const
+    const QString& showHeaderOptionName() const
     { return showHeaderOptionName_; }
 
     //* get mask
-    virtual unsigned int mask( void ) const;
-
-    //* set mask manually
-    virtual void setMask( const unsigned int& );
+    int mask() const;
 
     //* item margin
-    virtual int itemMargin( void ) const
+    int itemMargin() const
     { return itemMargin_; }
 
     //@}
@@ -93,19 +90,19 @@ class TreeView: public QTreeView, public Counter
     //@{
 
     //* model
-    virtual void setModel( QAbstractItemModel* );
+    void setModel( QAbstractItemModel* ) override;
 
     //* delegate
-    virtual void setItemDelegate( QAbstractItemDelegate* );
+    void setItemDelegate( QAbstractItemDelegate* );
 
     //* delegate
-    virtual void setItemDelegateForColumn( int, QAbstractItemDelegate* );
+    void setItemDelegateForColumn( int, QAbstractItemDelegate* );
 
     //* enable list finding
     void setFindEnabled( bool value );
 
     //* option name
-    virtual bool setOptionName( const QString& );
+    bool setOptionName( const QString& );
 
     //* lock column
     void lockColumnVisibility( int index )
@@ -131,14 +128,14 @@ class TreeView: public QTreeView, public Counter
     { iconSizeFromOptions_ = value; }
 
     //* force alternating row color
-    void forceAlternatingRowColors( void )
+    void forceAlternatingRowColors()
     {
         forceAlternatingRowColors_ = true;
         setAlternatingRowColors( true );
     }
 
     //* set item margins
-    virtual void setItemMargin( int );
+    void setItemMargin( int );
 
     //* set icon size manually and disable option
     void setIconSize( const QSize& size )
@@ -159,10 +156,13 @@ class TreeView: public QTreeView, public Counter
     }
 
     //* store scrollbar position
-    void storeScrollBarPosition( void );
+    void storeScrollBarPosition();
 
     //* restore scrollbar position
-    void restoreScrollBarPosition( void );
+    void restoreScrollBarPosition();
+
+    //* set mask manually
+    void setMask( int );
 
     //@}
 
@@ -171,47 +171,47 @@ class TreeView: public QTreeView, public Counter
     //@{
 
     //* select all
-    QAction& selectAllAction( void ) const
+    QAction& selectAllAction() const
     { return *selectAllAction_; }
 
     //* find from dialog
-    QAction& findAction( void ) const
+    QAction& findAction() const
     { return *findAction_; }
 
     //* find selection again
-    QAction& findSelectionAction( void ) const
+    QAction& findSelectionAction() const
     { return *findSelectionAction_; }
 
     //* find again
-    QAction& findAgainAction( void ) const
+    QAction& findAgainAction() const
     { return *findAgainAction_; }
 
     //* show header
-    QAction& showHeaderAction( void ) const
+    QAction& showHeaderAction() const
     { return *showHeaderAction_; }
 
     //@}
 
     //* container class for embedded Find dialog
-    class Container: public QWidget, public Counter
+    class Container: public QWidget, private Base::Counter<Container>
     {
 
         public:
 
         //* constructor
-        Container( QWidget* = nullptr );
+        explicit Container( QWidget* = nullptr );
 
         //* constructor
-        Container( QWidget*, TreeView* );
+        explicit Container( QWidget*, TreeView* );
 
         //*@name accessors
-        TreeView& treeView( void ) const
+        TreeView& treeView() const
         { return *treeView_; }
 
         private:
 
         //* initialize
-        void _initialize( void );
+        void _initialize();
 
         //* contained treeView
         TreeView* treeView_;
@@ -229,10 +229,10 @@ class TreeView: public QTreeView, public Counter
     void hovered( const QModelIndex& );
 
     //* emitted when selection could not be found
-    void noMatchFound( void );
+    void noMatchFound();
 
     //* emitted when selection could be found
-    void matchFound( void );
+    void matchFound();
 
     #if QT_VERSION < 0x050000
     //* icon size changed signal
@@ -242,113 +242,113 @@ class TreeView: public QTreeView, public Counter
     public Q_SLOTS:
 
     //* resize all visible columns to match contents
-    virtual void resizeColumns()
+    void resizeColumns()
     { resizeColumns( mask() ); }
 
     //* resize all visible columns to match contents
-    virtual void resizeColumns( const unsigned int& mask );
+    void resizeColumns( int mask );
 
     //* toggle show header
-    virtual void toggleShowHeader( bool value );
+    void toggleShowHeader( bool value );
 
     //*@name column mask
     //@{
 
     //* update column mask from option, if any
-    virtual void updateMask( void );
+    void updateMask();
 
     //* save column mask to option, if any
-    virtual void saveMask( void );
+    void saveMask();
 
     //@}
 
     //* sort order
-    virtual void updateSortOrder( void );
+    void updateSortOrder();
 
     //* sort order
-    virtual void saveSortOrder( void );
+    void saveSortOrder();
 
     //* find next occurence of TextSelection
-    virtual void find( TextSelection selection );
+    void find( TextSelection selection );
 
     //* find current selection forward
-    virtual void findSelectionForward( void )
+    void findSelectionForward()
     { _findForward( selection(), true ); }
 
     //* find current selection backward
-    virtual void findSelectionBackward( void )
+    void findSelectionBackward()
     { _findBackward( selection(), true ); }
 
     //* find last search forward
-    virtual void findAgainForward( void );
+    void findAgainForward();
 
     //* find last search forward
-    virtual void findAgainBackward( void );
+    void findAgainBackward();
 
     //* store selected indexes in model
-    void storeSelectedIndexes( void );
+    void storeSelectedIndexes();
 
     //* restore selected indexes from model
-    void restoreSelectedIndexes( void );
+    void restoreSelectedIndexes();
 
     //* store expanded indexes in model
-    void storeExpandedIndexes( void );
+    void storeExpandedIndexes();
 
     //* restore expanded indexes from model
-    void restoreExpandedIndexes( void );
+    void restoreExpandedIndexes();
 
     protected:
 
     //* generic event
-    virtual bool event( QEvent* );
+    bool event( QEvent* ) override;
 
     //* mouse move event
-    virtual void mouseMoveEvent( QMouseEvent* );
+    void mouseMoveEvent( QMouseEvent* ) override;
 
     //* mouse press event
-    virtual void mousePressEvent( QMouseEvent* );
+    void mousePressEvent( QMouseEvent* ) override;
 
     //* paint event
-    virtual void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
     //* find dialog
-    virtual void _createFindDialog( void );
+    void _createFindDialog();
 
     //* find widget
-    virtual void _createFindWidget( bool compact );
+    void _createFindWidget( bool compact );
 
     //* find selection in forward direction
-    virtual bool _findForward( const TextSelection& selection, bool rewind );
+    bool _findForward( const TextSelection& selection, bool rewind );
 
     //* find selection in backward direction
-    virtual bool _findBackward( const TextSelection& selection, bool rewind );
+    bool _findBackward( const TextSelection& selection, bool rewind );
 
     //* set item margin
-    virtual void _setItemMargin( int );
+    void _setItemMargin( int );
 
     //* hover index
-    virtual void _setHoverIndex( const QModelIndex& );
+    void _setHoverIndex( const QModelIndex& );
 
     protected Q_SLOTS:
 
     //* header menu
-    virtual void _raiseHeaderMenu( const QPoint& );
+    void _raiseHeaderMenu( const QPoint& );
 
     //* find text from dialog
-    virtual void _findFromDialog( void );
+    void _findFromDialog();
 
     //* hover index
-    virtual void _indexEntered( const QModelIndex& );
+    void _indexEntered( const QModelIndex& );
 
     private Q_SLOTS:
 
     //* update alternate item color
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
     //* install actions
-    virtual void _installActions( void );
+    void _installActions();
 
     //* return first index
     QModelIndex _firstIndex() const;
@@ -437,7 +437,7 @@ class TreeView: public QTreeView, public Counter
     int horizontal_ = 0;
 
     //* locked columns
-    unsigned lockedColumns_ = 0;
+    int lockedColumns_ = 0;
 
     friend class Container;
 
