@@ -33,23 +33,23 @@ ValidFileThread::ValidFileThread( QObject* parent ):
 }
 
 //______________________________________________________
-void ValidFileThread::run( void )
+void ValidFileThread::run()
 {
 
     QMutexLocker lock( &mutex_ );
     bool hasInvalidRecords( false );
 
     // loop over files, check if exists, set validity accordingly, and post event
-    for( FileRecord::List::iterator iter = records_.begin(); iter != records_.end(); ++iter )
+    for( auto& record:records_ )
     {
-        iter->setValid( File( iter->file() ).exists() );
-        hasInvalidRecords |= !iter->isValid();
+        record.setValid( File( record.file() ).exists() );
+        hasInvalidRecords |= !record.isValid();
     }
 
     // look for duplicated records
     if( checkDuplicates_ )
     {
-        for( FileRecord::List::iterator iter = records_.begin(); iter != records_.end(); )
+        for( auto&& iter = records_.begin(); iter != records_.end(); )
         {
 
             // check item validity
