@@ -28,7 +28,7 @@
 #include <QThread>
 
 //* independent thread used to automatically save file
-class ValidFileThread: public QThread, public Counter
+class ValidFileThread: public QThread, private Base::Counter<ValidFileThread>
 {
 
     Q_OBJECT
@@ -36,10 +36,7 @@ class ValidFileThread: public QThread, public Counter
     public:
 
     //* constructor
-    ValidFileThread( QObject* = nullptr );
-
-    //* destructor
-    virtual ~ValidFileThread(void) = default;
+    explicit ValidFileThread( QObject* = nullptr );
 
     //* check duplicates
     void setCheckDuplicates( bool value )
@@ -63,7 +60,7 @@ class ValidFileThread: public QThread, public Counter
     protected:
 
     //* Check files validity. Post a ValidFileEvent when finished
-    virtual void run( void );
+    void run() override;
 
     private:
 
