@@ -34,15 +34,15 @@ class WarningDialog: public DetailsDialog
     public:
 
     //* constructor
-    WarningDialog( QWidget* parent, const QString& = QString() );
+    explicit WarningDialog( QWidget* parent, const QString& = QString() );
 
     //* set text
-    virtual void setText( const QString& );
+    void setText( const QString& );
 
     protected:
 
     //* label
-    QLabel& _label( void ) const
+    QLabel& _label() const
     { return *label_; }
 
     private:
