@@ -30,7 +30,7 @@
 #include <QWidget>
 
 //* used to automatically save size of top level widgets
-class WidgetDragMonitor: public QObject, public Counter
+class WidgetDragMonitor: public QObject, private Base::Counter<WidgetDragMonitor>
 {
 
     Q_OBJECT
@@ -38,7 +38,7 @@ class WidgetDragMonitor: public QObject, public Counter
     public:
 
     //* constructor
-    WidgetDragMonitor( QWidget* );
+    explicit WidgetDragMonitor( QWidget* );
 
     //* mode
     enum ModeFlag
@@ -53,11 +53,11 @@ class WidgetDragMonitor: public QObject, public Counter
     //@{
 
     //* mode
-    Mode mode( void ) const
+    Mode mode() const
     { return mode_; }
 
     //* enabled state
-    bool isEnabled( void ) const
+    bool isEnabled() const
     { return enabled_; }
 
     //@}
@@ -72,16 +72,16 @@ class WidgetDragMonitor: public QObject, public Counter
     //@}
 
     //* event filter
-    virtual bool eventFilter( QObject*, QEvent* );
+    bool eventFilter( QObject*, QEvent* ) override;
 
 
     Q_SIGNALS:
 
-    void stateChangeRequest( void );
+    void stateChangeRequest();
 
     public Q_SLOTS:
 
-    void toggleState( void )
+    void toggleState()
     {
         enabled_ = !enabled_;
         if( !enabled_ ) _resetDrag();
@@ -96,7 +96,7 @@ class WidgetDragMonitor: public QObject, public Counter
     protected:
 
     //* timer event
-    virtual void timerEvent( QTimerEvent* );
+    void timerEvent( QTimerEvent* ) override;
 
     //* get corner from (relative) position
     XcbDefines::Direction _direction( QWidget* widget, const QPoint& ) const;
@@ -104,10 +104,10 @@ class WidgetDragMonitor: public QObject, public Counter
     protected Q_SLOTS:
 
     //* start drag
-    bool _startDrag( void );
+    bool _startDrag();
 
     //* reset drag
-    void _resetDrag( void );
+    void _resetDrag();
 
     private:
 
