@@ -25,18 +25,23 @@
 #include <QWidget>
 #include <QPixmap>
 
+#include <memory>
+
 class WinUtilPrivate;
 
-class WinUtil
+class WinUtil final
 {
 
     public:
 
     //* constructor
-    WinUtil( QWidget* );
+    explicit WinUtil( QWidget* );
 
-    //* destructor
-    virtual ~WinUtil( void );
+    //* destructor (needed due to std::unique_ptr)
+    ~WinUtil();
+
+    //* set layered widget transparent
+    void makeTransparent( double = 1.0 ) const;
 
     //* update layered widget using pixmap
     void update( const QPixmap&, double = 1.0 ) const;
@@ -53,21 +58,13 @@ class WinUtil
     //* has flag
     bool hasFlag( long int ) const;
 
-    protected:
-
-    // returns true if widget is of type layered window
-    bool _isLayered() const;
-
-    //* set widget a layered window
-    void _setLayered() const;
-
     private:
 
     //* private
-    WinUtilPrivate* private_;
+    std::unique_ptr<WinUtilPrivate> private_;
 
     //* target widget
-    QWidget *target_;
+    QWidget *target_ = nullptr;
 
 };
 
