@@ -27,6 +27,12 @@ class XcbDefines
 
     public:
 
+    //* destructor
+    virtual ~XcbDefines() = default;
+
+    //* used to access properties
+    static const uint32_t MAX_PROP_SIZE = 100000;
+
     //* used for stickyness
     static const uint32_t ALL_DESKTOPS = ~0;
 
