@@ -18,26 +18,24 @@
 *******************************************************************************/
 
 #include "XcbUtil.h"
-
-#include "Debug.h"
+#include "CppUtil.h"
 
 #include <QList>
 
+#if HAVE_XCB
+
 #if QT_VERSION >= 0x050000
 #include <QWindow>
 #include <QGuiApplication>
 #include <qpa/qplatformnativeinterface.h>
-#else
-#include <QX11Info>
 #endif
 
-#if HAVE_XCB
+#include <QX11Info>
+
 #include <X11/Xlib-xcb.h>
 #include <xcb/xcb.h>
-#endif
 
-//________________________________________________________________________
-static int debugLevel = 1;
+#endif
 
 //________________________________________________________________________
 class XcbUtil::Private
@@ -46,21 +44,21 @@ class XcbUtil::Private
     public:
 
     //* constructor
-    Private( void );
+    Private();
 
     #if HAVE_XCB
 
     //* xcb connection
-    xcb_connection_t* connection( void );
+    xcb_connection_t* connection();
 
     //* get screen matching a given number
-    xcb_screen_t* defaultScreen( void );
+    xcb_screen_t* defaultScreen();
 
     //* get screen matching a given number
     xcb_screen_t* screen( int );
 
     //* root window
-    xcb_window_t appRootWindow( void );
+    xcb_window_t appRootWindow();
 
     //* find atom
     xcb_atom_t* atom( const QString& );
@@ -79,20 +77,20 @@ class XcbUtil::Private
     SupportedAtomHash supportedAtomId_;
 
     //* default screen number
-    int defaultScreenNumber_;
+    int defaultScreenNumber_ = 0;
 
     private:
 
     #if HAVE_XCB
 
     //* xcb connection
-    xcb_connection_t* connection_;
+    xcb_connection_t* connection_ = nullptr;
 
     //* default screen
-    xcb_screen_t* defaultScreen_;
+    xcb_screen_t* defaultScreen_ = nullptr;
 
     //* root window
-    xcb_window_t appRootWindow_;
+    xcb_window_t appRootWindow_ = 0;
 
     //* atom names map
     typedef QHash<QString, xcb_atom_t> NamedAtomHash;
@@ -106,49 +104,45 @@ class XcbUtil::Private
 };
 
 //________________________________________________________________________
-XcbUtil::Private::Private( void )
+XcbUtil::Private::Private()
 {
 
-    #if HAVE_XCB
-    connection_ = 0;
-    defaultScreenNumber_ = 0;
-    defaultScreen_ = 0;
-    appRootWindow_ = 0;
-    #endif
-    atomNames_[WM_STATE] = "WM_STATE";
-
-    atomNames_[_NET_SUPPORTED] = "_NET_SUPPORTED";
-    atomNames_[_NET_CURRENT_DESKTOP] = "_NET_CURRENT_DESKTOP";
-    atomNames_[_NET_WM_DESKTOP] = "_NET_WM_DESKTOP";
-    atomNames_[_NET_WM_STATE] = "_NET_WM_STATE";
-    atomNames_[_NET_WM_STATE_STICKY] = "_NET_WM_STATE_STICKY";
-    atomNames_[_NET_WM_STATE_STAYS_ON_TOP] = "_NET_WM_STATE_STAYS_ON_TOP";
-    atomNames_[_NET_WM_STATE_ABOVE] = "_NET_WM_STATE_ABOVE";
-    atomNames_[_NET_WM_STATE_SKIP_TASKBAR] = "_NET_WM_STATE_SKIP_TASKBAR";
-    atomNames_[_NET_WM_STATE_SKIP_PAGER] = "_NET_WM_STATE_SKIP_PAGER";
-    atomNames_[_NET_WM_MOVERESIZE] = "_NET_WM_MOVERESIZE";
-    atomNames_[_NET_WM_CM] = "_NET_WM_CM";
-    atomNames_[_NET_WM_PID] = "_NET_WM_PID";
-    atomNames_[_NET_WM_ICON] = "_NET_WM_ICON";
-    atomNames_[_NET_WM_NAME] = "_NET_WM_NAME";
-    atomNames_[_KDE_NET_WM_BLUR_BEHIND_REGION] = "_KDE_NET_WM_BLUR_BEHIND_REGION";
+    atomNames_ = Base::makeT<AtomNameMap>(
+    {
+        { AtomId::WM_STATE, "WM_STATE" },
+        { AtomId::_NET_SUPPORTED, "_NET_SUPPORTED" },
+        { AtomId::_NET_CURRENT_DESKTOP, "_NET_CURRENT_DESKTOP" },
+        { AtomId::_NET_WM_DESKTOP, "_NET_WM_DESKTOP" },
+        { AtomId::_NET_WM_STATE, "_NET_WM_STATE" },
+        { AtomId::_NET_WM_STATE_STICKY, "_NET_WM_STATE_STICKY" },
+        { AtomId::_NET_WM_STATE_STAYS_ON_TOP, "_NET_WM_STATE_STAYS_ON_TOP" },
+        { AtomId::_NET_WM_STATE_ABOVE, "_NET_WM_STATE_ABOVE" },
+        { AtomId::_NET_WM_STATE_SKIP_TASKBAR, "_NET_WM_STATE_SKIP_TASKBAR" },
+        { AtomId::_NET_WM_STATE_SKIP_PAGER, "_NET_WM_STATE_SKIP_PAGER" },
+        { AtomId::_NET_WM_MOVERESIZE, "_NET_WM_MOVERESIZE" },
+        { AtomId::_NET_WM_CM, "_NET_WM_CM" },
+        { AtomId::_NET_WM_PID, "_NET_WM_PID" },
+        { AtomId::_NET_WM_ICON, "_NET_WM_ICON" },
+        { AtomId::_NET_WM_NAME, "_NET_WM_NAME" },
+        { AtomId::_KDE_NET_WM_BLUR_BEHIND_REGION, "_KDE_NET_WM_BLUR_BEHIND_REGION" }
+    });
 
 }
 
 
 #if HAVE_XCB
 //_______________________________________________________
-xcb_connection_t* XcbUtil::Private::connection( void )
+xcb_connection_t* XcbUtil::Private::connection()
 {
     if( !connection_ )
     {
 
         // get display
         #if QT_VERSION >= 0x050000
-        QPlatformNativeInterface *native = qApp->platformNativeInterface();
-        Display *display = reinterpret_cast<Display*>(native->nativeResourceForScreen(QByteArray("display"), QGuiApplication::primaryScreen()) );
+        auto nativeInterface = qApp->platformNativeInterface();
+        auto display = reinterpret_cast<Display*>(nativeInterface->nativeResourceForScreen(QByteArray("display"), QGuiApplication::primaryScreen()) );
         #else
-        Display* display = QX11Info::display();
+        auto display = QX11Info::display();
         #endif
 
         // get matching xcb connection
@@ -173,12 +167,12 @@ xcb_screen_t* XcbUtil::Private::screen( int screenNumber )
     for( xcb_screen_iterator_t iter = xcb_setup_roots_iterator( xcb_get_setup( connection() ) ); iter.rem; --screenNumber, xcb_screen_next( &iter ) )
     { if( screenNumber == 0 ) return iter.data; }
 
-    return 0x0;
+    return nullptr;
 
 }
 
 //_______________________________________________________
-xcb_screen_t* XcbUtil::Private::defaultScreen( void )
+xcb_screen_t* XcbUtil::Private::defaultScreen()
 {
     if( !defaultScreen_ )
     {
@@ -190,7 +184,7 @@ xcb_screen_t* XcbUtil::Private::defaultScreen( void )
 }
 
 //_______________________________________________________
-xcb_window_t XcbUtil::Private::appRootWindow( void )
+xcb_window_t XcbUtil::Private::appRootWindow()
 {
     if( !appRootWindow_ && defaultScreen() ) { appRootWindow_ = defaultScreen()->root; }
     return appRootWindow_;
@@ -200,15 +194,13 @@ xcb_window_t XcbUtil::Private::appRootWindow( void )
 xcb_atom_t* XcbUtil::Private::atom( const QString& atomName )
 {
 
-    Debug::Throw( "XcbUtil::Private::atom.\n" );
-
     // find atom in map
     NamedAtomHash::iterator iter( namedAtomId_.find( atomName ) );
     if( iter != namedAtomId_.end() ) return &iter.value();
 
     // create atom if not found
     xcb_intern_atom_cookie_t cookie( xcb_intern_atom( connection(), false, atomName.size(), qPrintable( atomName ) ) );
-    ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection(), cookie, 0x0 ) );
+    ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection(), cookie, nullptr ) );
     xcb_atom_t out = reply ? reply->atom:0;
     return &(namedAtomId_[atomName] = out);
 
@@ -218,15 +210,12 @@ xcb_atom_t* XcbUtil::Private::atom( const QString& atomName )
 xcb_atom_t* XcbUtil::Private::atom( AtomId atom )
 {
 
-    Debug::Throw( "XcbUtil::Private::atom.\n" );
-
     // find atom in map
     AtomHash::iterator iter( atoms_.find( atom ) );
     if( iter != atoms_.end() ) return &iter.value();
 
     // create atom if not found
-    xcb_intern_atom_cookie_t cookie( xcb_intern_atom( connection(), false, atomNames_[atom].size(), qPrintable( atomNames_[atom] ) ) );
-    ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection(), cookie, 0x0 ) );
+    xcb_intern_atom_cookie_t cookie( xcb_intern_atom( connection(), false, atomNames_[atom].size(), qPrintable( atomNames_[atom] ) ) );    ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection(), cookie, nullptr ) );
     xcb_atom_t out = reply ? reply->atom:0;
     return &(atoms_[atom] = out);
 
@@ -236,44 +225,55 @@ xcb_atom_t* XcbUtil::Private::atom( AtomId atom )
 
 
 //________________________________________________________________________
-XcbUtil& XcbUtil::get( void )
+XcbUtil& XcbUtil::get()
 {
     static XcbUtil singleton;
     return singleton;
 }
 
 //________________________________________________________________________
-XcbUtil::XcbUtil( void )
+XcbUtil::XcbUtil():
+    d( new Private )
+    {}
+
+//________________________________________________________________________
+bool XcbUtil::isX11()
 {
-    Debug::Throw( "XcbUtil::XcbUtil.\n" );
-    d = new Private();
+    #if HAVE_XCB
+    #if QT_VERSION >= 0x050000
+    static const bool isX11 = QX11Info::isPlatformX11();
+    return isX11;
+    #else
+    return true;
+    #endif
+    #endif
+
+    return false;
+
 }
 
 //________________________________________________________________________
-XcbUtil::~XcbUtil( void )
-{ delete d; }
-
-//________________________________________________________________________
-int XcbUtil::defaultScreenNumber( void ) const
+int XcbUtil::defaultScreenNumber() const
 {
     #if HAVE_XCB
-    d->connection();
+    if( isX11() ) d->connection();
     #endif
     return d->defaultScreenNumber_;
 }
 
 //_______________________________________________________
-WId XcbUtil::appRootWindow( void ) const
+WId XcbUtil::appRootWindow() const
 {
     #if HAVE_XCB
-    return d->appRootWindow();
-    #else
-    return 0;
+    if( isX11() ) return d->appRootWindow();
     #endif
+
+    return 0;
+
 }
 
 //________________________________________________________________________
-Qt::HANDLE XcbUtil::_connection( void ) const
+Qt::HANDLE XcbUtil::_connection() const
 {
     #if HAVE_XCB
     return Qt::HANDLE( d->connection() );
@@ -307,14 +307,11 @@ bool XcbUtil::isSupported( AtomId atomId ) const
 {
 
     #if HAVE_XCB
-    Debug::Throw( debugLevel ) << "XcbUtil::isSupported - " << d->atomNames_[atomId] << endl;
+    if( !isX11() ) return false;
 
     Private::SupportedAtomHash::const_iterator iter( d->supportedAtomId_.find( atomId ) );
     if( iter != d->supportedAtomId_.end() )
-    {
-        Debug::Throw() << "XcbUtil::isSupported - " << d->atomNames_[atomId] << (iter.value() ? " true ":" false ") << endl;
-        return iter.value();
-    }
+    { return iter.value(); }
 
     bool found( false );
     xcb_atom_t netSupported( *d->atom( _NET_SUPPORTED ) );
@@ -325,15 +322,11 @@ bool XcbUtil::isSupported( AtomId atomId ) const
     {
 
         xcb_get_property_cookie_t cookie( xcb_get_property( d->connection(), 0, d->appRootWindow(), netSupported, XCB_ATOM_ATOM, offset, 1 ) );
-        ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( d->connection(), cookie, 0x0 ) );
-        if( !reply )
-        {
-            Debug::Throw(debugLevel) << "XcbUtil::isSupported - XGetProperty failed" << endl;
-            return false;
-        }
+        ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( d->connection(), cookie, nullptr ) );
+        if( !reply ) return false;
 
         // cast atom
-        const xcb_atom_t current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.data() ))[0] );
+        auto current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.get() ))[0] );
         if( searched == current )
         {
 
@@ -361,17 +354,16 @@ bool XcbUtil::isSupported( AtomId atomId ) const
 //________________________________________________________________________
 bool XcbUtil::isRealWindow( WId window ) const
 {
-    Debug::Throw(debugLevel) << "XcbUtil::isRealWindow - " << windowIdString( window ) << endl;
 
     #if HAVE_XCB
+    if( !isX11() ) return false;
 
     xcb_connection_t* connection( d->connection() );
     xcb_atom_t atom( *d->atom( XcbDefines::WM_STATE ) );
-    const uint32_t maxLength = std::string().max_size();
 
-    xcb_get_property_cookie_t cookie = xcb_get_property( connection, 0, window, atom,  XCB_ATOM_ANY, 0, maxLength );
-    XcbUtil::ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( connection, cookie, 0x0 ) );
-    return ( reply && xcb_get_property_value_length( reply.data() ) > 0 && reply.data()->type != XCB_ATOM_NONE );
+    xcb_get_property_cookie_t cookie = xcb_get_property( connection, 0, window, atom,  XCB_ATOM_ANY, 0, XcbDefines::MAX_PROP_SIZE );
+    XcbUtil::ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( connection, cookie, nullptr ) );
+    return ( reply && xcb_get_property_value_length( reply.get() ) > 0 && reply->type != XCB_ATOM_NONE );
 
     #else
 
@@ -383,7 +375,6 @@ bool XcbUtil::isRealWindow( WId window ) const
 //________________________________________________________________________
 bool XcbUtil::hasState( WId window, AtomId atomId ) const
 {
-    Debug::Throw(debugLevel) << "XcbUtil::hasState - " << d->atomNames_[atomId] << endl;
 
     #if HAVE_XCB
 
@@ -398,15 +389,11 @@ bool XcbUtil::hasState( WId window, AtomId atomId ) const
     {
 
         xcb_get_property_cookie_t cookie( xcb_get_property(  d->connection(), 0, window, netWMState, XCB_ATOM_ATOM, offset, 1 ) );
-        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, 0x0 ) );
-        if( !reply )
-        {
-            Debug::Throw(debugLevel) << "XcbUtil::hasState - XGetProperty failed" << endl;
-            return false;
-        }
+        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, nullptr ) );
+        if( !reply ) return false;
 
         // cast atom
-        const xcb_atom_t current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.data() ))[0] );
+        auto current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.get() ))[0] );
 
         if( searched == current ) return true;
         else if( reply->bytes_after == 0 ) return false;
@@ -423,8 +410,6 @@ bool XcbUtil::hasState( WId window, AtomId atomId ) const
 void XcbUtil::printState( WId window ) const
 {
 
-    Debug::Throw(debugLevel, "XcbUtil::printState.\n" );
-
     #if HAVE_XCB
 
     // make sure atom is supported
@@ -437,21 +422,17 @@ void XcbUtil::printState( WId window ) const
     {
 
         xcb_get_property_cookie_t cookie( xcb_get_property(  d->connection(), 0, window, netWMState, XCB_ATOM_ATOM, offset, 1 ) );
-        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, 0x0 ) );
-        if( !reply )
-        {
-            Debug::Throw(debugLevel) << "XcbUtil::hasState - XGetProperty failed" << endl;
-            return;
-        }
+        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, nullptr ) );
+        if( !reply ) return;
 
         // cast atom
-        const xcb_atom_t current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.data() ))[0] );
+        auto current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.get() ))[0] );
         {
 
             xcb_get_atom_name_cookie_t cookie( xcb_get_atom_name( d->connection(), current ) );
             XcbUtil::ScopedPointer<xcb_get_atom_name_reply_t> reply( xcb_get_atom_name_reply( d->connection(), cookie, 0 ) );
             if( reply )
-            { atomNames.append( QString( QByteArray( xcb_get_atom_name_name( reply.data() ), xcb_get_atom_name_name_length( reply.data() ) ) ) ); }
+            { atomNames.append( QString( QByteArray( xcb_get_atom_name_name( reply.get() ), xcb_get_atom_name_name_length( reply.get() ) ) ) ); }
 
         }
 
@@ -460,8 +441,6 @@ void XcbUtil::printState( WId window ) const
 
     }
 
-    Debug::Throw(0) << "XcbUtil::printWindowState: " << atomNames.join( " " ) << endl;
-
     #endif
     return;
 
@@ -470,7 +449,6 @@ void XcbUtil::printState( WId window ) const
 //________________________________________________________________________
 uint32_t XcbUtil::cardinal( WId window, AtomId atom ) const
 {
-    Debug::Throw( "XcbUtil::cardinal" );
 
     #if HAVE_XCB
 
@@ -479,10 +457,10 @@ uint32_t XcbUtil::cardinal( WId window, AtomId atom ) const
 
     xcb_atom_t searched( *d->atom(atom) );
     xcb_get_property_cookie_t cookie( xcb_get_property( d->connection(), 0, window, searched, XCB_ATOM_CARDINAL, 0, 1 ) );
-    ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( d->connection(), cookie, 0x0 ) );
-    if( !( reply && xcb_get_property_value_length( reply.data() ) > 0 ) ) return 0;
+    ScopedPointer<xcb_get_property_reply_t> reply( xcb_get_property_reply( d->connection(), cookie, nullptr ) );
+    if( !( reply && xcb_get_property_value_length( reply.get() ) > 0 ) ) return 0;
 
-    return reinterpret_cast<uint32_t*>(xcb_get_property_value( reply.data() ) )[0];
+    return reinterpret_cast<uint32_t*>(xcb_get_property_value( reply.get() ) )[0];
 
     #else
     return 0;
@@ -490,21 +468,101 @@ uint32_t XcbUtil::cardinal( WId window, AtomId atom ) const
 
 }
 
+//________________________________________________________________________
+QIcon XcbUtil::icon( WId window ) const
+{
+    if( !isX11() ) return QIcon();
+
+    #if HAVE_XCB
+
+    QIcon result;
+
+    // connection and atom
+    auto connection( d->connection() );
+    auto atom( *d->atom( _NET_WM_ICON ) );
+
+    uint32_t offset(0);
+    ScopedPointer<xcb_get_property_reply_t> reply;
+    forever
+    {
+
+        // width
+        uint32_t width(0);
+        auto cookie( xcb_get_property( connection, 0, window, atom, XCB_ATOM_CARDINAL, offset, 1 ) );
+        reply.reset( xcb_get_property_reply( connection, cookie, nullptr ) );
+        if( reply && xcb_get_property_value_length( reply.get() ) > 0 )
+        {
+            width = reinterpret_cast<uint32_t*>( xcb_get_property_value(reply.get() ) )[0];
+            ++offset;
+
+        } else break;
+
+        // height
+        uint32_t height(0);
+        cookie = xcb_get_property( connection, 0, window, atom, XCB_ATOM_CARDINAL, offset, 1 );
+        reply.reset( xcb_get_property_reply( connection, cookie, nullptr ) );
+        if( reply && xcb_get_property_value_length( reply.get() ) > 0 )
+        {
+            height = reinterpret_cast<uint32_t*>( xcb_get_property_value( reply.get() ) )[0];
+            ++offset;
+
+        } else break;
+
+        // data
+        const uint32_t length( width*height );
+        cookie = xcb_get_property( connection, 0, window, atom, XCB_ATOM_CARDINAL, offset, length );
+        reply.reset( xcb_get_property_reply( connection, cookie, nullptr ) );
+        if( reply && xcb_get_property_value_length( reply.get() ) > 0 )
+        {
+
+            // get image data
+            const uint32_t* imageData( reinterpret_cast<uint32_t*>( xcb_get_property_value( reply.get() ) ) );
+
+            // create image
+            QImage image( width, height, QImage::Format_ARGB32);
+            for(int i=0; i<image.byteCount()/4; ++i)
+            { ((uint32_t*)image.bits())[i] = imageData[i]; }
+
+            // add to icon
+            result.addPixmap( QPixmap::fromImage( image ) );
+
+            // free reply and increment offset
+            offset += length;
+
+        } else break;
+    }
+
+    return result;
+
+    #endif
+
+}
+
 //________________________________________________________________________
 bool XcbUtil::changeState( QWidget* widget, AtomId atom, bool value ) const
 {
+    if( isX11() )
+    {
+
+        return widget->isHidden()  ?
+            _changeState( widget, atom, value ):
+            _requestStateChange( widget, atom, value );
+
+    } else return false;
 
-    return widget->isHidden()  ?
-        _changeState( widget, atom, value ):
-        _requestStateChange( widget, atom, value );
 }
 
 //________________________________________________________________________
 bool XcbUtil::changeCardinal( QWidget* widget, AtomId atom, uint32_t value ) const
 {
-    return widget->isHidden() ?
-        _changeCardinal( widget, atom, value ):
-        _requestCardinalChange( widget, atom, value );
+    if( isX11() )
+    {
+
+        return widget->isHidden() ?
+            _changeCardinal( widget, atom, value ):
+            _requestCardinalChange( widget, atom, value );
+
+    } else return false;
 }
 
 //________________________________________________________________________
@@ -515,9 +573,8 @@ bool XcbUtil::moveResizeWidget(
     Qt::MouseButton button )
 {
 
-    Debug::Throw() << "XcbUtil::moveResizeWidget - (" << position.x() << "," << position.y() << ")" << endl;
-
     if( !widget->isWindow() ) return false;
+    if( !isX11() ) return false;
 
     #if HAVE_XCB
 
@@ -540,24 +597,6 @@ bool XcbUtil::moveResizeWidget(
 
     #endif
 
-    // button release event
-    xcb_button_release_event_t releaseEvent;
-    memset(&releaseEvent, 0, sizeof(releaseEvent));
-
-    releaseEvent.response_type = XCB_BUTTON_RELEASE;
-    releaseEvent.event =  widget->winId();
-    releaseEvent.child = XCB_WINDOW_NONE;
-    releaseEvent.root = appRootWindow();
-    releaseEvent.event_x = localPosition.x();
-    releaseEvent.event_y = localPosition.y();
-    releaseEvent.root_x = position.x();
-    releaseEvent.root_y = position.y();
-    releaseEvent.detail = XCB_BUTTON_INDEX_1;
-    releaseEvent.state = XCB_BUTTON_MASK_1;
-    releaseEvent.time = XCB_CURRENT_TIME;
-    releaseEvent.same_screen = true;
-    xcb_send_event( d->connection(), false, widget->winId(), XCB_EVENT_MASK_BUTTON_RELEASE, reinterpret_cast<const char*>(&releaseEvent));
-
     xcb_ungrab_pointer( d->connection(), XCB_TIME_CURRENT_TIME );
 
     // move resize event
@@ -584,8 +623,6 @@ bool XcbUtil::moveResizeWidget(
 
     return true;
 
-    #else
-    return false;
     #endif
 }
 
@@ -593,13 +630,6 @@ bool XcbUtil::moveResizeWidget(
 bool XcbUtil::_changeState( QWidget* widget, AtomId atom, bool state ) const
 {
 
-    Debug::Throw()
-        << "XcbUtil::_changeState -"
-        << " winId: " << widget->winId()
-        << " atom: " << d->atomNames_[atom]
-        << " state: " << state
-        << endl;
-
     #if HAVE_XCB
 
     // make sure atoms are supported
@@ -614,15 +644,11 @@ bool XcbUtil::_changeState( QWidget* widget, AtomId atom, bool state ) const
     {
 
         xcb_get_property_cookie_t cookie( xcb_get_property(  d->connection(), 0, widget->winId(), netWMState, XCB_ATOM_ATOM, offset, 1 ) );
-        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, 0x0 ) );
-        if( !reply )
-        {
-            Debug::Throw(debugLevel) << "XcbUtil::hasState - XGetProperty failed" << endl;
-            return false;
-        }
+        ScopedPointer<xcb_get_property_reply_t>reply( xcb_get_property_reply( d->connection(), cookie, nullptr ) );
+        if( !reply ) return false;
 
         // cast atom and append
-        xcb_atom_t current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.data() ))[0] );
+        auto current( reinterpret_cast<xcb_atom_t*>(xcb_get_property_value( reply.get() ))[0] );
         atoms.append( current );
 
         if( reply->bytes_after == 0 ) break;
@@ -646,10 +672,11 @@ bool XcbUtil::_changeState( QWidget* widget, AtomId atom, bool state ) const
     }
 
     // change property
-    xcb_change_property( d->connection(), XCB_PROP_MODE_REPLACE, widget->winId(), netWMState, XCB_ATOM_ATOM, 32, atoms.size(), reinterpret_cast<const void*>( atoms.constData() ) );
+    auto cookie = xcb_change_property_checked( d->connection(), XCB_PROP_MODE_REPLACE, widget->winId(), netWMState, XCB_ATOM_ATOM, 32, atoms.size(), reinterpret_cast<const void*>( atoms.constData() ) );
+    ScopedPointer<xcb_generic_error_t> error( xcb_request_check( d->connection(), cookie ) );
     xcb_flush( d->connection() );
 
-    return true;
+    return !error;
     #endif
 
     return false;
@@ -659,12 +686,6 @@ bool XcbUtil::_changeState( QWidget* widget, AtomId atom, bool state ) const
 bool XcbUtil::_requestStateChange( QWidget* widget, AtomId atom, bool value ) const
 {
 
-    Debug::Throw(debugLevel) << "XcbUtil::_requestStateChange - "
-        << " winId: " << widget->winId()
-        << " atom: " << d->atomNames_[atom]
-        << " state: " << value
-        << endl;
-
     #if HAVE_XCB
 
     // make sure atoms are supported
@@ -703,18 +724,16 @@ bool XcbUtil::_requestStateChange( QWidget* widget, AtomId atom, bool value ) co
 bool XcbUtil::_changeCardinal( QWidget* widget, AtomId atom, uint32_t value ) const
 {
 
-    Debug::Throw( "XcbUtil::_changeCardinal.\n" );
-
     #if HAVE_XCB
 
     // make sure atom is supported
     if( !isSupported( atom ) ) return false;
 
     xcb_atom_t searched( *d->atom( atom ) );
-    xcb_change_property( d->connection(), XCB_PROP_MODE_REPLACE, widget->winId(), searched, XCB_ATOM_CARDINAL, 32, 1, &value );
+    auto cookie = xcb_change_property_checked( d->connection(), XCB_PROP_MODE_REPLACE, widget->winId(), searched, XCB_ATOM_CARDINAL, 32, 1, &value );
+    ScopedPointer<xcb_generic_error_t> error( xcb_request_check( d->connection(), cookie ) );
     xcb_flush( d->connection() );
-
-    return true;
+    return !error;
     #endif
 
     return false;
@@ -724,8 +743,6 @@ bool XcbUtil::_changeCardinal( QWidget* widget, AtomId atom, uint32_t value ) co
 bool XcbUtil::_requestCardinalChange( QWidget* widget, AtomId atom, uint32_t value ) const
 {
 
-    Debug::Throw( "XcbUtil::_requestChangeCardinal.\n" );
-
     #if HAVE_XCB
 
     // make sure atom is supported
