@@ -21,45 +21,42 @@
 *******************************************************************************/
 
 #include "XcbDefines.h"
+#include "NonCopyable.h"
 
 #include <QHash>
-#include <QScopedPointer>
+#include <QIcon>
 #include <QWidget>
 
-class XcbUtil: private XcbDefines
+#include <memory>
+
+class XcbUtil: private XcbDefines, private Base::NonCopyable<XcbUtil>
 {
 
     public:
 
-    //* convenience class to handle xcb replies
-    template <typename T> class ScopedPointer: public QScopedPointer<T, QScopedPointerPodDeleter>
-    {
-        public:
-
-        //* constructor
-        ScopedPointer( T* t ):
-            QScopedPointer<T, QScopedPointerPodDeleter>( t )
-            {}
-    };
+    //* delete object allocated with malloc
+    struct pod_delete{ void operator()(void* x) { free(x); } };
 
+    //* specialized unique pointer
+    template <typename T> using ScopedPointer = std::unique_ptr<T,pod_delete>;
 
     //* singleton
-    static XcbUtil& get( void );
-
-    //* destructor
-    virtual ~XcbUtil( void );
+    static XcbUtil& get();
 
     //*@name accessors
     //@{
 
+    //* true if platform is X11
+    static bool isX11( void );
+
     //* connection
-    template <typename T> T* connection( void ) const;
+    template <typename T> T* connection() const;
 
     //* default screen number
-    int defaultScreenNumber( void ) const;
+    int defaultScreenNumber() const;
 
     //* application root window
-    WId appRootWindow( void ) const;
+    WId appRootWindow() const;
 
     //* atom
     template <typename T> T* atom( const QString& ) const;
@@ -99,6 +96,9 @@ class XcbUtil: private XcbDefines
     //* get atom carninal value
     uint32_t cardinal( WId, AtomId ) const;
 
+    //* icon from window id
+    QIcon icon( WId ) const;
+
     //@}
 
     //*@name modifiers
@@ -124,7 +124,7 @@ class XcbUtil: private XcbDefines
     protected:
 
     //* connection
-    Qt::HANDLE _connection( void ) const;
+    Qt::HANDLE _connection() const;
 
     //* atom
     Qt::HANDLE _atom( const QString& ) const;
@@ -147,24 +147,24 @@ class XcbUtil: private XcbDefines
     bool _requestCardinalChange( QWidget*, AtomId, uint32_t ) const;
 
     //* constructor
-    XcbUtil( void );
+    explicit XcbUtil();
 
     //* private pointer
     class Private;
-    Private* d;
+    std::unique_ptr<Private> d;
 
 };
 
 //________________________________________________________________________
-template <typename T> T* XcbUtil::connection( void ) const
-{ return reinterpret_cast<T*>( _connection() ); }
+template <typename T> T* XcbUtil::connection() const
+{ return isX11() ? reinterpret_cast<T*>( _connection() ):nullptr; }
 
 //________________________________________________________________________
 template <typename T> T* XcbUtil::atom( const QString& value ) const
-{ return reinterpret_cast<T*>( _atom( value ) ); }
+{ return isX11() ? reinterpret_cast<T*>( _atom( value ) ):nullptr; }
 
 //________________________________________________________________________
 template <typename T> T* XcbUtil::atom( XcbUtil::AtomId value ) const
-{ return reinterpret_cast<T*>( _atom( value ) ); }
+{ return isX11() ? reinterpret_cast<T*>( _atom( value ) ):nullptr; }
 
 #endif
