@@ -29,13 +29,13 @@
 #include <QTextStream>
 
 //* Xml parsing error container
-class XmlError: public Counter
+class XmlError final: private Base::Counter<XmlError>
 {
 
     public:
 
     //* constructor
-    XmlError( const File& file = File() ):
+    explicit XmlError( const File& file = File() ):
         Counter( "XmlError" ),
         file_ ( file )
     {}
@@ -44,27 +44,27 @@ class XmlError: public Counter
     //@{
 
     //* cast to boolean
-    operator bool(void) const
-    { return error_.length() != 0; }
+    operator bool() const
+    { return !error_.isEmpty(); }
 
     //* File
-    const QString& file( void ) const
+    const File& file() const
     { return file_; }
 
     //* error
-    const QString& error( void ) const
+    const QString& error() const
     { return error_; }
 
     //* line
-    const int& line( void ) const
+    int line() const
     { return line_; }
 
     //* column
-    const int& column( void ) const
+    int column() const
     { return column_; }
 
     //* error
-    QString toString( void ) const
+    QString toString() const
     {
 
         QString out;
@@ -80,7 +80,7 @@ class XmlError: public Counter
     //@{
 
     //* clear
-    void clear( void )
+    void clear()
     {
         file_.clear();
         error_.clear();
@@ -93,44 +93,31 @@ class XmlError: public Counter
     { file_ = file; }
 
         //* error
-    QString& error( void )
+    QString& error()
     { return error_; }
 
     //* line
-    int& line( void )
+    int& line()
     { return line_; }
 
     //* column
-    int& column( void )
+    int& column()
     { return column_; }
 
     //@}
 
+    //* list
+    using List = QList<XmlError>;
 
-    class List: public QList<XmlError>
+    //* write error list to string
+    static QString toString( const List& list )
     {
+        QStringList out;
+        for( const auto& error:list )
+        { out.append( error.toString() ); }
 
-        public:
-
-        //* constructor
-        List( void )
-        {}
-
-        //* constructor
-        List( const QList<XmlError>& other ):
-            QList<XmlError>( other )
-        {}
-
-        //* convert to string
-        QString toString( void ) const
-        {
-            QStringList out;
-            foreach( const XmlError& error, *this )
-            { out << error.toString(); }
-            return out.join( "\n" );
-        }
-
-    };
+        return out.join( "\n" );
+    }
 
     private:
 
@@ -156,7 +143,7 @@ class XmlError: public Counter
     //* dumper
     friend QTextStream& operator << ( QTextStream &out, const List& errors )
     {
-        out << errors.toString() << endl;
+        out << XmlError::toString( errors ) << endl;
         return out;
     }
 
