@@ -38,38 +38,37 @@ class XmlFileList: public FileList
     public:
 
     //* constuctor
-    XmlFileList( QObject* parent = nullptr );
+    explicit XmlFileList( QObject* parent = nullptr );
+
+    //*@name modifiers
+    //@{
 
     // set tag name
     void setTagName( const QString& );
 
+    //* set db file
+    bool setDBFile( const File& );
+
+    //@}
+
+    public Q_SLOTS:
+
     //* Read fileList from file
-    virtual bool read( File = File() );
+    bool read( File = File() );
 
     //* write fileList to file
-    virtual bool write( File = File() );
+    bool write( File = File() );
 
     protected:
 
-    //* set db file
-    virtual bool _setDBFile( const File& );
-
     //* read
-    virtual bool _read( const XmlDocument& );
+    bool _read( const XmlDocument& );
 
-    private Q_SLOTS:
-
-    //* update configuration
-    void _updateConfiguration( void );
-
-    //* save configuration
-    void _saveConfiguration( void );
+    private:
 
     //* compare two record lists
     bool _differs( const FileRecord::List&, const FileRecord::List& ) const;
 
-    private:
-
     //* tag name
     QString tagName_;
 
