@@ -32,6 +32,7 @@ namespace Base
     {
         static const QString FileList = "FileList";
         static const QString SessionFileList = "SessionFileList";
+        static const QString LastSessionFileList = "LastSessionFileList";
         static const QString PathHistory = "PathHistory";
         static const QString Record = "record";
     }
@@ -44,30 +45,26 @@ class XmlFileRecord: public FileRecord
     public:
 
     //* constructor
-    XmlFileRecord( const FileRecord& file ):
+    explicit XmlFileRecord( const FileRecord& file ):
         FileRecord( file )
     {}
 
     //* constructor
-    XmlFileRecord( const QDomElement& );
+    explicit XmlFileRecord( const QDomElement& );
 
     //* write to dom
     QDomElement domElement( QDomDocument& ) const;
 
-    class List: public QList<XmlFileRecord>
+    using List = QList<XmlFileRecord>;
+    class Helper
     {
         public:
 
         //* constructor
-        List( void ):
-            QList<XmlFileRecord>()
-        {}
-
-        //* constructor
-        List( const QDomElement& );
+        static List list( const QDomElement& );
 
         //* write to dom
-        QDomElement domElement( QDomDocument& ) const;
+        static QDomElement domElement( const List&, QDomDocument& );
 
     };
 
