@@ -19,6 +19,7 @@
 
 #include "XmlPathHistory.h"
 
+#include "CppUtil.h"
 #include "Debug.h"
 #include "Singleton.h"
 #include "XmlDocument.h"
@@ -34,7 +35,7 @@ XmlPathHistory::XmlPathHistory( QObject* parent ):
 {
 
     Debug::Throw( "XmlPathHistory::XmlPathHistory.\n" );
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     connect( qApp, SIGNAL(aboutToQuit()), SLOT(_saveConfiguration()) );
     _updateConfiguration();
 
@@ -155,11 +156,11 @@ bool XmlPathHistory::write( File file )
 
     // create main element and insert
     QDomElement top = document.createElement( tagName_ );
-    foreach( const FileRecord& path, pathList )
+    for( const auto& path:pathList )
     {
 
         if( !path.file().isEmpty() )
-        { top.appendChild( XmlFileRecord( path ).domElement( document ) ); }
+        { top.appendChild( XmlFileRecord( path ).domElement( document.get() ) ); }
 
     }
 
@@ -196,7 +197,7 @@ bool XmlPathHistory::_setDBFile( const File& file )
 }
 
 //______________________________________
-void XmlPathHistory::_updateConfiguration( void )
+void XmlPathHistory::_updateConfiguration()
 {
     Debug::Throw( "XmlPathHistory::_updateConfiguration.\n" );
 
@@ -216,7 +217,7 @@ void XmlPathHistory::_updateConfiguration( void )
 }
 
 //______________________________________
-void XmlPathHistory::_saveConfiguration( void )
+void XmlPathHistory::_saveConfiguration()
 {
     Debug::Throw( "XmlPathHistory::_saveConfiguration.\n" );
     write();
