@@ -38,32 +38,32 @@ class XmlPathHistory: public PathHistory
     public:
 
     //* constuctor
-    XmlPathHistory( QObject* parent = nullptr );
+    explicit XmlPathHistory( QObject* parent = nullptr );
 
     // set tag name
     void setTagName( const QString& );
 
     //* Read fileList from file
-    virtual bool read( File = File() );
+    bool read( File = File() );
 
     //* write fileList to file
-    virtual bool write( File = File() );
+    bool write( File = File() );
 
     protected:
 
     //* set db file
-    virtual bool _setDBFile( const File& );
+    bool _setDBFile( const File& );
 
     //* read
-    virtual bool _read( const XmlDocument& );
+    bool _read( const XmlDocument& );
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     //* save configuration
-    void _saveConfiguration( void );
+    void _saveConfiguration();
 
     //* compare two record lists
     bool _differs( const FileRecord::List&, const FileRecord::List& ) const;
