@@ -29,52 +29,36 @@ namespace Server
 {
 
     //* Stores application name and user to uniquely identify an application.
-    class ApplicationId:public Counter
+    class ApplicationId final:private Base::Counter<ApplicationId>
     {
         public:
 
         //* constructor
-        ApplicationId( const QString& = QString(), QString = QString(), QString = QString() );
-
-        //* equal to operator
-        bool operator == (const ApplicationId& app ) const
-        { return name() == app.name() && user() == app.user(); }
-
-        //* equal to operator
-        bool operator != (const ApplicationId& app ) const
-        { return !( app == *this ); }
-
-        //* lower than to operator
-        bool operator < (const ApplicationId& app ) const
-        {
-            if ( name() != app.name() ) return name() < app.name();
-            else if( user() != app.user() ) return user() < app.user();
-            return false;
-        }
+        explicit ApplicationId( const QString& = QString(), QString = QString(), QString = QString() );
 
         //*@name accessors
         //@{
 
         //* name
-        const QString& name( void ) const
+        const QString& name() const
         { return name_; }
 
         //* short name
-        QString userName( void ) const;
+        QString userName() const;
 
         //* short name
-        QString display( void ) const;
+        QString display() const;
 
         //* user
-        const QString& user( void ) const
+        const QString& user() const
         { return user_; }
 
         //* pid
-        qint64 processId( void ) const
+        qint64 processId() const
         { return pid_; }
 
         //* returns true if user and name makes sense
-        bool isValid( void ) const
+        bool isValid() const
         { return !(name().isEmpty() || user().isEmpty() ); }
 
         //@}
@@ -114,6 +98,18 @@ namespace Server
         //@}
 
     };
+
+    //* equal to operator
+    inline bool operator == (const ApplicationId& first, const ApplicationId& second)
+    { return first.name() == second.name() && first.user() == second.user(); }
+
+    //* lower than to operator
+    inline bool operator < (const ApplicationId& first, const ApplicationId& second)
+    {
+        if ( first.name() != second.name() ) return first.name() < second.name();
+        else if( first.user() != second.user() ) return first.user() < second.user();
+        return false;
+    }
 };
 
 #endif
