@@ -18,7 +18,9 @@
 *******************************************************************************/
 
 #include "ApplicationManager.h"
+
 #include "Client.h"
+#include "CppUtil.h"
 #include "Debug.h"
 #include "Util.h"
 #include "XmlOptions.h"
@@ -61,7 +63,7 @@ namespace Server
     }
 
     //_________________________________________
-    ApplicationManager::~ApplicationManager( void )
+    ApplicationManager::~ApplicationManager()
     {}
 
     //_________________________________________
@@ -281,7 +283,7 @@ namespace Server
                 send the associated Identity to the sender
                 */
 
-                for( ClientMap::iterator it=acceptedClients_.begin(); it!=acceptedClients_.end(); it++ )
+                for( auto&& it=acceptedClients_.begin(); it!=acceptedClients_.end(); it++ )
                 { sender->sendCommand( ServerCommand( it.key(), ServerCommand::Identify ) ); }
 
                 return;
@@ -303,8 +305,8 @@ namespace Server
     {
 
         Debug::Throw() << "ApplicationManager::_Broadcast - id: " << command.id().name() << " command: " << command.commandName() << endl;
-        for( ClientList::iterator iter = connectedClients_.begin(); iter != connectedClients_.end(); ++iter )
-        { if( (*iter) != sender ) (*iter)->sendCommand( command ); }
+        for( auto& client:connectedClients_ )
+        { if( client != sender ) client->sendCommand( command ); }
 
     }
 
@@ -324,7 +326,7 @@ namespace Server
     }
 
     //_____________________________________________________
-    void ApplicationManager::_serverConnectionClosed( void )
+    void ApplicationManager::_serverConnectionClosed()
     {
         Debug::Throw( "ApplicationManager::_serverConnectionClosed - lost connection to server.\n" );
         serverInitialized_ = false;
@@ -332,7 +334,7 @@ namespace Server
     }
 
     //_____________________________________________________
-    void ApplicationManager::_clientConnectionClosed( void )
+    void ApplicationManager::_clientConnectionClosed()
     {
 
         Debug::Throw( "ApplicationManager::_clientConnectionClosed - client has disconnected.\n" );
@@ -480,7 +482,7 @@ namespace Server
     }
 
     //__________________________________________________________________________
-    bool ApplicationManager::_initializeServer( void )
+    bool ApplicationManager::_initializeServer()
     {
 
         Debug::Throw( "ApplicationManager::_initializeServer.\n" );
@@ -494,7 +496,7 @@ namespace Server
 
 
     //__________________________________________________________________________
-    bool ApplicationManager::_initializeClient( void )
+    bool ApplicationManager::_initializeClient()
     {
 
         Debug::Throw( "ApplicationManager::_initializeClient.\n" );
@@ -522,7 +524,7 @@ namespace Server
     }
 
     //__________________________________________________________________________
-    void ApplicationManager::_startTimer( void )
+    void ApplicationManager::_startTimer()
     {
         // time out delay (for existing server to reply)
         // one should really start the timer only when the client is connected
