@@ -39,7 +39,7 @@ namespace Server
 {
 
     //* ensures only one instance of an application is running
-    class ApplicationManager: public QObject, public Counter
+    class ApplicationManager: public QObject, private Base::Counter<ApplicationManager>
     {
 
         //* Qt meta object macro
@@ -48,13 +48,13 @@ namespace Server
         public:
 
         //* constructor
-        ApplicationManager( QObject* );
+        explicit ApplicationManager( QObject* );
 
         //* destructor
-        virtual ~ApplicationManager( void );
+        ~ApplicationManager() override;
 
         //* application name
-        virtual void setApplicationName( const QString& name );
+        void setApplicationName( const QString& );
 
         //* commandLine parser
         static CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true );
@@ -70,7 +70,7 @@ namespace Server
         };
 
         //* changes application state, emit signal if changed
-        virtual bool setState( const State& state )
+        bool setState( const State& state )
         {
             if( state == state_ ) return false;
             state_ = state;
@@ -78,17 +78,17 @@ namespace Server
         }
 
         //* reference to "this" client
-        virtual Client& client( void ) const
+        Client& client() const
         { return *client_; }
 
         //* retrieve Application ID
-        virtual const ApplicationId& id( void ) const
+        const ApplicationId& id() const
         { return id_; }
 
         public Q_SLOTS:
 
         //* (re)initialize server/client connections
-        virtual void initialize( CommandLineArguments args = CommandLineArguments() );
+        void initialize( CommandLineArguments args = CommandLineArguments() );
 
         Q_SIGNALS:
 
@@ -96,12 +96,12 @@ namespace Server
         void commandRecieved( Server::ServerCommand );
 
         //* emitted when the server is (re)initialized
-        void initialized( void );
+        void initialized();
 
         protected:
 
         //* timer event
-        virtual void timerEvent( QTimerEvent* );
+        void timerEvent( QTimerEvent* ) override;
 
         //* pair of application id and client
         using ClientPair = QPair< ApplicationId, Client* >;
@@ -118,7 +118,7 @@ namespace Server
             public:
 
             //* constructor
-            SameStateFTor( QAbstractSocket::SocketState state ):
+            explicit SameStateFTor( QAbstractSocket::SocketState state ):
                 Client::SameStateFTor( state )
             {}
 
@@ -138,7 +138,7 @@ namespace Server
             public:
 
             //* constructor
-            SameClientFTor( Client* client ):
+            explicit SameClientFTor( Client* client ):
                 client_( client )
                 {}
 
@@ -159,44 +159,44 @@ namespace Server
         /** \brief register a client, returns true if application is new.
         if forced is set to true, the old cliend, if any, is replaced
         */
-        virtual ClientMap::iterator _register( const ApplicationId& id, Client* client, bool forced = false );
+        ClientMap::iterator _register( const ApplicationId& id, Client* client, bool forced = false );
 
         //* redirect message
-        virtual void _redirect( ServerCommand, Client* );
+        void _redirect( ServerCommand, Client* );
 
         //* broadcast a message to all registered clients but the sender (if valid)
-        virtual void _broadcast( ServerCommand, Client* sender = 0 );
+        void _broadcast( ServerCommand, Client* sender = 0 );
 
         protected Q_SLOTS:
 
         //* a new connection is granted
-        virtual void _newConnection( void );
+        void _newConnection();
 
         //* a connection was closed
-        virtual void _serverConnectionClosed( void );
+        void _serverConnectionClosed();
 
         //* a connection was closed
-        virtual void _clientConnectionClosed( void );
+        void _clientConnectionClosed();
 
         //* client recieves errors
-        virtual void _error( QAbstractSocket::SocketError );
+        void _error( QAbstractSocket::SocketError );
 
         //* redistribute message when a connected client sends one
-        virtual void _redirect( Server::ServerCommand );
+        void _redirect( Server::ServerCommand );
 
         //* reads signal from server
         void _process( Server::ServerCommand );
 
         //* start timeout
-        void _startTimer( void );
+        void _startTimer();
 
         private:
 
         //* initialize client
-        bool _initializeClient( void );
+        bool _initializeClient();
 
         //* initialize server
-        bool _initializeServer( void );
+        bool _initializeServer();
 
         //* host
         QHostAddress host_;
