@@ -19,10 +19,13 @@
 
 #include "BaseApplication.h"
 #include "BaseIconNames.h"
+#include "Command.h"
+#include "CustomProcess.h"
 #include "File.h"
 #include "IconEngine.h"
 #include "IconSize.h"
 #include "QtUtil.h"
+#include "ServerSystemOptions.h"
 #include "Util.h"
 #include "XmlOptions.h"
 
@@ -34,10 +37,6 @@
 
 #include <QSettings>
 
-#ifndef QT_NO_DBUS
-#include <QDBusConnection>
-#endif
-
 //____________________________________________
 namespace Server
 {
@@ -60,13 +59,13 @@ bool Server::AppEventFilter::eventFilter( QObject* object, QEvent* event )
 
         case QEvent::Show:
 
-        if( QMessageBox* messageBox = qobject_cast<QMessageBox*>( object ) )
+        if( auto messageBox = qobject_cast<QMessageBox*>( object ) )
         {
 
             // try cast to message box and change buttons
             messageBox->setStandardButtons( QMessageBox::Close );
 
-        } else if( QDialogButtonBox* buttonBox = qobject_cast<QDialogButtonBox*>( object ) ) {
+        } else if( auto buttonBox = qobject_cast<QDialogButtonBox*>( object ) ) {
 
             // insert separator
             if( QGridLayout* gridLayout = qobject_cast<QGridLayout*>( buttonBox->parentWidget()->layout() ) )
@@ -98,6 +97,9 @@ BaseApplication::BaseApplication( QObject* parent, CommandLineArguments argument
 {
 
     Debug::Throw( "BaseApplication::BaseApplication.\n" );
+
+    installServerSystemOptions();
+
     connect( this, SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     connect( this, SIGNAL(configurationChanged()), SLOT(_updateFonts()) );
     connect( this, SIGNAL(configurationChanged()), SLOT(_updateIconTheme()) );
@@ -105,7 +107,7 @@ BaseApplication::BaseApplication( QObject* parent, CommandLineArguments argument
 }
 
 //____________________________________________
-bool BaseApplication::initApplicationManager( void )
+bool BaseApplication::initApplicationManager()
 {
     Debug::Throw( "BaseApplication::initApplicationManager.\n" );
 
@@ -115,24 +117,16 @@ bool BaseApplication::initApplicationManager( void )
 }
 
 //____________________________________________
-bool BaseApplication::realizeWidget( void )
+bool BaseApplication::realizeWidget()
 {
     Debug::Throw( "BaseApplication::realizeWidget.\n" );
 
     // check if the method has already been called.
     if( !BaseCoreApplication::realizeWidget() ) return false;
 
-    // use DBus connection to update on oxygen configuration change
-    #ifndef QT_NO_DBUS
-    QDBusConnection dbus = QDBusConnection::sessionBus();
-    dbus.connect( QString(), "/OxygenStyle", "org.kde.Oxygen.Style", "reparseConfiguration", this, SLOT(_updateFonts()) );
-    dbus.connect( QString(), "/BreezeStyle", "org.kde.Breeze.Style", "reparseConfiguration", this, SLOT(_updateFonts()) );
-    dbus.connect( QString(), "/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange", this, SLOT(_updateFonts()) );
-    #endif
-
     // parse user argument
     #if QT_VERSION >= 0x050400
-    const CommandLineParser parser( commandLineParser( _arguments() ) );
+    auto parser( commandLineParser( _arguments() ) );
     if( parser.hasFlag( "--highdpi" ) )
     {
 
@@ -155,8 +149,8 @@ bool BaseApplication::realizeWidget( void )
     aboutAction_ = new QAction( applicationIcon(), QString( tr( "About %1" ) ).arg( applicationName() ), this );
     connect( aboutAction_, SIGNAL(triggered()), SLOT(_about()) );
 
-    aboutQtAction_ = new QAction( IconEngine::get( IconNames::AboutQt, Base::IconCacheItem::FromCache|Base::IconCacheItem::FromResource ), tr( "About Qt" ), this );
-    connect( aboutQtAction_, SIGNAL(triggered()), this, SLOT(_aboutQt()) );
+    aboutQtAction_ = new QAction( IconEngine::get( IconNames::AboutQt, Base::IconCacheItem::Flag::FromCache|Base::IconCacheItem::Flag::FromResource ), tr( "About Qt" ), this );
+    connect( aboutQtAction_, SIGNAL(triggered()), SLOT(_aboutQt()) );
 
     closeAction_ = new QAction( IconEngine::get( IconNames::Exit ), tr( "Exit" ), this );
     closeAction_->setShortcut( QKeySequence::Quit );
@@ -196,22 +190,22 @@ CommandLineParser BaseApplication::commandLineParser( CommandLineArguments argum
 }
 
 //____________________________________________
-void BaseApplication::busy( void )
+void BaseApplication::busy()
 {
     qApp->setOverrideCursor( Qt::WaitCursor );
     qApp->processEvents();
 }
 
 //____________________________________________
-void BaseApplication::idle( void )
+void BaseApplication::idle()
 { qApp->restoreOverrideCursor(); }
 
 //_______________________________________________
-void BaseApplication::_aboutToQuit( void )
+void BaseApplication::_aboutToQuit()
 { Debug::Throw( "BaseApplication::_aboutToQuit.\n" ); }
 
 //_______________________________________________
-void BaseApplication::_aboutQt( void )
+void BaseApplication::_aboutQt()
 {
     Debug::Throw( "BaseApplication::aboutQt.\n" );
     Server::AppEventFilter eventFilter;
@@ -220,13 +214,13 @@ void BaseApplication::_aboutQt( void )
 }
 
 //_______________________________________________
-void BaseApplication::_about( void )
+void BaseApplication::_about()
 {
 
     Debug::Throw( "BaseApplication::_about.\n" );
 
     // make sure name is all lower case and starts with upper case.
-    QString name( applicationName() );
+    auto name( applicationName() );
     if( !name.isEmpty() )
     {
         name = name.toLower();
@@ -234,7 +228,7 @@ void BaseApplication::_about( void )
     }
 
     // modify version to remove qt4 for version
-    QString version( applicationVersion() );
+    auto version( applicationVersion() );
     if( version.indexOf( "qt4_" ) >= 0 )
     { version = version.replace( "qt4_", "" ) + " (qt4)"; }
 
@@ -255,10 +249,10 @@ void BaseApplication::_about( void )
 
     QMessageBox dialog;
     dialog.setWindowTitle( QString( tr( "About %1" ).arg( name ) ) );
-    const QIcon icon( applicationIcon() );
+    auto icon( applicationIcon() );
     dialog.setWindowIcon( icon );
 
-    QSize size = IconSize( IconSize::Maximum );
+    const auto& size = IconSize::get( IconSize::Maximum );
     dialog.setIconPixmap( icon.pixmap( size ) );
     dialog.setText( buffer );
     dialog.adjustSize();
@@ -273,20 +267,16 @@ void BaseApplication::_about( void )
 }
 
 //_______________________________________________
-void BaseApplication::_updateConfiguration( void )
+void BaseApplication::_updateConfiguration()
 {
     Debug::Throw( "BaseApplication::_updateConfiguration.\n" );
 
-    // style
-    if( XmlOptions::get().get<bool>( "FORCE_PLASTIQUE_STYLE" ) )
-    { QApplication::setStyle( "plastique" ); }
-
     // application icon
     const QIcon icon( applicationIcon() );
     qApp->setWindowIcon( icon );
 
     // also assign to all existing top level widgets
-    foreach( QWidget* widget, qApp->topLevelWidgets() )
+    for( const auto& widget:qApp->topLevelWidgets() )
     { widget->setWindowIcon( icon ); }
 
     // reload IconEngine cache (in case of icon_path_list that changed)
@@ -295,7 +285,7 @@ void BaseApplication::_updateConfiguration( void )
 }
 
 //_______________________________________________
-void BaseApplication::_updateFonts( void )
+void BaseApplication::_updateFonts()
 {
 
     Debug::Throw( "BaseApplication::_updateFonts.\n" );
@@ -317,43 +307,81 @@ void BaseApplication::_updateFonts( void )
 
     } else {
 
-        QStringList files;
-        files
-            << Util::home() + "/.kde4/share/config/kdeglobals"
-            << Util::home() + "/.kde/share/config/kdeglobals";
+        File::List configurationFiles;
+        if( XmlOptions::get().contains( "KDE_CONFIG" ) )
+        {
 
-        bool found( false );
-        foreach( const QString& file, files )
+            // get kde4 config command and retrieve output
+            const QString kde4ConfigCommand( XmlOptions::get().raw( "KDE_CONFIG" ) );
+
+            CustomProcess process( this );
+            process.start( Command( kde4ConfigCommand ) << "--path" << "config" );
+            if( process.waitForFinished() && process.exitStatus() == QProcess::NormalExit )
+            {
+                auto configurationPath = QString( process.readAllStandardOutput() ).trimmed().split( ':' );
+                for( const auto& path:configurationPath )
+                { configurationFiles.append( File( "kdeglobals" ).addPath( File( path ) ) ); }
+
+            }
+
+        }
+
+        if( configurationFiles.isEmpty() )
+        {
+            // add some files manually in case the above failed
+            configurationFiles.append( File( ".config/kdeglobals" ).addPath( Util::home() ) );
+            configurationFiles.append( File( ".kde/share/config/kdeglobals" ).addPath( Util::home() ) );
+            configurationFiles.append( File( ".kde4/share/config/kdeglobals" ).addPath( Util::home() ) );
+        }
+
+        bool fontFound( false );
+        bool fixedFontFound( !useFixedFonts() );
+        for( const auto& file:configurationFiles )
         {
 
             // check file existence
-            if( !File( file ).exists() ) continue;
-            found = true;
+            if( !file.exists() ) continue;
+
+            Debug::Throw() << "BaseApplication::_updateFonts - file: " << file << endl;
 
             // load settings
             QSettings settings( file, QSettings::IniFormat );
             settings.sync();
 
-            // debug
-            Debug::Throw() << "BaseApplication::_updateFonts - font: " << settings.value( "font" ).toStringList().join( "," ) << endl;
-            Debug::Throw() << "BaseApplication::_updateFonts - fixed: " << settings.value( "fixed" ).toStringList().join( "," ) << endl;
-
             // generic font
-            QFont font;
-            font.fromString( settings.value( "font" ).toStringList().join( "," ) );
-            qApp->setFont( font );
+            if( !fontFound && settings.contains( "font" ) )
+            {
+                auto fontName( settings.value( "font" ).toStringList().join( "," ) );
+                QFont font;
+                font.fromString( fontName );
+                qApp->setFont( font );
+                qApp->setFont( font, "QTextEdit" );
+                qApp->setFont( font, "QPlainTextEdit" );
+                fontFound = true;
+                Debug::Throw() << "BaseApplication::_updateFonts - font: " << fontName << endl;
+            }
 
             // fixed fonts
-            if( useFixedFonts() ) font.fromString( settings.value( "fixed" ).toStringList().join( "," ) );
-            qApp->setFont( font, "QTextEdit" );
-            qApp->setFont( font, "QPlainTextEdit" );
+            if( useFixedFonts() && !fixedFontFound && settings.contains( "fixed" ))
+            {
+                auto fixedFontName( settings.value( "fixed" ).toStringList().join( "," ) );
+                QFont font;
+                font.fromString( fixedFontName );
+                fixedFontFound = true;
+                Debug::Throw() << "BaseApplication::_updateFonts - fixed: " << fixedFontName << endl;
+                qApp->setFont( font, "QTextEdit" );
+                qApp->setFont( font, "QPlainTextEdit" );
+            }
+
+            if( fontFound && fixedFontFound ) break;
 
         }
 
-        if( !found )
+        if( !( fontFound && fixedFontFound ) )
         {
             qApp->setFont( QFont() );
             qApp->setFont( QFont(), "QTextEdit" );
+            qApp->setFont( QFont(), "QPlainTextEdit" );
         }
 
     }
@@ -361,7 +389,7 @@ void BaseApplication::_updateFonts( void )
 }
 
 //_______________________________________________
-void BaseApplication::_updateIconTheme( void )
+void BaseApplication::_updateIconTheme()
 {
 
     Debug::Throw( "BaseApplication::_updateIconTheme.\n" );
