@@ -37,16 +37,16 @@ class BaseApplication: public BaseCoreApplication
     public:
 
     //* constructor
-    BaseApplication( QObject* parent, CommandLineArguments arguments = CommandLineArguments() );
+    explicit BaseApplication( QObject* parent, CommandLineArguments arguments = CommandLineArguments() );
 
     //* initialize application manager
-    virtual bool initApplicationManager( void );
+    bool initApplicationManager() override;
 
     //* create all widgets
-    virtual bool realizeWidget( void );
+    bool realizeWidget() override;
 
     //* true if fixed fonts are used
-    virtual void setUseFixedFonts( bool value )
+    void setUseFixedFonts( bool value )
     {
         if( useFixedFonts_ == value ) return;
         useFixedFonts_ = value;
@@ -54,26 +54,26 @@ class BaseApplication: public BaseCoreApplication
     }
 
     //* true if fixed fonts are used
-    virtual bool useFixedFonts( void ) const
+    bool useFixedFonts() const
     { return useFixedFonts_; }
 
     //*@name actions
     //@{
 
     //* about
-    QAction& aboutAction( void ) const
+    QAction& aboutAction() const
     { return *aboutAction_; }
 
     //* about
-    QAction& aboutQtAction( void ) const
+    QAction& aboutQtAction() const
     { return *aboutQtAction_; }
 
     //* configuration
-    QAction& configurationAction( void ) const
+    QAction& configurationAction() const
     { return *configurationAction_; }
 
     //* exit safely
-    QAction& closeAction( void ) const
+    QAction& closeAction() const
     { return *closeAction_; }
 
     //@}
@@ -82,47 +82,47 @@ class BaseApplication: public BaseCoreApplication
     //@{
 
     //* command line parser
-    virtual CommandLineParser commandLineParser( CommandLineArguments arguments = CommandLineArguments(), bool ignoreWarnings = true ) const;
+    CommandLineParser commandLineParser( CommandLineArguments arguments = CommandLineArguments(), bool ignoreWarnings = true ) const override;
 
     // application icon
-    virtual QIcon applicationIcon( void ) const = 0;
+    virtual QIcon applicationIcon() const = 0;
 
     //@}
 
     public Q_SLOTS:
 
     //* set application busy
-    virtual void busy( void );
+    void busy();
 
     //* set application idle
-    virtual void idle( void );
+    void idle();
 
     protected Q_SLOTS:
 
     //* process request from application manager
-    virtual void _aboutQt( void );
+    void _aboutQt();
 
     //* configuration
-    virtual void _configuration( void ) = 0;
+    virtual void _configuration() = 0;
 
     //* about to quit
-    virtual void _aboutToQuit( void );
+    virtual void _aboutToQuit();
 
     private Q_SLOTS:
 
     //* configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     //* fonts
-    void _updateFonts( void );
+    void _updateFonts();
 
     //* update icon path
-    void _updateIconTheme( void );
+    void _updateIconTheme();
 
     private Q_SLOTS:
 
     //* application 'about' dialog
-    virtual void _about( void );
+    virtual void _about();
 
     private:
 
