@@ -30,7 +30,7 @@ namespace Server
 {
 
     //* interprocess communication client
-    class Client : public BaseSocketInterface, public Counter
+    class Client : public BaseSocketInterface, private Base::Counter<Client>
     {
 
         //* Qt meta object macro
@@ -42,13 +42,10 @@ namespace Server
         using List = QList<Client*>;
 
         //* constructor
-        Client( QObject*, QTcpSocket* = nullptr );
-
-        //* destructor
-        virtual ~Client( void ) = default;
+        explicit Client( QObject*, QTcpSocket* = nullptr );
 
         //* id
-        quint32 id( void ) const
+        quint32 id() const
         { return id_; }
 
         /** returns true if message could be sent */
@@ -61,16 +58,12 @@ namespace Server
             public:
 
             //* constructor
-            SameIdFTor( quint32 id ):
+            explicit SameIdFTor( quint32 id ):
                 id_( id )
             {}
 
-            //* destructor
-            virtual ~SameIdFTor( void )
-            {}
-
             //* predicate
-            virtual bool operator() ( const Client* client ) const
+            bool operator() ( const Client* client ) const
             { return client->id() == id_; }
 
             protected:
@@ -88,12 +81,12 @@ namespace Server
         private Q_SLOTS:
 
         //* process buffer
-        virtual void _parseBuffer( qint32, QByteArray );
+        void _parseBuffer( qint32, QByteArray );
 
         private:
 
         //* client counter
-        static quint32& _counter( void );
+        static quint32& _counter();
 
         //* client id
         quint32 id_ = 0;
