@@ -21,8 +21,10 @@
 *******************************************************************************/
 
 #include "ApplicationId.h"
+
 #include "CommandLineArguments.h"
 #include "Counter.h"
+#include "CppUtil.h"
 #include "Debug.h"
 #include "TimeStamp.h"
 #include "XmlOption.h"
@@ -37,7 +39,7 @@ namespace Server
 
     //_________________________________________
     //* command to be send over the server
-    class ServerCommand:public Counter
+    class ServerCommand final:private Base::Counter<ServerCommand>
     {
 
         public:
@@ -65,64 +67,42 @@ namespace Server
         using List = QList<ServerCommand>;
 
         //* constructor
-        ServerCommand( const ApplicationId& id = ApplicationId(), const CommandType& command = None );
-
-        //* equal-to operator
-        bool operator == ( const ServerCommand& command ) const
-        {
-            return timeStamp() == command.timeStamp() &&
-                id() == command.id() &&
-                ServerCommand::command() == command.command();
-        }
-
-        //* less-than operator
-        bool operator < ( const ServerCommand& command ) const
-        {
-            if( timeStamp() != command.timeStamp() ) return timeStamp() < command.timeStamp();
-            if( id() != command.id() ) return id() < command.id();
-
-            // to order command, place IDENTIFY_SERVER first
-            if( ServerCommand::command() != command.command() ) return ( ServerCommand::command() == IdentifyServer || ServerCommand::command() < command.command() );
-            return false;
-        }
+        explicit ServerCommand( const ApplicationId& id = ApplicationId(), const CommandType& command = None );
 
         //*@name accessors
         //@{
 
         //* true if this command is a child of argument
-        /*! this is needed to have commands appear in Tree view */
+        /** this is needed to have commands appear in Tree view */
         bool isChild( const ServerCommand& command ) const
         { return timeStamp() >= command.timeStamp() && id() == command.id(); }
 
         //* time stamp
-        const TimeStamp& timeStamp( void ) const
+        const TimeStamp& timeStamp() const
         { return timestamp_; }
 
         //* client id
-        quint32 clientId( void ) const
+        quint32 clientId() const
         { return clientId_; }
 
         //* application id
-        const ApplicationId& id( void ) const
+        const ApplicationId& id() const
         { return id_; }
 
         //* command
-        CommandType command( void ) const
+        CommandType command() const
         { return command_; }
 
         //* command name
-        QString commandName( void ) const
-        {
-            _initializeCommandNames();
-            return _commandNames()[ command() ];
-        }
+        QString commandName() const
+        { return _commandNames()[ command() ]; }
 
         //* arguments
-        const CommandLineArguments& arguments( void ) const
+        const CommandLineArguments& arguments() const
         { return arguments_; }
 
         //* option
-        const XmlOption& option( void ) const
+        const XmlOption& option() const
         {
             Q_ASSERT( command() == ServerCommand::Option );
             return option_;
@@ -161,13 +141,10 @@ namespace Server
         private:
 
         //* command names
-        using CommandMap = QHash<CommandType, QString >;
+        using CommandMap = QHash<CommandType, QString>;
 
         //* command names
-        static CommandMap& _commandNames( void );
-
-        //* map command types to names
-        void _initializeCommandNames( void ) const;
+        static CommandMap& _commandNames();
 
         //* time stamp
         TimeStamp timestamp_;
@@ -193,6 +170,26 @@ namespace Server
         friend QDataStream& operator >> (QDataStream&, ServerCommand& );
         //@}
     };
-};
+
+    //* equal-to operator
+    inline bool operator == ( const ServerCommand& first, const ServerCommand& second )
+    {
+        return first.timeStamp() == second.timeStamp() &&
+            first.id() == second.id() &&
+            first.command() == second.command();
+    }
+
+    //* less-than operator
+    inline bool operator < ( const ServerCommand& first, const ServerCommand& second )
+    {
+        if( first.timeStamp() != second.timeStamp() ) return first.timeStamp() < second.timeStamp();
+        if( first.id() != second.id() ) return first.id() < second.id();
+
+        // to order command, place IdentifyServer first
+        if( first.command() != second.command() ) return ( first.command() == ServerCommand::IdentifyServer || first.command() < second.command() );
+        return false;
+    }
+
+}
 
 #endif
