@@ -28,7 +28,7 @@ namespace Server
 {
 
   //! transparency common configuration
-  class ServerConfiguration: public QWidget, public OptionWidgetList, public Counter
+  class ServerConfiguration: public QWidget, public OptionWidgetList, private Base::Counter<ServerConfiguration>
   {
 
     Q_OBJECT
@@ -36,12 +36,12 @@ namespace Server
     public:
 
     //! constructor
-    ServerConfiguration( QWidget*, QString title = QString() );
+    explicit ServerConfiguration( QWidget*, QString title = QString() );
 
     Q_SIGNALS:
 
     //! modified
-    void modified( void );
+    void modified();
 
   };
 };
