@@ -29,7 +29,7 @@ namespace SpellCheck
 {
 
     //! Spell common configuration
-    class AutoSpellConfiguration: public QGroupBox, public OptionWidgetList, public Counter
+    class AutoSpellConfiguration: public QGroupBox, public OptionWidgetList, private Base::Counter<AutoSpellConfiguration>
     {
 
         Q_OBJECT
@@ -37,12 +37,12 @@ namespace SpellCheck
         public:
 
         //! constructor
-        AutoSpellConfiguration( QWidget* parent );
+        explicit AutoSpellConfiguration( QWidget* parent );
 
         Q_SIGNALS:
 
         //! modified
-        void modified( void );
+        void modified();
 
     };
 
