@@ -35,32 +35,32 @@ namespace SpellCheck
         public:
 
         //* constructor
-        DictionarySelectionButton( QWidget* );
+        explicit DictionarySelectionButton( QWidget* );
 
         //* retrieve value
-        QString value( void ) const
+        QString value() const
         { return value_; }
 
         //* read value from option
-        virtual void read( const Options& options )
+        void read( const Options& options ) override
         {
             value_ = options.raw( optionName() );
             _setConnected();
         }
 
         //* write value to option
-        virtual void write( Options& options ) const
+        void write( Options& options ) const override
         { options.set( optionName(), value_ ); }
 
         Q_SIGNALS:
 
         //* emitted when selection is modified
-        void modified( void );
+        void modified();
 
         protected Q_SLOTS:
 
         //* edit dictionaries
-        void _edit( void );
+        void _edit();
 
         private:
 
