@@ -43,7 +43,7 @@ namespace SpellCheck
     {
         Debug::Throw( "SpellCheckConfiguration::SpellCheckConfiguration.\n" );
 
-        GridLayout* gridLayout( new GridLayout() );
+        GridLayout* gridLayout( new GridLayout );
         gridLayout->setSpacing( 5 );
         gridLayout->setMargin( 5 );
         gridLayout->setMaxCount( 3 );
@@ -103,7 +103,7 @@ namespace SpellCheck
     }
 
     //___________________________________________
-    void SpellCheckConfiguration::_updateDictionaries( void )
+    void SpellCheckConfiguration::_updateDictionaries()
     {
         Debug::Throw( "SpellCheckConfiguration::_updateDictionaries.\n" );
 
@@ -117,7 +117,7 @@ namespace SpellCheck
 
         // get dictionary list and populate combobox
         SpellCheck::SpellInterface interface;
-        foreach( const QString& dictionary, interface.dictionaries() )
+        for( const auto& dictionary:interface.dictionaries() )
         { if( !disabledDictionaries.contains( dictionary ) ) dictionariesComboBox_->addItem( dictionary ); }
 
         // read default value from options
@@ -126,7 +126,7 @@ namespace SpellCheck
     }
 
     //___________________________________________
-    void SpellCheckConfiguration::_updateFilters( void )
+    void SpellCheckConfiguration::_updateFilters()
     {
         Debug::Throw( "SpellCheckConfiguration::_updateFilters.\n" );
 
@@ -140,7 +140,7 @@ namespace SpellCheck
 
         // get dictionary list and populate combobox
         SpellCheck::SpellInterface interface;
-        foreach( const QString& filter, interface.filters() )
+        for( const auto& filter:interface.filters() )
         { if( !disabledFilters.contains( filter ) ) filtersComboBox_->addItem( filter ); }
 
         // read default value from options
