@@ -52,19 +52,19 @@ namespace SpellCheck
         setOptionName( "SPELL_DIALOG" );
 
         // horizontal layout for suggestions and buttons
-        QHBoxLayout* hLayout = new QHBoxLayout();
+        QHBoxLayout* hLayout = new QHBoxLayout;
         hLayout->setMargin(0);
         hLayout->setSpacing(10);
         mainLayout().addLayout( hLayout, 1 );
 
         // insert left vertical box
-        QVBoxLayout *vLayout = new QVBoxLayout();
+        QVBoxLayout *vLayout = new QVBoxLayout;
         vLayout->setMargin( 0 );
         vLayout->setSpacing(5);
         hLayout->addLayout( vLayout );
 
         // grid for text editors
-        GridLayout *gridLayout = new GridLayout();
+        GridLayout *gridLayout = new GridLayout;
         gridLayout->setMargin( 0 );
         gridLayout->setSpacing(5);
         gridLayout->setMaxCount( 2 );
@@ -89,7 +89,7 @@ namespace SpellCheck
         list_->header()->hide();
 
         // grid layout for dictionary and filter
-        gridLayout = new GridLayout();
+        gridLayout = new GridLayout;
         gridLayout->setMargin( 0 );
         gridLayout->setSpacing(5);
         gridLayout->setMaxCount( 3 );
@@ -129,7 +129,7 @@ namespace SpellCheck
         gridLayout->setColumnStretch( 1, 1 );
 
         // right vbox
-        vLayout = new QVBoxLayout();
+        vLayout = new QVBoxLayout;
         vLayout->setMargin( 0 );
         vLayout->setSpacing(5);
         hLayout->addLayout( vLayout );
@@ -186,8 +186,8 @@ namespace SpellCheck
 
         // set text
         // check Editor seletion
-        unsigned int indexBegin( 0 );
-        unsigned int indexEnd( editor_->toPlainText().length() );
+        int indexBegin( 0 );
+        int indexEnd( editor_->toPlainText().length() );
         if( editor_->textCursor().hasSelection() )
         {
             indexBegin = editor_->textCursor().anchor();
@@ -196,13 +196,17 @@ namespace SpellCheck
         }
 
         // asign text
-        if( !interface().setText( editor_->toPlainText(), indexBegin, indexEnd ) )
-        { InformationDialog( this, interface().error() ).exec(); }
+        if( !interface_.setText( editor_->toPlainText(), indexBegin, indexEnd ) )
+        { InformationDialog( this, interface_.error() ).exec(); }
 
         // set TextEditor as ReadOnly
         readOnlyEditor_ = editor_->isReadOnly();
         editor_->setReadOnly( true );
 
+        // connection
+        connect( &closeButton(), SIGNAL(clicked()), SLOT(_saveWordList()) );
+        connect( &closeButton(), SIGNAL(clicked()), SLOT(_restoreReadOnly()) );
+
         Debug::Throw( "SpellCheck::SpellDialog::SpellDialog - done.\n" );
 
     }
@@ -234,9 +238,9 @@ namespace SpellCheck
         }
 
         // update interface
-        if( !interface().setDictionary( dictionary ) )
+        if( !interface_.setDictionary( dictionary ) )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return false;
         }
 
@@ -261,9 +265,9 @@ namespace SpellCheck
         }
 
         // update interface
-        if( !interface().setFilter( filter ) )
+        if( !interface_.setFilter( filter ) )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return false;
         }
 
@@ -275,7 +279,7 @@ namespace SpellCheck
     }
 
     //___________________________________________
-    void SpellDialog::_updateDictionaries( void )
+    void SpellDialog::_updateDictionaries()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_updateDictionaries.\n" );
 
@@ -289,7 +293,7 @@ namespace SpellCheck
         dictionariesComboBox_->clear();
 
         // get dictionary list and populate combobox
-        foreach( const QString& dictionary, interface().dictionaries() )
+        for( const auto& dictionary:interface_.dictionaries() )
         { if( !disabledDictionaries.contains( dictionary ) ) dictionariesComboBox_->addItem( dictionary ); }
 
         // restore default value
@@ -298,7 +302,7 @@ namespace SpellCheck
     }
 
     //___________________________________________
-    void SpellDialog::_updateFilters( void )
+    void SpellDialog::_updateFilters()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_updateFilters.\n" );
 
@@ -312,7 +316,7 @@ namespace SpellCheck
         filtersComboBox_->clear();
 
         // get dictionary list and populate combobox
-        foreach( const QString& filter, interface().filters() )
+        for( const auto& filter:interface_.filters() )
         { if( !disabledFilters.contains( filter ) ) filtersComboBox_->addItem( filter ); }
 
         // restore default value
@@ -334,17 +338,17 @@ namespace SpellCheck
         Debug::Throw( "SpellCheck::SpellDialog::_SelectDictionary.\n" );
 
         // see if changed
-        if( interface().dictionary() == dictionary ) return;
+        if( interface_.dictionary() == dictionary ) return;
 
         // try update interface
-        if( !interface().setDictionary( dictionary ) )
+        if( !interface_.setDictionary( dictionary ) )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return;
         }
 
         // emit signal
-        emit dictionaryChanged( interface().dictionary() );
+        emit dictionaryChanged( interface_.dictionary() );
 
         // restart
         _restart();
@@ -358,17 +362,17 @@ namespace SpellCheck
         Debug::Throw( "SpellCheck::SpellDialog::_SelectFilter.\n" );
 
         // see if changed
-        if( interface().filter() == filter ) return;
+        if( interface_.filter() == filter ) return;
 
         // try update interface
-        if( !interface().setFilter( filter ) )
+        if( !interface_.setFilter( filter ) )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return;
         }
 
         // emit signal
-        emit filterChanged( interface().filter() );
+        emit filterChanged( interface_.filter() );
 
         // restart
         _restart();
@@ -376,13 +380,13 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_restart( void )
+    void SpellDialog::_restart()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_restart.\n" );
 
-        if( !interface().reset() )
+        if( !interface_.reset() )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return;
         }
 
@@ -391,17 +395,17 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_addWord( void )
+    void SpellDialog::_addWord()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_addWord.\n" );
 
-        if( !interface().addWord( interface().word() ) )
+        if( !interface_.addWord( interface_.word() ) )
         {
-            InformationDialog( this, interface().error() ).exec();
+            InformationDialog( this, interface_.error() ).exec();
             return;
         }
 
-        emit ignoreWord( interface().word() );
+        emit ignoreWord( interface_.word() );
         emit needUpdate();
 
         // get next mispelled word
@@ -410,7 +414,7 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_checkWord( void )
+    void SpellDialog::_checkWord()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_checkWord.\n" );
 
@@ -420,7 +424,7 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_ignore( void )
+    void SpellDialog::_ignore()
     {
 
         Debug::Throw( "SpellCheck::SpellDialog::_ignore.\n" );
@@ -429,11 +433,11 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_ignoreAll( void )
+    void SpellDialog::_ignoreAll()
     {
 
         Debug::Throw( "SpellCheck::SpellDialog::_ignoreAll.\n" );
-        interface().ignoreWord( sourceLabel_->text() );
+        interface_.ignoreWord( sourceLabel_->text() );
         _ignore();
 
     }
@@ -448,7 +452,7 @@ namespace SpellCheck
         if( !local.isValid() ) return;
 
         const QString word( model_.get( local ) );
-        if( interface().replace( word ) ) _replaceSelection( word );
+        if( interface_.replace( word ) ) _replaceSelection( word );
 
         // parse next word
         nextWord();
@@ -456,7 +460,7 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_replaceAll( void )
+    void SpellDialog::_replaceAll()
     {
 
         Debug::Throw( "SpellCheck::SpellDialog::_replaceAll.\n" );
@@ -468,7 +472,7 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::_updateButtons( void )
+    void SpellDialog::_updateButtons()
     {
         Debug::Throw( "SpellCheck::SpellDialog::_updateButtons.\n" );
         const bool hasSelection( list_->selectionModel()->hasSelection() );
@@ -482,24 +486,24 @@ namespace SpellCheck
     }
 
     //____________________________________________________
-    void SpellDialog::nextWord( void )
+    void SpellDialog::nextWord()
     {
 
         Debug::Throw( "SpellCheck::SpellDialog::nextWord.\n" );
 
         bool accepted( false );
-        QString word( "" );
+        QString word;
         while( !accepted )
         {
             // get next word from interface
-            if( !interface().nextWord() )
+            if( !interface_.nextWord() )
             {
-                InformationDialog( this, interface().error() ).exec();
+                InformationDialog( this, interface_.error() ).exec();
                 return;
             }
 
             // check for completed spelling
-            word = interface().word();
+            word = interface_.word();
             if( word.isEmpty() )
             {
                 Debug::Throw() << "SpellCheck::SpellDialog::NextWord - empty word " << endl;
@@ -509,7 +513,7 @@ namespace SpellCheck
             Debug::Throw() << "SpellCheck::SpellDialog::NextWord - word: " << word << endl;
 
             // see if word is in ignore list
-            if( interface().isWordIgnored( word ) ) continue;
+            if( interface_.isWordIgnored( word ) ) continue;
 
             // see if word is in replace all list
             if( replacedWords_.find( word ) != replacedWords_.end() )
@@ -517,9 +521,9 @@ namespace SpellCheck
 
                 // automatic replacement
                 QHash< QString, QString >::iterator iter = replacedWords_.find( word );
-                _updateSelection( interface().position() + interface().offset(), word.size() );
+                _updateSelection( interface_.position() + interface_.offset(), word.size() );
                 _replaceSelection( iter.value() );
-                interface().replace( iter.value() );
+                interface_.replace( iter.value() );
                 continue;
             }
 
@@ -530,7 +534,7 @@ namespace SpellCheck
         if( accepted )
         {
 
-            _updateSelection( interface().position() + interface().offset(), word.size() );
+            _updateSelection( interface_.position() + interface_.offset(), word.size() );
             _displayWord( word );
 
         } else {
@@ -551,14 +555,22 @@ namespace SpellCheck
     //__________________________________________
     void SpellDialog::closeEvent( QCloseEvent *e )
     {
-        Debug::Throw( "SpellCheck::SpellDialog::closeEvent.\n" );
-        interface().saveWordList();
-        editor_->setReadOnly( readOnlyEditor_ );
+        Debug::Throw( 0, "SpellCheck::SpellDialog::closeEvent.\n" );
+        _restoreReadOnly();
+        _saveWordList();
         QDialog::closeEvent( e );
     }
 
+    //__________________________________________
+    void SpellDialog::_saveWordList()
+    { interface_.saveWordList(); }
+
+    //__________________________________________
+    void SpellDialog::_restoreReadOnly()
+    { editor_->setReadOnly( readOnlyEditor_ ); }
+
     //_________________________________________________________________
-    void SpellDialog::_updateSelection( const unsigned int& index, const unsigned int& length )
+    void SpellDialog::_updateSelection( int index, int length )
     {
         Debug::Throw() << "SpellCheck::SpellDialog::_updateSelection - index=" << index << endl;
         QTextCursor cursor( editor_->textCursor() );
@@ -591,7 +603,7 @@ namespace SpellCheck
 
         // clear list of suggestions
         model_.clear();
-        Model::List suggestions( interface().suggestions( word ) );
+        Model::List suggestions( interface_.suggestions( word ) );
         model_.add( suggestions );
 
         // select the first suggestion, if any
