@@ -47,37 +47,37 @@ namespace SpellCheck
         public:
 
         //* constructor
-        SpellDialog( TextEditor*, bool = false );
+        explicit SpellDialog( TextEditor*, bool = false );
 
         //* set read-only (enable/disable modification buttons)
 
         //* toggle filter combo box visibility
-        virtual void showFilter( bool value );
+        void showFilter( bool value );
 
         //* spell interface
-        virtual SpellInterface& interface( void )
+        SpellInterface& interface()
         { return interface_; }
 
         //* editor
-        TextEditor &editor( void )
+        TextEditor &editor()
         { return *editor_; }
 
         //* dictionary
         bool setDictionary( const QString& dict );
 
         //* dictionary
-        QString dictionary( void ) const
+        QString dictionary() const
         { return dictionariesComboBox_->itemText( dictionariesComboBox_->currentIndex() ); }
 
         //* filter
         bool setFilter( const QString& filter );
 
         //* dictionary
-        QString filter( void ) const
+        QString filter() const
         { return filtersComboBox_->itemText( filtersComboBox_->currentIndex() ); }
 
         //* go to next word to be checked
-        void nextWord( void );
+        void nextWord();
 
         Q_SIGNALS:
 
@@ -85,7 +85,7 @@ namespace SpellCheck
         void ignoreWord( const QString& );
 
         //* need update
-        void needUpdate( void );
+        void needUpdate();
 
         //* filter has changed
         void filterChanged( QString );
@@ -96,49 +96,57 @@ namespace SpellCheck
         protected Q_SLOTS:
 
         //* update dictionaries
-        void _updateDictionaries( void );
+        void _updateDictionaries();
 
         //* update filters
-        void _updateFilters( void );
+        void _updateFilters();
 
         //* select suggestion, update replaceEditor_
-        virtual void _selectSuggestion( const QModelIndex& );
+        void _selectSuggestion( const QModelIndex& );
 
         //* select suggestion, update replaceEditor_
-        virtual void _addWord( void );
+        void _addWord();
 
         //* check word in Replace Editor
-        virtual void _checkWord( void );
+        void _checkWord();
 
         //* select dictionary
-        virtual void _selectDictionary( const QString& dict );
+        void _selectDictionary( const QString& dict );
 
         //* select dictionary
-        virtual void _selectFilter( const QString& filter );
+        void _selectFilter( const QString& filter );
 
         //* recheck text from start
         /** initial begin/end are reset to the full text */
-        virtual void _restart( void );
+        void _restart();
 
         //* ignore
-        virtual void _ignore( void );
+        void _ignore();
 
         //* ignore all
-        virtual void _ignoreAll( void );
+        void _ignoreAll();
 
         //* replace
-        virtual void _replace( const QModelIndex& index = QModelIndex() );
+        void _replace( const QModelIndex& index = QModelIndex() );
 
         //* replace All
-        virtual void _replaceAll( void );
+        void _replaceAll();
 
         //* update buttons
-        virtual void _updateButtons( void );
+        void _updateButtons();
 
         protected:
 
         //* close
-        virtual void closeEvent( QCloseEvent *e );
+        void closeEvent( QCloseEvent* ) override;
+
+        protected Q_SLOTS:
+
+        //* save word list
+        void _saveWordList();
+
+        //* restore read only state
+        void _restoreReadOnly();
 
         private:
 
@@ -155,26 +163,21 @@ namespace SpellCheck
             //@{
 
             // return data for a given index
-            virtual QVariant data(const QModelIndex &index, int role) const;
+            QVariant data(const QModelIndex &index, int role) const override;
 
             //* header data
-            virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+            QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
             //* number of columns for a given index
-            virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
+            int columnCount(const QModelIndex &parent = QModelIndex()) const override
             { return nColumns; }
 
             //@}
 
-            protected:
-
-            virtual void _sort(int, Qt::SortOrder)
-            { return; }
-
         };
 
         //* update text editor selection
-        void _updateSelection( const unsigned int&, const unsigned int& );
+        void _updateSelection( int, int );
 
         //* replace text editor selection
         void _replaceSelection( const QString& );
@@ -183,7 +186,7 @@ namespace SpellCheck
         void _displayWord( const QString& word );
 
         //* spell checking completed
-        void _completed( void );
+        void _completed();
 
         //* spell interface
         SpellInterface interface_;
