@@ -40,7 +40,7 @@ namespace SpellCheck
         public:
 
         //* constructor
-        SpellItemDialog( QWidget* );
+        explicit SpellItemDialog( QWidget* );
 
         //* set items
         void setItems( const QOrderedSet<QString>& );
@@ -49,17 +49,17 @@ namespace SpellCheck
         void setDisabledItems( const QString& );
 
         //* disabled items
-        QString disabledItems( void ) const;
+        QString disabledItems() const;
 
         protected Q_SLOTS:
 
         //* select item
-        virtual void _selectItem( const QModelIndex& );
+        void _selectItem( const QModelIndex& );
 
         private:
 
         //* list
-        TreeView& _list( void ) const
+        TreeView& _list() const
         { return *list_; }
 
         //* model
