@@ -35,31 +35,31 @@ namespace SpellCheck
 {
 
   //* highlight text based on misspelled words
-  class SpellParser: public Counter
+  class SpellParser final: private Base::Counter<SpellParser>
   {
 
     public:
 
     //* constructor
-    SpellParser();
+    explicit SpellParser();
 
     //* highlight paragraph
-    virtual Word::Set parse( const QString& text );
+    Word::Set parse( const QString& );
 
     //* highlight color
     /* returns true if changed */
-    virtual bool setColor( const QColor& color );
+    bool setColor( const QColor& );
 
     //* color
-    virtual const QColor& color( void ) const
+    const QColor& color() const
     { return color_; }
 
     //* font format
     /* returns true if changed */
-    virtual bool setFontFormat( Format::TextFormatFlags );
+    bool setFontFormat( Format::TextFormatFlags );
 
     //* font format
-    virtual Format::TextFormatFlags fontFormat( void ) const
+    Format::TextFormatFlags fontFormat() const
     { return fontFormat_; }
 
     //* enabled. Returns true if changed.
@@ -71,15 +71,15 @@ namespace SpellCheck
     }
 
     //* enabled
-    bool isEnabled( void ) const
+    bool isEnabled() const
     { return enabled_; }
 
     //* spell interface
-    virtual const SpellInterface& interface( void ) const
+    const SpellInterface& interface() const
     { return interface_; }
 
     //* spell interface
-    virtual SpellInterface& interface( void )
+    SpellInterface& interface()
     { return interface_; }
 
     private:
