@@ -45,7 +45,7 @@ namespace SpellCheck
     }
 
     //________________________________________________________
-    void SuggestionMenu::_aboutToShow( void )
+    void SuggestionMenu::_aboutToShow()
     {
 
         Debug::Throw( "SuggestionMenu::_aboutToShow.\n" );
@@ -76,10 +76,7 @@ namespace SpellCheck
         if( !suggestions.isEmpty() )
         { addSeparator(); }
 
-        // add word action
         addAction( tr( "Add Word to Dictionary" ), this, SLOT(_addWord()) );
-
-        // ignore word action
         addAction( tr( "Ignore Word" ), this, SLOT(_ignoreWord()) );
 
     }
@@ -96,7 +93,7 @@ namespace SpellCheck
     }
 
     //________________________________________________
-    void SuggestionMenu::_addWord( void )
+    void SuggestionMenu::_addWord()
     {
 
         Debug::Throw( "SuggestionMenu::_addWord.\n" );
