@@ -21,18 +21,24 @@
 
 #include "Debug.h"
 #include "File.h"
+#include "Sleep.h"
 #include "SshLoginDialog.h"
 #include "SshSingleton.h"
 #include "SshSocket.h"
 #include "SshTunnel.h"
 
+#include <QCoreApplication>
+#include <QElapsedTimer>
 #include <QTcpServer>
 #include <QTextStream>
 #include <QTimer>
+#include <QThread>
 
 #if defined(Q_OS_WIN)
 #include <ws2tcpip.h>
 #else
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #endif
 
@@ -43,6 +49,7 @@
 #include <libssh2.h>
 #endif
 
+
 namespace Ssh
 {
 
@@ -53,32 +60,32 @@ namespace Ssh
     {}
 
     //_______________________________________________
-    Connection::~Connection( void )
+    Connection::~Connection()
     { disconnect(); }
 
     //_______________________________________________
-    bool Connection::createTunnels( void )
+    bool Connection::createTunnels()
     {
 
         Debug::Throw( "Ssh::Connection::createTunnels.\n" );
         if( !Singleton::get().initialized() ) return false;
 
         // loop over tunnel attributes
-        foreach( auto attributes, attributes_.tunnels() )
+        for( const auto& attributes:attributes_.tunnels() )
         {
 
             // create Tcp server
             QTcpServer* tcpServer = new QTcpServer( this );
-            connect( tcpServer, SIGNAL(newConnection()), this, SLOT(_newConnection()) );
+            connect( tcpServer, SIGNAL(newConnection()), SLOT(_newConnection()) );
             if( !tcpServer->listen( QHostAddress::LocalHost, attributes.localPort() ) )
             {
 
-                const QString message = QString( "Cannot listen to localhost:%1 - error:%2")
+                const QString message = tr( "Cannot listen to localhost:%1 - error:%2")
                     .arg( attributes.localPort() )
                     .arg( tcpServer->errorString() );
 
                 Debug::Throw() << "Ssh::Connection::connectTunnels - " << message << endl;
-                emit error( message );
+                _notifyError( message );
 
                 return false;
             }
@@ -93,7 +100,7 @@ namespace Ssh
     }
 
     //_______________________________________________
-    bool Connection::connect( void )
+    bool Connection::connect()
     {
 
         Debug::Throw( "Ssh::Connection::connect.\n" );
@@ -104,7 +111,7 @@ namespace Ssh
         sshSocket_ = socket( PF_INET, SOCK_STREAM, IPPROTO_TCP);
         if( sshSocket_ == -1 )
         {
-            emit error( "Unable to create ssh socket" );
+            _notifyError( tr( "unable to create ssh socket" ) );
             return false;
         }
 
@@ -112,13 +119,13 @@ namespace Ssh
         const int flags( fcntl(sshSocket_, F_GETFL ) );
         if( flags < 0 )
         {
-            emit error( "Unable to get socket flags" );
+            _notifyError( tr( "unable to get socket flags" ) );
             return false;
         }
 
         if( fcntl( sshSocket_, F_SETFL, flags|O_NONBLOCK ) < 0 )
         {
-            emit error( "Unable to set socket flags" );
+            _notifyError( tr( "unable to set socket flags" ) );
             return false;
         }
 
@@ -129,12 +136,12 @@ namespace Ssh
         if(!( session_ = libssh2_session_init() ))
         {
             Debug::Throw() << "Ssh::Connection::connect - Cannot initialize session" << endl;
-            emit error( "Cannot initialize Ssh session" );
+            _notifyError( tr( "cannot initialize ssh session" ) );
             return false;
         }
 
         // cast session
-        LIBSSH2_SESSION* session( reinterpret_cast<LIBSSH2_SESSION*>(session_) );
+        auto session( static_cast<LIBSSH2_SESSION*>(session_) );
 
         // initialize agent
         agent_ = libssh2_agent_init(session);
@@ -183,8 +190,40 @@ namespace Ssh
 
     }
 
+    //_______________________________________________________________________
+    bool Connection::waitForConnected( int msecs )
+    {
+
+        // do nothing if already connected
+        if( isConnected() ) return true;
+
+        // setup host manually if not already set
+        if( sshHost_.lookupId() < 0 )
+        {
+            sshHost_ = QHostInfo::fromName( attributes_.host() );
+            sshHost_.setLookupId( 0 );
+        }
+
+        // start timer
+        QElapsedTimer timer;
+        timer.start();
+
+        while( (msecs < 0 || timer.elapsed() < msecs) && _processCommands() )
+        { qApp->processEvents(); }
+
+//         while( msecs < 0 || timer.elapsed() < msecs )
+//         {
+//             // qApp->processEvents();
+//             if( !_processCommands() ) break;
+//             Sleep::msleep( 100 );
+//         }
+
+        return isConnected();
+
+    }
+
     //_______________________________________________
-    void Connection::addCommand( SshCommand command )
+    void Connection::addCommand( Command command )
     {
         Debug::Throw() << "Ssh::Connection::AddCommand: " << command << endl;
         commands_.append( command );
@@ -192,14 +231,14 @@ namespace Ssh
     }
 
     //_______________________________________________
-    void Connection::abortCommands( void )
+    void Connection::abortCommands()
     {
         if( timer_.isActive() ) timer_.stop();
         commands_.clear();
     }
 
     //_______________________________________________
-    void Connection::disconnect( void )
+    void Connection::disconnect()
     {
 
         Debug::Throw( "Ssh::Connection::disconnect.\n" );
@@ -214,13 +253,13 @@ namespace Ssh
     { sshHost_ = host; }
 
     //_______________________________________________
-    void Connection::_disconnectChannels( void )
+    void Connection::_disconnectChannels()
     {
 
         Debug::Throw( "Ssh::Connection::_disconnectChannels.\n" );
 
         // loop over tunnels and delete
-        foreach( auto tunnel, findChildren<Tunnel*>() )
+        for( const auto& tunnel:findChildren<Tunnel*>() )
         {
             tunnel->close();
             tunnel->deleteLater();
@@ -229,7 +268,7 @@ namespace Ssh
     }
 
     //_______________________________________________
-    void Connection::_disconnectSession( void )
+    void Connection::_disconnectSession()
     {
 
         Debug::Throw( "Ssh::Connection::_disconnectSession.\n" );
@@ -241,7 +280,7 @@ namespace Ssh
             // disconnect agent
             if( agent_ )
             {
-                LIBSSH2_AGENT* agent( reinterpret_cast<LIBSSH2_AGENT*>(agent_) );
+                auto agent( static_cast<LIBSSH2_AGENT*>(agent_) );
                 libssh2_agent_disconnect(agent);
                 libssh2_agent_free(agent);
                 agent_ = nullptr;
@@ -251,7 +290,7 @@ namespace Ssh
             // close session
             if( session_ )
             {
-                LIBSSH2_SESSION* session( reinterpret_cast<LIBSSH2_SESSION*>(session_) );
+                auto session( static_cast<LIBSSH2_SESSION*>(session_) );
                 libssh2_session_disconnect( session, "Client disconnecting normally" );
                 libssh2_session_free( session );
                 session_ = nullptr;
@@ -272,12 +311,12 @@ namespace Ssh
     }
 
     //_______________________________________________
-    void Connection::_disconnectTunnels( void )
+    void Connection::_disconnectTunnels()
     {
         Debug::Throw( "Ssh::Connection::_disconnectTunnel.\n" );
 
         // disconnect all tcp servers
-        foreach( auto tcpServer, findChildren<QTcpServer*>() )
+        for( const auto& tcpServer:findChildren<QTcpServer*>() )
         {
             if( tcpServer->isListening() ) tcpServer->close();
             tcpServer->deleteLater();
@@ -289,7 +328,7 @@ namespace Ssh
     }
 
     //_______________________________________________
-    bool Connection::isSupported( void )
+    bool Connection::isSupported()
     {
         #if HAVE_SSH
         return true;
@@ -302,36 +341,46 @@ namespace Ssh
     void Connection::timerEvent( QTimerEvent* event )
     {
 
-        if( event->timerId() != timer_.timerId() )
-        { return QObject::timerEvent( event ); }
+        if( event->timerId() == timer_.timerId() )
+        {
+
+            if( !_processCommands() && timer_.isActive() ) timer_.stop();
+
+        } else {
+
+            return QObject::timerEvent( event );
+
+        }
+
+    }
+
+    //_______________________________________________
+    bool Connection::_processCommands()
+    {
 
         // check empty commands list
-        if( commands_.empty() )
-        {
-            timer_.stop();
-            return;
-        }
+        if( commands_.empty() ) return false;
 
         // check session
         if( !session_ )
         {
             _abortCommands( tr( "Session is invalid" ) );
-            return;
+            return false;
         }
 
         // emit message
         if( commands_.front() != lastCommand_ )
         {
             lastCommand_ = commands_.front();
-            emit message( _commandMessage( lastCommand_ ) );
+            _notifyMessage( _commandMessage( lastCommand_ ) );
         }
 
         #if HAVE_SSH
 
-        Debug::Throw() << "Ssh::Connection::timerEvent - processing command: " << _commandMessage(commands_.front()) << " (" << commands_.front() << ")" << endl;
+        Debug::Throw() << "Ssh::Connection::_processCommands - processing command: " << _commandMessage(commands_.front()) << " (" << commands_.front() << ")" << endl;
 
         // cast session. It is used for almost all commands
-        LIBSSH2_SESSION* session( reinterpret_cast<LIBSSH2_SESSION*>(session_) );
+        auto session( static_cast<LIBSSH2_SESSION*>(session_) );
         switch( commands_.front() )
         {
 
@@ -339,7 +388,11 @@ namespace Ssh
             {
 
                 // check host
-                if( sshHost_.lookupId() < 0 ) break;
+                if( sshHost_.lookupId() < 0 )
+                {
+                    Debug::Throw() << "Ssh::Connection::_processCommands - lookup failed" << endl;
+                    break;
+                }
 
                 // initialize socket address structure
                 QHostAddress address;
@@ -348,11 +401,11 @@ namespace Ssh
                 {
 
                     _abortCommands( tr( "Invalid host: %1" ).arg( attributes_.host() ) );
-                    return;
+                    return false;
 
                 }
 
-                Debug::Throw() << "Ssh::Connection::timerEvent - connection."
+                Debug::Throw() << "Ssh::Connection::_processCommands - connection."
                     << " Host: " << attributes_.host()
                     << " Port: " << attributes_.port()
                     << endl;
@@ -364,13 +417,13 @@ namespace Ssh
                 socketAddress.sin_addr.s_addr = htonl(address.toIPv4Address());
 
                 // try connect
-                const int result( ::connect( sshSocket_, reinterpret_cast<struct sockaddr*>(&socketAddress), sizeof(struct sockaddr_in) ) );
+                auto result( ::connect( sshSocket_, reinterpret_cast<struct sockaddr*>(&socketAddress), sizeof(struct sockaddr_in) ) );
                 if( !result )
                 {
 
                     // success
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 } else if( errno != EALREADY && errno != EINPROGRESS ) {
 
@@ -378,7 +431,7 @@ namespace Ssh
                         .arg(attributes_.host())
                         .arg(attributes_.port())
                         .arg(errno) );
-                    return;
+                    return false;
 
                 }
 
@@ -394,12 +447,12 @@ namespace Ssh
 
                     // success
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 } else if( result != LIBSSH2_ERROR_EAGAIN ) {
 
                     _abortCommands( tr( "Handshake failed" ) );
-                    return;
+                    return false;
 
                 }
 
@@ -412,17 +465,17 @@ namespace Ssh
 
                 // skip if no agent is defined
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else {
 
                 // accept in all cases except EAGAIN
-                LIBSSH2_AGENT* agent( reinterpret_cast<LIBSSH2_AGENT*>(agent_) );
+                auto agent( static_cast<LIBSSH2_AGENT*>(agent_) );
                 if( libssh2_agent_connect(agent) != LIBSSH2_ERROR_EAGAIN  )
                 {
 
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 }
 
@@ -450,12 +503,12 @@ namespace Ssh
                     }
 
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 } else {
 
                     _abortCommands( tr( "Login cancelled" ) );
-                    return;
+                    return false;
 
                 }
 
@@ -469,12 +522,12 @@ namespace Ssh
 
                     // success
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 } else if( libssh2_session_last_errno( session ) != LIBSSH2_ERROR_EAGAIN ) {
 
                     _abortCommands( tr( "Failed retrieving authentication methods" ) );
-                    return;
+                    return false;
 
                 }
 
@@ -487,24 +540,24 @@ namespace Ssh
 
                 // skip if no agent is defined
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else if( !authenticationMethods_.contains( "publickey" ) ) {
 
-                Debug::Throw( 0, "Ssh::Connection::timerEvent - public key authentication is not supported.\n" );
+                Debug::Throw( 0, "Ssh::Connection::_processCommands - public key authentication is not supported.\n" );
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else {
 
                 // accept in all cases except EAGAIN
-                LIBSSH2_AGENT* agent( reinterpret_cast<LIBSSH2_AGENT*>(agent_) );
+                auto agent( static_cast<LIBSSH2_AGENT*>(agent_) );
                 if( libssh2_agent_list_identities( agent ) != LIBSSH2_ERROR_EAGAIN  )
                 {
 
                     identity_ = nullptr;
                     commands_.removeFirst();
-                    return;
+                    return true;
 
                 }
 
@@ -517,20 +570,20 @@ namespace Ssh
 
                 // skip if no agent is defined
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else if( !authenticationMethods_.contains( "publickey" ) ) {
 
-                Debug::Throw( 0, "Ssh::Connection::timerEvent - public key authentication is not supported.\n" );
+                Debug::Throw( 0, "Ssh::Connection::_processCommands - public key authentication is not supported.\n" );
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else {
 
-                Debug::Throw() << "Ssh::Connection::timerEvent - identity: " << identity_ << endl;
+                Debug::Throw() << "Ssh::Connection::_processCommands - identity: " << identity_ << endl;
 
-                LIBSSH2_AGENT* agent( reinterpret_cast<LIBSSH2_AGENT*>(agent_) );
-                struct libssh2_agent_publickey* identity( reinterpret_cast<struct libssh2_agent_publickey*>( identity_ ) );
+                auto agent( static_cast<LIBSSH2_AGENT*>(agent_) );
+                auto identity( static_cast<struct libssh2_agent_publickey*>( identity_ ) );
                 if( identity )
                 {
 
@@ -544,7 +597,7 @@ namespace Ssh
                         state_ |= Connected;
                         commands_.clear();
                         emit connected();
-                        return;
+                        return false;
 
                     } else if( result == LIBSSH2_ERROR_EAGAIN ) {
 
@@ -569,7 +622,8 @@ namespace Ssh
                 {
                     identity_ = nullptr;
                     commands_.removeFirst();
-                    return;
+                    return true;
+
                 } else identity_ = nextIdentity;
 
             }
@@ -580,13 +634,13 @@ namespace Ssh
             {
 
                 // check authentication methods
-                Debug::Throw( 0, "Ssh::Connection::timerEvent - password authentication is not supported.\n" );
+                Debug::Throw( 0, "Ssh::Connection::_processCommands - password authentication is not supported.\n" );
                 commands_.removeFirst();
-                return;
+                return true;
 
             } else {
 
-                Debug::Throw() << "Ssh::Connection::timerEvent - password authentication."
+                Debug::Throw() << "Ssh::Connection::_processCommands - password authentication."
                     << " Host: " << attributes_.host()
                     << " User: " << attributes_.userName()
                     << " Password: " << attributes_.password()
@@ -602,7 +656,7 @@ namespace Ssh
                     commands_.clear();
                     emit connected();
 
-                    return;
+                    return false;
 
                 }  else if( result != LIBSSH2_ERROR_EAGAIN ) {
 
@@ -613,7 +667,7 @@ namespace Ssh
                     _disconnectSession();
                     connect();
                     authenticate( true );
-                    return;
+                    return true;
 
                 }
 
@@ -622,28 +676,43 @@ namespace Ssh
 
             default:
             commands_.removeFirst();
-            return;
+            return true;
 
         }
 
+        return true;
+
+
         #else
 
         _abortCommands( tr( "No SSH support" ) );
+        return false;
 
         #endif
 
     }
 
     //_______________________________________________
-    void Connection::_notifyError( QString message )
-    { Debug::Throw(0) << "Ssh::Connection::_notifyError: " << message << endl; }
+    void Connection::_notifyError( QString error )
+    {
+        Debug::Throw(0) << "Ssh::Connection::_notifyError: " << error << endl;
+        error_ = error;
+        emit this->error( error );
+    }
+
+    //_______________________________________________
+    void Connection::_notifyMessage( QString message )
+    {
+        Debug::Throw() << "Ssh::Connection::_notifyMessage: " << message << endl;
+        emit this->message( message );
+    }
 
     //_______________________________________________
     void Connection::_notifyDebug( QString message )
     { Debug::Throw() << message << endl; }
 
     //_______________________________________________
-    void Connection::_newConnection( void )
+    void Connection::_newConnection()
     {
         Debug::Throw( "Ssh::Connection::_newConnection.\n" );
 
@@ -655,7 +724,7 @@ namespace Ssh
         }
 
         // loop over tcp servers
-        foreach( auto tcpServer, findChildren<QTcpServer*>() )
+        for( const auto& tcpServer:findChildren<QTcpServer*>() )
         {
 
             // check pending connection
@@ -676,9 +745,8 @@ namespace Ssh
                 Tunnel* tunnel = new Tunnel( this, tcpSocket );
                 tunnel->sshSocket()->connectToHost( session_, iter->host(), iter->remotePort() );
 
-                connect( tunnel, SIGNAL(error(QString)), this, SIGNAL(error(QString)) );
-                connect( tunnel, SIGNAL(error(QString)), this, SLOT(_notifyError(QString)) );
-                connect( tunnel, SIGNAL(debug(QString)), this, SLOT(_notifyDebug(QString)) );
+                connect( tunnel, SIGNAL(error(QString)), SLOT(_notifyError(QString)) );
+                connect( tunnel, SIGNAL(debug(QString)), SLOT(_notifyDebug(QString)) );
                 connect( tunnel->sshSocket(), SIGNAL(error(QAbstractSocket::SocketError)), tunnel, SLOT(deleteLater()) );
                 connect( tunnel->sshSocket(), SIGNAL(readChannelFinished()), tunnel, SLOT(deleteLater()) );
             }
@@ -688,7 +756,7 @@ namespace Ssh
     }
 
     //_______________________________________________
-    QString Connection::_commandMessage( SshCommand command ) const
+    QString Connection::_commandMessage( Command command ) const
     {
         switch( command )
         {
@@ -713,7 +781,7 @@ namespace Ssh
         Debug::Throw( "Ssh::Connection::_abortCommands.\n" );
         if( timer_.isActive() ) timer_.stop();
         commands_.clear();
-        emit error( errorMessage );
+        _notifyError( errorMessage );
     }
 
 }
