@@ -34,7 +34,7 @@
 namespace Ssh
 {
     //_________________________________________________________
-    class Connection: public QObject, public Counter
+    class Connection: public QObject, private Base::Counter<Connection>
     {
 
         Q_OBJECT
@@ -42,18 +42,22 @@ namespace Ssh
         public:
 
         //* constructor
-        Connection( QObject* );
+        explicit Connection( QObject* );
 
         //* destructor
-        virtual ~Connection( void );
+        ~Connection() override;
 
         //*@name accessors
         //@{
 
         //* connection attributes
-        const ConnectionAttributes& attributes( void ) const
+        const ConnectionAttributes& attributes() const
         { return attributes_; }
 
+        //* session
+        void* session() const
+        { return session_; }
+
         //* connection state
         enum State
         {
@@ -65,21 +69,25 @@ namespace Ssh
 
         Q_DECLARE_FLAGS( StateMask, State );
 
-        StateMask state( void ) const
+        StateMask state() const
         { return state_; }
 
         //* true if connected
-        bool isConnected( void ) const
+        bool isConnected() const
         { return state_ & Connected; }
 
         //* true if disconnected
-        bool isDisconnected( void ) const
+        bool isDisconnected() const
         { return !(state_ & (TunnelCreated|SessionCreated|Connected)  ); }
 
         //* true if connecting
-        bool isConnecting( void ) const
+        bool isConnecting() const
         { return !(isDisconnected() || isConnected() ); }
 
+        //* error string
+        QString errorString() const
+        { return error_; }
+
         //@}
 
         //*@name modifiers
@@ -92,16 +100,20 @@ namespace Ssh
         { attributes_ = attributes; }
 
         //* tunnels
-        bool createTunnels( void );
+        bool createTunnels();
 
         //* connect
-        bool connect( void );
+        bool connect();
+
+        //* wait for connected
+        /** warning, this method is blocking */
+        bool waitForConnected( int msecs = 30000 );
 
         //* authenticate
         bool authenticate( bool forceRequestIdentity = false );
 
         //* command list
-        enum SshCommand
+        enum Command
         {
             None,
             Connect,
@@ -115,19 +127,19 @@ namespace Ssh
         };
 
         //* add command
-        void addCommand( SshCommand );
+        void addCommand( Command );
 
         //* abort commands
         /* warning, if happens while SshInterface is in timer event, this might cause crash */
-        void abortCommands( void );
+        void abortCommands();
 
         //* disconnect
-        void disconnect( void );
+        void disconnect();
 
         //@}
 
         //* true if ssh is supported
-        static bool isSupported( void );
+        static bool isSupported();
 
         Q_SIGNALS:
 
@@ -138,18 +150,18 @@ namespace Ssh
         void error( const QString& );
 
         //* attributes updated
-        void attributesChanged( void );
+        void attributesChanged();
 
         //* connected
-        void connected( void );
+        void connected();
 
         //* login failed
-        void loginFailed( void );
+        void loginFailed();
 
         protected:
 
         //* timer event
-        virtual void timerEvent( QTimerEvent* );
+        void timerEvent( QTimerEvent* ) override;
 
         protected Q_SLOTS:
 
@@ -157,13 +169,16 @@ namespace Ssh
         void _saveHost( QHostInfo );
 
         //* disconnect channels
-        void _disconnectChannels( void );
+        void _disconnectChannels();
 
         //* disconnect session
-        void _disconnectSession( void );
+        void _disconnectSession();
 
         //* disconnect tunnel
-        void _disconnectTunnels( void );
+        void _disconnectTunnels();
+
+        //* message handling
+        void _notifyMessage( QString );
 
         //* error handling
         void _notifyError( QString );
@@ -172,12 +187,15 @@ namespace Ssh
         void _notifyDebug( QString );
 
         //* new tcp connection (from QTcpServer)
-        void _newConnection( void );
+        void _newConnection();
 
         private:
 
         //* get message command
-        QString _commandMessage( SshCommand ) const;
+        QString _commandMessage( Command ) const;
+
+        //* process pending commands
+        bool _processCommands();
 
         //* abort all commands
         void _abortCommands( const QString& );
@@ -206,16 +224,19 @@ namespace Ssh
         //* state
         StateMask state_ = Uninitialized;
 
+        //* error string
+        QString error_;
+
         //* command list
-        using CommandList = QList<SshCommand>;
+        using CommandList = QList<Command>;
         CommandList commands_;
-        SshCommand lastCommand_ = None;
+        Command lastCommand_ = None;
 
         //* timer
         QBasicTimer timer_;
 
         //* latency
-        int latency_ = 20;
+        int latency_ = 10;
 
     };
 }
