@@ -30,7 +30,7 @@ namespace Ssh
 {
 
     //_________________________________________________________
-    class ConnectionAttributes: public Counter
+    class ConnectionAttributes: private Base::Counter<ConnectionAttributes>
     {
         public:
 
@@ -41,58 +41,49 @@ namespace Ssh
         using ListIterator = QListIterator<ConnectionAttributes>;
 
         //* constructor
-        ConnectionAttributes( void ):
+        explicit ConnectionAttributes():
             Counter( "Ssh::ConnectionAttributes" )
         {}
 
-        //* equal to operator
-        bool operator == (const ConnectionAttributes& other) const;
-
-        //* different from operator
-        bool operator != (const ConnectionAttributes& other ) const
-        { return !(*this == other); }
-
-        //* less than operator
-        bool operator < ( const ConnectionAttributes& other ) const
-        { return name_ < other.name_; }
+        virtual ~ConnectionAttributes() = default;
 
         //*@name accessors
         //@{
 
         //* name
-        const QString& name( void ) const
+        const QString& name() const
         { return name_; }
 
         //* host
-        const QString& host( void ) const
+        const QString& host() const
         { return host_; }
 
         //* user name
-        const QString& userName( void ) const
+        const QString& userName() const
         { return userName_; }
 
         //* password
-        const QString& password( void ) const
+        const QString& password() const
         { return password_; }
 
         //* true if password is to be remembered
-        bool rememberPassword( void ) const
+        bool rememberPassword() const
         { return rememberPassword_; }
 
         //* true if auto connect
-        bool autoConnect( void ) const
+        bool autoConnect() const
         { return autoConnect_; }
 
         //* port
-        int port( void ) const
+        int port() const
         { return port_; }
 
         //* tunnels
-        TunnelAttributes::Set tunnels( void ) const
+        TunnelAttributes::Set tunnels() const
         { return tunnels_; }
 
         //* validity
-        bool isValid( void ) const;
+        bool isValid() const;
 
         //@}
 
@@ -141,7 +132,7 @@ namespace Ssh
             public:
 
             //* constructor
-            SameNameFTor( const QString& name ):
+            explicit SameNameFTor( const QString& name ):
                 name_( name )
             {}
 
@@ -182,7 +173,15 @@ namespace Ssh
         //* tunnels
         TunnelAttributes::Set tunnels_;
 
+        //* equal to operator
+        friend bool operator == (const ConnectionAttributes&, const ConnectionAttributes&);
+
     };
+
+    //* less than operator
+    inline bool operator < (const ConnectionAttributes& first, const ConnectionAttributes& second)
+    { return first.name() < second.name(); }
+
 }
 
 #endif
