@@ -38,13 +38,13 @@ namespace Ssh
         public:
 
         //* constructor
-        LoginDialog( QWidget* );
+        explicit LoginDialog( QWidget* );
 
         //*@name accessors
         //@{
 
         //* connection attributes
-        ConnectionAttributes attributes( void ) const;
+        ConnectionAttributes attributes() const;
 
         //@}
 
