@@ -21,32 +21,33 @@
 *******************************************************************************/
 
 #include "Counter.h"
+#include "NonCopyable.h"
 
 namespace Ssh
 {
 
     //* singleton, to handle ssh allocation and freeing
-    class Singleton: public Counter
+    class Singleton final: private Base::Counter<Singleton>, private Base::NonCopyable<Singleton>
     {
         public:
 
         //* destructor
-        ~Singleton( void );
+        ~Singleton();
 
         //* accessor
-        static Singleton& get( void );
+        static Singleton& get();
 
         //* true if initialized
-        bool initialized( void ) const
+        bool initialized() const
         { return initialized_; }
 
         //* initialize
-        void initialize( void );
+        void initialize();
 
         private:
 
         //* constructor
-        Singleton( void );
+        explicit Singleton();
 
         //* true if initalized
         bool initialized_ = false;
