@@ -34,17 +34,17 @@ namespace Ssh
         Debug::Throw( "Ssh::Tunnel::Tunnel.\n" );
 
         buffer_.resize(maxSize_ );
-        connect( tcpSocket_, SIGNAL(readyRead()), this, SLOT(_readFromTcpSocket()) );
-        connect( tcpSocket_, SIGNAL(disconnected()), this, SLOT(close()) );
+        connect( tcpSocket_, SIGNAL(readyRead()), SLOT(_readFromTcpSocket()) );
+        connect( tcpSocket_, SIGNAL(disconnected()), SLOT(close()) );
 
-        connect( sshSocket_, SIGNAL(connected()), this, SLOT(_readFromTcpSocket()) );
-        connect( sshSocket_, SIGNAL(readyRead()), this, SLOT(_readFromSshSocket()) );
-        connect( sshSocket_, SIGNAL(readChannelFinished()), this, SLOT(close()) );
+        connect( sshSocket_, SIGNAL(connected()), SLOT(_readFromTcpSocket()) );
+        connect( sshSocket_, SIGNAL(readyRead()), SLOT(_readFromSshSocket()) );
+        connect( sshSocket_, SIGNAL(readChannelFinished()), SLOT(close()) );
 
     }
 
     //______________________________________________________
-    void Tunnel::close( void )
+    void Tunnel::close()
     {
         Debug::Throw( "Ssh::Tunnel::close.\n" );
         tcpSocket_->close();
@@ -52,7 +52,7 @@ namespace Ssh
     }
 
     //______________________________________________________
-    void Tunnel::_readFromTcpSocket( void )
+    void Tunnel::_readFromTcpSocket()
     {
         Debug::Throw( "Ssh::Tunnel::_readFromTcpSocket.\n" );
 
@@ -65,12 +65,20 @@ namespace Ssh
             qint64 bytesRead = tcpSocket_->read( buffer_.data(), buffer_.size() );
             emit debug( QString( "Ssh::Tunnel::_readFromTcpSocket - bytesAvailable=%1, bytesRead=%2" ).arg( bytesAvailable ).arg( bytesRead ) );
 
+            if( bytesRead < 0 )
+            {
+                emit error( tr( "invalid read from tcp socket: %1" ).arg( bytesRead ) );
+                return;
+            }
+
+
             ssize_t bytesWritten = 0;
             ssize_t i = 0;
             do
             {
                 i = sshSocket_->write( buffer_.data() + bytesWritten, bytesRead-bytesWritten );
                 Debug::Throw() << "Ssh::Tunnel::_readFromTcpSocket - written: " << i << endl;
+
                 if (i < 0)
                 {
                     emit error( tr( "invalid write to tcp socket: %1, error: %2" ).arg( i ).arg( sshSocket_->errorString() ) );
@@ -87,7 +95,7 @@ namespace Ssh
     }
 
     //______________________________________________________
-    void Tunnel::_readFromSshSocket( void )
+    void Tunnel::_readFromSshSocket()
     {
         Debug::Throw( "Ssh::Tunnel::_readFromSshSocket.\n" );
 
@@ -97,6 +105,13 @@ namespace Ssh
         {
             qint64 bytesRead = sshSocket_->read( buffer_.data(), buffer_.size() );
             emit debug( QString( "Ssh::Tunnel::_readFromSshSocket - bytesAvailable=%1, bytesRead=%2" ).arg( bytesAvailable ).arg( bytesRead ) );
+
+            if( bytesRead < 0 )
+            {
+                emit error( tr( "invalid read from ssh socket: %1" ).arg( bytesRead ) );
+                return;
+            }
+
             ssize_t bytesWritten = 0;
             ssize_t i = 0;
             do
@@ -104,7 +119,7 @@ namespace Ssh
                 i = tcpSocket_->write( buffer_.data() + bytesWritten, bytesRead - bytesWritten );
                 if (i < 0)
                 {
-                    emit error( tr( "invalid write to ssh socket: %1" ).arg( i ) );
+                    emit error( tr( "invalid write to tcp socket: %1" ).arg( i ) );
                     return;
                 }
 
