@@ -32,7 +32,7 @@ namespace Ssh
     class Socket;
 
     //* tunnel
-    class Tunnel: public QObject, public Counter
+    class Tunnel: public QObject, private Base::Counter<Tunnel>
     {
 
         Q_OBJECT
@@ -40,18 +40,15 @@ namespace Ssh
         public:
 
         //* constructor
-        Tunnel( QObject*, QTcpSocket* );
-
-        //* destructor
-        virtual ~Tunnel( void ) = default;
+        explicit Tunnel( QObject*, QTcpSocket* );
 
         //*@name accessors
         //@{
 
-        QTcpSocket* tcpSocket( void ) const
+        QTcpSocket* tcpSocket() const
         { return tcpSocket_; }
 
-        Socket* sshSocket( void ) const
+        Socket* sshSocket() const
         { return sshSocket_; }
 
         //@}
@@ -67,15 +64,15 @@ namespace Ssh
         public Q_SLOTS:
 
         //* close
-        void close( void );
+        void close();
 
         protected Q_SLOTS:
 
         //* read from tcp socket
-        void _readFromTcpSocket( void );
+        void _readFromTcpSocket();
 
         //* read from ssh socket
-        void _readFromSshSocket( void );
+        void _readFromSshSocket();
 
         private:
 
