@@ -30,7 +30,7 @@ namespace Ssh
 {
 
     //_________________________________________________________
-    class TunnelAttributes: public Counter
+    class TunnelAttributes: private Base::Counter<TunnelAttributes>
     {
         public:
 
@@ -38,31 +38,30 @@ namespace Ssh
         using List = QList<TunnelAttributes>;
 
         //* constructor
-        TunnelAttributes( void ):
+        explicit TunnelAttributes():
             Counter( "Ssh::TunnelAttributes" )
         {}
 
-        //* equal to operator
-        bool operator == (const TunnelAttributes& other ) const
-        { return localPort_ == other.localPort_; }
+        //* destructor
+        virtual ~TunnelAttributes() = default;
 
         //*@name accessors
         //@{
 
         //* host
-        const QString& host( void ) const
+        const QString& host() const
         { return host_; }
 
         //* port
-        int localPort( void ) const
+        int localPort() const
         { return localPort_; }
 
         //* port
-        int remotePort( void ) const
+        int remotePort() const
         { return remotePort_; }
 
         //* validity
-        bool isValid( void ) const
+        bool isValid() const
         { return !(host_.isEmpty() || localPort_ <= 0 || remotePort_ <= 0 ); }
 
         //@}
@@ -90,6 +89,11 @@ namespace Ssh
         int localPort_ = 0;
         int remotePort_ = 0;
 
+        //* equal to operator
+        friend bool operator == (const TunnelAttributes& first, const TunnelAttributes& second)
+        { return first.localPort_ == second.localPort_; }
+
+
     };
 
     //____________________________________________________
