@@ -31,7 +31,7 @@ namespace Svg
 {
 
     //! SVG common configuration
-    class SvgConfiguration: public QWidget, public OptionWidgetList, public Counter
+    class SvgConfiguration: public QWidget, public OptionWidgetList, private Base::Counter<SvgConfiguration>
     {
 
         Q_OBJECT
@@ -39,12 +39,12 @@ namespace Svg
         public:
 
         //! constructor
-        SvgConfiguration( QWidget* parent );
+        explicit SvgConfiguration( QWidget* parent );
 
         Q_SIGNALS:
 
         //! modified
-        void modified( void );
+        void modified();
 
     };
 
