@@ -25,12 +25,12 @@
 
 //_____________________________________________________
 //* default options installer
-void installSvgOptions( void )
+void installSvgOptions()
 {
     XmlOptions::get().setAutoDefault( true );
     XmlOptions::get().keep( "SVG_BACKGROUND" );
     XmlOptions::get().add( "SVG_BACKGROUND", Option( ":/svg/background-air.svgz" ) );
-    XmlOptions::get().add( "SVG_BACKGROUND", Option( ":/svg/background-dark.svgz", Option::Recordable|Option::Current ) );
+    XmlOptions::get().add( "SVG_BACKGROUND", Option( ":/svg/background-dark.svgz", Option::Flag::Recordable|Option::Flag::Current ) );
     XmlOptions::get().add( "SVG_BACKGROUND", Option( ":/svg/background-light.svgz" ) );
     XmlOptions::get().set<bool>( "USE_SVG", true );
     XmlOptions::get().set<bool>( "SVG_USE_PLASMA_INTERFACE", true );
