@@ -20,6 +20,7 @@
 #include "SvgPlasmaInterface.h"
 
 #include "Command.h"
+#include "CppUtil.h"
 #include "CustomProcess.h"
 #include "Debug.h"
 #include "SvgSystemOptions.h"
@@ -33,10 +34,39 @@ namespace Svg
 
     //_________________________________________________
     SvgPlasmaInterface::SvgPlasmaInterface( QObject* parent ):
-        QObject( parent ),
-        imagePath_( WidgetBackground )
+        QObject( parent )
     { installSvgSystemOptions(); }
 
+    //_________________________________________________
+    QPalette SvgPlasmaInterface::themePalette() const
+    {
+
+        QPalette out;
+
+        QSettings settings( themePaletteFilename_, QSettings::IniFormat );
+        settings.sync();
+
+        auto updateColor = [&out,&settings](QPalette::ColorRole role, QString name)
+        {
+            if( settings.contains( name ) )
+            {
+                auto rgb( settings.value( name ).toStringList() );
+                if( rgb.size() == 3 )
+                { out.setColor( role, QColor( rgb[0].toInt(), rgb[1].toInt(), rgb[2].toInt() ) ); }
+            }
+        };
+
+        updateColor( QPalette::WindowText, "Colors:Window/ForegroundNormal" );
+        updateColor( QPalette::Window, "Colors:Window/BackgroundNormal" );
+        updateColor( QPalette::Highlight, "Colors:Selection/BackgroundNormal" );
+        updateColor( QPalette::Text, "Colors:View/ForegroundNormal" );
+        updateColor( QPalette::Base, "Colors:View/BackgroundNormal" );
+        updateColor( QPalette::ButtonText, "Colors:Button/ForegroundNormal" );
+        updateColor( QPalette::Button, "Colors:Button/BackgroundNormal" );
+        return out;
+
+    }
+
     //_________________________________________________
     bool SvgPlasmaInterface::setImagePath( ImagePath id )
     {
@@ -46,25 +76,25 @@ namespace Svg
     }
 
     //_________________________________________________
-    bool SvgPlasmaInterface::loadTheme( void )
+    bool SvgPlasmaInterface::loadTheme()
     {
 
-        File::List configurationFiles;
+        Debug::Throw() << "Svg::SvgPlasmaInterface::loadTheme" << endl;
 
-        // TODO: use kde4-config to get the path of all config files
-        if( XmlOptions::get().contains( "KDE4_CONFIG" ) )
+        File::List configurationFiles;
+        if( XmlOptions::get().contains( "KDE_CONFIG" ) )
         {
 
             // get kde4 config command and retrieve output
-            const QString kde4ConfigCommand( XmlOptions::get().raw( "KDE4_CONFIG" ) );
+            const QString kdeConfigCommand( XmlOptions::get().raw( "KDE_CONFIG" ) );
 
             CustomProcess process( this );
-            process.start( Command( kde4ConfigCommand ) << "--path" << "config" );
+            process.start( Command( kdeConfigCommand ) << "--path" << "config" );
             if( process.waitForFinished() && process.exitStatus() == QProcess::NormalExit )
             {
-                const QStringList configurationPath = QString( process.readAllStandardOutput() ).trimmed().split( QRegExp(":") );
-                foreach( const QString& path, configurationPath )
-                { configurationFiles << File( "plasmarc" ).addPath( path ); }
+                auto configurationPath = QString( process.readAllStandardOutput() ).trimmed().split( ':' );
+                for( const auto& path:configurationPath )
+                { configurationFiles.append( File( "plasmarc" ).addPath( File( path ) ) ); }
 
             }
 
@@ -73,9 +103,8 @@ namespace Svg
         if( configurationFiles.isEmpty() )
         {
             // add some files manually in case the above failed
-            configurationFiles
-                << File( ".kde/share/config/plasmarc" ).addPath( Util::home() )
-                << File( ".kde4/share/config/plasmarc" ).addPath( Util::home() );
+            configurationFiles.append( File( ".kde/share/config/plasmarc" ).addPath( Util::home() ) );
+            configurationFiles.append( File( ".kde4/share/config/plasmarc" ).addPath( Util::home() ) );
         }
 
         // make sure fileSystemWatcher is valid
@@ -86,17 +115,17 @@ namespace Svg
         }
 
         // add valid configuration files to watcher
-        QStringList oldFiles( fileSystemWatcher_->files() );
-        foreach( const File& file, configurationFiles )
+        auto oldFiles( fileSystemWatcher_->files() );
+        for( const auto& file:configurationFiles )
         { if( file.exists() && !oldFiles.contains( file ) ) fileSystemWatcher_->addPath( file ); }
 
         // look for theme in selected configuration files
         QString theme( "default" );
-        foreach( const File& file, configurationFiles )
+        for( const auto& file:configurationFiles )
         {
             if( !file.exists() ) continue;
 
-            Debug::Throw() << "SvgPlasmaInterface::loadTheme - checking: " << file << endl;
+            Debug::Throw() << "Svg::SvgPlasmaInterface::loadTheme - checking: " << file << endl;
 
             // read group
             QSettings settings( file, QSettings::IniFormat );
@@ -109,15 +138,31 @@ namespace Svg
 
         }
 
-        Debug::Throw() << "SvgPlasmaInterface::loadTheme - using theme: " << theme << endl;
-        return _setTheme( theme );
+        Debug::Throw() << "Svg::SvgPlasmaInterface::loadTheme - using theme: " << theme << endl;
+
+        // reset colorFilename
+        auto oldThemePaletteFilename = themePaletteFilename_;
+        themePaletteFilename_.clear();
+
+        // assign theme
+        bool modified = _setTheme( theme );
+        Debug::Throw() << "Svg::SvgPlasmaInterface::loadTheme - using color scheme: " << themePaletteFilename_ << endl;
+
+        // set as modified if themePaletteFile has changed
+        modified |= (themePaletteFilename_ != oldThemePaletteFilename);
+        Debug::Throw() << "Svg::SvgPlasmaInterface::loadTheme - modified: " << modified << endl;
+
+        // return modified state
+        return modified;
 
     }
 
     //_________________________________________________
-    bool SvgPlasmaInterface::loadFile( void )
+    bool SvgPlasmaInterface::loadFile()
     {
 
+        Debug::Throw( "Svg::SvgPlasmaInterface::loadFile.\n" );
+
         // check path
         if( !path_.exists() ) return _setValid( false );
 
@@ -137,40 +182,48 @@ namespace Svg
     //_________________________________________________
     void SvgPlasmaInterface::_configurationFileChanged( const QString& file )
     {
+        Debug::Throw(0) << "Svg::SvgPlasmaInterface::_configurationFileChanged - file: " << file << endl;
+        if( !timer_.isActive() ) timer_.start( 100, this );
+    }
 
-        Debug::Throw() << "SvgPlasmaInterface::_configurationFileChanged - file: " << file << endl;
-        if( loadTheme() )
+    //_________________________________________________
+    void SvgPlasmaInterface::timerEvent( QTimerEvent* event )
+    {
+        if( event->timerId() == timer_.timerId() )
         {
-            loadFile();
+
+            Debug::Throw(0, "Svg::SvgPlasmaInterface::timerEvent.\n" );
+            timer_.stop();
             emit themeChanged();
-        }
+
+        } else return QObject::timerEvent( event );
     }
 
     //_________________________________________________
     bool SvgPlasmaInterface::_setTheme( const QString& theme )
     {
 
-        Debug::Throw() << "SvgPlasmaInterface::_setTheme - theme:" << theme << endl;
+        Debug::Throw() << "Svg::SvgPlasmaInterface::_setTheme - theme:" << theme << endl;
         File::List themePathList;
 
-        if( XmlOptions::get().contains( "KDE4_CONFIG" ) )
+        if( XmlOptions::get().contains( "KDE_CONFIG" ) )
         {
 
             // get kde4 config command and retrieve output
-            const QString kde4ConfigCommand( XmlOptions::get().raw( "KDE4_CONFIG" ) );
+            const QString kdeConfigCommand( XmlOptions::get().raw( "KDE_CONFIG" ) );
 
             CustomProcess process( this );
-            process.start( Command( kde4ConfigCommand ) << "--path" << "data" );
+            process.start( Command( kdeConfigCommand ) << "--path" << "data" );
             if( process.waitForFinished() && process.exitStatus() == QProcess::NormalExit )
             {
                 const QStringList configurationPath = QString( process.readAllStandardOutput() ).trimmed().split( QRegExp(":") );
 
                 #if QT_VERSION >= 0x050000
-                foreach( const QString& path, configurationPath )
-                { themePathList << File( theme ).addPath( File( "plasma/desktoptheme/" ).addPath( path ) ); }
+                for( const auto& path:configurationPath )
+                { themePathList.append( File( theme ).addPath( File( "plasma/desktoptheme/" ).addPath( File( path ) ) ) ); }
                 #else
-                foreach( const QString& path, configurationPath )
-                { themePathList << File( theme ).addPath( File( "desktoptheme/" ).addPath( path ) ); }
+                for( const auto& path:configurationPath )
+                { themePathList.append( File( theme ).addPath( File( "desktoptheme/" ).addPath( File( path ) ) ) ); }
                 #endif
 
             }
@@ -180,23 +233,32 @@ namespace Svg
         if( themePathList.empty() )
         {
             // add local path
-            QStringList localPath;
-            localPath
-                << ".kde/share/apps/desktoptheme/"
-                << ".kde4/share/apps/desktoptheme/";
-
-            foreach( const QString& pathName, localPath )
-            { themePathList << File( theme ).addPath( File( pathName ).addPath( Util::home() ) ); }
+            QStringList localPath = { ".kde/share/apps/desktoptheme/", ".kde4/share/apps/desktoptheme/" };
+            for( const auto& pathName:localPath )
+            { themePathList.append( File( theme ).addPath( File( pathName ).addPath( Util::home() ) ) ); }
 
         }
 
         // add local path
-        themePathList << File( theme ).addPath( File( "/usr/share/apps/desktoptheme/" ) );
-        foreach( const File& themePath, themePathList )
+        themePathList.append( File( theme ).addPath( File( "/usr/share/apps/desktoptheme/" ) ) );
+        for( const auto& themePath:themePathList )
         {
-            Debug::Throw() << "SvgPlasmaInterface::_setTheme - checking " << themePath << endl;
-            if( themePath.exists() && !_findImage( themePath, WidgetBackground ).isEmpty() )
-            { return _setPath( themePath ); }
+            Debug::Throw() << "Svg::SvgPlasmaInterface::_setTheme - checking " << themePath << endl;
+            if( themePath.exists() )
+            {
+
+                // try load color palette
+                if( themePaletteFilename_.isEmpty() )
+                {
+                    File file = File( "colors" ).addPath( themePath );
+                    if( file.exists() ) themePaletteFilename_ = file;
+                }
+
+                if( !_findImage( themePath, WidgetBackground ).isEmpty() )
+                { return _setPath( themePath ); }
+
+            }
+
         }
 
         // try use default theme
@@ -204,7 +266,7 @@ namespace Svg
         {
 
             bool changed( false );
-            changed |= _setPath( QString() );
+            changed |= _setPath( File() );
             changed |= _setValid( false );
             return changed;
 
@@ -212,6 +274,22 @@ namespace Svg
 
     }
 
+    //_________________________________________________
+    bool SvgPlasmaInterface::_setPath( const File& path )
+    {
+        if( path_ == path ) return false;
+        path_ = path;
+        return true;
+    }
+
+    //_________________________________________________
+    bool SvgPlasmaInterface::_setFileName( const File& file )
+    {
+        if( filename_ == file ) return false;
+        filename_ = file;
+        return true;
+    }
+
     //_________________________________________________
     File SvgPlasmaInterface::_imagePath( SvgPlasmaInterface::ImagePath id ) const
     {
@@ -233,13 +311,10 @@ namespace Svg
         if( !path.exists() ) return File();
 
         // build list of candidates
-        const File imagePath( _imagePath( id ) );
-        const File::List files = File::List()
-            << imagePath
-            << File( imagePath + ".svg" )
-            << File( imagePath + ".svgz" );
-        foreach( File file, files )
-        { if( (file = file.addPath( path ) ).exists() ) return file; }
+        auto imagePath( _imagePath( id ) );
+        auto files = { imagePath, File( imagePath + ".svg" ), File( imagePath + ".svgz" ) };
+        for( auto file:files )
+        { if( file.addPath( path ).exists() ) return file; }
 
         return File();
     }
