@@ -22,9 +22,12 @@
 
 #include "File.h"
 
-#include <QObject>
-#include <QString>
+#include <QBasicTimer>
 #include <QFileSystemWatcher>
+#include <QObject>
+#include <QPalette>
+#include <QString>
+#include <QTimerEvent>
 
 namespace Svg
 {
@@ -38,7 +41,10 @@ namespace Svg
     public:
 
     //* constructor
-    SvgPlasmaInterface( QObject* = nullptr );
+    explicit SvgPlasmaInterface( QObject* = nullptr );
+
+    //*@name accessors
+    //@{
 
     //* image path
     enum ImagePath
@@ -48,35 +54,54 @@ namespace Svg
         WidgetTranslucentBackground
     };
 
-    //* image path
-    bool setImagePath( ImagePath );
-
     //* validity
-    bool isValid( void ) const
+    bool isValid() const
     { return valid_; }
 
     //* filename
-    const QString& fileName( void ) const
+    QString fileName() const
     { return filename_; }
 
+    //* theme palette
+    bool hasThemePalette() const
+    { return !themePaletteFilename_.isEmpty() && themePaletteFilename_.exists(); }
+
+    //* theme palette
+    QPalette themePalette() const;
+
+    //@}}
+
+    //*@name modifiers
+    //@{
+
+    //* image path
+    bool setImagePath( ImagePath );
+
     //* get default theme from configuration file
     /** returns true if changed */
-    bool loadTheme( void );
+    bool loadTheme();
 
     //* load svg filename
     /** returns true if changed */
-    bool loadFile( void );
+    bool loadFile();
+
+    //@}
 
     Q_SIGNALS:
 
     //* emitted when svg file changed
     void themeChanged();
 
-    private Q_SLOTS:
+    protected Q_SLOTS:
 
-    //* connected to kde configuration file changed
+    //* configuration file modified
     void _configurationFileChanged( const QString& );
 
+    protected:
+
+    //* timer event
+    void timerEvent( QTimerEvent* ) override;
+
     private:
 
     //* validity
@@ -91,21 +116,11 @@ namespace Svg
     bool _setTheme( const QString& );
 
     //* set path matching theme
-    bool _setPath( const File& path )
-    {
-      if( path_ == path ) return false;
-      path_ = path;
-      return true;
-    }
+    bool _setPath( const File& );
 
     //* set filename
     /** returns true when changed */
-    bool _setFileName( const File& file )
-    {
-      if( filename_ == file ) return false;
-      filename_ = file;
-      return true;
-    }
+    bool _setFileName( const File& );
 
     //* return image path matching id
     File _imagePath( ImagePath ) const;
@@ -116,12 +131,15 @@ namespace Svg
     //* validity
     bool valid_ = false;
 
+    //* type of svg to be loaded
+    ImagePath imagePath_ = WidgetBackground;
+
     //* path to file name
     /** loaded from plasma configuration */
     File path_;
 
-    //* path to image (relative to path_)
-    ImagePath imagePath_;
+    //* theme color file name
+    File themePaletteFilename_;
 
     //* filename
     File filename_;
@@ -130,6 +148,9 @@ namespace Svg
     /** needed to track modifications of kde configuration file */
     QFileSystemWatcher* fileSystemWatcher_ = nullptr;
 
+    //* timer needed to prevent repeated calls to file change
+    QBasicTimer timer_;
+
   };
 };
 
