@@ -22,60 +22,17 @@
 #include "XmlOptions.h"
 
 #include <QPainter>
+#include <QDomDocument>
+
+#if WITH_ZLIB
+#include <zlib.h>
+#endif
 
 namespace Svg
 {
 
     //________________________________________________
-    SvgRenderer::SvgRenderer( void ):
-        QSvgRenderer(),
-        Counter( "Svg::SvgRendered" )
-    {}
-
-    //________________________________________________
-    bool SvgRenderer::load( const QString& filename )
-    {
-      bool loaded( QSvgRenderer::load( filename ) );
-      if( loaded )
-      {
-        isValid_ = _hasPrefix();
-        if( !_hasMargins() )
-        {
-            hasShadowMargins_ = _hasMargins( "shadow" );
-            hasShadowPrefix_ = _hasPrefix( "shadow", Ring );
-            hasShadow_ = hasShadowMargins_ && hasShadowPrefix_;
-        }
-
-        hasOverlay_ = elementExists( Svg::Overlay );
-
-        // centering hints
-        overlayHints_ = OverlayNone;
-        if( elementExists( "hint-overlay-pos-right" ) ) overlayHints_ |= OverlayPosRight;
-        if( elementExists( "hint-overlay-pos-bottom" ) ) overlayHints_ |= OverlayPosBottom;
-
-        if( elementExists( "hint-overlay-stretch") ) overlayHints_ |= OverlayStretch;
-        else if( elementExists( "hint-overlay-tile-horizontal" ) ) overlayHints_ |= OverlayTileHorizontal;
-        else if( elementExists( "hint-overlay-tile-vertical") ) overlayHints_ |= OverlayTileVertical;
-
-        hints_ = HintNone;
-        if( elementExists( "hint-compose-over-border" ) ) hints_ = HintComposeOverBorder;
-
-        if( _hasPrefix( "mask-overlay" ) ) maskPrefix_ = "mask-overlay";
-        else if( _hasPrefix( "mask" ) ) maskPrefix_ = "mask";
-        else maskPrefix_ = QString();
-
-      } else {
-
-        isValid_ = false;
-
-      }
-
-      return loaded;
-
-    }
-
-    //________________________________________________
-    bool SvgRenderer::updateConfiguration( void )
+    bool SvgRenderer::updateConfiguration()
     {
         bool drawOverlay( XmlOptions::get().get<bool>( "SVG_DRAW_OVERLAY" ) );
         if( drawOverlay == drawOverlay_ ) return false;
@@ -83,6 +40,51 @@ namespace Svg
         return true;
     }
 
+    //________________________________________________
+    bool SvgRenderer::load( const QString& filename )
+    {
+
+        // load filename directly
+        bool loaded( BaseSvgRenderer::load( filename ) );
+
+        if( loaded )
+        {
+            isValid_ = _hasPrefix();
+            if( !_hasMargins() )
+            {
+                hasShadowMargins_ = _hasMargins( "shadow" );
+                hasShadowPrefix_ = _hasPrefix( "shadow", Ring );
+                hasShadow_ = hasShadowMargins_ && hasShadowPrefix_;
+            }
+
+            hasOverlay_ = elementExists( Svg::Overlay );
+
+            // centering hints
+            overlayHints_ = OverlayNone;
+            if( elementExists( "hint-overlay-pos-right" ) ) overlayHints_ |= OverlayPosRight;
+            if( elementExists( "hint-overlay-pos-bottom" ) ) overlayHints_ |= OverlayPosBottom;
+
+            if( elementExists( "hint-overlay-stretch") ) overlayHints_ |= OverlayStretch;
+            else if( elementExists( "hint-overlay-tile-horizontal" ) ) overlayHints_ |= OverlayTileHorizontal;
+            else if( elementExists( "hint-overlay-tile-vertical") ) overlayHints_ |= OverlayTileVertical;
+
+            hints_ = HintNone;
+            if( elementExists( "hint-compose-over-border" ) ) hints_ = HintComposeOverBorder;
+
+            if( _hasPrefix( "mask-overlay" ) ) maskPrefix_ = "mask-overlay";
+            else if( _hasPrefix( "mask" ) ) maskPrefix_ = "mask";
+            else maskPrefix_ = QString();
+
+        } else {
+
+            isValid_ = false;
+
+        }
+
+        return loaded;
+
+    }
+
     //________________________________________________
     void SvgRenderer::render( QPaintDevice& device, const QString& id )
     {
@@ -98,7 +100,7 @@ namespace Svg
             double height = device.height();
 
             QPainter painter( &device );
-            QSvgRenderer::render( &painter, id, QRectF( QPointF( 0, 0 ), QSizeF( width, height ) ) );
+            BaseSvgRenderer::render( &painter, id, QRectF( QPointF( 0, 0 ), QSizeF( width, height ) ) );
 
         } else {
 
@@ -143,7 +145,7 @@ namespace Svg
         if( !prefix.isEmpty() ) prefix+="-";
 
         // check base class
-        if( !QSvgRenderer::isValid() ) return false;
+        if( !BaseSvgRenderer::isValid() ) return false;
 
         // make sure needed elements are present
         if( (mask & TopLeft) && !elementExists( prefix+Svg::TopLeft ) ) return false;
@@ -169,19 +171,19 @@ namespace Svg
         if( !prefix.isEmpty() ) prefix+="-";
 
         // check base class
-        if( !QSvgRenderer::isValid() ) return false;
+        if( !BaseSvgRenderer::isValid() ) return false;
 
         // make sure needed elements are present
-        if( (mask & Top) && !elementExists( prefix+Svg::MarginTop ) ) return false;
-        if( (mask & Left) && !elementExists( prefix+Svg::MarginLeft ) ) return false;
-        if( (mask & Right) && !elementExists( prefix+Svg::MarginRight ) ) return false;
-        if( (mask & Bottom) && !elementExists( prefix+Svg::MarginBottom ) ) return false;
+        if( (mask & Top) && !elementExists( prefix + Svg::MarginTop ) ) return false;
+        if( (mask & Left) && !elementExists( prefix + Svg::MarginLeft ) ) return false;
+        if( (mask & Right) && !elementExists( prefix + Svg::MarginRight ) ) return false;
+        if( (mask & Bottom) && !elementExists( prefix + Svg::MarginBottom ) ) return false;
         return true;
 
     }
 
     //________________________________________________
-    Base::Margins SvgRenderer::margins( void ) const
+    Base::Margins SvgRenderer::margins() const
     {
         Base::Margins out;
         if( elementExists( Svg::MarginLeft ) ) out.setLeft( boundsOnElement( Svg::MarginLeft ).width() );
@@ -196,7 +198,7 @@ namespace Svg
     }
 
     //________________________________________________
-    Base::Margins SvgRenderer::outerPadding( void ) const
+    Base::Margins SvgRenderer::outerPadding() const
     {
         Base::Margins out;
         if( hasShadowMargins_ )
@@ -252,7 +254,7 @@ namespace Svg
             if( overlayHints_ & OverlayPosRight ) overlayPainter.translate( device.width() - overlayRect.width(), 0 );
             if( overlayHints_ & OverlayPosBottom ) overlayPainter.translate( 0, device.height() - overlayRect.height() );
 
-            QSvgRenderer::render( &overlayPainter, Svg::Overlay, overlayRect );
+            BaseSvgRenderer::render( &overlayPainter, Svg::Overlay, overlayRect );
             overlayPainter.end();
 
             // draw on main painter
@@ -324,7 +326,7 @@ namespace Svg
 
         // center
         if( centerRect.isValid() && elements & Center )
-        { QSvgRenderer::render( &painter, prefix+Svg::Center, centerRect ); }
+        { BaseSvgRenderer::render( &painter, prefix+Svg::Center, centerRect ); }
 
         if( padding )
         {
@@ -333,14 +335,14 @@ namespace Svg
             {
                 // topLeft corner
                 painter.setClipRect( QRect( targetRect.topLeft(), targetRect.center() ) );
-                QSvgRenderer::render( &painter, prefix+Svg::TopLeft, QRectF( QPointF( 0, 0 ), boundsOnElement( prefix+Svg::TopLeft ).size() ) );
+                BaseSvgRenderer::render( &painter, prefix+Svg::TopLeft, QRectF( QPointF( 0, 0 ), boundsOnElement( prefix+Svg::TopLeft ).size() ) );
             }
 
             if( elements & TopRight )
             {
                 // topRight corner
                 painter.setClipRect( QRect( QPoint(  targetRect.center().x()+1, targetRect.top() ), QPoint( targetRect.right(), targetRect.center().y() ) ) );
-                QSvgRenderer::render( &painter, prefix+Svg::TopRight, QRectF( QPointF( centerRect.right(), 0 ), boundsOnElement( prefix+Svg::TopRight ).size() ) );
+                BaseSvgRenderer::render( &painter, prefix+Svg::TopRight, QRectF( QPointF( centerRect.right(), 0 ), boundsOnElement( prefix+Svg::TopRight ).size() ) );
             }
 
             if( elements & BottomLeft )
@@ -348,14 +350,14 @@ namespace Svg
 
                 // topRight corner
                 painter.setClipRect( QRect( QPoint(  targetRect.left(), targetRect.center().y()+1 ), QPoint( targetRect.center().x(), targetRect.bottom() ) ) );
-                QSvgRenderer::render( &painter, prefix+Svg::BottomLeft, QRectF( QPointF( 0, centerRect.bottom() ), boundsOnElement( prefix+Svg::BottomRight ).size() ) );
+                BaseSvgRenderer::render( &painter, prefix+Svg::BottomLeft, QRectF( QPointF( 0, centerRect.bottom() ), boundsOnElement( prefix+Svg::BottomRight ).size() ) );
             }
 
             if( elements & BottomRight )
             {
                 // bottomRight corner
                 painter.setClipRect( QRect( targetRect.center()+QPoint( 1, 1 ), targetRect.bottomRight() ) );
-                QSvgRenderer::render( &painter, prefix+Svg::BottomRight, QRectF( centerRect.bottomRight(), boundsOnElement( prefix+Svg::BottomRight ).size() ) );
+                BaseSvgRenderer::render( &painter, prefix+Svg::BottomRight, QRectF( centerRect.bottomRight(), boundsOnElement( prefix+Svg::BottomRight ).size() ) );
             }
 
             if( centerRect.width() > 0 )
@@ -365,14 +367,14 @@ namespace Svg
                 {
                     // top size
                     painter.setClipRect( QRect( targetRect.topLeft(), QPoint( targetRect.right(), targetRect.center().y() ) ) );
-                    QSvgRenderer::render( &painter, prefix+Svg::Top, QRectF( QPointF( centerRect.left(), 0 ), QSizeF( centerRect.width(), boundsOnElement( prefix+Svg::Top ).height() ) ) );
+                    BaseSvgRenderer::render( &painter, prefix+Svg::Top, QRectF( QPointF( centerRect.left(), 0 ), QSizeF( centerRect.width(), boundsOnElement( prefix+Svg::Top ).height() ) ) );
                 }
 
                 if( elements & Bottom )
                 {
                     // bottom size
                     painter.setClipRect( QRect( QPoint( targetRect.left(), targetRect.center().y()+1 ), targetRect.bottomRight() ) );
-                    QSvgRenderer::render( &painter, prefix+Svg::Bottom, QRectF( centerRect.bottomLeft(), QSizeF( centerRect.width(), boundsOnElement( prefix+Svg::Bottom ).height() ) ) );
+                    BaseSvgRenderer::render( &painter, prefix+Svg::Bottom, QRectF( centerRect.bottomLeft(), QSizeF( centerRect.width(), boundsOnElement( prefix+Svg::Bottom ).height() ) ) );
                 }
 
             }
@@ -384,13 +386,13 @@ namespace Svg
                 {
                     // left side
                     painter.setClipRect( QRect( targetRect.topLeft(), QPoint( targetRect.center().x(), targetRect.bottom() ) ) );
-                    QSvgRenderer::render( &painter, prefix+Svg::Left, QRectF( QPointF( 0, centerRect.top() ), QSizeF( boundsOnElement( prefix+Svg::Left ).width(), centerRect.height() ) ) );
+                    BaseSvgRenderer::render( &painter, prefix+Svg::Left, QRectF( QPointF( 0, centerRect.top() ), QSizeF( boundsOnElement( prefix+Svg::Left ).width(), centerRect.height() ) ) );
                 }
 
                 if( elements & Right )
                 {
                     painter.setClipRect( QRect( QPoint( targetRect.center().x()+1, targetRect.top() ), targetRect.bottomRight() ) );
-                    QSvgRenderer::render( &painter, prefix+Svg::Right, QRectF( centerRect.topRight(), QSizeF( boundsOnElement( prefix+Svg::Right ).width(), centerRect.height() ) ) );
+                    BaseSvgRenderer::render( &painter, prefix+Svg::Right, QRectF( centerRect.topRight(), QSizeF( boundsOnElement( prefix+Svg::Right ).width(), centerRect.height() ) ) );
                 }
 
             }
