@@ -20,41 +20,25 @@
 *
 *******************************************************************************/
 
-#include "Counter.h"
+#include "BaseSvgRenderer.h"
 #include "Margins.h"
 
-#include <QSvgRenderer>
+#include <QByteArray>
+#include <QIODevice>
 #include <QPaintDevice>
+#include <QPalette>
 
 //* construct pixmap of given size using Svg renderer
 namespace Svg
 {
-    class SvgRenderer: public QSvgRenderer, public Counter
+    class SvgRenderer: public BaseSvgRenderer
     {
 
         public:
 
         //* constructor
-        SvgRenderer( void );
-
-        //* render
-        void render( QPaintDevice&, const QString& id = QString() );
-
-        //* validity
-        virtual bool isValid( void ) const
-        { return isValid_; }
-
-        //* configuration
-        bool updateConfiguration( void );
-
-        //* load file
-        virtual bool load( const QString& );
-
-        //* margins
-        Base::Margins margins( void ) const;
-
-        //* outer padding
-        Base::Margins outerPadding( void ) const;
+        explicit SvgRenderer()
+        {}
 
         // svg element enumeration
         enum SvgElement
@@ -74,6 +58,35 @@ namespace Svg
 
         Q_DECLARE_FLAGS( SvgElements, SvgElement );
 
+        //*@name accessors
+        //@{
+
+        //* validity
+        bool isValid() const
+        { return isValid_; }
+
+        //* margins
+        Base::Margins margins() const;
+
+        //* outer padding
+        Base::Margins outerPadding() const;
+
+        //@}
+
+        //*@name modifiers
+        //@{
+
+        //* configuration
+        bool updateConfiguration();
+
+        //* load file
+        bool load( const QString& ) override;
+
+        //* render
+        void render( QPaintDevice&, const QString& id = QString() );
+
+        //@}
+
         protected:
 
         //* true if svg has all elements matching prefix
@@ -126,7 +139,8 @@ namespace Svg
         OverlayHints overlayHints_ = OverlayNone;
 
         //* painting hints
-        enum Hint {
+        enum Hint
+        {
             HintNone,
             HintComposeOverBorder,
         };
