@@ -30,7 +30,7 @@ namespace Transparency
 {
 
     //_______________________________________________________________
-    CompositeEngine& CompositeEngine::get( void )
+    CompositeEngine& CompositeEngine::get()
     {
 
         //! singleton
@@ -40,13 +40,13 @@ namespace Transparency
     }
 
     //_______________________________________________________________
-    CompositeEngine::CompositeEngine( void ):
+    CompositeEngine::CompositeEngine():
         available_( false ),
         initialized_( false )
     { Debug::Throw( "CompositeEngine::CompositeEngine.\n" ); }
 
     //_______________________________________________________________
-    void CompositeEngine::_initialize( void )
+    void CompositeEngine::_initialize()
     {
 
         Debug::Throw( "CompositeEngine::initialize\n" );
@@ -58,7 +58,7 @@ namespace Transparency
     }
 
     //_______________________________________________________________
-    bool CompositeEngine::_compositingAvailable( void ) const
+    bool CompositeEngine::_compositingAvailable() const
     {
         Debug::Throw( "CompositeEngine::_compositingAvailable\n" );
 
@@ -67,6 +67,9 @@ namespace Transparency
         #endif
 
         #if HAVE_XCB
+
+        if( !XcbUtil::isX11() ) return false;
+
         // connection
         xcb_connection_t* connection( XcbUtil::get().connection<xcb_connection_t>() );
 
