@@ -25,23 +25,59 @@
 
 #include <QStringList>
 
-class CommandLineArguments: public QStringList, public Counter
+class CommandLineArguments: private Base::Counter<CommandLineArguments>
 {
 
     public:
 
     //* constructor
-    CommandLineArguments( int argc = 0, char* argv[] = nullptr );
+    explicit CommandLineArguments( int argc = 0, char* argv[] = nullptr );
 
     //* constructor
-    CommandLineArguments( const QStringList& );
+    explicit CommandLineArguments( const QStringList& );
 
-    //* return arg counts
-    int argc( void ) const
-    { return size(); }
+    //* constructor
+    explicit CommandLineArguments( QStringList&& );
 
-    //* return argv
-    char** argv( void ) const;
+    //* destructor
+    virtual ~CommandLineArguments() = default;
+
+    //*@name accessors
+    //@{
+
+    const QStringList& get() const { return arguments_; }
+
+    //* empty
+    bool isEmpty() const { return arguments_.isEmpty(); }
+
+    //* size
+    int size() const { return arguments_.size(); }
+
+    const QString& operator[] (int i) const { return arguments_[i]; }
+
+    //@}
+
+    //*@name modifiers
+    //@{
+
+    QStringList& get() { return arguments_; }
+
+    //* append
+    void append( const QString& str ) { arguments_.append(str); }
+
+    //* streamers
+    template<class T>
+    CommandLineArguments & operator<< ( const T& t )
+    {
+        arguments_ << t;
+        return *this;
+    }
+
+    //@}
+
+    private:
+
+    QStringList arguments_;
 
 };
 
