@@ -29,13 +29,16 @@
 #include <QMap>
 
 //* parse command line argument.
-class CommandLineParser: public Counter
+class CommandLineParser: private Base::Counter<CommandLineParser>
 {
 
     public:
 
     //* constructor
-    CommandLineParser( void );
+    explicit CommandLineParser();
+
+    //* destructor
+    virtual ~CommandLineParser() = default;
 
     //*@name default group names
     //@{
@@ -45,7 +48,7 @@ class CommandLineParser: public Counter
     //@}
 
     //* used to register options/flags
-    class Tag: public Counter
+    class Tag: private Base::Counter<Tag>
     {
 
         public:
@@ -57,45 +60,23 @@ class CommandLineParser: public Counter
             shortName_( shortName )
         {}
 
-        //* equal to operator
-        bool operator == (const Tag& other ) const
-        {
-            if( shortName_.isNull() ) return longName_ == other.longName_ || longName_ == other.shortName_;
-            else if( other.shortName_.isNull() ) return longName_ == other.longName_ || shortName_ == other.longName_;
-            else return longName_ == other.longName_ && shortName_ == other.shortName_;
-        }
-
-        //* less than operator
-        bool operator < (const Tag& other ) const
-        {
-            if( shortName_.isNull() )
-            {
-                if( other.shortName_.isNull() ) return longName_ < other.longName_;
-                else return false;
-            } else {
-                if( other.shortName_.isNull() ) return true;
-                else if( shortName_ != other.shortName_ ) return shortName_ < other.shortName_;
-                else return  longName_ < other.longName_;
-            }
-        }
-
         //*@name accessors
         //@{
 
         //* long name
-        const QString& longName( void ) const
+        const QString& longName() const
         { return longName_; }
 
         //* short name
-        const QString& shortName( void ) const
+        const QString& shortName() const
         { return shortName_; }
 
         //* convert to string
-        QString toString( void ) const
+        QString toString() const
         { return shortName_.isNull() ? longName_:(shortName_+", "+longName_); }
 
         //* size
-        int size( void ) const
+        int size() const
         { return toString().size(); }
 
         using List = QList<Tag>;
@@ -105,19 +86,41 @@ class CommandLineParser: public Counter
         QString longName_;
         QString shortName_;
 
+        //* equal to operator
+        friend bool operator == (const Tag& first, const Tag& second )
+        {
+            if( first.shortName_.isNull() ) return first.longName_ == second.longName_ || first.longName_ == second.shortName_;
+            else if( second.shortName_.isNull() ) return first.longName_ == second.longName_ || first.shortName_ == second.longName_;
+            else return first.longName_ == second.longName_ && first.shortName_ == second.shortName_;
+        }
+
+        //* less than operator
+        friend bool operator < (const Tag& first, const Tag& second)
+        {
+            if( first.shortName_.isNull() )
+            {
+                if( second.shortName_.isNull() ) return first.longName_ < second.longName_;
+                else return false;
+            } else {
+                if( second.shortName_.isNull() ) return true;
+                else if( first.shortName_ != second.shortName_ ) return first.shortName_ < second.shortName_;
+                else return  first.longName_ < second.longName_;
+            }
+        }
+
     };
 
     //* accessors
     //@{
 
     //* print help
-    void usage( void ) const;
+    void usage() const;
 
     //* return 'rectified' arguments
-    CommandLineArguments arguments( void ) const;
+    CommandLineArguments arguments() const;
 
     //* application name
-    QString applicationName( void ) const
+    QString applicationName() const
     { return applicationName_; }
 
     //* return true if flag is on
@@ -131,7 +134,7 @@ class CommandLineParser: public Counter
 
     //* orphans
     /** list of command line arguments located at the end of the list and that do not match any option */
-    const QStringList& orphans( void ) const
+    const QStringList& orphans() const
     { return orphans_; }
 
     //@}
@@ -165,11 +168,11 @@ class CommandLineParser: public Counter
     CommandLineParser& parse( const CommandLineArguments&, bool ignoreWarnings = true );
 
     //* clear
-    void clear( void );
+    void clear();
 
     //* orphans
     /** list of command line arguments located at the end of the list and that do not match any option */
-    QStringList& orphans( void )
+    QStringList& orphans()
     { return orphans_; }
 
     //@}
@@ -183,17 +186,20 @@ class CommandLineParser: public Counter
     bool _isTag( const QString& ) const;
 
     //* flag class
-    class Flag: public Counter
+    class Flag: private Base::Counter<Flag>
     {
 
         public:
 
         //* constructor
-        Flag( QString helpText = QString() ):
+        explicit Flag( QString helpText = QString() ):
             Counter( "CommandLineParser::Flag" ),
             helpText_( helpText )
         {}
 
+        //* destructor
+        virtual ~Flag() = default;
+
         //* help text
         QString helpText_;
 
@@ -209,7 +215,7 @@ class CommandLineParser: public Counter
         public:
 
         //* constructor
-        Option( QString type = QString(), QString helpText = QString() ):
+        explicit Option( QString type = QString(), QString helpText = QString() ):
             Flag( helpText ),
             type_( type )
         {}
@@ -253,7 +259,7 @@ class CommandLineParser: public Counter
         public:
 
         //* constructor
-        SameTagFTor( const QString& tag ):
+        explicit SameTagFTor( const QString& tag ):
             tag_( tag )
             {}
 
@@ -274,7 +280,7 @@ class CommandLineParser: public Counter
         public:
 
         //* clear
-        void clear( void );
+        void clear();
 
         using Map = QHash< QString, Group>;
 
@@ -293,10 +299,10 @@ class CommandLineParser: public Counter
     };
 
     //* return all flags
-    Group::FlagMap _allFlags( void ) const;
+    Group::FlagMap _allFlags() const;
 
     //* return all options
-    Group::OptionMap _allOptions( void ) const;
+    Group::OptionMap _allOptions() const;
 
     //* find tag in list of flags
     Group::FlagMap::iterator _findTag( Group::FlagMap&, const QString& ) const;
