@@ -20,34 +20,48 @@
 *
 *******************************************************************************/
 
+#include "CounterMap.h"
+
 #include <QString>
-#include <QPair>
 
-//* Object counter
-class Counter {
+namespace Base
+{
+    template<typename T>
+    class Counter
+    {
 
-    public:
+        public:
 
-    //* counter name and counts pair
-    using Pair = QPair<QString, int>;
+        //* construtor
+        explicit Counter( QString name )
+        {
+            if( !initialized )
+            {
+                initialized = true;
+                Base::CounterMap::get().insert( name, &count );
+            }
 
-    //* constructor
-    Counter( const QString& name );
+            count++;
+        }
 
-    //* constructor
-    Counter( const Counter& counter );
+        //* copy constructor
+        explicit Counter(const Counter& other )
+        { count++; }
 
-    //* destructor
-    virtual ~Counter( void );
+        //* destructor
+        ~Counter()
+        { count--; }
 
-    //* retrieves counter count
-    int count( void ) const;
+        private:
 
-    private:
+        //* count
+        static bool initialized;
+        static int count;
+    };
 
-    //* pointer to integer counter
-    int* count_ = nullptr;
+}
 
-};
+template <typename T> bool Base::Counter<T>::initialized( false );
+template <typename T> int Base::Counter<T>::count( 0 );
 
 #endif
