@@ -27,11 +27,11 @@
 #include "TimeStamp.h"
 
 #include <QList>
-#include <QMap>
+#include <QHash>
 #include <QStringList>
 
 //* handles previously opened file and tags
-class FileRecord: public Counter
+class FileRecord: private Base::Counter<FileRecord>
 {
 
     public:
@@ -45,107 +45,47 @@ class FileRecord: public Counter
     static const QString MimeType;
 
     //* constructor
-    FileRecord( const File& file = File(""), const TimeStamp& time = TimeStamp::now() ):
+    explicit FileRecord( const File& file = File(), const TimeStamp& time = TimeStamp::now() ):
         Counter( "FileRecord" ),
         file_( file ),
         time_( time ),
         valid_( true )
     {}
 
-    //* less than operator
-    bool operator < (const FileRecord& record ) const;
+    //* constructor
+    explicit FileRecord( File&& file, const TimeStamp& time = TimeStamp::now() ):
+        Counter( "FileRecord" ),
+        file_( std::move(file) ),
+        time_( time ),
+        valid_( true )
+    {}
 
-    //* less than operator
-    bool operator == (const FileRecord& record ) const;
+    //* destructor
+    virtual ~FileRecord() = default;
 
-    //* file
-    const File& file( void ) const
-    { return file_; }
-
-    //* file
-    FileRecord& setFile( const QString& file )
-    {
-        file_ = file;
-        return *this;
-    }
-
-    //* time stamp
-    const int& time( void ) const
-    { return time_; }
-
-    //* time stamp
-    FileRecord& setTime( const TimeStamp& time )
-    {
-        time_ = time;
-        return *this;
-    }
-
-    //*@name flags
+    //*@name accessors
     //@{
 
-    //* flags
-    FileRecord& setFlags( unsigned int value )
-    {
-        flags_ = value;
-        return *this;
-    }
+    //* file
+    const File& file() const { return file_; }
+
+    //* time stamp
+    const TimeStamp& time() const
+    { return time_; }
 
     //* flags
-    FileRecord& setFlag( unsigned int flag, bool value = true )
-    {
-        if( value ) { flags_ |= flag; }
-        else { flags_ &= (~flag); }
-        return *this;
-    }
-
-    //* flags
-    const unsigned int& flags( void ) const
+    int flags() const
     { return flags_; }
 
     //* flags
-    bool hasFlag( const unsigned int& flag ) const
+    bool hasFlag( int flag ) const
     { return flags_ & flag; }
 
-    //* used to retrieve file records that match a given flag
-    class HasFlagFTor
-    {
-
-        public:
-
-        //* constructor
-        HasFlagFTor( const unsigned int& flag ):
-            flag_( flag )
-         {}
-
-        //* predicate
-        bool operator() ( const FileRecord& record ) const
-        { return record.hasFlag( flag_ ); }
-
-        private:
-
-        // predicted flag
-        unsigned int flag_;
-
-    };
-
-    //@}
-
     //* validity
-    bool isValid( void ) const
+    bool isValid() const
     { return valid_; }
 
-    //* validity
-    FileRecord& setValid( bool valid )
-    {
-        valid_ = valid;
-        return *this;
-    }
-
-
-    //*@name properties
-    //@{
-
-    //* map string to unsigned int property ID
+    //* map string to property ID
     class PropertyId
     {
 
@@ -155,7 +95,7 @@ class FileRecord: public Counter
 
         //* get id matching name
         /** insert in map if name is new */
-        static Id get( QString name );
+        static Id get( QString );
 
         //* get name matching id
         /** throw exception if not found */
@@ -164,10 +104,10 @@ class FileRecord: public Counter
         private:
 
         //* counter
-        static Id& _counter( void );
+        static Id& _counter();
 
         //* id map
-        using IdMap = QMap< QString, Id >;
+        using IdMap = QHash< QString, Id >;
 
         //* id map
         static IdMap& _idMap();
@@ -180,13 +120,6 @@ class FileRecord: public Counter
 
     };
 
-    //* add property
-    FileRecord& addProperty( QString tag, QString value )
-    { return addProperty( PropertyId::get( tag ), value ); }
-
-    //* add property
-    FileRecord& addProperty( PropertyId::Id, QString );
-
     //* true if property is available
     bool hasProperty( QString tag ) const
     { return hasProperty( PropertyId::get( tag ) ); }
@@ -196,10 +129,10 @@ class FileRecord: public Counter
     { return properties_.find( id ) != properties_.end(); }
 
     //* additional property map
-    using PropertyMap = QMap< PropertyId::Id, QString >;
+    using PropertyMap = QHash< PropertyId::Id, QString >;
 
     //* property map
-    const PropertyMap& properties( void ) const
+    const PropertyMap& properties() const
     { return properties_; }
 
     //* retrieve property
@@ -215,6 +148,76 @@ class FileRecord: public Counter
 
     //@}
 
+    //*@name modifiers
+    //@{
+
+    //* file
+    FileRecord& setFile( const File& file )
+    {
+        file_ = file;
+        return *this;
+    }
+
+    //* time stamp
+    FileRecord& setTime( const TimeStamp& time )
+    {
+        time_ = time;
+        return *this;
+    }
+
+    //* flags
+    FileRecord& setFlags( int value )
+    {
+        flags_ = value;
+        return *this;
+    }
+
+    //* flags
+    FileRecord& setFlag( int flag, bool value = true )
+    {
+        if( value ) { flags_ |= flag; }
+        else { flags_ &= (~flag); }
+        return *this;
+    }
+
+    //* validity
+    FileRecord& setValid( bool valid )
+    {
+        valid_ = valid;
+        return *this;
+    }
+
+    //* add property
+    FileRecord& addProperty( QString tag, QString value )
+    { return addProperty( PropertyId::get( tag ), value ); }
+
+    //* add property
+    FileRecord& addProperty( PropertyId::Id, QString );
+
+    //@}
+
+    //* used to retrieve file records that match a given flag
+    class HasFlagFTor
+    {
+
+        public:
+
+        //* constructor
+        explicit HasFlagFTor( int flag ):
+            flag_( flag )
+         {}
+
+        //* predicate
+        bool operator() ( const FileRecord& record ) const
+        { return record.hasFlag( flag_ ); }
+
+        private:
+
+        // predicted flag
+        int flag_;
+
+    };
+
     //* used to sort records according to files
     class FileFTor
     {
@@ -234,12 +237,12 @@ class FileRecord: public Counter
         public:
 
         //* constructor
-        SameFileFTor( const File& file = File("") ):
+        explicit SameFileFTor( const File& file = File("") ):
             file_( file )
         {}
 
         //* constructor
-        SameFileFTor( const FileRecord& record ):
+        explicit SameFileFTor( const FileRecord& record ):
             file_( record.file() )
         {}
 
@@ -278,12 +281,12 @@ class FileRecord: public Counter
         public:
 
         //* constructor
-        SameCanonicalFileFTor( const File& file = File("") ):
+        explicit SameCanonicalFileFTor( const File& file = File("") ):
             file_( file.canonicalName() )
         {}
 
         //* constructor
-        SameCanonicalFileFTor( const FileRecord& record ):
+        explicit SameCanonicalFileFTor( const FileRecord& record ):
             file_( record.file().canonicalName() )
         {}
 
@@ -345,10 +348,10 @@ class FileRecord: public Counter
     PropertyMap properties_;
 
     //* time
-    int time_ = 0;
+    TimeStamp time_;
 
     //* flags
-    unsigned int flags_ = 0;
+    int flags_ = 0;
 
     //* file validity (true if file exists)
     bool valid_ = false;
@@ -362,6 +365,12 @@ class FileRecord: public Counter
         return out;
     }
 
+    //* less than operator
+    friend bool operator < (const FileRecord&, const FileRecord& );
+
+    //* less than operator
+    friend bool operator == (const FileRecord&, const FileRecord& );
+
 };
 
 #endif
