@@ -34,7 +34,7 @@ namespace Base
         public:
 
         //* constructor
-        Key( void ):
+        explicit Key():
             key_( _counter()++ )
         {}
 
@@ -45,65 +45,20 @@ namespace Base
         The new key gets a new unique id. It gets associated to all objects
         in the list
         */
-        Key( const Key& key ):
+        explicit Key( const Key& key ):
             key_( _counter()++ ),
             associatedKeys_( key.associatedKeys_ )
         {
-            foreach( Key* associate, associatedKeys_ )
+            for( const auto& associate:associatedKeys_ )
             { associate->_associate( this ); }
         }
 
         //* destructor
-        virtual ~Key( void )
-        { clearAssociations(); }
-
-        //* equal to operator
-        bool operator == (const Key& key ) const
-        { return this->key() == key.key(); }
-
-        //* lower than operator
-        bool operator < (const Key& key ) const
-        { return this->key() < key.key(); }
+        inline virtual ~Key() = 0;
 
         //* shortcut for key unique id
         using Type = quint32;
 
-        //* retrieve key
-        virtual const Type& key( void ) const
-        { return key_; }
-
-        //* shortcut for set of Key
-        using Set = QSet< Key* >;
-
-        //* retrieve all associated keys
-        const Set& getAssociated( void ) const
-        { return associatedKeys_; }
-
-        //* clear associations for this key
-        void clearAssociations( void )
-        {
-            foreach( Key* key, associatedKeys_ ) key->_disassociate( this );
-            associatedKeys_.clear();
-        }
-
-        //* clear associations of a given type for this key
-        template<typename T> inline void clearAssociations( void );
-
-        //* associated two Keys
-        static void associate( Key* first, Key* second )
-        {
-            Q_ASSERT( first->key() != second->key() );
-            first->_associate( second );
-            second->_associate( first );
-        }
-
-        //* associated two Keys
-        static void associate( Key& first, Key& second )
-        {
-            Q_ASSERT( first.key() != second.key() );
-            first._associate( &second );
-            second._associate( &first );
-        }
 
         //* used to find keys of matching id
         class SameKeyFTor
@@ -112,7 +67,7 @@ namespace Base
             public:
 
             //* constructor
-            SameKeyFTor( const Type& key ):
+            explicit SameKeyFTor( Type key ):
                 key_( key )
             {}
 
@@ -134,7 +89,7 @@ namespace Base
             public:
 
             //* constructor
-            IsAssociatedFTor( const Key* key ):
+            explicit IsAssociatedFTor( const Key* key ):
                 key_( key )
             {}
 
@@ -149,6 +104,19 @@ namespace Base
 
         };
 
+        //*@name accessors
+        //@{
+
+        //* retrieve key
+        Type key() const
+        { return key_; }
+
+        //* shortcut for set of Key
+        using Set = QSet< Key* >;
+
+        //* retrieve all associated keys
+        const Set& associatedKeys() const
+        { return associatedKeys_; }
 
         //* return true if keys are associated
         bool isAssociated( const Key* key ) const
@@ -159,6 +127,49 @@ namespace Base
                 SameKeyFTor( key->key() ) ) != associatedKeys_.end();
         }
 
+        //*@}
+
+        //*@name modifiers
+        //@{
+
+        //* clear associations for this key
+        void clearAssociations()
+        {
+            for( const auto& key:associatedKeys_ )
+            { key->_disassociate( this ); }
+            associatedKeys_.clear();
+        }
+
+        //* clear associations of a given type for this key
+        template<typename T> inline void clearAssociations();
+
+        //* remove all associated keys
+        /** warning: this is non reflexive, unlike clear associations */
+        void removeAssociatedKeys()
+        { associatedKeys_.clear(); }
+
+        //* remove all associated keys of a given type
+        /** warning: this is non reflexive, unlike clear associations */
+        template<typename T> inline void removeAssociatedKeys();
+
+        //* associated two Keys
+        static void associate( Key* first, Key* second )
+        {
+            Q_ASSERT( first->key() != second->key() );
+            first->_associate( second );
+            second->_associate( first );
+        }
+
+        //* associated two Keys
+        static void associate( Key& first, Key& second )
+        {
+            if( first.key() != second.key() )
+            {
+                first._associate( &second );
+                second._associate( &first );
+            }
+        }
+
         //* disassociate two Keys
         static void disassociate( Key* first, Key* second )
         {
@@ -173,6 +184,8 @@ namespace Base
             second._disassociate( &first );
         }
 
+        //@}
+
         private:
 
         //* add a key to associates
@@ -190,7 +203,7 @@ namespace Base
         Set associatedKeys_;
 
         //* unique id counter
-        static Type& _counter( void );
+        static Type& _counter();
 
         //* to dump Key and associations
         friend QTextStream &operator << (QTextStream &out,const Key &key)
@@ -204,7 +217,7 @@ namespace Base
             {
                 out << " associations:";
 
-                foreach( Key* associate, key.associatedKeys_ )
+                for( const auto& associate:key.associatedKeys_ )
                 { out << " " << associate->key(); }
 
             }
@@ -216,31 +229,35 @@ namespace Base
     };
 
     /** \brief
-    templatized sorted set of casted keys.
+    templatized unsorted set of casted keys.
     Is constructed from a pointer to a Key;
     Contains all objects of type T associated to the Key.
     */
     template<typename T>
-    class KeySet: public QSet< T* >
+    class KeySet final
     {
 
+        private:
+
+        QSet<T*> set_;
+
         public:
 
         //* default constructor
-        KeySet( void )
+        explicit KeySet()
         {}
 
         /**
         \brief constructor
         fill the set with all objects of type T associated with the key
         */
-        KeySet( const Key* key )
+        explicit KeySet( const Key* key )
         {
 
-            foreach( Key* associate, key->getAssociated() )
+            for( const auto& associate:key->associatedKeys() )
             {
-                T* t( dynamic_cast<T*>( associate ) );
-                if( t ) this->insert( t );
+                auto t( dynamic_cast<T*>( associate ) );
+                if(t) set_.insert(t);
             }
 
         }
@@ -249,53 +266,97 @@ namespace Base
         \brief constructor
         fill the set with all objects of type T associated with the key
         */
-        KeySet( const Key& key )
+        explicit KeySet( const Key& key )
         {
 
-            foreach( Key* associate, key.getAssociated() )
+            for( const auto& associate:key.associatedKeys() )
             {
-                T* t( dynamic_cast<T*>( associate ) );
-                if( t ) this->insert( t );
+                auto t( dynamic_cast<T*>( associate ) );
+                if(t) set_.insert(t);
             }
 
         }
 
-        //* Merge argument KeySet with this one
-        void merge( const KeySet<T>& keySet )
+        //*@name accessors
+        //@{
+
+        using iterator = typename QSet<T*>::iterator;
+        using const_iterator = typename QSet<T*>::const_iterator;
+
+        const_iterator begin() const { return set_.begin(); }
+        const_iterator end() const { return set_.end(); }
+
+        iterator begin() { return set_.begin(); }
+        iterator end() { return set_.end(); }
+
+        const QSet<T*>& get() const { return set_; }
+
+        int size() const { return set_.size(); }
+        bool empty() const { return set_.empty(); }
+
+        QList<T*> toList() const { return set_.toList(); }
+
+        //@}
+
+        //*@name modifiers
+        //@{
+
+        //* mutable accessor
+        QSet<T*>& get() { return set_; }
+
+        //* insert
+        /** needs decltype because return type ofr set_.insert has changed with qt version */
+        auto insert( T* t ) -> decltype(set_.insert( t ))
+        { return set_.insert( t ); }
+
+        //* remove
+        bool remove( T* t ) { return set_.remove( t ); }
+
+        //* find
+        iterator find( T* t ) { return set_.find( t ); }
+
+        //* unite too keysets
+        KeySet& unite( const KeySet& other )
         {
-            foreach( T* key, keySet )
-            { this->insert( key ); }
+            set_.unite( other.set_ );
+            return *this;
         }
 
+        //@}
+
     };
 
-    /** \brief
-    templatized sorted set of casted keys.
-    Is constructed from a pointer to a Key;
-    Contains all objects of type T associated to the Key.
-    */
     template<typename T>
-    class KeySetIterator: public QSetIterator< T* >
+    using KeySetIterator = QSetIterator<T*>;
+
+    //* equal to operator
+    inline bool operator == (const Key& first, const Key& second )
+    { return first.key() == second.key(); }
+
+    //* lower than operator
+    inline bool operator < (const Key& first, const Key& second )
+    { return first.key() < second.key(); }
+
+    //______________________________________________________________
+    Key::~Key() { clearAssociations(); }
+
+    //______________________________________________________________
+    template<typename T> void Key::clearAssociations()
     {
-        public:
-
-        //* constructor
-        KeySetIterator( KeySet<T> keySet ):
-            QSetIterator<T*>( keySet )
-        {}
-    };
-
-};
-
-//______________________________________________________________
-template<typename T> void Base::Key::clearAssociations( void )
-{
-    KeySet<T> tmp( this );
-    foreach( T* key, tmp )
-    {
-        key->_disassociate( this );
-        _disassociate( key );
+        for( const auto& key:KeySet<T>(this) )
+        {
+            key->_disassociate( this );
+            _disassociate( key );
+        }
     }
+
+    //______________________________________________________________
+    template<typename T> void Key::removeAssociatedKeys()
+    {
+        for( const auto& key:KeySet<T>(this) )
+        { _disassociate( key ); }
+    }
+
 }
 
 //____________________________________________________
