@@ -22,7 +22,7 @@
 //________________________________________________________
 QTextStream& operator >> ( QTextStream& in, bool& value )
 {
-    short unsigned int local;
+    int local;
     in >> local;
     value = (bool)( local );
     return in;
@@ -37,10 +37,7 @@ Option::Option():
 Option::Option( const char* value, Flags flags ):
     Counter( "Option" ),
     flags_( flags )
-{
-    Q_CHECK_PTR( value );
-    value_ = value;
-}
+{ value_ = value; }
 
 //________________________________________________________
 Option::Option( const QByteArray& value, Flags flags ):
@@ -56,14 +53,6 @@ Option::Option( const QString& value, Flags flags ):
     flags_( flags )
 {}
 
-//________________________________________________________
-Option::Option( const QByteArray& value, const QString& comments, Flags flags ):
-    Counter( "Option" ),
-    value_( value ),
-    comments_( comments ),
-    flags_( flags )
-{}
-
 //________________________________________________________
 QDataStream &operator << ( QDataStream &stream, const Option& option )
 {
@@ -72,7 +61,6 @@ QDataStream &operator << ( QDataStream &stream, const Option& option )
         << version
         << option.value_
         << option.defaultValue_
-        << option.comments_
         << quint32(option.flags_)
         << quint32(option.defaultFlags_);
     return stream;
@@ -91,7 +79,6 @@ QDataStream &operator >> ( QDataStream &stream, Option& option )
         stream
             >> option.value_
             >> option.defaultValue_
-            >> option.comments_
             >> flags
             >> defaultFlags;
         option.flags_ = Option::Flags( flags );
@@ -113,7 +100,7 @@ QTextStream &operator << ( QTextStream &out, const Option& option )
 //________________________________________________________
 QTextStream &operator << ( QTextStream &out, const QList<Option>& options )
 {
-    foreach( const Option& option, options )
+    for( const auto& option:options )
     { out << option << " "; }
     return out;
 }
