@@ -34,7 +34,7 @@ QTextStream& operator >> ( QTextStream& in, bool& value );
 \class   Option
 \brief   Option objects for string, int, bool and double options
 */
-class Option:public Counter
+class Option:private Base::Counter<Option>
 {
 
     public:
@@ -49,48 +49,26 @@ class Option:public Counter
 
     Q_DECLARE_FLAGS(Flags, Flag)
 
-    //* constructor
-    Option();
+    //* default constructor
+    explicit Option();
 
     //* constructor
-    Option( const char*, Flags = Recordable );
+    explicit Option( const char*, Flags = Flag::Recordable );
 
     //* constructor
-    Option( const QByteArray&, Flags = Recordable );
+    explicit Option( const QByteArray&, Flags = Flag::Recordable );
 
     //* constructor
-    Option( const QByteArray&, const QString&, Flags = Recordable );
+    explicit Option( const QString&, Flags = Flag::Recordable );
 
-    //* constructor
-    Option( const QString&, Flags = Recordable );
-
-    //* less than operator
-    bool operator < (const Option& other ) const
-    {
-        if( value_ != other.value_ ) return value_ < other.value_;
-        else if( flags_ != other.flags_ ) return flags_ < other.flags_;
-        else if( defaultValue_ != other.defaultValue_ ) return defaultValue_ < other.defaultValue_;
-        else if( defaultFlags_ != other.defaultFlags_ ) return defaultFlags_ < other.defaultFlags_;
-        else return comments_ < other.comments_;
-    }
-
-    //* equal operator
-    bool operator == (const Option& other ) const
-    { return value_ == other.value_ && flags_ == other.flags_; }
-
-    //* different operator
-    bool operator != (const Option& other ) const
-    { return !( *this == other ); }
+    //* destructor
+    virtual ~Option() = default;
 
     //*@name accessors
     //@{
 
-    //* option comments
-    const QString& comments( void ) const
-    { return comments_; }
-
     //* flags
-    Flags flags( void ) const
+    Flags flags() const
     { return flags_; }
 
     //* flags
@@ -98,28 +76,28 @@ class Option:public Counter
     { return flags_ & flag; }
 
     //* current
-    bool isCurrent( void ) const
-    { return hasFlag( Current ); }
+    bool isCurrent() const
+    { return hasFlag( Flag::Current ); }
 
     //* default
-    bool isDefault( void ) const
+    bool isDefault() const
     { return defaultValue_ == value_ && defaultFlags_ == flags_; }
 
     //* recordable
-    bool isRecordable( void ) const
-    { return hasFlag( Recordable ); }
+    bool isRecordable() const
+    { return hasFlag( Flag::Recordable ); }
 
     //* raw accessor
-    const QByteArray& raw( void ) const
+    const QByteArray& raw() const
     { return value_; }
 
     //* default value
-    const QByteArray& defaultValue( void ) const
+    const QByteArray& defaultValue() const
     { return defaultValue_; }
 
     //* generic accessor
     template < typename T >
-        T get( void ) const
+        T get() const
     {
 
         // check if option is set
@@ -136,7 +114,7 @@ class Option:public Counter
     }
 
     //* check status
-    bool isSet( void ) const
+    bool isSet() const
     {return !value_.isEmpty();}
 
     //@}
@@ -144,13 +122,6 @@ class Option:public Counter
     //*@name modifiers
     //@{
 
-    //* option comments
-    Option& setComments( const QString& comments )
-    {
-        comments_ = comments;
-        return *this;
-    }
-
     //* flags
     Option& setFlags( Flags value )
     {
@@ -162,16 +133,16 @@ class Option:public Counter
     Option& setFlag( Flag flag, bool value = true )
     {
         if( value ) { flags_ |= flag; }
-        else { flags_ &= (~flag); }
+        else { flags_ &= ~static_cast<Flags>(flag); }
         return *this;
     }
 
     //* current
     Option& setCurrent( bool value )
-    { return setFlag( Current, value ); }
+    { return setFlag( Flag::Current, value ); }
 
     //* default
-    Option& setDefault( void )
+    Option& setDefault()
     {
         defaultValue_ = value_;
         defaultFlags_ = flags_;
@@ -221,7 +192,7 @@ class Option:public Counter
         public:
 
         //* constructor
-        HasFlagFTor( Option::Flags flags ):
+        explicit HasFlagFTor( Option::Flags flags ):
             flags_( flags )
         {}
 
@@ -247,7 +218,7 @@ class Option:public Counter
         public:
 
         //* constructor
-        SameValueFTor( const Option& option ):
+        explicit SameValueFTor( const Option& option ):
             value_( option.value_ )
             {}
 
@@ -270,14 +241,11 @@ class Option:public Counter
     //* option default value
     QByteArray defaultValue_;
 
-    //* option comments
-    QString comments_;
-
     //* flags
-    Flags flags_ = Recordable;
+    Flags flags_ = Flag::Recordable;
 
     //* default flags
-    Flags defaultFlags_ = Recordable;
+    Flags defaultFlags_ = Flag::Recordable;
 
     //*@name serializer
     //@{
@@ -294,7 +262,18 @@ class Option:public Counter
     friend QTextStream &operator << ( QTextStream &out, const QList<Option>& options );
     //@}
 
+    //* less than operator
+    friend bool operator < (const Option& first, const Option& second )
+    {
+        if( first.value_ != second.value_ ) return first.value_ < second.value_;
+        else if( first.flags_ != second.flags_ ) return first.flags_ < second.flags_;
+        else if( first.defaultValue_ != second.defaultValue_ ) return first.defaultValue_ < second.defaultValue_;
+        else return first.defaultFlags_ < second.defaultFlags_;
+    }
 
+    //* equal to operator
+    friend bool operator == (const Option& first, const Option& second )
+    { return first.value_ == second.value_ && first.flags_ == second.flags_; }
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( Option::Flags )
