@@ -31,7 +31,7 @@
 #include <QTextStream>
 
 //* Option file parser based on Xml
-class Options: public Counter
+class Options: private Base::Counter<Options>
 {
 
     public:
@@ -49,54 +49,41 @@ class Options: public Counter
     using SpecialMap = QMap<QString,List>;
 
     //* constructor
-    Options( void );
+    explicit Options();
 
-    //* equality operator
-    bool operator == ( const Options& other ) const
-    {
-        Debug::Throw( "Options::operator ==.\n" );
-        bool out(
-            ( options_ == other.options_ ) &&
-            ( specialOptions_ == other.specialOptions_ ) );
-        return out;
-    }
-
-    //* different operator
-    bool operator != ( const Options& other ) const
-    { return !( *this == other ); }
+    //* destructor
+    virtual ~Options() = default;
 
     //* install defaults
-    virtual void installDefaultOptions( void );
+    void installDefaultOptions();
 
     //*@name accessors
     //@{
 
     //* retrieve Option map
-    virtual const Map& options( void ) const
+    const Map& options() const
     { return options_; }
 
     //* retrieve special Option map
-    virtual const SpecialMap& specialOptions( void ) const
+    const SpecialMap& specialOptions() const
     { return specialOptions_; }
 
     //* returns true if option name is special
-    virtual bool isSpecialOption( const QString& name ) const;
+    bool isSpecialOption( const QString& name ) const;
 
     //* retrieve list of special (i.e. kept) options matching a given name
     template <typename T> QList<T> specialOptions( const QString& name ) const
     {
 
-        const List& optionList( specialOptions( name ) );
         QList<T> out;
-
-        foreach( const Option& option, optionList )
+        for( const auto& option:specialOptions( name ) )
         { out << option.get<T>(); }
         return out;
 
     }
 
     //* retrieve list of special (i.e. kept) options matching a given name
-    virtual const List& specialOptions( const QString& name ) const
+    const List& specialOptions( const QString& name ) const
     {
         SpecialMap::const_iterator iter( specialOptions_.find( name ) );
         Q_ASSERT( iter != specialOptions_.end() );
@@ -104,11 +91,11 @@ class Options: public Counter
     }
 
     //* returns true if option with matching name is found
-    virtual bool contains( const QString& name ) const
+    bool contains( const QString& name ) const
     { return options_.find( name ) != options_.end(); }
 
     //* option matching given name
-    virtual const Option& option( const QString& name ) const
+    const Option& option( const QString& name ) const
     { return options_.find( name ).value(); }
 
     //* option value accessor
@@ -116,7 +103,7 @@ class Options: public Counter
     { return _find( name ).value().get<T>(); }
 
     //* option raw value accessor
-    virtual QByteArray raw( const QString& name ) const
+    QByteArray raw( const QString& name ) const
     { return _find( name ).value().raw(); }
 
     //@}
@@ -125,13 +112,31 @@ class Options: public Counter
     //@{
 
     //* adds a new special option. Return true if option is added
-    virtual bool add( const QString&, const Option&, bool isDefault = false );
-
-    //* clear list of special (i.e. kept) options matching a given name
-    virtual void clearSpecialOptions( const QString& name );
+    bool add( const QString&, const Option&, bool isDefault = false );
 
     //* option value modifier
-    template <typename T>
+    template <
+        typename T,
+        typename = typename std::enable_if<!std::is_base_of<Option, typename std::decay<T>::type>::value>::type
+        >
+    void add( const QString& name, const T& value, bool isDefault = false )
+    {
+        Option option;
+        option.set<T>( value );
+        add( name, option, isDefault );
+    }
+
+    //* clear list of special (i.e. kept) options matching a given name
+    void clearSpecialOptions( const QString& name );
+
+    //* assign an option to given name
+    void set( const QString&, const Option&, bool isDefault = false );
+
+    //* option value modifier
+    template <
+        typename T,
+        typename = typename std::enable_if<!std::is_base_of<Option, typename std::decay<T>::type>::value>::type
+        >
     void set( const QString& name, const T& value, bool isDefault = false )
     {
         Q_ASSERT( !isSpecialOption( name ) );
@@ -141,11 +146,8 @@ class Options: public Counter
 
     }
 
-    //* assign an option to given name
-    void set( const QString&, const Option&, bool isDefault = false );
-
     //* option raw value modifier
-    virtual void setRaw( const QString& name, const QByteArray& value, bool isDefault = false )
+    void setRaw( const QString& name, const QByteArray& value, bool isDefault = false )
     {
         Q_ASSERT( !isSpecialOption( name ) );
         Option &option( options_[name] );
@@ -154,7 +156,7 @@ class Options: public Counter
     }
 
     //* option raw value modifier
-    virtual void setRaw( const QString& name, const QString& value, bool isDefault = false )
+    void setRaw( const QString& name, const QString& value, bool isDefault = false )
     {
         Q_ASSERT( !isSpecialOption( name ) );
         Option &option( options_[name] );
@@ -169,7 +171,7 @@ class Options: public Counter
     takes more time with respect to the "standard" options, which are stored
     in a map.
     */
-    virtual void keep( const QString& name )
+    void keep( const QString& name )
     {
         if( specialOptions_.find( name ) == specialOptions_.end() )
         { specialOptions_.insert( name, List() ); }
@@ -180,7 +182,7 @@ class Options: public Counter
     { autoDefault_ = value; }
 
     //* restore defaults
-    void restoreDefaults( void );
+    void restoreDefaults();
 
     //@}
 
@@ -190,7 +192,7 @@ class Options: public Counter
     Map::const_iterator _find( const QString& name ) const;
 
     //* auto-default
-    bool _autoDefault( void ) const
+    bool _autoDefault() const
     { return autoDefault_; }
 
     private:
@@ -207,6 +209,10 @@ class Options: public Counter
     //* streamer
     friend QTextStream &operator << ( QTextStream &,const Options &);
 
+    //* equality operator
+    friend bool operator == ( const Options& first, const Options& second )
+    { return ( first.options_ == second.options_ ) && ( first.specialOptions_ == second.specialOptions_ ); }
+
 };
 
 #endif
