@@ -27,7 +27,7 @@
 #include <time.h>
 
 //* time manipulation object
-class TimeStamp:public Counter
+class TimeStamp:private Base::Counter<TimeStamp>
 {
 
     public:
@@ -36,17 +36,20 @@ class TimeStamp:public Counter
     static const QString TimeStampUnknown;
 
     //* empty creator
-    TimeStamp( void ):
+    explicit TimeStamp():
         Counter( "TimeStamp" )
     {}
 
     //* time_t creator
-    TimeStamp( time_t time ):
+    explicit TimeStamp( time_t time ):
         Counter( "TimeStamp" )
     { setTime( time ); }
 
+    //* destructor
+    virtual ~TimeStamp() = default;
+
     //* set time
-    virtual bool setTime( time_t time )
+    bool setTime( time_t time )
     {
         valid_ = time >= 0;
         time_ = time;
@@ -55,41 +58,21 @@ class TimeStamp:public Counter
     }
 
     //* convert tm_ into time_
-    virtual bool makeTime( void )
+    bool makeTime()
     {
         valid_ = (time_ = mktime( &tm_ ) ) >= 0;
         return valid_;
     }
 
-    //* inferior to operator
-    virtual bool operator < (const TimeStamp& stamp ) const
-    { return( time_ < stamp.time_ ); }
-
-    //* inferior to operator
-    virtual bool operator >= (const TimeStamp& stamp ) const
-    { return( time_ >= stamp.time_ ); }
-
-    //* inferior to operator
-    virtual bool operator > (const TimeStamp& stamp ) const
-    { return( time_ > stamp.time_ ); }
-
-    //* inferior to operator
-    virtual bool operator == (const TimeStamp& stamp ) const
-    { return( time_ == stamp.time_ ); }
-
     //*@name accessors
     //@{
 
     //* checks if timestamp is valid or not
-    virtual bool isValid( void ) const
+    bool isValid() const
     { return valid_; }
 
-    //* used to have fast access to the integer value
-    virtual operator int (void) const
-    { return int( time_ ); }
-
     //* timestamp format enumeration
-    enum Format
+    enum class Format
     {
 
         //* DD/MM/YYYY
@@ -122,45 +105,45 @@ class TimeStamp:public Counter
     };
 
     //* if timestamp is valid returns formated string
-    virtual QString toString( Format = Short ) const;
+    QString toString( Format = Format::Short ) const;
 
     //* if timestamp is valid, returns formated string
-    virtual QString toString( Qt::DateFormat format ) const
+    QString toString( Qt::DateFormat format ) const
     { return valid_ ? QDateTime::fromTime_t( time_ ).toString( format ) : TimeStampUnknown; }
 
     //* if timestamp is valid, returns formated string
-    virtual QString toString( const QString& format ) const
+    QString toString( const QString& format ) const
     { return valid_ ? QDateTime::fromTime_t( time_ ).toString( format ) : TimeStampUnknown; }
 
     //* returns time in second
-    virtual time_t unixTime( void ) const
+    time_t unixTime() const
     { return time_; }
 
     //* returns TimeStamp corresponding to _now_
-    static TimeStamp now( void );
+    static TimeStamp now();
 
     //* retrieve seconds (between 0 and 59)
-    virtual int seconds( void ) const
+    int seconds() const
     { return (valid_) ? tm_.tm_sec:0; }
 
     //* retrieve minutes (between 0 and 59)
-    virtual int minutes( void ) const
+    int minutes() const
     { return (valid_) ? tm_.tm_min:0; }
 
     //* retrieve hour (between 0 and 23)
-    virtual int hours( void ) const
+    int hours() const
     { return (valid_) ? tm_.tm_hour:0; }
 
     //* retrieves day (between 1 and 31)
-    virtual int day( void ) const
+    int day() const
     { return (valid_) ? tm_.tm_mday:0; }
 
     //* retrieves month (between 1 and 12)
-    virtual int month( void ) const
+    int month() const
     { return (valid_) ? tm_.tm_mon+1:0; }
 
     //* retrieves year (between 1 and 12)
-    virtual int year( void ) const
+    int year() const
     { return (valid_) ? tm_.tm_year+1900:0; }
 
     //* true if same day
@@ -182,52 +165,52 @@ class TimeStamp:public Counter
     //@{
 
     //* seconds (between 0 and 59)
-    virtual TimeStamp& setSeconds( int value )
+    TimeStamp& setSeconds( int value )
     {
         tm_.tm_sec = value;
         return *this;
     }
 
     //* minutes (between 0 and 59)
-    virtual TimeStamp& setMinutes( int value )
+    TimeStamp& setMinutes( int value )
     {
         tm_.tm_min = value;
         return *this;
     }
 
     //* hour (between 0 and 23)
-    virtual TimeStamp& setHours( int value )
+    TimeStamp& setHours( int value )
     {
         tm_.tm_hour = value;
         return *this;
     }
 
     //* retrieves day (between 1 and 31)
-    virtual TimeStamp& setDay( int value )
+    TimeStamp& setDay( int value )
     {
         tm_.tm_mday = value;
         return *this;
     }
 
     //* retrieves month (between 1 and 12)
-    virtual TimeStamp& setMonth( int value )
+    TimeStamp& setMonth( int value )
     {
         tm_.tm_mon = value - 1;
         return *this;
     }
 
     //* retrieves month (from string)
-    virtual TimeStamp& setMonth( const QString& );
+    TimeStamp& setMonth( const QString& );
 
     //* retrieves year (between 1 and 12)
-    virtual TimeStamp& setYear( int value )
+    TimeStamp& setYear( int value )
     {
         tm_.tm_year = value - 1900;
         return *this;
     }
 
     //* tells if timestamp is valid or not
-    virtual TimeStamp& setValid( bool value )
+    TimeStamp& setValid( bool value )
     {
         valid_ = value;
         return *this;
@@ -252,6 +235,14 @@ class TimeStamp:public Counter
     friend QDataStream& operator >> ( QDataStream&, TimeStamp& );
     //@}
 
+    //* less than operator
+    friend bool operator < (const TimeStamp& first, const TimeStamp& second)
+    { return( first.time_ < second.time_ ); }
+
+    //* equal to operator
+    friend bool operator == (const TimeStamp& first, const TimeStamp& second)
+    { return( first.time_ == second.time_ ); }
+
 };
 
 #endif
