@@ -35,11 +35,7 @@ Application::Application( CommandLineArguments arguments ) :
 {}
 
 //____________________________________________
-Application::~Application( void )
-{ if( interface_ ) delete interface_; }
-
-//____________________________________________
-bool Application::realizeWidget( void )
+bool Application::realizeWidget()
 {
     Debug::Throw( "Application::realizeWidget.\n" );
 
@@ -48,24 +44,24 @@ bool Application::realizeWidget( void )
     if( parser.hasOption( "--user" ) )
     {
         XmlOptions::get().clearSpecialOptions( "USER_NAME" );
-        XmlOptions::get().add( "USER_NAME", Option( parser.option( "--user" ), Option::Recordable|Option::Current  ) );
+        XmlOptions::get().add( "USER_NAME", Option( parser.option( "--user" ), Option::Flag::Recordable|Option::Flag::Current  ) );
     }
 
     // check if the method has already been called.
     if( !BaseApplication::realizeWidget() ) return false;
 
     // interface
-    interface_ = new JobInterface();
+    interface_.reset( new JobInterface );
 
     // top widget
-    mainWindow_ = new MainWindow();
+    mainWindow_ = new MainWindow;
     mainWindow_->setWindowTitle( "Top" );
 
     // connection between job manager and interface
-    connect( mainWindow_, SIGNAL(commandRequested(JobCommand)), interface_, SLOT(addCommand(JobCommand)) );
-    connect( interface_, SIGNAL(jobListReady(Job::Set)), mainWindow_, SLOT(processJobList(Job::Set)) );
-    connect( interface_, SIGNAL(userListReady(UserSet)), mainWindow_, SLOT(updateUsers(UserSet)) );
-    connect( interface_, SIGNAL(messageAvailable(QString)), &mainWindow_->statusBar().label(), SLOT(setTextAndUpdate(QString)) );
+    connect( mainWindow_, SIGNAL(commandRequested(JobCommand)), interface_.get(), SLOT(addCommand(JobCommand)) );
+    connect( interface_.get(), SIGNAL(jobListReady(Job::Set)), mainWindow_, SLOT(processJobList(Job::Set)) );
+    connect( interface_.get(), SIGNAL(userListReady(UserSet)), mainWindow_, SLOT(updateUsers(UserSet)) );
+    connect( interface_.get(), SIGNAL(messageAvailable(QString)), &mainWindow_->statusBar().label(), SLOT(setTextAndUpdate(QString)) );
 
     mainWindow_->installFrames();
     mainWindow_->requestJobList();
@@ -95,7 +91,7 @@ CommandLineParser Application::commandLineParser( CommandLineArguments arguments
 }
 
 //____________________________________________
-void Application::usage( void ) const
+void Application::usage() const
 {
     _usage( "Top" );
     commandLineParser().usage();
@@ -103,7 +99,7 @@ void Application::usage( void ) const
 }
 
 //_______________________________________________
-void Application::_configuration( void )
+void Application::_configuration()
 {
 
     Debug::Throw( "Application::_configuration.\n" );
