@@ -25,12 +25,15 @@
 #include "CommandLineArguments.h"
 #include "Counter.h"
 #include "IconEngine.h"
+#include "JobInterface.h"
+
+#include <memory>
 
 class MainWindow;
-class JobInterface;
+// class JobInterface;
 
 //* Main Window singleton object
-class Application: public BaseApplication, public Counter
+class Application: public BaseApplication, private Base::Counter<Application>
 {
 
     //* Qt meta object declaration
@@ -39,41 +42,38 @@ class Application: public BaseApplication, public Counter
     public:
 
     //* constructor
-    Application( CommandLineArguments );
-
-    //* destructor
-    virtual ~Application( void );
+    explicit Application( CommandLineArguments );
 
     //* create all widgets
-    virtual bool realizeWidget( void );
+    bool realizeWidget() override;
 
     //* interface
-    virtual JobInterface& interface( void ) const
+    JobInterface& interface() const
     { return *interface_; }
 
     //* retrieves top layout
-    virtual MainWindow & mainWindow( void ) const
+    MainWindow& mainWindow() const
     { return *mainWindow_; }
 
     //*@name application information
     //@{
 
     //* command line parser
-    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const;
+    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const override;
 
     //* usage
-    void usage( void ) const;
+    void usage() const override;
 
     //* application name
-    virtual QString applicationName( void ) const
+    QString applicationName() const override
     { return "Top"; }
 
     //* application icon
-    virtual QIcon applicationIcon( void ) const
+    QIcon applicationIcon() const override
     { return IconEngine::get( ":/Top.png" ); }
 
     // application version
-    virtual QString applicationVersion( void ) const
+    QString applicationVersion() const override
     { return VERSION; }
 
     //@}
@@ -81,15 +81,15 @@ class Application: public BaseApplication, public Counter
     protected Q_SLOTS:
 
     //* configuration
-    virtual void _configuration( void );
+    void _configuration() override;
 
     //* process request from application manager
-    virtual bool _processCommand( Server::ServerCommand );
+    bool _processCommand( Server::ServerCommand ) override;
 
     private:
 
     //* pointer to top interface
-    JobInterface* interface_ = nullptr;
+    std::unique_ptr<JobInterface> interface_;
 
     //* pointer to top widget
     MainWindow *mainWindow_ = nullptr;
