@@ -30,7 +30,7 @@ class ConfigurationDialog: public BaseConfigurationDialog
     public:
 
     //* creator
-    ConfigurationDialog( QWidget *parent = nullptr );
+    explicit ConfigurationDialog( QWidget *parent = nullptr );
 
 };
 
