@@ -28,7 +28,7 @@
 
 //_____________________________________________________
 //* default options installer
-void installDefaultOptions( void )
+void installDefaultOptions()
 {
 
     XmlOptions::get().keep( "USER_NAME" );
@@ -36,10 +36,10 @@ void installDefaultOptions( void )
     XmlOptions::get().setAutoDefault( true );
 
     XmlOptions::get().set<int>( "DB_SIZE", 10 );
-    XmlOptions::get().set<Base::Color>( "DIV_COLOR", QColor( "#cccccc" ) );
+    XmlOptions::get().set( "DIV_COLOR", Base::Color( "#cccccc" ) );
     XmlOptions::get().set<int>( "DIV_X", 0 );
     XmlOptions::get().set<int>( "DIV_Y", 5 );
-    XmlOptions::get().set<Base::Color>( "FOREGROUND_COLOR", QColor( "#aa0000" ) );
+    XmlOptions::get().set( "FOREGROUND_COLOR", Base::Color( "#aa0000" ) );
     XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 300 );
     XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 492 );
 
@@ -61,7 +61,9 @@ void installDefaultOptions( void )
     XmlOptions::get().set<bool>( "SHOW_FULL_NAMES", true );
 
     // run-time non recordable options
-    XmlOptions::get().set( "RC_FILE", Option( File(".Toprc").addPath( Util::home() ), Option::None ) );
+    XmlOptions::get().set( "OLD_RC_FILE", Option( File(".Toprc").addPath( Util::home() ), Option::Flag::None ) );
+    XmlOptions::get().set( "RC_FILE", Option( File("qtoprc").addPath( Util::config() ), Option::Flag::None ) );
+
     XmlOptions::get().setAutoDefault( false );
 
 };
