@@ -38,7 +38,7 @@ HistogramWidget::HistogramWidget( QScrollArea* parent ):
 {
     Debug::Throw( "HistogramWidget::HistogramWidget.\n" );
     setBackgroundRole( QPalette::Base );
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 }
 
@@ -47,13 +47,13 @@ HistogramWidget::HistogramWidget( QScrollArea* parent ):
 void HistogramWidget::_updateConfiguration()
 {
     Debug::Throw( "HistogramWidget::_updateConfiguration.\n" );
-    divX_ = XmlOptions::get().get<unsigned int>( "DIV_X" );
-    divY_ = XmlOptions::get().get<unsigned int>( "DIV_Y" );
+    divX_ = XmlOptions::get().get<int>( "DIV_X" );
+    divY_ = XmlOptions::get().get<int>( "DIV_Y" );
     divColor_.update();
 
     // update datasets colors
-    for( DataSet::List::iterator iter = _dataSets().begin(); iter != _dataSets().end(); ++iter )
-    { iter->color().update(); }
+    for( auto& data:dataSets_ )
+    { data.color().update(); }
 
     update();
 }
@@ -77,24 +77,24 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
     painter.setPen( pen );
 
     // horizontal divisions
-    for( unsigned int i=1; i<divY_; i++ )
+    for( int i=1; i<divY_; i++ )
     {
         int line = static_cast<int>( double(i*height)/divY_ );
         painter.drawLine( 0, line, width()-1, line );
     }
 
     // vertical divisions
-    for( unsigned int i=1; i<divX_; i++ )
+    for( int i=1; i<divX_; i++ )
     {
-        unsigned int col = static_cast<unsigned int>( double(i*width())/divX_ );
+        int col = static_cast<int>( double(i*width())/divX_ );
         painter.drawLine( col, 0, col, height-1 );
     }
 
     painter.setRenderHint(QPainter::Antialiasing, true);
 
     // adjust values to width
-    for( DataSet::List::iterator iter = _dataSets().begin(); iter != _dataSets().end(); ++iter )
-    { while( int( iter->values().size()) > width() ) iter->values().erase( iter->values().begin() ); }
+    for( auto& data:dataSets_ )
+    { while( int( data.values().size()) > width() ) data.values().erase( data.values().begin() ); }
 
     //! get values maximum and ratio
     double maximum(0);
@@ -103,7 +103,7 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
     {
         double value( 0 );
         bool valid( false );
-        foreach( const DataSet& dataSet, _dataSets() )
+        for( const auto& dataSet:dataSets_ )
         {
             if( index >= dataSet.values().size() ) continue;
             valid = true;
@@ -123,7 +123,7 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
         double ratio( maximum > 0 ? static_cast<double>( height-1 )/maximum  : 1 );
 
         //! allocate a polygon for each dataset
-        QVector<QPolygonF> polygons( _dataSets().size(), QPolygonF() );
+        QVector<QPolygonF> polygons( dataSets_.size(), QPolygonF() );
 
         // fill polygons
         double x_min(0);
@@ -135,12 +135,12 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
         {
             bool valid( false );
             double y_max = y_min;
-            for( int i = 0; i < _dataSets().size(); i++ )
+            for( int i = 0; i < dataSets_.size(); i++ )
             {
 
                 if( index >= dataSet(i).values().size() )
                 {
-                    if( i < _dataSets().size()-1 ) y_max -= qMax( 1.0, ratio*dataSet(i).values().back() );
+                    if( i < dataSets_.size()-1 ) y_max -= qMax( 1.0, ratio*dataSet(i).values().back() );
                     continue;
                 }
 
@@ -156,7 +156,7 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
         }
 
         // close polygons
-        for( int i = int( _dataSets().size() ) -1; i>=0 ; i-- )
+        for( int i = int( dataSets_.size() ) -1; i>=0 ; i-- )
         {
             if( polygons[i].isEmpty() ) continue;
 
@@ -205,10 +205,10 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
             painter.setPen( divColor_.foreground() );
             int x( parent_->horizontalScrollBar()->value() + parent_->width() - 10 );
             const double interval( maximum/divY_ );
-            for( unsigned int i=0; i<divY_; i++ )
+            for( int i=0; i<divY_; i++ )
             {
 
-                unsigned int y = static_cast<unsigned int>( double(i*height)/divY_ );
+                int y = static_cast<int>( double(i*height)/divY_ );
                 double value = std::floor(0.5 + 100*interval*( divY_ - i ) )/100;
 
                 // calculate text position
@@ -235,7 +235,7 @@ void HistogramWidget::paintEvent( QPaintEvent* event )
 void HistogramWidget::resizeEvent( QResizeEvent* event )
 {
     Debug::Throw( "HistogramWidget::resizeEvent.\n" );
-    for( int i=0; i<_dataSets().size(); i++ )
+    for( int i=0; i<dataSets_.size(); i++ )
     { dataSet(i).color().updateGradient( event->size() ); }
 
     return QWidget::resizeEvent( event );
@@ -243,7 +243,7 @@ void HistogramWidget::resizeEvent( QResizeEvent* event )
 }
 
 //__________________________________________________________
-void HistogramWidget::Color::update( void )
+void HistogramWidget::Color::update()
 {
 
     Debug::Throw( "HistogramWidgetWidget::Color::update.\n" );
