@@ -18,39 +18,24 @@
 *******************************************************************************/
 
 #include "JobCommand.h"
-
-
+#include "CppUtil.h"
 
 //___________________________________________________________________
-unsigned int& JobCommand::_counter( void )
+const JobCommand::NameMap& JobCommand::_names()
 {
-    static unsigned int counter( 0 );
-    return counter;
-}
+    static const NameMap names = Base::makeT<NameMap>(
+    {
+        { JobCommand::Type::None, QObject::tr( "None" ) },
+        { JobCommand::Type::JobList, QObject::tr( "Query process list" ) },
+        { JobCommand::Type::Signal, QObject::tr( "Signal selected processes" ) }
+    });
 
-//___________________________________________________________________
-QString JobCommand::name( const Type& type )
-{
-    Debug::Throw( "JobCommand::name.\n" );
-
-    if( _names().empty() ) _initializeNames();
-    NameMap::const_iterator iter( _names().find( type ) );
-    return iter != _names().end() ? iter.value():"";
-}
-
-//___________________________________________________________________
-void JobCommand::_initializeNames( void )
-{
-    Debug::Throw( "JobCommand::_initializeNames.\n" );
-
-    _names()[None] = QObject::tr( "None" );
-    _names()[JobList]= QObject::tr( "Query process list" );
-    _names()[Signal]= QObject::tr( "Signal selected processes" );
-}
-
-//___________________________________________________________________
-JobCommand::NameMap& JobCommand::_names( void )
-{
-    static NameMap names;
     return names;
 }
+
+//___________________________________________________________________
+int& JobCommand::_counter()
+{
+    static int counter( 0 );
+    return counter;
+}
