@@ -36,7 +36,7 @@ JobInformationDialog::JobInformationDialog( QWidget* parent ):
 {
 
     Debug::Throw( "JobInformationDialog::JobInformationDialog.\n" );
-    setWindowTitle( "Job Information - Gridwatch" );
+    setWindowTitle( "Job Information - Top" );
     setAttribute( Qt::WA_DeleteOnClose );
     setOptionName( "JOB_INFORMATION_DIALOG" );
 
@@ -51,9 +51,9 @@ JobInformationDialog::JobInformationDialog( QWidget* parent ):
 
     // general information
     QWidget *box;
-    tabWidget_->addTab( box = new QWidget(), tr( "General" ) );
+    tabWidget_->addTab( box = new QWidget, tr( "General" ) );
 
-    QHBoxLayout* hLayout = new QHBoxLayout();
+    QHBoxLayout* hLayout = new QHBoxLayout;
     hLayout->setMargin(5);
     hLayout->setSpacing(5);
     box->setLayout( hLayout );
@@ -63,21 +63,21 @@ JobInformationDialog::JobInformationDialog( QWidget* parent ):
     iconLabel_->setPixmap( IconEngine::get( IconNames::DialogInformation ).pixmap( iconSize() ) );
     hLayout->addWidget( iconLabel_, 0, Qt::AlignTop );
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    QVBoxLayout* layout = new QVBoxLayout;
     layout->setMargin(0);
     layout->setSpacing( 5 );
     hLayout->addLayout( layout, 1 );
 
-    GridLayout* gridLayout = new GridLayout();
+    GridLayout* gridLayout = new GridLayout;
     gridLayout->setSpacing( 5 );
     gridLayout->setMaxCount( 2 );
     layout->addLayout( gridLayout );
 
-    ( nameLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Bold|GridLayoutItem::Selectable ) )->setKey( tr( "Name:" ) );
-    ( idLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Selectable ) )->setKey( tr( "Process id:" ) );
-    ( parentIdLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Selectable ) )->setKey( tr( "Parent id:" ) );
-    ( userLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Selectable| GridLayoutItem::Elide ) )->setKey( tr( "User:" ) );
-    ( commandLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Selectable| GridLayoutItem::Elide ) )->setKey( tr( "Command:" ) );
+    ( nameLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Flag::Selectable ) )->setKey( tr( "Name:" ) );
+    ( idLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Flag::Selectable ) )->setKey( tr( "Process id:" ) );
+    ( parentIdLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Flag::Selectable ) )->setKey( tr( "Parent id:" ) );
+    ( userLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Flag::Selectable| GridLayoutItem::Flag::Elide ) )->setKey( tr( "User:" ) );
+    ( commandLabel_ = new GridLayoutItem( box, gridLayout, GridLayoutItem::Flag::Selectable| GridLayoutItem::Flag::Elide ) )->setKey( tr( "Command:" ) );
     ( startTimeLabel_ = new GridLayoutItem( box, gridLayout ) )->setKey( tr( "Started:" ) );
     ( completionTimeLabel_ = new GridLayoutItem( box, gridLayout ) )->setKey( tr( "Completed:" ) );
     completionTimeLabel_->hide();
@@ -86,10 +86,10 @@ JobInformationDialog::JobInformationDialog( QWidget* parent ):
     layout->addStretch( 1 );
 
     // statistics
-    tabWidget_->addTab( box = new QWidget(), tr( "Resources" ) );
+    tabWidget_->addTab( box = new QWidget, tr( "Resources" ) );
 
     // create vbox layout
-    box->setLayout( new QVBoxLayout() );
+    box->setLayout( new QVBoxLayout );
     box->layout()->setSpacing(5);
     box->layout()->setMargin(5);
 
@@ -97,7 +97,7 @@ JobInformationDialog::JobInformationDialog( QWidget* parent ):
     box->layout()->addWidget( memoryHistogram_ = new RecordHistogram( box ) );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
 
     // close accelerator
     new QShortcut( QKeySequence::Close, this, SLOT(close()) );
@@ -128,9 +128,12 @@ void JobInformationDialog::update( Job::Set jobs )
 
     if( !alive_ ) return;
 
-    Job::Set::const_iterator iter( std::find_if( jobs.begin(), jobs.end(), Job::SameIdFTor( job_.id() ) ) );
+    auto iter( std::find_if( jobs.begin(), jobs.end(), Job::SameIdFTor( job_.id() ) ) );
     if( iter == jobs.end() ) {
 
+        const QString buffer = QString( tr( "Process %1 (%2) (finished) - Top" ) ).arg( job_.id() ).arg( job_.longName().isEmpty() ? job_.name():job_.longName() );
+        setWindowTitle( buffer );
+
         completionTimeLabel_->setText( TimeStamp::now().toString() );
         alive_ = false;
 
@@ -166,19 +169,19 @@ void JobInformationDialog::resizeEvent( QResizeEvent* e )
 }
 
 //_______________________________________________________________
-void JobInformationDialog::_updateConfiguration( void )
+void JobInformationDialog::_updateConfiguration()
 {
 
     Debug::Throw( "JobInformationDialog::_updateConfiguration.\n" );
 
     // record length and sample size
-    record_.samples().setMaxLength( XmlOptions::get().get<unsigned int>( "RECORD_LENGTH" ) );
-    record_.samples().setSampleSize( XmlOptions::get().get<unsigned int>( "SAMPLES" ) );
+    record_.samples().setMaxLength( XmlOptions::get().get<int>( "RECORD_LENGTH" ) );
+    record_.samples().setSampleSize( XmlOptions::get().get<int>( "SAMPLES" ) );
 
 }
 
 //_____________________________________________________________________________
-void JobInformationDialog::_updateJobInformation( void )
+void JobInformationDialog::_updateJobInformation()
 {
     Debug::Throw( "JobInformationDialog::_updateJobInformation.\n" );
 
@@ -199,7 +202,7 @@ void JobInformationDialog::_updateJobInformation( void )
 }
 
 //_____________________________________________________________________________
-void JobInformationDialog::_updateHistograms( void )
+void JobInformationDialog::_updateHistograms()
 {
 
     Debug::Throw( "JobInformationDialog::_updateHistograms.\n" );
@@ -215,7 +218,7 @@ void JobInformationDialog::_updateHistograms( void )
 
         // update histograms
         HistogramWidget::DataSet::ValueList values;
-        foreach( const JobRecord::Record& record, valueList ) values << record.cpu_;
+        for( const auto& record:valueList ) values << record.cpu_;
         cpuHistogram_->setValues( values );
 
     }
@@ -228,7 +231,7 @@ void JobInformationDialog::_updateHistograms( void )
             .arg( QString::number( record_.current().memory_, 'f', 1 ) ) );
 
         HistogramWidget::DataSet::ValueList values;
-        foreach( const JobRecord::Record& record, valueList ) values << record.memory_;
+        for( const auto& record:valueList ) values << record.memory_;
         memoryHistogram_->setValues( values );
     }
 
