@@ -41,17 +41,17 @@ class JobInformationDialog: public CustomDialog, public Base::Key
     public:
 
     //* constructor
-    JobInformationDialog( QWidget* );
+    explicit JobInformationDialog( QWidget* );
 
     //*@name accessors
     //@{
 
     //* job
-    const Job& job( void ) const
+    const Job& job() const
     { return job_; }
 
     //* record
-    const JobRecord& record( void ) const
+    const JobRecord& record() const
     { return record_; }
 
     //@}
@@ -77,23 +77,23 @@ class JobInformationDialog: public CustomDialog, public Base::Key
     protected:
 
     //* resize event
-    virtual void closeEvent( QCloseEvent* );
+    void closeEvent( QCloseEvent* ) override;
 
     //* resize event
-    virtual void resizeEvent( QResizeEvent* );
+    void resizeEvent( QResizeEvent* ) override;
 
     private Q_SLOTS:
 
     //* configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
     //* update job information
-    void _updateJobInformation( void );
+    void _updateJobInformation();
 
     //* update from record
-    void _updateHistograms( void );
+    void _updateHistograms();
 
     //* job
     Job job_;
