@@ -94,7 +94,7 @@ void JobInterface::_commandCompleted( int returnCode, QProcess::ExitStatus statu
     switch( command.type() )
     {
 
-        case JobCommand::JobList:
+        case JobCommand::Type::JobList:
         {
             // process summary output
             _processJobList();
@@ -120,7 +120,7 @@ void JobInterface::_commandCompleted( int returnCode, QProcess::ExitStatus statu
 }
 
 //________________________________________________________________________
-void JobInterface::_processJobList( void )
+void JobInterface::_processJobList()
 {
 
     Debug::Throw( "JobInterface::_processJobList.\n" );
@@ -134,10 +134,10 @@ void JobInterface::_processJobList( void )
     users << Util::user();
 
     QOrderedSet<QString> jobUsers;
-    foreach( const Job& job, jobs )
+    for( const auto& job:jobs )
     { jobUsers.insert( job.user() ); }
 
-    foreach( const QString& user, jobUsers )
+    for( const auto& user:jobUsers )
     { if( !users.contains( user ) ) users << user; }
 
     emit jobListReady( jobs );
@@ -145,21 +145,21 @@ void JobInterface::_processJobList( void )
 }
 
 //___________________________________________________________________
-void JobInterface::_readStdout(  void )
+void JobInterface::_readStdout()
 {
     process_->setReadChannel( QProcess::StandardOutput );
     stdoutBuffer_.append( QString::fromLocal8Bit( process_->readAll() ) );
 }
 
 //___________________________________________________________________
-void JobInterface::_readStderr(  void )
+void JobInterface::_readStderr()
 {
     process_->setReadChannel( QProcess::StandardError );
     stdoutBuffer_.append( QString::fromLocal8Bit( process_->readAll() ) );
 }
 
 //____________________________________________________________
-void JobInterface::_resetBuffers( void )
+void JobInterface::_resetBuffers()
 {
     Debug::Throw( "JobInterface::_resetBuffer.\n" );
     stdoutBuffer_.clear();
@@ -167,7 +167,7 @@ void JobInterface::_resetBuffers( void )
 }
 
 //__________________________________________________________________________________
-bool JobInterface::_runCommand( void )
+bool JobInterface::_runCommand()
 {
 
     if( commands_.empty() )
@@ -188,7 +188,7 @@ bool JobInterface::_runCommand( void )
     switch( command.type() )
     {
 
-        case JobCommand::JobList:
+        case JobCommand::Type::JobList:
         {
 
             thread_->start();
@@ -196,13 +196,13 @@ bool JobInterface::_runCommand( void )
 
         }
 
-        case JobCommand::Signal:
+        case JobCommand::Type::Signal:
         {
 
             // send "STOP" signal to all selected processes
             bool first( true );
             int signal( 0 );
-            foreach( const QString& argument, command.arguments() )
+            for( const auto& argument:command.arguments() )
             {
 
                 if( first )
@@ -229,7 +229,7 @@ bool JobInterface::_runCommand( void )
 }
 
 //___________________________________________
-void JobInterface::_resetProcess( void )
+void JobInterface::_resetProcess()
 {
     if( process_ )
     {
@@ -239,14 +239,14 @@ void JobInterface::_resetProcess( void )
 }
 
 //____________________________________________________________
-CustomProcess& JobInterface::_newProcess( void )
+CustomProcess& JobInterface::_newProcess()
 {
 
     _resetProcess();
 
     process_ = new CustomProcess( this );
     connect( process_, SIGNAL(error(QProcess::ProcessError)), SLOT(_error(QProcess::ProcessError)) );
-    connect( process_, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(_commandCompleted(int,QProcess::ExitStatus)) );
+    connect( process_, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(_commandCompleted(int,QProcess::ExitStatus)) );
     connect( process_, SIGNAL(readyReadStandardOutput()), SLOT(_readStdout()) );
     connect( process_, SIGNAL(readyReadStandardError()), SLOT(_readStderr()) );
     return *process_;
