@@ -35,7 +35,7 @@ class CustomProcess;
 class JobThread;
 
 //* Job managment
-class JobInterface:public QObject, public Counter
+class JobInterface:public QObject, private Base::Counter<JobInterface>
 {
 
     //* Qt meta object declaration
@@ -44,7 +44,7 @@ class JobInterface:public QObject, public Counter
     public:
 
     //* constructor
-    JobInterface( QObject* parent = nullptr );
+    explicit JobInterface( QObject* parent = nullptr );
 
     Q_SIGNALS:
 
@@ -58,7 +58,7 @@ class JobInterface:public QObject, public Counter
     void commandCompleted( JobCommand );
 
     //* emitted when there is no more commands in pile
-    void ready( void );
+    void ready();
 
     //* message
     void messageAvailable( const QString& );
@@ -77,34 +77,34 @@ class JobInterface:public QObject, public Counter
     void _commandCompleted( int = 0, QProcess::ExitStatus = QProcess::NormalExit );
 
     //* read on-fly from process
-    void _readStdout( void );
+    void _readStdout();
 
     //* read on-fly from process
-    void _readStderr( void );
+    void _readStderr();
 
     protected:
 
     //* process job set (using top)
-    void _processJobList( void );
+    void _processJobList();
 
     //* reset buffers
-    void _resetBuffers( void );
+    void _resetBuffers();
 
     //* run next command in pile
-    bool _runCommand( void );
+    bool _runCommand();
 
     //* reset process
-    void _resetProcess( void );
+    void _resetProcess();
 
     //* process
-    bool _hasProcess( void ) const
+    bool _hasProcess() const
     { return process_; }
 
     //* create new process to run command
-    CustomProcess& _newProcess( void );
+    CustomProcess& _newProcess();
 
     //* process
-    CustomProcess& _process( void ) const
+    CustomProcess& _process() const
     { return *process_; }
 
     //* convert string number (using k, M, G) into a number
