@@ -43,20 +43,20 @@ class JobManager:public QWidget
     public:
 
     //* constructor
-    JobManager( QWidget* );
+    explicit JobManager( QWidget* );
 
     //* list
-    TreeView& list( void ) const
+    TreeView& list() const
     { return *treeView_; }
 
     //* resume selected jobs
-    void resume( void );
+    void resume();
 
     //* pause selected jobs
-    void pause( void );
+    void pause();
 
     //* kill selected jobs
-    void kill( void );
+    void kill();
 
     //* tree view
     bool toggleTreeView( bool );
@@ -65,18 +65,18 @@ class JobManager:public QWidget
     void processJobList( Job::Set );
 
     //* jobs
-    const Job::List& jobs( void ) const
+    const Job::List& jobs() const
     { return jobs_; }
 
     //* retrieve selected jobs
-    Job::List selectedJobs( void ) const;
+    Job::List selectedJobs() const;
 
     //* user
-    QString user( void ) const
+    QString user() const
     { return user_; }
 
     //* tree view
-    bool treeViewEnabled( void ) const
+    bool treeViewEnabled() const
     { return treeViewEnabled_; }
 
     //* update user
@@ -90,12 +90,12 @@ class JobManager:public QWidget
     protected:
 
     //* update model
-    void _updateModel( void );
+    void _updateModel();
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
