@@ -31,7 +31,7 @@ class JobManager;
 class SummaryFrame;
 
 //* customized QVBox to recieve close event
-class JobManagerFrame: public QWidget, public Counter, public Base::Key
+class JobManagerFrame: public QWidget, private Base::Counter<JobManagerFrame>, public Base::Key
 {
 
     Q_OBJECT
@@ -39,14 +39,14 @@ class JobManagerFrame: public QWidget, public Counter, public Base::Key
     public:
 
     //* constructor
-    JobManagerFrame( QWidget* = nullptr );
+    explicit JobManagerFrame( QWidget* = nullptr );
 
     //* jobManager
-    JobManager& jobManager( void ) const
+    JobManager& jobManager() const
     { return *jobManager_; }
 
     //* summary frame
-    SummaryFrame& summaryFrame( void ) const
+    SummaryFrame& summaryFrame() const
     { return *summaryFrame_; }
 
     //* set user (convenience function)
