@@ -27,7 +27,7 @@
 #include <QColor>
 
 //* Job model. Stores job information for display in lists
-class JobModel : public TreeModel<Job>, public Counter
+class JobModel : public TreeModel<Job>, private Base::Counter<JobModel>
 {
 
     //* Qt meta object declaration
@@ -36,7 +36,7 @@ class JobModel : public TreeModel<Job>, public Counter
     public:
 
     //* constructor
-    JobModel(QObject *parent = nullptr);
+    explicit JobModel(QObject *parent = nullptr);
 
     //* column type enumeration
     enum ColumnType
@@ -64,13 +64,13 @@ class JobModel : public TreeModel<Job>, public Counter
     //@{
 
     // return job for a given index
-    virtual QVariant data( const QModelIndex&, int ) const;
+    QVariant data( const QModelIndex&, int ) const override;
 
     //* header data
-    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;
+    QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;
 
     //* number of columns for a given index
-    virtual int columnCount(const QModelIndex& = QModelIndex()) const
+    int columnCount(const QModelIndex& = QModelIndex()) const override
     { return nColumns; }
 
     //@}
@@ -82,13 +82,13 @@ class JobModel : public TreeModel<Job>, public Counter
     protected:
 
     //* sorting
-    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
+    void _sort( int column, Qt::SortOrder order ) override
     { _root().sort( SortFTor( column, order ) ); }
 
     private Q_SLOTS:
 
     //* configuration
-    void _updateConfiguration(void);
+    void _updateConfiguration();
 
     private:
 
@@ -100,7 +100,7 @@ class JobModel : public TreeModel<Job>, public Counter
         public:
 
         //* constructor
-        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
+        explicit SortFTor( int type, Qt::SortOrder order ):
             ItemModel::SortFTor( type, order )
         {}
 
