@@ -26,7 +26,7 @@
 #include <QList>
 
 //* keep track of job memory and usage
-class JobRecord: public Counter
+class JobRecord final: private Base::Counter<JobRecord>
 {
 
     public:
@@ -35,7 +35,7 @@ class JobRecord: public Counter
     using List = QList<JobRecord>;
 
     //* constructor
-    JobRecord( void ):
+    explicit JobRecord():
         Counter( "JobRecord" ),
         records_(
         XmlOptions::get().get<int>( "SAMPLES" ),
@@ -43,7 +43,7 @@ class JobRecord: public Counter
     {}
 
     //* constructor
-    JobRecord( const Job& job ):
+    explicit JobRecord( const Job& job ):
         Counter( "JobRecord" ),
         job_( job ),
         records_(
@@ -51,72 +51,56 @@ class JobRecord: public Counter
         XmlOptions::get().get<int>( "RECORD_LENGTH" ) )
     { updateJob( job ); }
 
-    //* lower than operator
-    bool operator < ( const JobRecord& other ) const
-    { return id() < other.id(); }
-
-
-    //* equal to operator
-    bool operator == ( const JobRecord& other ) const
-    { return id() == other.id(); }
-
     //* storage
-    class Record: public Counter
+    class Record final: private Base::Counter<Record>
     {
 
         public:
 
         //* empty constructor
-        Record( void ):
-            Counter( "Record" ),
-            virtualMemory_(0),
-            residentMemory_(0),
-            sharedMemory_(0),
-            cpu_(0),
-            memory_(0)
+        explicit Record():
+            Counter( "Record" )
         {}
 
         //* constructo from job
-        Record( const Job& job );
+        explicit Record( const Job& job );
 
         //* sum operator
-        Record& operator += ( const Record& record )
+        Record& operator += ( const Record& other )
         {
-            virtualMemory_ += record.virtualMemory_;
-            residentMemory_ += record.residentMemory_;
-            sharedMemory_ += record.sharedMemory_;
-            cpu_ += record.cpu_;
-            memory_ += record.memory_;
+            virtualMemory_ += other.virtualMemory_;
+            residentMemory_ += other.residentMemory_;
+            sharedMemory_ += other.sharedMemory_;
+            cpu_ += other.cpu_;
+            memory_ += other.memory_;
             return *this;
         }
 
         //* divide
-        Record divide( const int& value )
+        Record& operator /= ( int value )
         {
-            Q_ASSERT( value > 0 );
-            Record out( *this );
-            out.virtualMemory_ /= value;
-            out.residentMemory_ /= value;
-            out.sharedMemory_ /= value;
-            out.cpu_ /= value;
-            out.memory_ /= value;
-            return out;
+            virtualMemory_ /= value;
+            residentMemory_ /= value;
+            sharedMemory_ /= value;
+            cpu_ /= value;
+            memory_ /= value;
+            return *this;
         }
 
         //* virtual memory
-        int virtualMemory_;
+        int virtualMemory_ = 0;
 
         //* resident memory
-        int residentMemory_;
+        int residentMemory_ = 0;
 
         //* shared memory
-        int sharedMemory_;
+        int sharedMemory_ = 0;
 
         //* cpu (%)
-        double cpu_;
+        double cpu_ = 0;
 
         //* mem (%)
-        double memory_;
+        double memory_ = 0;
 
         //* streamer
         friend QTextStream& operator << ( QTextStream& out, const Record& record )
@@ -131,30 +115,30 @@ class JobRecord: public Counter
     using RecordList = QList<Record>;
 
     //* data samples storage
-    class Samples: public Counter
+    class Samples final: private Base::Counter<Samples>
     {
 
         public:
 
         //* construtor
-        Samples( int sampleSize = 0, int length = 0 ):
+        explicit Samples( int sampleSize = 0, int length = 0 ):
             Counter( "JobRecord::Samples" ),
             sampleSize_( sampleSize ),
             maxLength_( length )
         {}
 
         //* set sample size
-        void setSampleSize( const int& sampleSize );
+        void setSampleSize( int sampleSize );
 
         //* set data point size
         void setMaxLength( const int length );
 
         //* max length
-        int maxLength( void ) const
+        int maxLength() const
         { return maxLength_; }
 
         //* retrieve data
-        const RecordList& records( void ) const
+        const RecordList& records() const
         { return recordList_; }
 
         //* add a data point
@@ -180,19 +164,19 @@ class JobRecord: public Counter
     //@{
 
     //* id
-    int id( void ) const
+    int id() const
     { return job_.id(); }
 
     //* current record
-    const Record& current( void ) const
+    const Record& current() const
     { return current_; }
 
     //* max record
-    const Record& max( void ) const
+    const Record& max() const
     { return max_; }
 
     //* get records
-    const Samples& samples( void ) const
+    const Samples& samples() const
     { return records_; }
 
     //@}
@@ -204,7 +188,7 @@ class JobRecord: public Counter
     bool updateJob( const Job& job );
 
     //* get records
-    Samples& samples( void )
+    Samples& samples()
     { return records_; }
 
     //@}
@@ -215,7 +199,7 @@ class JobRecord: public Counter
         public:
 
         //* constructor
-        SameIdFTor( const int& id ):
+        explicit SameIdFTor( int id ):
             id_( id )
         {}
 
@@ -246,4 +230,13 @@ class JobRecord: public Counter
 
 };
 
+//* lower than operator
+inline bool operator < ( const JobRecord& first, const JobRecord& second)
+{ return first.id() < second.id(); }
+
+//* equal to operator
+inline bool operator == ( const JobRecord& first, const JobRecord& second)
+{ return first.id() == second.id(); }
+
+
 #endif
