@@ -33,7 +33,7 @@ JobThread::JobThread( QObject* parent ):
 { timer_.start(); }
 
 //________________________________________________________________________
-void JobThread::resetUserMap( void )
+void JobThread::resetUserMap()
 {
     QMutexLocker lock( &mutex_ );
     userMapInitialized_ = false;
@@ -41,7 +41,7 @@ void JobThread::resetUserMap( void )
 }
 
 //________________________________________________________________________
-void JobThread::run( void )
+void JobThread::run()
 {
 
     // initialize usermap
@@ -63,7 +63,7 @@ void JobThread::run( void )
 
     // get list of jobs from /proc
     QDir dir( "/proc" );
-    foreach( const QString& file, dir.entryList() )
+    for( const auto& file:dir.entryList() )
     {
 
         bool ok( true );
@@ -97,7 +97,7 @@ void JobThread::run( void )
 }
 
 //________________________________________________________________________
-void JobThread::_readUserMap( void )
+void JobThread::_readUserMap()
 {
     QFile file( "/etc/passwd" );
     if( !file.open(QIODevice::ReadOnly) ) return;
@@ -116,7 +116,7 @@ void JobThread::_readUserMap( void )
 }
 
 //________________________________________________________________________
-void JobThread::_readTotalMemory( void )
+void JobThread::_readTotalMemory()
 {
 
     #ifdef _SC_PHYS_PAGES
