@@ -29,7 +29,7 @@
 #include <QThread>
 
 //* independent thread used to automatically save file
-class JobThread: public QThread, public Counter
+class JobThread: public QThread, private Base::Counter<JobThread>
 {
 
     Q_OBJECT
@@ -37,25 +37,25 @@ class JobThread: public QThread, public Counter
     public:
 
     //* constructor
-    JobThread( QObject* = 0 );
+    explicit JobThread( QObject* = 0 );
 
     //* reset user map
-    void resetUserMap( void );
+    void resetUserMap();
 
     //* return set of jobs
-    const Job::Set& jobs( void ) const
+    const Job::Set& jobs() const
     { return jobs_; }
 
     protected:
 
     //* Check files validity. Post a ValidFileEvent when finished
-    virtual void run( void );
+    void run() override;
 
     //* read total available memory
-    void _readTotalMemory( void );
+    void _readTotalMemory();
 
     //* read user map (might better move to a thread)
-    void _readUserMap( void );
+    void _readUserMap();
 
     private:
 
