@@ -54,7 +54,7 @@ class TabWidget: public QTabWidget
     public:
 
     //* constructor
-    TabWidget( QWidget* parent ):
+    explicit TabWidget( QWidget* parent ):
         QTabWidget( parent )
     {}
 
@@ -91,7 +91,7 @@ MainWindow::MainWindow( QWidget* parent ):
 
     // install actions
     _installActions();
-    Application& application( *static_cast<Application*>(Singleton::get().application()) );
+    Application& application( *static_cast<Application*>(Base::Singleton::get().application()) );
     addAction( &application.closeAction() );
 
     // statusBar
@@ -107,7 +107,7 @@ MainWindow::MainWindow( QWidget* parent ):
     // add default users to user_selection frame
     UserSet users;
     users << UserSet::allUsers() << Util::user();
-    userFrame_->updateUsers( users );
+    userFrame_->updateUsers( users.get() );
 
     toolbar_ =  new CustomToolBar( tr( "Main Toolbar" ), this, "TOOLBAR" );
     toolbar_->addAction( &addFrameAction() );
@@ -124,7 +124,7 @@ MainWindow::MainWindow( QWidget* parent ):
 
     // main widget and layout
     QWidget* main( new QWidget( this ) );
-    main->setLayout( new QVBoxLayout() );
+    main->setLayout( new QVBoxLayout );
     main->layout()->setMargin(0);
     main->layout()->setSpacing(0);
     setCentralWidget( main );
@@ -137,7 +137,7 @@ MainWindow::MainWindow( QWidget* parent ):
     // create removeTab button
     #if QT_VERSION < 0x040500
     {
-        QToolButton* button = new QToolButton();
+        QToolButton* button = new QToolButton;
         button->setDefaultAction( removeFrameAction_ );
         button->setAutoRaise( true );
         tabWidget_->setCornerWidget( button, Qt::TopRightCorner );
@@ -160,7 +160,7 @@ MainWindow::MainWindow( QWidget* parent ):
 }
 
 //_______________________________________
-void MainWindow::updateActions( void )
+void MainWindow::updateActions()
 {
 
     Debug::Throw( "MainWindow::updateActions.\n" );
@@ -178,7 +178,7 @@ void MainWindow::updateUsers( UserSet users )
 {
 
     Debug::Throw( "MainWindow::updateUsers.\n" );
-    userFrame_->updateUsers(users);
+    userFrame_->updateUsers(users.get());
     if( hasActiveFrame() )
     { userFrame_->setUser( activeFrame().jobManager().user() ); }
 
@@ -190,7 +190,7 @@ void MainWindow::addFrame( const QString& user )
     Debug::Throw() << "MainWindow::addFrame - user: " << user << endl;
 
     // check whether it is already displayed or not
-    foreach( JobManagerFrame* frame, Base::KeySet<JobManagerFrame>( this ) )
+    for( const auto& frame:Base::KeySet<JobManagerFrame>( this ) )
     {
         if( user == frame->jobManager().user() )
         {
@@ -211,10 +211,10 @@ void MainWindow::addFrame( const QString& user )
 }
 
 //____________________________________________________________
-void MainWindow::requestJobList( void )
+void MainWindow::requestJobList()
 {
     Debug::Throw( "MainWindow::requestJobList.\n" );
-    emit commandRequested( JobCommand( JobCommand::JobList ) );
+    emit commandRequested( JobCommand( JobCommand::Type::JobList ) );
 }
 
 //____________________________________________________________
@@ -246,12 +246,12 @@ void MainWindow::processJobList( Job::Set jobs )
 }
 
 //____________________________________________________________
-void MainWindow::closeJobInformationDialogs( void )
+void MainWindow::closeJobInformationDialogs()
 {
     Debug::Throw( "MainWindow::closeJobInformationDialog.\n" );
 
     // loop over record dialogs
-    foreach( JobInformationDialog* dialog, Base::KeySet<JobInformationDialog>( this ) )
+    for( const auto& dialog:Base::KeySet<JobInformationDialog>( this ) )
     {
 
         if( !toggleRecordAction_->isChecked() )
@@ -274,17 +274,17 @@ void MainWindow::closeJobInformationDialogs( void )
 }
 
 //_______________________________________
-void MainWindow::installFrames( void )
+void MainWindow::installFrames()
 {
 
     Debug::Throw( "MainWindow::installFrames.\n" );
 
     // get users from options
     Options::List users( XmlOptions::get().specialOptions( "USER_NAME" ) );
-    if( users.empty() ) users << Util::user();
+    if( users.empty() ) users.append( Option( Util::user() ) );
 
     JobManagerFrame* firstFrame(0);
-    foreach( const Option& option, users )
+    for( const auto& option:users )
     {
 
         Debug::Throw() << "MainWindow::installFrames - adding user: " << option.raw() << endl;
@@ -306,7 +306,7 @@ void MainWindow::installFrames( void )
 }
 
 //_______________________________________
-void MainWindow::_updateConfiguration( void )
+void MainWindow::_updateConfiguration()
 {
     Debug::Throw( "MainWindow::_updateConfiguration.\n" );
 
@@ -319,7 +319,7 @@ void MainWindow::_updateConfiguration( void )
 
     // tree view
     treeViewAction_->setChecked( XmlOptions::get().get<bool>("TREE_VIEW") );
-    foreach( JobManagerFrame* frame, Base::KeySet<JobManagerFrame>( this ) )
+    for( const auto& frame:Base::KeySet<JobManagerFrame>( this ) )
     { frame->jobManager().toggleTreeView( treeViewAction_->isChecked() ); }
 
     // refresh rate
@@ -331,7 +331,7 @@ void MainWindow::_updateConfiguration( void )
 }
 
 //________________________________________
-void MainWindow::_saveConfiguration( void )
+void MainWindow::_saveConfiguration()
 {
     Debug::Throw( "MainWindow::_saveConfiguration.\n" );
 
@@ -353,7 +353,7 @@ void MainWindow::_updateUser( QString user )
     if( !hasActiveFrame() ) return;
 
     // check whether it is already displayed or not
-    foreach( JobManagerFrame* frame, Base::KeySet<JobManagerFrame>( this ) )
+    for( const auto& frame:Base::KeySet<JobManagerFrame>( this ) )
     {
         if( user == frame->jobManager().user() )
         {
@@ -368,15 +368,15 @@ void MainWindow::_updateUser( QString user )
 }
 
 //_______________________________________________
-void MainWindow::_resume( void )
+void MainWindow::_resume()
 { _sendSignal( SIGCONT ); }
 
 //_______________________________________________
-void MainWindow::_pause( void )
+void MainWindow::_pause()
 { _sendSignal( SIGSTOP ); }
 
 //_______________________________________________
-void MainWindow::_kill( void )
+void MainWindow::_kill()
 { _sendSignal( SIGKILL ); }
 
 //___________________________________________________________________________________
@@ -386,30 +386,30 @@ void MainWindow::_sendSignal( int signal )
     if( !hasActiveFrame() ) return;
 
     Job::List jobs;
-    foreach( const Job& job, activeFrame().jobManager().selectedJobs() )
+    for( const auto& job:activeFrame().jobManager().selectedJobs() )
     { if( job.id() > 0 ) jobs.append( job ); }
 
     if( jobs.empty() ) return;
     if( !SignalJobsDialog( this, signal, jobs ).exec() ) return;
 
     // create command and append requested signal
-    JobCommand command( JobCommand::Signal );
+    JobCommand command( JobCommand::Type::Signal );
     command << QString::number( signal );
 
     // add arguments to command
-    foreach( const Job& job, jobs )
+    for( const auto& job:jobs )
     {  if( job.id() > 0 ) command << QString::number( job.id() ); }
 
     if( !command.arguments().isEmpty() )
     {
         emit commandRequested( command );
-        emit commandRequested( JobCommand( JobCommand::JobList ) );
+        emit commandRequested( JobCommand( JobCommand::Type::JobList ) );
     }
 
 }
 
 //_______________________________________________
-void MainWindow::_record( void )
+void MainWindow::_record()
 {
     Debug::Throw( "MainWindow::_record.\n" );
     if( !hasActiveFrame() ) return;
@@ -430,12 +430,12 @@ void MainWindow::_record( void )
     Job::Set invalid;
 
     // loop over jobs, find matching record
-    foreach( const Job& job, jobs )
+    for( const auto& job:jobs )
     {
 
         // try find matching job
         bool found( false );
-        foreach( JobInformationDialog* dialog, dialogs )
+        for( const auto& dialog:dialogs )
         {
             if( dialog->record().id() == job.id() )
             {
@@ -449,7 +449,7 @@ void MainWindow::_record( void )
         if( found ) continue;
 
         // get matching job record
-        JobRecord::List::iterator recordIter( std::find_if( records_.begin(), records_.end(), JobRecord::SameIdFTor( job.id() ) ) );
+        auto recordIter( std::find_if( records_.begin(), records_.end(), JobRecord::SameIdFTor( job.id() ) ) );
         if( recordIter == records_.end() )
         {
 
@@ -488,8 +488,8 @@ void MainWindow::_record( void )
         if( invalid.size() == 1 ) buffer = QString( tr( "Process %1 has no record" ) ).arg( invalid.begin()->id() );
         else {
             buffer = QString( tr( "Following processes have no record:\n" ) );
-            unsigned int index(0);
-            foreach( const Job& job, invalid )
+            int index(0);
+            for( const auto& job:invalid )
             {
                 if( index && !(index%10) ) buffer += "\n";
                 buffer += QString( " %1" ).arg( job.id() );
@@ -575,7 +575,7 @@ void MainWindow::_activeFrameChanged( int index )
 }
 
 //_______________________________________
-void MainWindow::_addFrame( void )
+void MainWindow::_addFrame()
 {
     Debug::Throw( "MainWindow::_addFrame.\n" );
 
@@ -585,7 +585,7 @@ void MainWindow::_addFrame( void )
     // update user selection
     UserSet users;
     users << Util::user() << UserSet::allUsers();
-    dialog.userSelectionFrame().updateUsers( users );
+    dialog.userSelectionFrame().updateUsers( users.get() );
     dialog.userSelectionFrame().updateUsers( userFrame_->users() );
     dialog.userSelectionFrame().setUser( userFrame_->user() );
 
@@ -599,7 +599,7 @@ void MainWindow::_addFrame( void )
 }
 
 //_______________________________________
-void MainWindow::_removeFrame( void )
+void MainWindow::_removeFrame()
 { return _removeFrame( tabWidget_->currentIndex() ); }
 
 //_______________________________________
@@ -609,7 +609,7 @@ void MainWindow::_removeFrame( int index )
     Debug::Throw( "MainWindow::_removeFrame.\n" );
 
     // check counts
-    unsigned int counts( Base::KeySet<JobManagerFrame>( this ).size() );
+    int counts( Base::KeySet<JobManagerFrame>( this ).size() );
     Q_ASSERT( counts > 1 && hasActiveFrame() );
 
     // check frame
@@ -663,7 +663,7 @@ void MainWindow::timerEvent( QTimerEvent *event )
     if (event->timerId() == timer_.timerId() )
     {
         timer_.stop();
-        emit commandRequested( JobCommand( JobCommand::JobList ) );
+        emit commandRequested( JobCommand( JobCommand::Type::JobList ) );
     }
 
 }
@@ -690,12 +690,12 @@ void MainWindow::_setActiveFrame( JobManagerFrame& frame )
 }
 
 //________________________________________
-JobManagerFrame& MainWindow::_newFrame( void )
+JobManagerFrame& MainWindow::_newFrame()
 {
 
     Debug::Throw( "MainWindow::_newFrame.\n" );
 
-    JobManagerFrame* frame( new JobManagerFrame() );
+    JobManagerFrame* frame( new JobManagerFrame );
 
     // add actions to list
     QMenu* menu = new ContextMenu( &frame->jobManager().list() );
@@ -733,11 +733,11 @@ void MainWindow::_updateFrames( const Job::Set& jobs )
     // split against users
     using JobSetMap = QMap<QString, Job::Set >;
     JobSetMap jobMap;
-    foreach( const Job& job, jobs )
+    for( const auto& job:jobs )
     { jobMap[job.user()].insert( job ); }
 
     // update all frames
-    foreach( JobManagerFrame* frame, Base::KeySet<JobManagerFrame>( this ) )
+    for( const auto& frame:Base::KeySet<JobManagerFrame>( this ) )
     {
 
         if( frame->jobManager().user().isEmpty() || UserSet::isAllUsers( frame->jobManager().user() ) )
@@ -771,12 +771,12 @@ void MainWindow::_updateRecords( Job::Set jobs )
 
     // adds the jobs which have no existing records
     if( toggleRecordAction_->isChecked() )
-    { foreach( const Job& job, jobs ) records_ << JobRecord( job ); }
+    { for( const auto& job:jobs ) records_ << JobRecord( job ); }
 
 };
 
 //________________________________________
-void MainWindow::_installActions( void )
+void MainWindow::_installActions()
 {
 
     Debug::Throw( "MainWindow::_installActions.\n" );
@@ -846,7 +846,7 @@ void MainWindow::_installActions( void )
 bool MainWindow::NoJobFTor::operator() ( JobRecord& record )
 {
 
-    Job::Set::iterator iter( std::find_if( jobs_.begin(), jobs_.end(), Job::SameIdFTor( record.id() ) ) );
+    auto iter( std::find_if( jobs_.begin(), jobs_.end(), Job::SameIdFTor( record.id() ) ) );
     if( iter == jobs_.end() ) return true;
     else {
         record.updateJob( *iter );
