@@ -48,84 +48,84 @@ class MainWindow: public BaseMainWindow, public Base::Key
     public:
 
     //* constructor
-    MainWindow( QWidget* = nullptr );
+    explicit MainWindow( QWidget* = nullptr );
 
     //* user
-    UserSelectionFrame& userSelectionFrame( void ) const
+    UserSelectionFrame& userSelectionFrame() const
     { return *userFrame_; }
 
     //* toolbar
-    CustomToolBar& userToolBar( void )
+    CustomToolBar& userToolBar()
     { return *userToolBar_; }
 
     //* toolbar
-    CustomToolBar& toolBar( void )
+    CustomToolBar& toolBar()
     { return *toolbar_; }
 
     //* active frame
-    bool hasActiveFrame( void ) const
+    bool hasActiveFrame() const
     { return (bool) activeFrame_; }
 
     //* active frame
-    JobManagerFrame& activeFrame( void ) const
+    JobManagerFrame& activeFrame() const
     { return *activeFrame_; }
 
     //* status bar
-    BaseStatusBar& statusBar( void ) const
+    BaseStatusBar& statusBar() const
     { return *statusBar_; }
 
     //* pause state
-    bool isPaused( void ) const
+    bool isPaused() const
     { return isPaused_; }
 
     //* install frames
-    void installFrames( void );
+    void installFrames();
 
     //*@name actions
     //@{
 
     //* toggle summary
-    QAction& toggleSummaryAction( void ) const
+    QAction& toggleSummaryAction() const
     { return *toggleSummaryAction_; }
 
     //* resume paused job
-    QAction& resumeAction( void ) const
+    QAction& resumeAction() const
     { return *resumeAction_; }
 
     //* pause job
-    QAction& pauseAction( void ) const
+    QAction& pauseAction() const
     { return *pauseAction_; }
 
     //* kill job
-    QAction& killAction( void ) const
+    QAction& killAction() const
     { return *killAction_; }
 
     //* update
-    QAction& updateAction( void ) const
+    QAction& updateAction() const
     { return *updateAction_; }
 
     //* tree view action
-    QAction& treeViewAction( void ) const
+    QAction& treeViewAction() const
     { return *treeViewAction_; }
 
     //* lock
-    QAction& lockAction( void ) const
+    QAction& lockAction() const
     { return *lockAction_; }
 
     //* add frame
-    QAction& addFrameAction( void ) const
+    QAction& addFrameAction() const
     { return *addFrameAction_; }
 
     //* remove current frame
-    QAction& removeFrameAction( void ) const
+    QAction& removeFrameAction() const
     { return *removeFrameAction_; }
 
     //* record
-    QAction& recordAction( void ) const
+    QAction& recordAction() const
     { return *recordAction_; }
 
     //* record
-    QAction& toggleRecordAction( void ) const
+    QAction& toggleRecordAction() const
     { return *toggleRecordAction_; }
 
     //@}
@@ -141,7 +141,7 @@ class MainWindow: public BaseMainWindow, public Base::Key
     public Q_SLOTS:
 
     //* update actions visibility
-    void updateActions( void );
+    void updateActions();
 
     //* update users
     void updateUsers(UserSet);
@@ -150,21 +150,21 @@ class MainWindow: public BaseMainWindow, public Base::Key
     void addFrame( const QString& );
 
     //* run top to look for job updates
-    void requestJobList( void );
+    void requestJobList();
 
     //* process job list
     void processJobList( Job::Set );
 
     //* close record dialogs
-    void closeJobInformationDialogs( void );
+    void closeJobInformationDialogs();
 
     protected Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     //* save configuration
-    void _saveConfiguration( void );
+    void _saveConfiguration();
 
     //* update uesr
     void _updateUser( QString );
@@ -176,19 +176,19 @@ class MainWindow: public BaseMainWindow, public Base::Key
     void _toggleSummary( bool );
 
     //* resume selected jobs
-    void _resume( void );
+    void _resume();
 
     //* pause selected jobs
-    void _pause( void );
+    void _pause();
 
     //* kill selected jobs
-    void _kill( void );
+    void _kill();
 
     //* send signal to selected jobs
     void _sendSignal( int );
 
     //* opens recorder for selected jobs
-    void _record( void );
+    void _record();
 
     //* toggle record all jobs
     void _toggleRecordAllJobs( bool );
@@ -200,10 +200,10 @@ class MainWindow: public BaseMainWindow, public Base::Key
     void _toggleUpdate( bool );
 
     //* add frame
-    void _addFrame( void );
+    void _addFrame();
 
     //* remove frame
-    void _removeFrame( void );
+    void _removeFrame();
 
     //* remove frame at index
     void _removeFrame( int );
@@ -223,7 +223,7 @@ class MainWindow: public BaseMainWindow, public Base::Key
     void _setActiveFrame( JobManagerFrame& frame );
 
     //* create a new frame
-    JobManagerFrame& _newFrame( void );
+    JobManagerFrame& _newFrame();
 
     //* update frames
     void _updateFrames( const Job::Set& );
@@ -234,7 +234,7 @@ class MainWindow: public BaseMainWindow, public Base::Key
     private:
 
     //* summary
-    void _installActions( void );
+    void _installActions();
 
     //* used to find records which have no matching job
     /**
@@ -250,7 +250,7 @@ class MainWindow: public BaseMainWindow, public Base::Key
         public:
 
         //* constructor
-        NoJobFTor( Job::Set& jobs ):
+        explicit NoJobFTor( Job::Set& jobs ):
             jobs_( jobs )
         {}
 
