@@ -25,7 +25,7 @@
 #include <QMenuBar>
 
 //! main menu
-class Menu:public QMenuBar, public Counter
+class Menu:public QMenuBar, private Base::Counter<Menu>
 {
 
     Q_OBJECT
@@ -33,12 +33,12 @@ class Menu:public QMenuBar, public Counter
     public:
 
     //! creator
-    Menu( QWidget* parent );
+    explicit Menu( QWidget* parent );
 
     private Q_SLOTS:
 
     //! get list of editor windows into menu
-    void _updateWindowsMenu( void );
+    void _updateWindowsMenu();
 
     private:
 
