@@ -33,10 +33,10 @@ class NewFrameDialog: public CustomDialog
     public:
 
     //! constructor
-    NewFrameDialog( QWidget* parent );
+    explicit NewFrameDialog( QWidget* parent );
 
     //! user selection frame
-    UserSelectionFrame& userSelectionFrame( void ) const
+    UserSelectionFrame& userSelectionFrame() const
     { return *userSelectionFrame_; }
 
     private:
