@@ -34,7 +34,7 @@ class SignalJobsDialog: public QuestionDialog
     public:
 
     //* constructor
-    SignalJobsDialog( QWidget*, int, Job::List );
+    explicit SignalJobsDialog( QWidget*, int, Job::List );
 
     private:
 
