@@ -26,7 +26,7 @@
 #include <QMenu>
 #include <QHash>
 
-class SignalMenu: public QMenu, public Counter
+class SignalMenu: public QMenu, private Base::Counter<SignalMenu>
 {
 
     Q_OBJECT
@@ -34,7 +34,7 @@ class SignalMenu: public QMenu, public Counter
     public:
 
     //* constructor
-    SignalMenu( QWidget* = nullptr );
+    explicit SignalMenu( QWidget* = nullptr );
 
     //* signal name matching given id
     QString signalName( int ) const;
