@@ -36,7 +36,7 @@ ToolTipWidget::ToolTipWidget( QWidget* parent ):
     Debug::Throw( "ToolTipWidget::ToolTipWidget.\n" );
 
     // layout
-    QHBoxLayout* hLayout = new QHBoxLayout();
+    QHBoxLayout* hLayout = new QHBoxLayout;
     hLayout->setMargin( 10 );
     hLayout->setSpacing( 10 );
     setLayout( hLayout );
@@ -44,7 +44,7 @@ ToolTipWidget::ToolTipWidget( QWidget* parent ):
     hLayout->addWidget( iconLabel_ = new QLabel( this ) );
     iconLabel_->setAlignment( Qt::AlignHCenter|Qt::AlignTop );
 
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    QVBoxLayout* vLayout = new QVBoxLayout;
     vLayout->setMargin( 0 );
     vLayout->setSpacing( 5 );
     hLayout->addLayout( vLayout );
@@ -59,7 +59,7 @@ ToolTipWidget::ToolTipWidget( QWidget* parent ):
     separator_->setFrameStyle( QFrame::HLine );
 
     // grid layout
-    GridLayout* gridLayout = new GridLayout();
+    GridLayout* gridLayout = new GridLayout;
     gridLayout->setMaxCount( 2 );
     gridLayout->setColumnAlignment( 0, Qt::AlignVCenter|Qt::AlignRight );
     gridLayout->setColumnAlignment( 1, Qt::AlignVCenter|Qt::AlignLeft );
@@ -77,7 +77,7 @@ ToolTipWidget::ToolTipWidget( QWidget* parent ):
     vLayout->addStretch( 1 );
 
     // configuration
-    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
+    connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
     _updateConfiguration();
 
 }
@@ -153,7 +153,7 @@ void ToolTipWidget::setJob( const Job& job, const QIcon& icon )
 }
 
 //_____________________________________________
-void ToolTipWidget::_updateConfiguration( void )
+void ToolTipWidget::_updateConfiguration()
 {
     Debug::Throw( "ToolTipWidget::_updateConfiguration.\n" );
     if( XmlOptions::get().contains( "TOOLTIPS_PIXMAP_SIZE" ) ) setPixmapSize( XmlOptions::get().get<int>( "TOOLTIPS_PIXMAP_SIZE" ) );
