@@ -37,7 +37,7 @@ class ToolTipWidget: public BaseToolTipWidget
     public:
 
     //* constructor
-    ToolTipWidget( QWidget* );
+    explicit ToolTipWidget( QWidget* );
 
     //* set data
     void setJob( const Job&, const QIcon& = QIcon() );
@@ -51,13 +51,13 @@ class ToolTipWidget: public BaseToolTipWidget
     }
 
     //* reload
-    virtual void reload( void )
+    void reload()
     { setJob( job_, icon_ ); }
 
     private Q_SLOTS:
 
     //* update configuration
-    void _updateConfiguration( void );
+    void _updateConfiguration();
 
     private:
 
