@@ -25,28 +25,58 @@
 #include <QString>
 #include <QStringList>
 
-//! user priority class
-class UserSet: public QStringList, public Counter
+// user priority class
+class UserSet final: private Base::Counter<UserSet>
 {
     public:
 
-    //! constructor
-    UserSet( QStringList users = QStringList() ):
-        QStringList( users ),
-        Counter( "UserSet" )
+    //* universal constructor
+    template<typename... Args>
+    explicit UserSet(Args&&... args):
+        Counter( "UserSet" ),
+        users_( std::forward<Args>(args)... )
     {}
 
-    //! true if given user is all
+    //*@name accessors
+    //@{
+
+    //* convert
+    const QStringList& get() const
+    { return users_; }
+
+    //* contains
+    bool contains( const QString& value ) const
+    { return users_.contains( value ); }
+
+    //* true if given user is all
     static bool isAllUsers( const QString& value )
     { return value == AllUsers; }
 
-    //! all users string
-    static const QString& allUsers( void )
+    //* all users string
+    static const QString& allUsers()
     { return AllUsers; }
 
+    //@}
+
+    //*@name modifiers
+    //@{
+
+    //* streamer
+    template<class T>
+    UserSet& operator<< ( const T& t )
+    {
+        users_ << t;
+        return *this;
+    }
+
+    //@}
+
     private:
 
-    //! all users
+    //* users
+    QStringList users_;
+
+    //* all users
     static const QString AllUsers;
 
 };
