@@ -25,13 +25,13 @@
 
 #include <QIcon>
 
-class XcbInterface: public Counter
+class XcbInterface final: private Base::Counter<XcbInterface>
 {
 
     public:
 
     //* constructor
-    XcbInterface( void ):
+    explicit XcbInterface():
         Counter( "XcbInterface" )
     {}
 
@@ -43,9 +43,6 @@ class XcbInterface: public Counter
     //* find pixmaps, starting from window [recursive]
     void _findIcons( WId, Job::List& ) const;
 
-    //* find icon for a given window
-    QIcon _icon( WId ) const;
-
 };
 
 #endif
